return {
  auth = {
    oauth2 = {
      scopes = {
        ["https://www.googleapis.com/auth/display-video"] = {
          description = "Create, see, edit, and permanently delete your Display & Video 360 entities and reports",
        },
        ["https://www.googleapis.com/auth/display-video-mediaplanning"] = {
          description = "Create, see, and edit Display & Video 360 Campaign entities and see billing invoices",
        },
        ["https://www.googleapis.com/auth/display-video-user-management"] = {
          description = "Private Service: https://www.googleapis.com/auth/display-video-user-management",
        },
        ["https://www.googleapis.com/auth/doubleclickbidmanager"] = {
          description = "View and manage your reports in DoubleClick Bid Manager",
        },
      },
    },
  },
  basePath = "",
  baseUrl = "https://displayvideo.googleapis.com/",
  batchPath = "batch",
  canonicalName = "Display Video",
  description = "Display & Video 360 API allows users to automate complex Display & Video 360 workflows, such as creating insertion orders and setting targeting options for individual line items.",
  discoveryVersion = "v1",
  documentationLink = "https://developers.google.com/display-video/",
  fullyEncodeReservedExpansion = true,
  icons = {
    x16 = "http://www.google.com/images/icons/product/search-16.gif",
    x32 = "http://www.google.com/images/icons/product/search-32.gif",
  },
  id = "displayvideo:v1",
  kind = "discovery#restDescription",
  mtlsRootUrl = "https://displayvideo.mtls.googleapis.com/",
  name = "displayvideo",
  ownerDomain = "google.com",
  ownerName = "Google",
  parameters = {
    ["$.xgafv"] = {
      description = "V1 error format.",
      enum = {
        "1",
        "2",
      },
      enumDescriptions = {
        "v1 error format",
        "v2 error format",
      },
      location = "query",
      type = "string",
    },
    access_token = {
      description = "OAuth access token.",
      location = "query",
      type = "string",
    },
    alt = {
      default = "json",
      description = "Data format for response.",
      enum = {
        "json",
        "media",
        "proto",
      },
      enumDescriptions = {
        "Responses with Content-Type of application/json",
        "Media download with context-dependent Content-Type",
        "Responses with Content-Type of application/x-protobuf",
      },
      location = "query",
      type = "string",
    },
    callback = {
      description = "JSONP",
      location = "query",
      type = "string",
    },
    fields = {
      description = "Selector specifying which fields to include in a partial response.",
      location = "query",
      type = "string",
    },
    key = {
      description = "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.",
      location = "query",
      type = "string",
    },
    oauth_token = {
      description = "OAuth 2.0 token for the current user.",
      location = "query",
      type = "string",
    },
    prettyPrint = {
      default = "true",
      description = "Returns response with indentations and line breaks.",
      location = "query",
      type = "boolean",
    },
    quotaUser = {
      description = "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.",
      location = "query",
      type = "string",
    },
    uploadType = {
      description = "Legacy upload protocol for media (e.g. \"media\", \"multipart\").",
      location = "query",
      type = "string",
    },
    upload_protocol = {
      description = "Upload protocol for media (e.g. \"raw\", \"multipart\").",
      location = "query",
      type = "string",
    },
  },
  protocol = "rest",
  resources = {
    advertisers = {
      methods = {
        audit = {
          description = "Audits an advertiser. Returns the counts of used entities per resource type under the advertiser provided. Used entities count towards their respective resource limit. See https://support.google.com/displayvideo/answer/6071450.",
          flatPath = "v1/advertisers/{advertisersId}:audit",
          httpMethod = "GET",
          id = "displayvideo.advertisers.audit",
          parameterOrder = {
            "advertiserId",
          },
          parameters = {
            advertiserId = {
              description = "Required. The ID of the advertiser to audit.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            readMask = {
              description = "Optional. The specific fields to return. If no mask is specified, all fields in the response proto will be filled. Valid values are: * usedLineItemsCount * usedInsertionOrdersCount * usedCampaignsCount * channelsCount * negativelyTargetedChannelsCount * negativeKeywordListsCount * adGroupCriteriaCount * campaignCriteriaCount",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/advertisers/{+advertiserId}:audit",
          response = {
            ["$ref"] = "AuditAdvertiserResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        bulkEditAdvertiserAssignedTargetingOptions = {
          description = "Bulk edits targeting options under a single advertiser. The operation will delete the assigned targeting options provided in BulkEditAdvertiserAssignedTargetingOptionsRequest.delete_requests and then create the assigned targeting options provided in BulkEditAdvertiserAssignedTargetingOptionsRequest.create_requests .",
          flatPath = "v1/advertisers/{advertisersId}:bulkEditAdvertiserAssignedTargetingOptions",
          httpMethod = "POST",
          id = "displayvideo.advertisers.bulkEditAdvertiserAssignedTargetingOptions",
          parameterOrder = {
            "advertiserId",
          },
          parameters = {
            advertiserId = {
              description = "Required. The ID of the advertiser.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/advertisers/{+advertiserId}:bulkEditAdvertiserAssignedTargetingOptions",
          request = {
            ["$ref"] = "BulkEditAdvertiserAssignedTargetingOptionsRequest",
          },
          response = {
            ["$ref"] = "BulkEditAdvertiserAssignedTargetingOptionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        bulkListAdvertiserAssignedTargetingOptions = {
          description = "Lists assigned targeting options of an advertiser across targeting types.",
          flatPath = "v1/advertisers/{advertisersId}:bulkListAdvertiserAssignedTargetingOptions",
          httpMethod = "GET",
          id = "displayvideo.advertisers.bulkListAdvertiserAssignedTargetingOptions",
          parameterOrder = {
            "advertiserId",
          },
          parameters = {
            advertiserId = {
              description = "Required. The ID of the advertiser the line item belongs to.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            filter = {
              description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`.. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `targetingType` Examples: * targetingType with value TARGETING_TYPE_CHANNEL `targetingType=\"TARGETING_TYPE_CHANNEL\"` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `targetingType` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `targetingType desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. The size must be an integer between `1` and `5000`. If unspecified, the default is '5000'. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token that lets the client fetch the next page of results. Typically, this is the value of next_page_token returned from the previous call to `BulkListAdvertiserAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
          },
          path = "v1/advertisers/{+advertiserId}:bulkListAdvertiserAssignedTargetingOptions",
          response = {
            ["$ref"] = "BulkListAdvertiserAssignedTargetingOptionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        create = {
          description = "Creates a new advertiser. Returns the newly created advertiser if successful. This method can take up to 180 seconds to complete.",
          flatPath = "v1/advertisers",
          httpMethod = "POST",
          id = "displayvideo.advertisers.create",
          parameterOrder = {},
          parameters = {},
          path = "v1/advertisers",
          request = {
            ["$ref"] = "Advertiser",
          },
          response = {
            ["$ref"] = "Advertiser",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        delete = {
          description = "Deletes an advertiser. Deleting an advertiser will delete all of its child resources, for example, campaigns, insertion orders and line items. A deleted advertiser cannot be recovered.",
          flatPath = "v1/advertisers/{advertisersId}",
          httpMethod = "DELETE",
          id = "displayvideo.advertisers.delete",
          parameterOrder = {
            "advertiserId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser we need to delete.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/advertisers/{+advertiserId}",
          response = {
            ["$ref"] = "Empty",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets an advertiser.",
          flatPath = "v1/advertisers/{advertisersId}",
          httpMethod = "GET",
          id = "displayvideo.advertisers.get",
          parameterOrder = {
            "advertiserId",
          },
          parameters = {
            advertiserId = {
              description = "Required. The ID of the advertiser to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/advertisers/{+advertiserId}",
          response = {
            ["$ref"] = "Advertiser",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists advertisers that are accessible to the current user. The order is defined by the order_by parameter. A single partner_id is required. Cross-partner listing is not supported.",
          flatPath = "v1/advertisers",
          httpMethod = "GET",
          id = "displayvideo.advertisers.list",
          parameterOrder = {},
          parameters = {
            filter = {
              description = "Allows filtering by advertiser properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator used on `updateTime` must be `GREATER THAN OR EQUAL TO (>=)` or `LESS THAN OR EQUAL TO (<=)`. * The operator must be `EQUALS (=)`. * Supported fields: - `advertiserId` - `displayName` - `entityStatus` - `updateTime` (input in ISO 8601 format, or YYYY-MM-DDTHH:MM:SSZ) Examples: * All active advertisers under a partner: `entityStatus=\"ENTITY_STATUS_ACTIVE\"` * All advertisers with an update time less than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime<=\"2020-11-04T18:54:47Z\"` * All advertisers with an update time greater than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime>=\"2020-11-04T18:54:47Z\"` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `entityStatus` * `updateTime` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListAdvertisers` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "Required. The ID of the partner that the fetched advertisers should all belong to. The system only supports listing advertisers for one partner at a time.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/advertisers",
          response = {
            ["$ref"] = "ListAdvertisersResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an existing advertiser. Returns the updated advertiser if successful.",
          flatPath = "v1/advertisers/{advertisersId}",
          httpMethod = "PATCH",
          id = "displayvideo.advertisers.patch",
          parameterOrder = {
            "advertiserId",
          },
          parameters = {
            advertiserId = {
              description = "Output only. The unique ID of the advertiser. Assigned by the system.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/advertisers/{+advertiserId}",
          request = {
            ["$ref"] = "Advertiser",
          },
          response = {
            ["$ref"] = "Advertiser",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
      resources = {
        assets = {
          methods = {
            upload = {
              description = "Uploads an asset. Returns the ID of the newly uploaded asset if successful. The asset file size should be no more than 10 MB for images, 200 MB for ZIP files, and 1 GB for videos. Must be used within the [multipart media upload process](/display-video/api/guides/how-tos/upload#multipart). Examples using provided client libraries can be found in our [Creating Creatives guide](/display-video/api/guides/creating-creatives/overview#upload_an_asset).",
              flatPath = "v1/advertisers/{advertisersId}/assets",
              httpMethod = "POST",
              id = "displayvideo.advertisers.assets.upload",
              mediaUpload = {
                accept = {
                  "*/*",
                },
                protocols = {
                  simple = {
                    multipart = true,
                    path = "/upload/v1/advertisers/{+advertiserId}/assets",
                  },
                },
              },
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this asset belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/assets",
              request = {
                ["$ref"] = "CreateAssetRequest",
              },
              response = {
                ["$ref"] = "CreateAssetResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
              supportsMediaUpload = true,
            },
          },
        },
        campaigns = {
          methods = {
            bulkListCampaignAssignedTargetingOptions = {
              description = "Lists assigned targeting options of a campaign across targeting types.",
              flatPath = "v1/advertisers/{advertisersId}/campaigns/{campaignsId}:bulkListCampaignAssignedTargetingOptions",
              httpMethod = "GET",
              id = "displayvideo.advertisers.campaigns.bulkListCampaignAssignedTargetingOptions",
              parameterOrder = {
                "advertiserId",
                "campaignId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser the campaign belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                campaignId = {
                  description = "Required. The ID of the campaign to list assigned targeting options for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR` on the same field. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `targetingType` - `inheritance` Examples: * AssignedTargetingOptions of targeting type TARGETING_TYPE_LANGUAGE or TARGETING_TYPE_GENDER `targetingType=\"TARGETING_TYPE_LANGUAGE\" OR targetingType=\"TARGETING_TYPE_GENDER\"` * AssignedTargetingOptions with inheritance status of NOT_INHERITED or INHERITED_FROM_PARTNER `inheritance=\"NOT_INHERITED\" OR inheritance=\"INHERITED_FROM_PARTNER\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `targetingType` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `targetingType desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. The size must be an integer between `1` and `5000`. If unspecified, the default is `5000`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token that lets the client fetch the next page of results. Typically, this is the value of next_page_token returned from the previous call to `BulkListCampaignAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/campaigns/{+campaignId}:bulkListCampaignAssignedTargetingOptions",
              response = {
                ["$ref"] = "BulkListCampaignAssignedTargetingOptionsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            create = {
              description = "Creates a new campaign. Returns the newly created campaign if successful.",
              flatPath = "v1/advertisers/{advertisersId}/campaigns",
              httpMethod = "POST",
              id = "displayvideo.advertisers.campaigns.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the campaign belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/campaigns",
              request = {
                ["$ref"] = "Campaign",
              },
              response = {
                ["$ref"] = "Campaign",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
            delete = {
              description = "Permanently deletes a campaign. A deleted campaign cannot be recovered. The campaign should be archived first, i.e. set entity_status to `ENTITY_STATUS_ARCHIVED`, to be able to delete it.",
              flatPath = "v1/advertisers/{advertisersId}/campaigns/{campaignsId}",
              httpMethod = "DELETE",
              id = "displayvideo.advertisers.campaigns.delete",
              parameterOrder = {
                "advertiserId",
                "campaignId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser this campaign belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                campaignId = {
                  description = "The ID of the campaign we need to delete.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/campaigns/{+campaignId}",
              response = {
                ["$ref"] = "Empty",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
            get = {
              description = "Gets a campaign.",
              flatPath = "v1/advertisers/{advertisersId}/campaigns/{campaignsId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.campaigns.get",
              parameterOrder = {
                "advertiserId",
                "campaignId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this campaign belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                campaignId = {
                  description = "Required. The ID of the campaign to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/campaigns/{+campaignId}",
              response = {
                ["$ref"] = "Campaign",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
            list = {
              description = "Lists campaigns in an advertiser. The order is defined by the order_by parameter. If a filter by entity_status is not specified, campaigns with `ENTITY_STATUS_ARCHIVED` will not be included in the results.",
              flatPath = "v1/advertisers/{advertisersId}/campaigns",
              httpMethod = "GET",
              id = "displayvideo.advertisers.campaigns.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser to list campaigns for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by campaign properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator used on `updateTime` must be `GREATER THAN OR EQUAL TO (>=)` or `LESS THAN OR EQUAL TO (<=)`. * The operator must be `EQUALS (=)`. * Supported fields: - `campaignId` - `displayName` - `entityStatus` - `updateTime` (input in ISO 8601 format, or YYYY-MM-DDTHH:MM:SSZ) Examples: * All `ENTITY_STATUS_ACTIVE` or `ENTITY_STATUS_PAUSED` campaigns under an advertiser: `(entityStatus=\"ENTITY_STATUS_ACTIVE\" OR entityStatus=\"ENTITY_STATUS_PAUSED\")` * All campaigns with an update time less than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime<=\"2020-11-04T18:54:47Z\"` * All campaigns with an update time greater than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime>=\"2020-11-04T18:54:47Z\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `entityStatus` * `updateTime` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCampaigns` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/campaigns",
              response = {
                ["$ref"] = "ListCampaignsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
            patch = {
              description = "Updates an existing campaign. Returns the updated campaign if successful.",
              flatPath = "v1/advertisers/{advertisersId}/campaigns/{campaignsId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.campaigns.patch",
              parameterOrder = {
                "advertiserId",
                "campaignId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the campaign belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                campaignId = {
                  description = "Output only. The unique ID of the campaign. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/campaigns/{+campaignId}",
              request = {
                ["$ref"] = "Campaign",
              },
              response = {
                ["$ref"] = "Campaign",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
          },
          resources = {
            targetingTypes = {
              resources = {
                assignedTargetingOptions = {
                  methods = {
                    get = {
                      description = "Gets a single targeting option assigned to a campaign.",
                      flatPath = "v1/advertisers/{advertisersId}/campaigns/{campaignsId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                      httpMethod = "GET",
                      id = "displayvideo.advertisers.campaigns.targetingTypes.assignedTargetingOptions.get",
                      parameterOrder = {
                        "advertiserId",
                        "campaignId",
                        "targetingType",
                        "assignedTargetingOptionId",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the campaign belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        assignedTargetingOptionId = {
                          description = "Required. An identifier unique to the targeting type in this campaign that identifies the assigned targeting option being requested.",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        campaignId = {
                          description = "Required. The ID of the campaign the assigned targeting option belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_AGE_RANGE` * `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS` * `TARGETING_TYPE_CONTENT_INSTREAM_POSITION` * `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_ENVIRONMENT` * `TARGETING_TYPE_EXCHANGE` * `TARGETING_TYPE_GENDER` * `TARGETING_TYPE_GEO_REGION` * `TARGETING_TYPE_HOUSEHOLD_INCOME` * `TARGETING_TYPE_INVENTORY_SOURCE` * `TARGETING_TYPE_INVENTORY_SOURCE_GROUP` * `TARGETING_TYPE_LANGUAGE` * `TARGETING_TYPE_ON_SCREEN_POSITION` * `TARGETING_TYPE_PARENTAL_STATUS` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION` * `TARGETING_TYPE_SUB_EXCHANGE` * `TARGETING_TYPE_THIRD_PARTY_VERIFIER` * `TARGETING_TYPE_VIEWABILITY`",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/campaigns/{+campaignId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                      response = {
                        ["$ref"] = "AssignedTargetingOption",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                    list = {
                      description = "Lists the targeting options assigned to a campaign for a specified targeting type.",
                      flatPath = "v1/advertisers/{advertisersId}/campaigns/{campaignsId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                      httpMethod = "GET",
                      id = "displayvideo.advertisers.campaigns.targetingTypes.assignedTargetingOptions.list",
                      parameterOrder = {
                        "advertiserId",
                        "campaignId",
                        "targetingType",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the campaign belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        campaignId = {
                          description = "Required. The ID of the campaign to list assigned targeting options for.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        filter = {
                          description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedTargetingOptionId` - `inheritance` Examples: * AssignedTargetingOptions with ID 1 or 2 `assignedTargetingOptionId=\"1\" OR assignedTargetingOptionId=\"2\"` * AssignedTargetingOptions with inheritance status of NOT_INHERITED or INHERITED_FROM_PARTNER `inheritance=\"NOT_INHERITED\" OR inheritance=\"INHERITED_FROM_PARTNER\"` The length of this field should be no more than 500 characters.",
                          location = "query",
                          type = "string",
                        },
                        orderBy = {
                          description = "Field by which to sort the list. Acceptable values are: * `assignedTargetingOptionId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `assignedTargetingOptionId desc`.",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Requested page size. Must be between `1` and `5000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCampaignAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                          location = "query",
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of assigned targeting options to list. Supported targeting types: * `TARGETING_TYPE_AGE_RANGE` * `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS` * `TARGETING_TYPE_CONTENT_INSTREAM_POSITION` * `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_ENVIRONMENT` * `TARGETING_TYPE_EXCHANGE` * `TARGETING_TYPE_GENDER` * `TARGETING_TYPE_GEO_REGION` * `TARGETING_TYPE_HOUSEHOLD_INCOME` * `TARGETING_TYPE_INVENTORY_SOURCE` * `TARGETING_TYPE_INVENTORY_SOURCE_GROUP` * `TARGETING_TYPE_LANGUAGE` * `TARGETING_TYPE_ON_SCREEN_POSITION` * `TARGETING_TYPE_PARENTAL_STATUS` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION` * `TARGETING_TYPE_SUB_EXCHANGE` * `TARGETING_TYPE_THIRD_PARTY_VERIFIER` * `TARGETING_TYPE_VIEWABILITY`",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/campaigns/{+campaignId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                      response = {
                        ["$ref"] = "ListCampaignAssignedTargetingOptionsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                  },
                },
              },
            },
          },
        },
        channels = {
          methods = {
            create = {
              description = "Creates a new channel. Returns the newly created channel if successful.",
              flatPath = "v1/advertisers/{advertisersId}/channels",
              httpMethod = "POST",
              id = "displayvideo.advertisers.channels.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the created channel.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the created channel.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/channels",
              request = {
                ["$ref"] = "Channel",
              },
              response = {
                ["$ref"] = "Channel",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a channel for a partner or advertiser.",
              flatPath = "v1/advertisers/{advertisersId}/channels/{channelsId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.channels.get",
              parameterOrder = {
                "advertiserId",
                "channelId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the fetched channel.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                channelId = {
                  description = "Required. The ID of the channel to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the fetched channel.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/channels/{+channelId}",
              response = {
                ["$ref"] = "Channel",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists channels for a partner or advertiser.",
              flatPath = "v1/advertisers/{advertisersId}/channels",
              httpMethod = "GET",
              id = "displayvideo.advertisers.channels.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the channels.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by channel fields. Supported syntax: * Filter expressions for channel currently can only contain at most one * restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `displayName` Examples: * All channels for which the display name contains \"google\": `displayName : \"google\"`. The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `channelId` The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListChannels` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the channels.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/channels",
              response = {
                ["$ref"] = "ListChannelsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates a channel. Returns the updated channel if successful.",
              flatPath = "v1/advertisers/{advertisersId}/channels/{channelId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.channels.patch",
              parameterOrder = {
                "advertiserId",
                "channelId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the created channel.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                channelId = {
                  description = "Output only. The unique ID of the channel. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the created channel.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/channels/{channelId}",
              request = {
                ["$ref"] = "Channel",
              },
              response = {
                ["$ref"] = "Channel",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
          resources = {
            sites = {
              methods = {
                bulkEdit = {
                  description = "Bulk edits sites under a single channel. The operation will delete the sites provided in BulkEditSitesRequest.deleted_sites and then create the sites provided in BulkEditSitesRequest.created_sites.",
                  flatPath = "v1/advertisers/{advertiserId}/channels/{channelsId}/sites:bulkEdit",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.channels.sites.bulkEdit",
                  parameterOrder = {
                    "advertiserId",
                    "channelId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel to which the sites belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/channels/{+channelId}/sites:bulkEdit",
                  request = {
                    ["$ref"] = "BulkEditSitesRequest",
                  },
                  response = {
                    ["$ref"] = "BulkEditSitesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                create = {
                  description = "Creates a site in a channel.",
                  flatPath = "v1/advertisers/{advertiserId}/channels/{channelsId}/sites",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.channels.sites.create",
                  parameterOrder = {
                    "advertiserId",
                    "channelId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel in which the site will be created.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/channels/{+channelId}/sites",
                  request = {
                    ["$ref"] = "Site",
                  },
                  response = {
                    ["$ref"] = "Site",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                delete = {
                  description = "Deletes a site from a channel.",
                  flatPath = "v1/advertisers/{advertiserId}/channels/{channelsId}/sites/{sitesId}",
                  httpMethod = "DELETE",
                  id = "displayvideo.advertisers.channels.sites.delete",
                  parameterOrder = {
                    "advertiserId",
                    "channelId",
                    "urlOrAppId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel to which the site belongs.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "query",
                      type = "string",
                    },
                    urlOrAppId = {
                      description = "Required. The URL or app ID of the site to delete.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/channels/{+channelId}/sites/{+urlOrAppId}",
                  response = {
                    ["$ref"] = "Empty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                list = {
                  description = "Lists sites in a channel.",
                  flatPath = "v1/advertisers/{advertisersId}/channels/{channelsId}/sites",
                  httpMethod = "GET",
                  id = "displayvideo.advertisers.channels.sites.list",
                  parameterOrder = {
                    "advertiserId",
                    "channelId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel to which the requested sites belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    filter = {
                      description = "Allows filtering by site fields. Supported syntax: * Filter expressions for site currently can only contain at most one * restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `urlOrAppId` Examples: * All sites for which the URL or app ID contains \"google\": `urlOrAppId : \"google\"`",
                      location = "query",
                      type = "string",
                    },
                    orderBy = {
                      description = "Field by which to sort the list. Acceptable values are: * `urlOrAppId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `urlOrAppId desc`.",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Requested page size. Must be between `1` and `10000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListSites` method. If not specified, the first page of results will be returned.",
                      location = "query",
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{+advertiserId}/channels/{+channelId}/sites",
                  response = {
                    ["$ref"] = "ListSitesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                replace = {
                  description = "Replaces all of the sites under a single channel. The operation will replace the sites under a channel with the sites provided in ReplaceSitesRequest.new_sites.",
                  flatPath = "v1/advertisers/{advertiserId}/channels/{channelsId}/sites:replace",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.channels.sites.replace",
                  parameterOrder = {
                    "advertiserId",
                    "channelId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel whose sites will be replaced.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/channels/{+channelId}/sites:replace",
                  request = {
                    ["$ref"] = "ReplaceSitesRequest",
                  },
                  response = {
                    ["$ref"] = "ReplaceSitesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
              },
            },
          },
        },
        creatives = {
          methods = {
            create = {
              description = "Creates a new creative. Returns the newly created creative if successful.",
              flatPath = "v1/advertisers/{advertisersId}/creatives",
              httpMethod = "POST",
              id = "displayvideo.advertisers.creatives.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the creative belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/creatives",
              request = {
                ["$ref"] = "Creative",
              },
              response = {
                ["$ref"] = "Creative",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            delete = {
              description = "Deletes a creative. Returns error code `NOT_FOUND` if the creative does not exist. The creative should be archived first, i.e. set entity_status to `ENTITY_STATUS_ARCHIVED`, before it can be deleted.",
              flatPath = "v1/advertisers/{advertisersId}/creatives/{creativesId}",
              httpMethod = "DELETE",
              id = "displayvideo.advertisers.creatives.delete",
              parameterOrder = {
                "advertiserId",
                "creativeId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser this creative belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                creativeId = {
                  description = "The ID of the creative to be deleted.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/creatives/{+creativeId}",
              response = {
                ["$ref"] = "Empty",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a creative.",
              flatPath = "v1/advertisers/{advertisersId}/creatives/{creativesId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.creatives.get",
              parameterOrder = {
                "advertiserId",
                "creativeId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this creative belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                creativeId = {
                  description = "Required. The ID of the creative to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/creatives/{+creativeId}",
              response = {
                ["$ref"] = "Creative",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists creatives in an advertiser. The order is defined by the order_by parameter. If a filter by entity_status is not specified, creatives with `ENTITY_STATUS_ARCHIVED` will not be included in the results.",
              flatPath = "v1/advertisers/{advertisersId}/creatives",
              httpMethod = "GET",
              id = "displayvideo.advertisers.creatives.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser to list creatives for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by creative properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restriction for the same field must be combined by `OR`. * Restriction for different fields must be combined by `AND`. * Between `(` and `)` there can only be restrictions combined by `OR` for the same field. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)` for the following fields: - `entityStatus` - `creativeType`. - `dimensions` - `minDuration` - `maxDuration` - `approvalStatus` - `exchangeReviewStatus` - `dynamic` - `creativeId` * The operator must be `HAS (:)` for the following fields: - `lineItemIds` * The operator must be `GREATER THAN OR EQUAL TO (>=)` or `LESS THAN OR EQUAL TO (<=)` for the following fields: - `updateTime` (input in ISO 8601 format, or YYYY-MM-DDTHH:MM:SSZ) * For `entityStatus`, `minDuration`, `maxDuration`, `updateTime`, and `dynamic`, there may be at most one restriction. * For `dimensions`, the value is in the form of `\"{width}x{height}\"`. * For `exchangeReviewStatus`, the value is in the form of `{exchange}-{reviewStatus}`. * For `minDuration` and `maxDuration`, the value is in the form of `\"{duration}s\"`. Only seconds are supported with millisecond granularity. * For `updateTime`, a creative resource's field value reflects the last time that a creative has been updated, which includes updates made by the system (e.g. creative review updates). * There may be multiple `lineItemIds` restrictions in order to search against multiple possible line item IDs. * There may be multiple `creativeId` restrictions in order to search against multiple possible creative IDs. Examples: * All native creatives: `creativeType=\"CREATIVE_TYPE_NATIVE\"` * All active creatives with 300x400 or 50x100 dimensions: `entityStatus=\"ENTITY_STATUS_ACTIVE\" AND (dimensions=\"300x400\" OR dimensions=\"50x100\")` * All dynamic creatives that are approved by AdX or AppNexus, with a minimum duration of 5 seconds and 200ms. `dynamic=\"true\" AND minDuration=\"5.2s\" AND (exchangeReviewStatus=\"EXCHANGE_GOOGLE_AD_MANAGER-REVIEW_STATUS_APPROVED\" OR exchangeReviewStatus=\"EXCHANGE_APPNEXUS-REVIEW_STATUS_APPROVED\")` * All video creatives that are associated with line item ID 1 or 2: `creativeType=\"CREATIVE_TYPE_VIDEO\" AND (lineItemIds:1 OR lineItemIds:2)` * Find creatives by multiple creative IDs: `creativeId=1 OR creativeId=2` * All creatives with an update time greater than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime>=\"2020-11-04T18:54:47Z\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `creativeId` (default) * `createTime` * `mediaDuration` * `dimensions` (sorts by width first, then by height) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `createTime desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCreatives` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/creatives",
              response = {
                ["$ref"] = "ListCreativesResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates an existing creative. Returns the updated creative if successful.",
              flatPath = "v1/advertisers/{advertisersId}/creatives/{creativesId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.creatives.patch",
              parameterOrder = {
                "advertiserId",
                "creativeId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the creative belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                creativeId = {
                  description = "Output only. The unique ID of the creative. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/creatives/{+creativeId}",
              request = {
                ["$ref"] = "Creative",
              },
              response = {
                ["$ref"] = "Creative",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
        },
        insertionOrders = {
          methods = {
            bulkListInsertionOrderAssignedTargetingOptions = {
              description = "Lists assigned targeting options of an insertion order across targeting types.",
              flatPath = "v1/advertisers/{advertisersId}/insertionOrders/{insertionOrdersId}:bulkListInsertionOrderAssignedTargetingOptions",
              httpMethod = "GET",
              id = "displayvideo.advertisers.insertionOrders.bulkListInsertionOrderAssignedTargetingOptions",
              parameterOrder = {
                "advertiserId",
                "insertionOrderId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser the insertion order belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR` on the same field. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `targetingType` - `inheritance` Examples: * AssignedTargetingOptions of targeting type TARGETING_TYPE_PROXIMITY_LOCATION_LIST or TARGETING_TYPE_CHANNEL `targetingType=\"TARGETING_TYPE_PROXIMITY_LOCATION_LIST\" OR targetingType=\"TARGETING_TYPE_CHANNEL\"` * AssignedTargetingOptions with inheritance status of NOT_INHERITED or INHERITED_FROM_PARTNER `inheritance=\"NOT_INHERITED\" OR inheritance=\"INHERITED_FROM_PARTNER\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                insertionOrderId = {
                  description = "Required. The ID of the insertion order to list assigned targeting options for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `targetingType` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `targetingType desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. The size must be an integer between `1` and `5000`. If unspecified, the default is `5000`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token that lets the client fetch the next page of results. Typically, this is the value of next_page_token returned from the previous call to `BulkListInsertionOrderAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/insertionOrders/{+insertionOrderId}:bulkListInsertionOrderAssignedTargetingOptions",
              response = {
                ["$ref"] = "BulkListInsertionOrderAssignedTargetingOptionsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            create = {
              description = "Creates a new insertion order. Returns the newly created insertion order if successful.",
              flatPath = "v1/advertisers/{advertisersId}/insertionOrders",
              httpMethod = "POST",
              id = "displayvideo.advertisers.insertionOrders.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the insertion order belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/insertionOrders",
              request = {
                ["$ref"] = "InsertionOrder",
              },
              response = {
                ["$ref"] = "InsertionOrder",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            delete = {
              description = "Deletes an insertion order. Returns error code `NOT_FOUND` if the insertion order does not exist. The insertion order should be archived first, i.e. set entity_status to `ENTITY_STATUS_ARCHIVED`, to be able to delete it.",
              flatPath = "v1/advertisers/{advertisersId}/insertionOrders/{insertionOrdersId}",
              httpMethod = "DELETE",
              id = "displayvideo.advertisers.insertionOrders.delete",
              parameterOrder = {
                "advertiserId",
                "insertionOrderId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser this insertion order belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                insertionOrderId = {
                  description = "The ID of the insertion order to delete.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/insertionOrders/{+insertionOrderId}",
              response = {
                ["$ref"] = "Empty",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets an insertion order. Returns error code `NOT_FOUND` if the insertion order does not exist.",
              flatPath = "v1/advertisers/{advertisersId}/insertionOrders/{insertionOrdersId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.insertionOrders.get",
              parameterOrder = {
                "advertiserId",
                "insertionOrderId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this insertion order belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                insertionOrderId = {
                  description = "Required. The ID of the insertion order to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/insertionOrders/{+insertionOrderId}",
              response = {
                ["$ref"] = "InsertionOrder",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists insertion orders in an advertiser. The order is defined by the order_by parameter. If a filter by entity_status is not specified, insertion orders with `ENTITY_STATUS_ARCHIVED` will not be included in the results.",
              flatPath = "v1/advertisers/{advertisersId}/insertionOrders",
              httpMethod = "GET",
              id = "displayvideo.advertisers.insertionOrders.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser to list insertion orders for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by insertion order properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator used on `budget.budget_segments.date_range.end_date` must be LESS THAN (<). * The operator used on `updateTime` must be `GREATER THAN OR EQUAL TO (>=)` or `LESS THAN OR EQUAL TO (<=)`. * The operators used on all other fields must be `EQUALS (=)`. * Supported fields: - `campaignId` - `displayName` - `entityStatus` - `budget.budget_segments.date_range.end_date` (input as YYYY-MM-DD) - `updateTime` (input in ISO 8601 format, or YYYY-MM-DDTHH:MM:SSZ) Examples: * All insertion orders under a campaign: `campaignId=\"1234\"` * All `ENTITY_STATUS_ACTIVE` or `ENTITY_STATUS_PAUSED` insertion orders under an advertiser: `(entityStatus=\"ENTITY_STATUS_ACTIVE\" OR entityStatus=\"ENTITY_STATUS_PAUSED\")` * All insertion orders whose budget segments' dates end before March 28, 2019: `budget.budget_segments.date_range.end_date<\"2019-03-28\"` * All insertion orders with an update time less than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime<=\"2020-11-04T18:54:47Z\"` * All insertion orders with an update time greater than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime>=\"2020-11-04T18:54:47Z\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * \"displayName\" (default) * \"entityStatus\" * \"updateTime\" The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `100`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListInsertionOrders` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/insertionOrders",
              response = {
                ["$ref"] = "ListInsertionOrdersResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates an existing insertion order. Returns the updated insertion order if successful.",
              flatPath = "v1/advertisers/{advertisersId}/insertionOrders/{insertionOrdersId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.insertionOrders.patch",
              parameterOrder = {
                "advertiserId",
                "insertionOrderId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the insertion order belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                insertionOrderId = {
                  description = "Output only. The unique ID of the insertion order. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/insertionOrders/{+insertionOrderId}",
              request = {
                ["$ref"] = "InsertionOrder",
              },
              response = {
                ["$ref"] = "InsertionOrder",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
          resources = {
            targetingTypes = {
              resources = {
                assignedTargetingOptions = {
                  methods = {
                    get = {
                      description = "Gets a single targeting option assigned to an insertion order.",
                      flatPath = "v1/advertisers/{advertisersId}/insertionOrders/{insertionOrdersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                      httpMethod = "GET",
                      id = "displayvideo.advertisers.insertionOrders.targetingTypes.assignedTargetingOptions.get",
                      parameterOrder = {
                        "advertiserId",
                        "insertionOrderId",
                        "targetingType",
                        "assignedTargetingOptionId",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the insertion order belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        assignedTargetingOptionId = {
                          description = "Required. An identifier unique to the targeting type in this insertion order that identifies the assigned targeting option being requested.",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        insertionOrderId = {
                          description = "Required. The ID of the insertion order the assigned targeting option belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of this assigned targeting option.",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/insertionOrders/{+insertionOrderId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                      response = {
                        ["$ref"] = "AssignedTargetingOption",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                    list = {
                      description = "Lists the targeting options assigned to an insertion order.",
                      flatPath = "v1/advertisers/{advertisersId}/insertionOrders/{insertionOrdersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                      httpMethod = "GET",
                      id = "displayvideo.advertisers.insertionOrders.targetingTypes.assignedTargetingOptions.list",
                      parameterOrder = {
                        "advertiserId",
                        "insertionOrderId",
                        "targetingType",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the insertion order belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        filter = {
                          description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedTargetingOptionId` - `inheritance` Examples: * AssignedTargetingOptions with ID 1 or 2 `assignedTargetingOptionId=\"1\" OR assignedTargetingOptionId=\"2\"` * AssignedTargetingOptions with inheritance status of NOT_INHERITED or INHERITED_FROM_PARTNER `inheritance=\"NOT_INHERITED\" OR inheritance=\"INHERITED_FROM_PARTNER\"` The length of this field should be no more than 500 characters.",
                          location = "query",
                          type = "string",
                        },
                        insertionOrderId = {
                          description = "Required. The ID of the insertion order to list assigned targeting options for.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        orderBy = {
                          description = "Field by which to sort the list. Acceptable values are: * `assignedTargetingOptionId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `assignedTargetingOptionId desc`.",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Requested page size. Must be between `1` and `5000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListInsertionOrderAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                          location = "query",
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of assigned targeting options to list.",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/insertionOrders/{+insertionOrderId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                      response = {
                        ["$ref"] = "ListInsertionOrderAssignedTargetingOptionsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                  },
                },
              },
            },
          },
        },
        invoices = {
          methods = {
            list = {
              description = "Lists invoices posted for an advertiser in a given month. Invoices generated by billing profiles with a \"Partner\" invoice level are not retrievable through this method.",
              flatPath = "v1/advertisers/{advertisersId}/invoices",
              httpMethod = "GET",
              id = "displayvideo.advertisers.invoices.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser to list invoices for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                issueMonth = {
                  description = "The month to list the invoices for. If not set, the request will retrieve invoices for the previous month. Must be in the format YYYYMM.",
                  location = "query",
                  type = "string",
                },
                loiSapinInvoiceType = {
                  description = "Select type of invoice to retrieve for Loi Sapin advertisers. Only applicable to Loi Sapin advertisers. Will be ignored otherwise.",
                  enum = {
                    "LOI_SAPIN_INVOICE_TYPE_UNSPECIFIED",
                    "LOI_SAPIN_INVOICE_TYPE_MEDIA",
                    "LOI_SAPIN_INVOICE_TYPE_PLATFORM",
                  },
                  enumDescriptions = {
                    "Value is not specified.",
                    "Invoices with Media cost.",
                    "Invoices with Platform fee.",
                  },
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListInvoices` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/invoices",
              response = {
                ["$ref"] = "ListInvoicesResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
            lookupInvoiceCurrency = {
              description = "Retrieves the invoice currency used by an advertiser in a given month.",
              flatPath = "v1/advertisers/{advertisersId}/invoices:lookupInvoiceCurrency",
              httpMethod = "GET",
              id = "displayvideo.advertisers.invoices.lookupInvoiceCurrency",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser to lookup currency for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                invoiceMonth = {
                  description = "Month for which the currency is needed. If not set, the request will return existing currency settings for the advertiser. Must be in the format YYYYMM.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/invoices:lookupInvoiceCurrency",
              response = {
                ["$ref"] = "LookupInvoiceCurrencyResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/display-video-mediaplanning",
              },
            },
          },
        },
        lineItems = {
          methods = {
            bulkEditLineItemAssignedTargetingOptions = {
              description = "Bulk edits targeting options under a single line item. The operation will delete the assigned targeting options provided in BulkEditLineItemAssignedTargetingOptionsRequest.delete_requests and then create the assigned targeting options provided in BulkEditLineItemAssignedTargetingOptionsRequest.create_requests. Requests to this endpoint cannot be made concurrently with the following requests updating the same line item: * UpdateLineItem * CreateLineItemAssignedTargetingOption * DeleteLineItemAssignedTargetingOption",
              flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}:bulkEditLineItemAssignedTargetingOptions",
              httpMethod = "POST",
              id = "displayvideo.advertisers.lineItems.bulkEditLineItemAssignedTargetingOptions",
              parameterOrder = {
                "advertiserId",
                "lineItemId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser the line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                lineItemId = {
                  description = "Required. The ID of the line item the assigned targeting option will belong to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}:bulkEditLineItemAssignedTargetingOptions",
              request = {
                ["$ref"] = "BulkEditLineItemAssignedTargetingOptionsRequest",
              },
              response = {
                ["$ref"] = "BulkEditLineItemAssignedTargetingOptionsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            bulkListLineItemAssignedTargetingOptions = {
              description = "Lists assigned targeting options of a line item across targeting types.",
              flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}:bulkListLineItemAssignedTargetingOptions",
              httpMethod = "GET",
              id = "displayvideo.advertisers.lineItems.bulkListLineItemAssignedTargetingOptions",
              parameterOrder = {
                "advertiserId",
                "lineItemId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser the line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR` on the same field. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `targetingType` - `inheritance` Examples: * AssignedTargetingOptions of targeting type TARGETING_TYPE_PROXIMITY_LOCATION_LIST or TARGETING_TYPE_CHANNEL `targetingType=\"TARGETING_TYPE_PROXIMITY_LOCATION_LIST\" OR targetingType=\"TARGETING_TYPE_CHANNEL\"` * AssignedTargetingOptions with inheritance status of NOT_INHERITED or INHERITED_FROM_PARTNER `inheritance=\"NOT_INHERITED\" OR inheritance=\"INHERITED_FROM_PARTNER\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                lineItemId = {
                  description = "Required. The ID of the line item to list assigned targeting options for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `targetingType` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `targetingType desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. The size must be an integer between `1` and `5000`. If unspecified, the default is '5000'. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token that lets the client fetch the next page of results. Typically, this is the value of next_page_token returned from the previous call to `BulkListLineItemAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}:bulkListLineItemAssignedTargetingOptions",
              response = {
                ["$ref"] = "BulkListLineItemAssignedTargetingOptionsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            create = {
              description = "Creates a new line item. Returns the newly created line item if successful.",
              flatPath = "v1/advertisers/{advertisersId}/lineItems",
              httpMethod = "POST",
              id = "displayvideo.advertisers.lineItems.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems",
              request = {
                ["$ref"] = "LineItem",
              },
              response = {
                ["$ref"] = "LineItem",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            delete = {
              description = "Deletes a line item. Returns error code `NOT_FOUND` if the line item does not exist. The line item should be archived first, i.e. set entity_status to `ENTITY_STATUS_ARCHIVED`, to be able to delete it.",
              flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}",
              httpMethod = "DELETE",
              id = "displayvideo.advertisers.lineItems.delete",
              parameterOrder = {
                "advertiserId",
                "lineItemId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser this line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                lineItemId = {
                  description = "The ID of the line item to delete.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}",
              response = {
                ["$ref"] = "Empty",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            generateDefault = {
              description = "Creates a new line item with settings (including targeting) inherited from the insertion order and an `ENTITY_STATUS_DRAFT` entity_status. Returns the newly created line item if successful. There are default values based on the three fields: * The insertion order's insertion_order_type * The insertion order's automation_type * The given line_item_type",
              flatPath = "v1/advertisers/{advertisersId}/lineItems:generateDefault",
              httpMethod = "POST",
              id = "displayvideo.advertisers.lineItems.generateDefault",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems:generateDefault",
              request = {
                ["$ref"] = "GenerateDefaultLineItemRequest",
              },
              response = {
                ["$ref"] = "LineItem",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a line item.",
              flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.lineItems.get",
              parameterOrder = {
                "advertiserId",
                "lineItemId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                lineItemId = {
                  description = "Required. The ID of the line item to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}",
              response = {
                ["$ref"] = "LineItem",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists line items in an advertiser. The order is defined by the order_by parameter. If a filter by entity_status is not specified, line items with `ENTITY_STATUS_ARCHIVED` will not be included in the results.",
              flatPath = "v1/advertisers/{advertisersId}/lineItems",
              httpMethod = "GET",
              id = "displayvideo.advertisers.lineItems.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser to list line items for.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by line item properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator used on `flight.dateRange.endDate` must be LESS THAN (<). * The operator used on `updateTime` must be `GREATER THAN OR EQUAL TO (>=)` or `LESS THAN OR EQUAL TO (<=)`. * The operator used on `warningMessages` must be `HAS (:)`. * The operators used on all other fields must be `EQUALS (=)`. * Supported properties: - `campaignId` - `displayName` - `insertionOrderId` - `entityStatus` - `lineItemId` - `lineItemType` - `flight.dateRange.endDate` (input formatted as YYYY-MM-DD) - `warningMessages` - `flight.triggerId` - `updateTime` (input in ISO 8601 format, or YYYY-MM-DDTHH:MM:SSZ) - `targetedChannelId` - `targetedNegativeKeywordListId` Examples: * All line items under an insertion order: `insertionOrderId=\"1234\"` * All `ENTITY_STATUS_ACTIVE` or `ENTITY_STATUS_PAUSED` and `LINE_ITEM_TYPE_DISPLAY_DEFAULT` line items under an advertiser: `(entityStatus=\"ENTITY_STATUS_ACTIVE\" OR entityStatus=\"ENTITY_STATUS_PAUSED\") AND lineItemType=\"LINE_ITEM_TYPE_DISPLAY_DEFAULT\"` * All line items whose flight dates end before March 28, 2019: `flight.dateRange.endDate<\"2019-03-28\"` * All line items that have `NO_VALID_CREATIVE` in `warningMessages`: `warningMessages:\"NO_VALID_CREATIVE\"` * All line items with an update time less than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime<=\"2020-11-04T18:54:47Z\"` * All line items with an update time greater than or equal to `2020-11-04T18:54:47Z (format of ISO 8601)`: `updateTime>=\"2020-11-04T18:54:47Z\"` * All line items that are using both the specified channel and specified negative keyword list in their targeting: `targetedNegativeKeywordListId=789 AND targetedChannelId=12345` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `entityStatus` * `flight.dateRange.endDate` * `updateTime` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListLineItems` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems",
              response = {
                ["$ref"] = "ListLineItemsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates an existing line item. Returns the updated line item if successful. Requests to this endpoint cannot be made concurrently with the following requests updating the same line item: * BulkEditAssignedTargetingOptions * BulkUpdateLineItems * CreateLineItemAssignedTargetingOption * DeleteLineItemAssignedTargetingOption",
              flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.lineItems.patch",
              parameterOrder = {
                "advertiserId",
                "lineItemId",
              },
              parameters = {
                advertiserId = {
                  description = "Output only. The unique ID of the advertiser the line item belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                lineItemId = {
                  description = "Output only. The unique ID of the line item. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}",
              request = {
                ["$ref"] = "LineItem",
              },
              response = {
                ["$ref"] = "LineItem",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
          resources = {
            targetingTypes = {
              resources = {
                assignedTargetingOptions = {
                  methods = {
                    create = {
                      description = "Assigns a targeting option to a line item. Returns the assigned targeting option if successful. Requests to this endpoint cannot be made concurrently with the following requests updating the same line item: * BulkEditAssignedTargetingOptions * BulkUpdate * UpdateLineItem * DeleteLineItemAssignedTargetingOption",
                      flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                      httpMethod = "POST",
                      id = "displayvideo.advertisers.lineItems.targetingTypes.assignedTargetingOptions.create",
                      parameterOrder = {
                        "advertiserId",
                        "lineItemId",
                        "targetingType",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the line item belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        lineItemId = {
                          description = "Required. The ID of the line item the assigned targeting option will belong to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of this assigned targeting option.",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                      request = {
                        ["$ref"] = "AssignedTargetingOption",
                      },
                      response = {
                        ["$ref"] = "AssignedTargetingOption",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                    delete = {
                      description = "Deletes an assigned targeting option from a line item. Requests to this endpoint cannot be made concurrently with the following requests updating the same line item: * BulkEditAssignedTargetingOptions * BulkUpdate * UpdateLineItem * CreateLineItemAssignedTargetingOption",
                      flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                      httpMethod = "DELETE",
                      id = "displayvideo.advertisers.lineItems.targetingTypes.assignedTargetingOptions.delete",
                      parameterOrder = {
                        "advertiserId",
                        "lineItemId",
                        "targetingType",
                        "assignedTargetingOptionId",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the line item belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        assignedTargetingOptionId = {
                          description = "Required. The ID of the assigned targeting option to delete.",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        lineItemId = {
                          description = "Required. The ID of the line item the assigned targeting option belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of this assigned targeting option.",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                      response = {
                        ["$ref"] = "Empty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                    get = {
                      description = "Gets a single targeting option assigned to a line item.",
                      flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                      httpMethod = "GET",
                      id = "displayvideo.advertisers.lineItems.targetingTypes.assignedTargetingOptions.get",
                      parameterOrder = {
                        "advertiserId",
                        "lineItemId",
                        "targetingType",
                        "assignedTargetingOptionId",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the line item belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        assignedTargetingOptionId = {
                          description = "Required. An identifier unique to the targeting type in this line item that identifies the assigned targeting option being requested.",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        lineItemId = {
                          description = "Required. The ID of the line item the assigned targeting option belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of this assigned targeting option.",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                      response = {
                        ["$ref"] = "AssignedTargetingOption",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                    list = {
                      description = "Lists the targeting options assigned to a line item.",
                      flatPath = "v1/advertisers/{advertisersId}/lineItems/{lineItemsId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                      httpMethod = "GET",
                      id = "displayvideo.advertisers.lineItems.targetingTypes.assignedTargetingOptions.list",
                      parameterOrder = {
                        "advertiserId",
                        "lineItemId",
                        "targetingType",
                      },
                      parameters = {
                        advertiserId = {
                          description = "Required. The ID of the advertiser the line item belongs to.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        filter = {
                          description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedTargetingOptionId` - `inheritance` Examples: * AssignedTargetingOptions with ID 1 or 2 `assignedTargetingOptionId=\"1\" OR assignedTargetingOptionId=\"2\"` * AssignedTargetingOptions with inheritance status of NOT_INHERITED or INHERITED_FROM_PARTNER `inheritance=\"NOT_INHERITED\" OR inheritance=\"INHERITED_FROM_PARTNER\"` The length of this field should be no more than 500 characters.",
                          location = "query",
                          type = "string",
                        },
                        lineItemId = {
                          description = "Required. The ID of the line item to list assigned targeting options for.",
                          format = "int64",
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                        orderBy = {
                          description = "Field by which to sort the list. Acceptable values are: * `assignedTargetingOptionId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `assignedTargetingOptionId desc`.",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Requested page size. Must be between `1` and `5000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListLineItemAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                          location = "query",
                          type = "string",
                        },
                        targetingType = {
                          description = "Required. Identifies the type of assigned targeting options to list.",
                          enum = {
                            "TARGETING_TYPE_UNSPECIFIED",
                            "TARGETING_TYPE_CHANNEL",
                            "TARGETING_TYPE_APP_CATEGORY",
                            "TARGETING_TYPE_APP",
                            "TARGETING_TYPE_URL",
                            "TARGETING_TYPE_DAY_AND_TIME",
                            "TARGETING_TYPE_AGE_RANGE",
                            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                            "TARGETING_TYPE_GENDER",
                            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                            "TARGETING_TYPE_USER_REWARDED_CONTENT",
                            "TARGETING_TYPE_PARENTAL_STATUS",
                            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                            "TARGETING_TYPE_DEVICE_TYPE",
                            "TARGETING_TYPE_AUDIENCE_GROUP",
                            "TARGETING_TYPE_BROWSER",
                            "TARGETING_TYPE_HOUSEHOLD_INCOME",
                            "TARGETING_TYPE_ON_SCREEN_POSITION",
                            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                            "TARGETING_TYPE_ENVIRONMENT",
                            "TARGETING_TYPE_CARRIER_AND_ISP",
                            "TARGETING_TYPE_OPERATING_SYSTEM",
                            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                            "TARGETING_TYPE_KEYWORD",
                            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                            "TARGETING_TYPE_VIEWABILITY",
                            "TARGETING_TYPE_CATEGORY",
                            "TARGETING_TYPE_INVENTORY_SOURCE",
                            "TARGETING_TYPE_LANGUAGE",
                            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                            "TARGETING_TYPE_GEO_REGION",
                            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                            "TARGETING_TYPE_EXCHANGE",
                            "TARGETING_TYPE_SUB_EXCHANGE",
                            "TARGETING_TYPE_POI",
                            "TARGETING_TYPE_BUSINESS_CHAIN",
                            "TARGETING_TYPE_CONTENT_DURATION",
                            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                            "TARGETING_TYPE_OMID",
                            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                            "TARGETING_TYPE_CONTENT_GENRE",
                          },
                          enumDescriptions = {
                            "Default value when type is not specified or is unknown in this version.",
                            "Target a channel (a custom group of related websites or apps).",
                            "Target an app category (for example, education or puzzle games).",
                            "Target a specific app (for example, Angry Birds).",
                            "Target a specific url (for example, quora.com).",
                            "Target ads during a chosen time period on a specific day.",
                            "Target ads to a specific age range (for example, 18-24).",
                            "Target ads to the specified regions on a regional location list.",
                            "Target ads to the specified points of interest on a proximity location list.",
                            "Target ads to a specific gender (for example, female or male).",
                            "Target a specific video player size for video ads.",
                            "Target user rewarded content for video ads.",
                            "Target ads to a specific parental status (for example, parent or not a parent).",
                            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                            "Target ads in a specific content outstream position.",
                            "Target ads to a specific device type (for example, tablet or connected TV).",
                            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                            "Target ads to specific web browsers (for example, Chrome).",
                            "Target ads to a specific household income range (for example, top 10%).",
                            "Target ads in a specific on screen position.",
                            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                            "Filter website content by sensitive categories (for example, adult).",
                            "Target ads to a specific environment (for example, web or app).",
                            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                            "Target ads to a specific operating system (for example, macOS).",
                            "Target ads to a specific device make or model (for example, Roku or Samsung).",
                            "Target ads to a specific keyword (for example, dog or retriever).",
                            "Target ads to a specific negative keyword list.",
                            "Target ads to a specific viewability (for example, 80% viewable).",
                            "Target ads to a specific content category (for example, arts & entertainment).",
                            "Purchase impressions from specific deals and auction packages.",
                            "Target ads to a specific language (for example, English or Japanese).",
                            "Target ads to ads.txt authorized sellers.",
                            "Target ads to a specific regional location (for example, a city or state).",
                            "Purchase impressions from a group of deals and auction packages.",
                            "Purchase impressions from specific exchanges.",
                            "Purchase impressions from specific sub-exchanges.",
                            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                            "Target ads around locations of a business chain within a specific geo region.",
                            "Target ads to a specific video content duration.",
                            "Target ads to a specific video content stream type.",
                            "Target ads to a specific native content position.",
                            "Target ads in an Open Measurement enabled inventory.",
                            "Target ads to a specific audio content type.",
                            "Target ads to a specific content genre.",
                          },
                          location = "path",
                          pattern = "^[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v1/advertisers/{+advertiserId}/lineItems/{+lineItemId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                      response = {
                        ["$ref"] = "ListLineItemAssignedTargetingOptionsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/display-video",
                      },
                    },
                  },
                },
              },
            },
          },
        },
        locationLists = {
          methods = {
            create = {
              description = "Creates a new location list. Returns the newly created location list if successful.",
              flatPath = "v1/advertisers/{advertisersId}/locationLists",
              httpMethod = "POST",
              id = "displayvideo.advertisers.locationLists.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the location list belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/locationLists",
              request = {
                ["$ref"] = "LocationList",
              },
              response = {
                ["$ref"] = "LocationList",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a location list.",
              flatPath = "v1/advertisers/{advertisersId}/locationLists/{locationListsId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.locationLists.get",
              parameterOrder = {
                "advertiserId",
                "locationListId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the fetched location list belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                locationListId = {
                  description = "Required. The ID of the location list to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/locationLists/{+locationListId}",
              response = {
                ["$ref"] = "LocationList",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists location lists based on a given advertiser id.",
              flatPath = "v1/advertisers/{advertisersId}/locationLists",
              httpMethod = "GET",
              id = "displayvideo.advertisers.locationLists.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the fetched location lists belong.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by location list fields. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `locationType` Examples: * All regional location list: `locationType=\"TARGETING_LOCATION_TYPE_REGIONAL\"` * All proximity location list: `locationType=\"TARGETING_LOCATION_TYPE_PROXIMITY\"`",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `locationListId` (default) * `displayName` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. Defaults to `100` if not set. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListLocationLists` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/locationLists",
              response = {
                ["$ref"] = "ListLocationListsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates a location list. Returns the updated location list if successful.",
              flatPath = "v1/advertisers/{advertisersId}/locationLists/{locationListId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.locationLists.patch",
              parameterOrder = {
                "advertiserId",
                "locationListId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the location lists belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                locationListId = {
                  description = "Output only. The unique ID of the location list. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/locationLists/{locationListId}",
              request = {
                ["$ref"] = "LocationList",
              },
              response = {
                ["$ref"] = "LocationList",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
          resources = {
            assignedLocations = {
              methods = {
                bulkEdit = {
                  description = "Bulk edits multiple assignments between locations and a single location list. The operation will delete the assigned locations provided in BulkEditAssignedLocationsRequest.deleted_assigned_locations and then create the assigned locations provided in BulkEditAssignedLocationsRequest.created_assigned_locations.",
                  flatPath = "v1/advertisers/{advertiserId}/locationLists/{locationListsId}/assignedLocations:bulkEdit",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.locationLists.assignedLocations.bulkEdit",
                  parameterOrder = {
                    "advertiserId",
                    "locationListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the location list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    locationListId = {
                      description = "Required. The ID of the location list to which these assignments are assigned.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/locationLists/{+locationListId}/assignedLocations:bulkEdit",
                  request = {
                    ["$ref"] = "BulkEditAssignedLocationsRequest",
                  },
                  response = {
                    ["$ref"] = "BulkEditAssignedLocationsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                create = {
                  description = "Creates an assignment between a location and a location list.",
                  flatPath = "v1/advertisers/{advertiserId}/locationLists/{locationListId}/assignedLocations",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.locationLists.assignedLocations.create",
                  parameterOrder = {
                    "advertiserId",
                    "locationListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the location list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    locationListId = {
                      description = "Required. The ID of the location list for which the assignment will be created.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/locationLists/{locationListId}/assignedLocations",
                  request = {
                    ["$ref"] = "AssignedLocation",
                  },
                  response = {
                    ["$ref"] = "AssignedLocation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                delete = {
                  description = "Deletes the assignment between a location and a location list.",
                  flatPath = "v1/advertisers/{advertiserId}/locationLists/{locationListId}/assignedLocations/{assignedLocationsId}",
                  httpMethod = "DELETE",
                  id = "displayvideo.advertisers.locationLists.assignedLocations.delete",
                  parameterOrder = {
                    "advertiserId",
                    "locationListId",
                    "assignedLocationId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the location list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    assignedLocationId = {
                      description = "Required. The ID of the assigned location to delete.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    locationListId = {
                      description = "Required. The ID of the location list to which this assignment is assigned.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/locationLists/{locationListId}/assignedLocations/{+assignedLocationId}",
                  response = {
                    ["$ref"] = "Empty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                list = {
                  description = "Lists locations assigned to a location list.",
                  flatPath = "v1/advertisers/{advertiserId}/locationLists/{locationListId}/assignedLocations",
                  httpMethod = "GET",
                  id = "displayvideo.advertisers.locationLists.assignedLocations.list",
                  parameterOrder = {
                    "advertiserId",
                    "locationListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the location list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    filter = {
                      description = "Allows filtering by location list assignment fields. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedLocationId` The length of this field should be no more than 500 characters.",
                      location = "query",
                      type = "string",
                    },
                    locationListId = {
                      description = "Required. The ID of the location list to which these assignments are assigned.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    orderBy = {
                      description = "Field by which to sort the list. Acceptable values are: * `assignedLocationId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `assignedLocationId desc`.",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListAssignedLocations` method. If not specified, the first page of results will be returned.",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/locationLists/{locationListId}/assignedLocations",
                  response = {
                    ["$ref"] = "ListAssignedLocationsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
              },
            },
          },
        },
        manualTriggers = {
          methods = {
            activate = {
              description = "Activates a manual trigger. Each activation of the manual trigger must be at least 5 minutes apart, otherwise an error will be returned.",
              flatPath = "v1/advertisers/{advertisersId}/manualTriggers/{manualTriggersId}:activate",
              httpMethod = "POST",
              id = "displayvideo.advertisers.manualTriggers.activate",
              parameterOrder = {
                "advertiserId",
                "triggerId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser that the manual trigger belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                triggerId = {
                  description = "Required. The ID of the manual trigger to activate.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/manualTriggers/{+triggerId}:activate",
              request = {
                ["$ref"] = "ActivateManualTriggerRequest",
              },
              response = {
                ["$ref"] = "ManualTrigger",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            create = {
              description = "Creates a new manual trigger. Returns the newly created manual trigger if successful.",
              flatPath = "v1/advertisers/{advertisersId}/manualTriggers",
              httpMethod = "POST",
              id = "displayvideo.advertisers.manualTriggers.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. Immutable. The unique ID of the advertiser that the manual trigger belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/manualTriggers",
              request = {
                ["$ref"] = "ManualTrigger",
              },
              response = {
                ["$ref"] = "ManualTrigger",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            deactivate = {
              description = "Deactivates a manual trigger.",
              flatPath = "v1/advertisers/{advertisersId}/manualTriggers/{manualTriggersId}:deactivate",
              httpMethod = "POST",
              id = "displayvideo.advertisers.manualTriggers.deactivate",
              parameterOrder = {
                "advertiserId",
                "triggerId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser that the manual trigger belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                triggerId = {
                  description = "Required. The ID of the manual trigger to deactivate.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/manualTriggers/{+triggerId}:deactivate",
              request = {
                ["$ref"] = "DeactivateManualTriggerRequest",
              },
              response = {
                ["$ref"] = "ManualTrigger",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a manual trigger.",
              flatPath = "v1/advertisers/{advertisersId}/manualTriggers/{manualTriggersId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.manualTriggers.get",
              parameterOrder = {
                "advertiserId",
                "triggerId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser this manual trigger belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                triggerId = {
                  description = "Required. The ID of the manual trigger to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/manualTriggers/{+triggerId}",
              response = {
                ["$ref"] = "ManualTrigger",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists manual triggers that are accessible to the current user for a given advertiser ID. The order is defined by the order_by parameter. A single advertiser_id is required.",
              flatPath = "v1/advertisers/{advertisersId}/manualTriggers",
              httpMethod = "GET",
              id = "displayvideo.advertisers.manualTriggers.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the advertiser that the fetched manual triggers belong to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by manual trigger properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `displayName` - `state` Examples: * All active manual triggers under an advertiser: `state=\"ACTIVE\"` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `state` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListManualTriggers` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/manualTriggers",
              response = {
                ["$ref"] = "ListManualTriggersResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates a manual trigger. Returns the updated manual trigger if successful.",
              flatPath = "v1/advertisers/{advertisersId}/manualTriggers/{manualTriggersId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.manualTriggers.patch",
              parameterOrder = {
                "advertiserId",
                "triggerId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. Immutable. The unique ID of the advertiser that the manual trigger belongs to.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                triggerId = {
                  description = "Output only. The unique ID of the manual trigger.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/manualTriggers/{+triggerId}",
              request = {
                ["$ref"] = "ManualTrigger",
              },
              response = {
                ["$ref"] = "ManualTrigger",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
        },
        negativeKeywordLists = {
          methods = {
            create = {
              description = "Creates a new negative keyword list. Returns the newly created negative keyword list if successful.",
              flatPath = "v1/advertisers/{advertisersId}/negativeKeywordLists",
              httpMethod = "POST",
              id = "displayvideo.advertisers.negativeKeywordLists.create",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the negative keyword list will belong.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/negativeKeywordLists",
              request = {
                ["$ref"] = "NegativeKeywordList",
              },
              response = {
                ["$ref"] = "NegativeKeywordList",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            delete = {
              description = "Deletes a negative keyword list given an advertiser ID and a negative keyword list ID.",
              flatPath = "v1/advertisers/{advertisersId}/negativeKeywordLists/{negativeKeywordListsId}",
              httpMethod = "DELETE",
              id = "displayvideo.advertisers.negativeKeywordLists.delete",
              parameterOrder = {
                "advertiserId",
                "negativeKeywordListId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the negative keyword list belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                negativeKeywordListId = {
                  description = "Required. The ID of the negative keyword list to delete.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/negativeKeywordLists/{+negativeKeywordListId}",
              response = {
                ["$ref"] = "Empty",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a negative keyword list given an advertiser ID and a negative keyword list ID.",
              flatPath = "v1/advertisers/{advertisersId}/negativeKeywordLists/{negativeKeywordListsId}",
              httpMethod = "GET",
              id = "displayvideo.advertisers.negativeKeywordLists.get",
              parameterOrder = {
                "advertiserId",
                "negativeKeywordListId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the fetched negative keyword list belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                negativeKeywordListId = {
                  description = "Required. The ID of the negative keyword list to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/negativeKeywordLists/{+negativeKeywordListId}",
              response = {
                ["$ref"] = "NegativeKeywordList",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists negative keyword lists based on a given advertiser id.",
              flatPath = "v1/advertisers/{advertisersId}/negativeKeywordLists",
              httpMethod = "GET",
              id = "displayvideo.advertisers.negativeKeywordLists.list",
              parameterOrder = {
                "advertiserId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the fetched negative keyword lists belong.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. Defaults to `100` if not set. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListNegativeKeywordLists` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/negativeKeywordLists",
              response = {
                ["$ref"] = "ListNegativeKeywordListsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates a negative keyword list. Returns the updated negative keyword list if successful.",
              flatPath = "v1/advertisers/{advertisersId}/negativeKeywordLists/{negativeKeywordListId}",
              httpMethod = "PATCH",
              id = "displayvideo.advertisers.negativeKeywordLists.patch",
              parameterOrder = {
                "advertiserId",
                "negativeKeywordListId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The ID of the DV360 advertiser to which the negative keyword list belongs.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                negativeKeywordListId = {
                  description = "Output only. The unique ID of the negative keyword list. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/advertisers/{+advertiserId}/negativeKeywordLists/{negativeKeywordListId}",
              request = {
                ["$ref"] = "NegativeKeywordList",
              },
              response = {
                ["$ref"] = "NegativeKeywordList",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
          resources = {
            negativeKeywords = {
              methods = {
                bulkEdit = {
                  description = "Bulk edits negative keywords in a single negative keyword list. The operation will delete the negative keywords provided in BulkEditNegativeKeywordsRequest.deleted_negative_keywords and then create the negative keywords provided in BulkEditNegativeKeywordsRequest.created_negative_keywords. This operation is guaranteed to be atomic and will never result in a partial success or partial failure.",
                  flatPath = "v1/advertisers/{advertiserId}/negativeKeywordLists/{negativeKeywordListsId}/negativeKeywords:bulkEdit",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.negativeKeywordLists.negativeKeywords.bulkEdit",
                  parameterOrder = {
                    "advertiserId",
                    "negativeKeywordListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the parent negative keyword list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    negativeKeywordListId = {
                      description = "Required. The ID of the parent negative keyword list to which the negative keywords belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/negativeKeywordLists/{+negativeKeywordListId}/negativeKeywords:bulkEdit",
                  request = {
                    ["$ref"] = "BulkEditNegativeKeywordsRequest",
                  },
                  response = {
                    ["$ref"] = "BulkEditNegativeKeywordsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                create = {
                  description = "Creates a negative keyword in a negative keyword list.",
                  flatPath = "v1/advertisers/{advertiserId}/negativeKeywordLists/{negativeKeywordListsId}/negativeKeywords",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.negativeKeywordLists.negativeKeywords.create",
                  parameterOrder = {
                    "advertiserId",
                    "negativeKeywordListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the parent negative keyword list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    negativeKeywordListId = {
                      description = "Required. The ID of the parent negative keyword list in which the negative keyword will be created.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/negativeKeywordLists/{+negativeKeywordListId}/negativeKeywords",
                  request = {
                    ["$ref"] = "NegativeKeyword",
                  },
                  response = {
                    ["$ref"] = "NegativeKeyword",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                delete = {
                  description = "Deletes a negative keyword from a negative keyword list.",
                  flatPath = "v1/advertisers/{advertiserId}/negativeKeywordLists/{negativeKeywordListsId}/negativeKeywords/{negativeKeywordsId}",
                  httpMethod = "DELETE",
                  id = "displayvideo.advertisers.negativeKeywordLists.negativeKeywords.delete",
                  parameterOrder = {
                    "advertiserId",
                    "negativeKeywordListId",
                    "keywordValue",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the parent negative keyword list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    keywordValue = {
                      description = "Required. The keyword value of the negative keyword to delete.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    negativeKeywordListId = {
                      description = "Required. The ID of the parent negative keyword list to which the negative keyword belongs.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/negativeKeywordLists/{+negativeKeywordListId}/negativeKeywords/{+keywordValue}",
                  response = {
                    ["$ref"] = "Empty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                list = {
                  description = "Lists negative keywords in a negative keyword list.",
                  flatPath = "v1/advertisers/{advertisersId}/negativeKeywordLists/{negativeKeywordListsId}/negativeKeywords",
                  httpMethod = "GET",
                  id = "displayvideo.advertisers.negativeKeywordLists.negativeKeywords.list",
                  parameterOrder = {
                    "advertiserId",
                    "negativeKeywordListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the parent negative keyword list belongs.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    filter = {
                      description = "Allows filtering by negative keyword fields. Supported syntax: * Filter expressions for negative keyword currently can only contain at most one * restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `keywordValue` Examples: * All negative keywords for which the keyword value contains \"google\": `keywordValue : \"google\"`",
                      location = "query",
                      type = "string",
                    },
                    negativeKeywordListId = {
                      description = "Required. The ID of the parent negative keyword list to which the requested negative keywords belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    orderBy = {
                      description = "Field by which to sort the list. Acceptable values are: * `keywordValue` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `keywordValue desc`.",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Requested page size. Must be between `1` and `1000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListNegativeKeywords` method. If not specified, the first page of results will be returned.",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{+advertiserId}/negativeKeywordLists/{+negativeKeywordListId}/negativeKeywords",
                  response = {
                    ["$ref"] = "ListNegativeKeywordsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                replace = {
                  description = "Replaces all negative keywords in a single negative keyword list. The operation will replace the keywords in a negative keyword list with keywords provided in ReplaceNegativeKeywordsRequest.new_negative_keywords.",
                  flatPath = "v1/advertisers/{advertiserId}/negativeKeywordLists/{negativeKeywordListsId}/negativeKeywords:replace",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.negativeKeywordLists.negativeKeywords.replace",
                  parameterOrder = {
                    "advertiserId",
                    "negativeKeywordListId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the DV360 advertiser to which the parent negative keyword list belongs.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    negativeKeywordListId = {
                      description = "Required. The ID of the parent negative keyword list to which the negative keywords belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{advertiserId}/negativeKeywordLists/{+negativeKeywordListId}/negativeKeywords:replace",
                  request = {
                    ["$ref"] = "ReplaceNegativeKeywordsRequest",
                  },
                  response = {
                    ["$ref"] = "ReplaceNegativeKeywordsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
              },
            },
          },
        },
        targetingTypes = {
          resources = {
            assignedTargetingOptions = {
              methods = {
                create = {
                  description = "Assigns a targeting option to an advertiser. Returns the assigned targeting option if successful.",
                  flatPath = "v1/advertisers/{advertisersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                  httpMethod = "POST",
                  id = "displayvideo.advertisers.targetingTypes.assignedTargetingOptions.create",
                  parameterOrder = {
                    "advertiserId",
                    "targetingType",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the advertiser.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_CHANNEL` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_OMID` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{+advertiserId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                  request = {
                    ["$ref"] = "AssignedTargetingOption",
                  },
                  response = {
                    ["$ref"] = "AssignedTargetingOption",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                delete = {
                  description = "Deletes an assigned targeting option from an advertiser.",
                  flatPath = "v1/advertisers/{advertisersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                  httpMethod = "DELETE",
                  id = "displayvideo.advertisers.targetingTypes.assignedTargetingOptions.delete",
                  parameterOrder = {
                    "advertiserId",
                    "targetingType",
                    "assignedTargetingOptionId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the advertiser.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    assignedTargetingOptionId = {
                      description = "Required. The ID of the assigned targeting option to delete.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_CHANNEL` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_OMID` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{+advertiserId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                  response = {
                    ["$ref"] = "Empty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                get = {
                  description = "Gets a single targeting option assigned to an advertiser.",
                  flatPath = "v1/advertisers/{advertisersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                  httpMethod = "GET",
                  id = "displayvideo.advertisers.targetingTypes.assignedTargetingOptions.get",
                  parameterOrder = {
                    "advertiserId",
                    "targetingType",
                    "assignedTargetingOptionId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the advertiser.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    assignedTargetingOptionId = {
                      description = "Required. An identifier unique to the targeting type in this advertiser that identifies the assigned targeting option being requested.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_CHANNEL` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_OMID` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{+advertiserId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                  response = {
                    ["$ref"] = "AssignedTargetingOption",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                list = {
                  description = "Lists the targeting options assigned to an advertiser.",
                  flatPath = "v1/advertisers/{advertisersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                  httpMethod = "GET",
                  id = "displayvideo.advertisers.targetingTypes.assignedTargetingOptions.list",
                  parameterOrder = {
                    "advertiserId",
                    "targetingType",
                  },
                  parameters = {
                    advertiserId = {
                      description = "Required. The ID of the advertiser.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    filter = {
                      description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedTargetingOptionId` Examples: * AssignedTargetingOption with ID 123456 `assignedTargetingOptionId=\"123456\"` The length of this field should be no more than 500 characters.",
                      location = "query",
                      type = "string",
                    },
                    orderBy = {
                      description = "Field by which to sort the list. Acceptable values are: * `assignedTargetingOptionId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `assignedTargetingOptionId desc`.",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Requested page size. Must be between `1` and `5000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListAdvertiserAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                      location = "query",
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of assigned targeting options to list. Supported targeting types: * `TARGETING_TYPE_CHANNEL` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_OMID` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/advertisers/{+advertiserId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                  response = {
                    ["$ref"] = "ListAdvertiserAssignedTargetingOptionsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
              },
            },
          },
        },
      },
    },
    combinedAudiences = {
      methods = {
        get = {
          description = "Gets a combined audience.",
          flatPath = "v1/combinedAudiences/{combinedAudiencesId}",
          httpMethod = "GET",
          id = "displayvideo.combinedAudiences.get",
          parameterOrder = {
            "combinedAudienceId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the fetched combined audience.",
              format = "int64",
              location = "query",
              type = "string",
            },
            combinedAudienceId = {
              description = "Required. The ID of the combined audience to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the fetched combined audience.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/combinedAudiences/{+combinedAudienceId}",
          response = {
            ["$ref"] = "CombinedAudience",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists combined audiences. The order is defined by the order_by parameter.",
          flatPath = "v1/combinedAudiences",
          httpMethod = "GET",
          id = "displayvideo.combinedAudiences.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the fetched combined audiences.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by combined audience fields. Supported syntax: * Filter expressions for combined audiences currently can only contain at most one restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `displayName` Examples: * All combined audiences for which the display name contains \"Google\": `displayName : \"Google\"`. The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `combinedAudienceId` (default) * `displayName` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCombinedAudiences` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the fetched combined audiences.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/combinedAudiences",
          response = {
            ["$ref"] = "ListCombinedAudiencesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    customBiddingAlgorithms = {
      methods = {
        create = {
          description = "Creates a new custom bidding algorithm. Returns the newly created custom bidding algorithm if successful.",
          flatPath = "v1/customBiddingAlgorithms",
          httpMethod = "POST",
          id = "displayvideo.customBiddingAlgorithms.create",
          parameterOrder = {},
          parameters = {},
          path = "v1/customBiddingAlgorithms",
          request = {
            ["$ref"] = "CustomBiddingAlgorithm",
          },
          response = {
            ["$ref"] = "CustomBiddingAlgorithm",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets a custom bidding algorithm.",
          flatPath = "v1/customBiddingAlgorithms/{customBiddingAlgorithmsId}",
          httpMethod = "GET",
          id = "displayvideo.customBiddingAlgorithms.get",
          parameterOrder = {
            "customBiddingAlgorithmId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the DV360 partner that has access to the custom bidding algorithm.",
              format = "int64",
              location = "query",
              type = "string",
            },
            customBiddingAlgorithmId = {
              description = "Required. The ID of the custom bidding algorithm to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the DV360 partner that has access to the custom bidding algorithm.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/customBiddingAlgorithms/{+customBiddingAlgorithmId}",
          response = {
            ["$ref"] = "CustomBiddingAlgorithm",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists custom bidding algorithms that are accessible to the current user and can be used in bidding stratgies. The order is defined by the order_by parameter.",
          flatPath = "v1/customBiddingAlgorithms",
          httpMethod = "GET",
          id = "displayvideo.customBiddingAlgorithms.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the DV360 advertiser that has access to the custom bidding algorithm.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by custom bidding algorithm fields. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND`. A sequence of restrictions * implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)` or `EQUALS (=)`. * The operator must be `CONTAINS (:)` for the following field: - `displayName` * The operator must be `EQUALS (=)` for the following field: - `customBiddingAlgorithmType` * For `displayName`, the value is a string. We return all custom bidding algorithms whose display_name contains such string. * For `customBiddingAlgorithmType`, the value is a string. We return all algorithms whose custom_bidding_algorithm_type is equal to the given type. Examples: * All custom bidding algorithms for which the display name contains \"politics\": `displayName:politics`. * All custom bidding algorithms for which the type is \"SCRIPT_BASED\": `customBiddingAlgorithmType=SCRIPT_BASED` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCustomBiddingAlgorithms` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the DV360 partner that has access to the custom bidding algorithm.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/customBiddingAlgorithms",
          response = {
            ["$ref"] = "ListCustomBiddingAlgorithmsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an existing custom bidding algorithm. Returns the updated custom bidding algorithm if successful.",
          flatPath = "v1/customBiddingAlgorithms/{customBiddingAlgorithmsId}",
          httpMethod = "PATCH",
          id = "displayvideo.customBiddingAlgorithms.patch",
          parameterOrder = {
            "customBiddingAlgorithmId",
          },
          parameters = {
            customBiddingAlgorithmId = {
              description = "Output only. The unique ID of the custom bidding algorithm. Assigned by the system.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/customBiddingAlgorithms/{+customBiddingAlgorithmId}",
          request = {
            ["$ref"] = "CustomBiddingAlgorithm",
          },
          response = {
            ["$ref"] = "CustomBiddingAlgorithm",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        uploadScript = {
          description = "Creates a custom bidding script reference object for a script file. The resulting reference object provides a resource path to which the script file should be uploaded. This reference object should be included in when creating a new custom bidding script object.",
          flatPath = "v1/customBiddingAlgorithms/{customBiddingAlgorithmsId}:uploadScript",
          httpMethod = "GET",
          id = "displayvideo.customBiddingAlgorithms.uploadScript",
          parameterOrder = {
            "customBiddingAlgorithmId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that owns the parent custom bidding algorithm.",
              format = "int64",
              location = "query",
              type = "string",
            },
            customBiddingAlgorithmId = {
              description = "Required. The ID of the custom bidding algorithm owns the script.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that owns the parent custom bidding algorithm. Only this partner will have write access to this custom bidding script.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/customBiddingAlgorithms/{+customBiddingAlgorithmId}:uploadScript",
          response = {
            ["$ref"] = "CustomBiddingScriptRef",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
      resources = {
        scripts = {
          methods = {
            create = {
              description = "Creates a new custom bidding script. Returns the newly created script if successful.",
              flatPath = "v1/customBiddingAlgorithms/{customBiddingAlgorithmsId}/scripts",
              httpMethod = "POST",
              id = "displayvideo.customBiddingAlgorithms.scripts.create",
              parameterOrder = {
                "customBiddingAlgorithmId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the parent custom bidding algorithm.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                customBiddingAlgorithmId = {
                  description = "Required. The ID of the custom bidding algorithm that owns the script.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the parent custom bidding algorithm. Only this partner will have write access to this custom bidding script.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/customBiddingAlgorithms/{+customBiddingAlgorithmId}/scripts",
              request = {
                ["$ref"] = "CustomBiddingScript",
              },
              response = {
                ["$ref"] = "CustomBiddingScript",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a custom bidding script.",
              flatPath = "v1/customBiddingAlgorithms/{customBiddingAlgorithmsId}/scripts/{scriptsId}",
              httpMethod = "GET",
              id = "displayvideo.customBiddingAlgorithms.scripts.get",
              parameterOrder = {
                "customBiddingAlgorithmId",
                "customBiddingScriptId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the parent custom bidding algorithm.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                customBiddingAlgorithmId = {
                  description = "Required. The ID of the custom bidding algorithm owns the script.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                customBiddingScriptId = {
                  description = "Required. The ID of the custom bidding script to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the parent custom bidding algorithm. Only this partner will have write access to this custom bidding script.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/customBiddingAlgorithms/{+customBiddingAlgorithmId}/scripts/{+customBiddingScriptId}",
              response = {
                ["$ref"] = "CustomBiddingScript",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists custom bidding scripts that belong to the given algorithm. The order is defined by the order_by parameter.",
              flatPath = "v1/customBiddingAlgorithms/{customBiddingAlgorithmsId}/scripts",
              httpMethod = "GET",
              id = "displayvideo.customBiddingAlgorithms.scripts.list",
              parameterOrder = {
                "customBiddingAlgorithmId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the parent custom bidding algorithm.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                customBiddingAlgorithmId = {
                  description = "Required. The ID of the custom bidding algorithm owns the script.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `createTime desc` (default) The default sorting order is descending. To specify ascending order for a field, the suffix \"desc\" should be removed. Example: `createTime`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCustomBiddingScripts` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the parent custom bidding algorithm. Only this partner will have write access to this custom bidding script.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/customBiddingAlgorithms/{+customBiddingAlgorithmId}/scripts",
              response = {
                ["$ref"] = "ListCustomBiddingScriptsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
        },
      },
    },
    customLists = {
      methods = {
        get = {
          description = "Gets a custom list.",
          flatPath = "v1/customLists/{customListsId}",
          httpMethod = "GET",
          id = "displayvideo.customLists.get",
          parameterOrder = {
            "customListId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the DV360 advertiser that has access to the fetched custom lists.",
              format = "int64",
              location = "query",
              type = "string",
            },
            customListId = {
              description = "Required. The ID of the custom list to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/customLists/{+customListId}",
          response = {
            ["$ref"] = "CustomList",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists custom lists. The order is defined by the order_by parameter.",
          flatPath = "v1/customLists",
          httpMethod = "GET",
          id = "displayvideo.customLists.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the DV360 advertiser that has access to the fetched custom lists.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by custom list fields. Supported syntax: * Filter expressions for custom lists currently can only contain at most one restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `displayName` Examples: * All custom lists for which the display name contains \"Google\": `displayName : \"Google\"`. The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `customListId` (default) * `displayName` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListCustomLists` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
          },
          path = "v1/customLists",
          response = {
            ["$ref"] = "ListCustomListsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    firstAndThirdPartyAudiences = {
      methods = {
        create = {
          description = "Creates a FirstAndThirdPartyAudience. Only supported for the following audience_type: * `CUSTOMER_MATCH_CONTACT_INFO` * `CUSTOMER_MATCH_DEVICE_ID`",
          flatPath = "v1/firstAndThirdPartyAudiences",
          httpMethod = "POST",
          id = "displayvideo.firstAndThirdPartyAudiences.create",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "Required. The ID of the advertiser under whom the FirstAndThirdPartyAudience will be created.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/firstAndThirdPartyAudiences",
          request = {
            ["$ref"] = "FirstAndThirdPartyAudience",
          },
          response = {
            ["$ref"] = "FirstAndThirdPartyAudience",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        editCustomerMatchMembers = {
          description = "Updates the member list of a Customer Match audience. Only supported for the following audience_type: * `CUSTOMER_MATCH_CONTACT_INFO` * `CUSTOMER_MATCH_DEVICE_ID`",
          flatPath = "v1/firstAndThirdPartyAudiences/{firstAndThirdPartyAudiencesId}:editCustomerMatchMembers",
          httpMethod = "POST",
          id = "displayvideo.firstAndThirdPartyAudiences.editCustomerMatchMembers",
          parameterOrder = {
            "firstAndThirdPartyAudienceId",
          },
          parameters = {
            firstAndThirdPartyAudienceId = {
              description = "Required. The ID of the Customer Match FirstAndThirdPartyAudience whose members will be edited.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/firstAndThirdPartyAudiences/{+firstAndThirdPartyAudienceId}:editCustomerMatchMembers",
          request = {
            ["$ref"] = "EditCustomerMatchMembersRequest",
          },
          response = {
            ["$ref"] = "EditCustomerMatchMembersResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets a first and third party audience.",
          flatPath = "v1/firstAndThirdPartyAudiences/{firstAndThirdPartyAudiencesId}",
          httpMethod = "GET",
          id = "displayvideo.firstAndThirdPartyAudiences.get",
          parameterOrder = {
            "firstAndThirdPartyAudienceId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the fetched first and third party audience.",
              format = "int64",
              location = "query",
              type = "string",
            },
            firstAndThirdPartyAudienceId = {
              description = "Required. The ID of the first and third party audience to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the fetched first and third party audience.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/firstAndThirdPartyAudiences/{+firstAndThirdPartyAudienceId}",
          response = {
            ["$ref"] = "FirstAndThirdPartyAudience",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists first and third party audiences. The order is defined by the order_by parameter.",
          flatPath = "v1/firstAndThirdPartyAudiences",
          httpMethod = "GET",
          id = "displayvideo.firstAndThirdPartyAudiences.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the fetched first and third party audiences.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by first and third party audience fields. Supported syntax: * Filter expressions for first and third party audiences currently can only contain at most one restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `displayName` Examples: * All first and third party audiences for which the display name contains \"Google\": `displayName : \"Google\"`. The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `firstAndThirdPartyAudienceId` (default) * `displayName` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListFirstAndThirdPartyAudiences` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the fetched first and third party audiences.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/firstAndThirdPartyAudiences",
          response = {
            ["$ref"] = "ListFirstAndThirdPartyAudiencesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an existing FirstAndThirdPartyAudience. Only supported for the following audience_type: * `CUSTOMER_MATCH_CONTACT_INFO` * `CUSTOMER_MATCH_DEVICE_ID`",
          flatPath = "v1/firstAndThirdPartyAudiences/{firstAndThirdPartyAudiencesId}",
          httpMethod = "PATCH",
          id = "displayvideo.firstAndThirdPartyAudiences.patch",
          parameterOrder = {
            "firstAndThirdPartyAudienceId",
          },
          parameters = {
            advertiserId = {
              description = "Required. The ID of the owner advertiser of the updated FirstAndThirdPartyAudience.",
              format = "int64",
              location = "query",
              type = "string",
            },
            firstAndThirdPartyAudienceId = {
              description = "Output only. The unique ID of the first and third party audience. Assigned by the system.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update. Updates are only supported for the following fields: * `displayName` * `description` * `membershipDurationDays`",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/firstAndThirdPartyAudiences/{+firstAndThirdPartyAudienceId}",
          request = {
            ["$ref"] = "FirstAndThirdPartyAudience",
          },
          response = {
            ["$ref"] = "FirstAndThirdPartyAudience",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    floodlightGroups = {
      methods = {
        get = {
          description = "Gets a Floodlight group.",
          flatPath = "v1/floodlightGroups/{floodlightGroupsId}",
          httpMethod = "GET",
          id = "displayvideo.floodlightGroups.get",
          parameterOrder = {
            "floodlightGroupId",
          },
          parameters = {
            floodlightGroupId = {
              description = "Required. The ID of the Floodlight group to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "Required. The partner context by which the Floodlight group is being accessed.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/floodlightGroups/{+floodlightGroupId}",
          response = {
            ["$ref"] = "FloodlightGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an existing Floodlight group. Returns the updated Floodlight group if successful.",
          flatPath = "v1/floodlightGroups/{floodlightGroupId}",
          httpMethod = "PATCH",
          id = "displayvideo.floodlightGroups.patch",
          parameterOrder = {
            "floodlightGroupId",
          },
          parameters = {
            floodlightGroupId = {
              description = "Output only. The unique ID of the Floodlight group. Assigned by the system.",
              format = "int64",
              location = "path",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "Required. The partner context by which the Floodlight group is being accessed.",
              format = "int64",
              location = "query",
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/floodlightGroups/{floodlightGroupId}",
          request = {
            ["$ref"] = "FloodlightGroup",
          },
          response = {
            ["$ref"] = "FloodlightGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    googleAudiences = {
      methods = {
        get = {
          description = "Gets a Google audience.",
          flatPath = "v1/googleAudiences/{googleAudiencesId}",
          httpMethod = "GET",
          id = "displayvideo.googleAudiences.get",
          parameterOrder = {
            "googleAudienceId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the fetched Google audience.",
              format = "int64",
              location = "query",
              type = "string",
            },
            googleAudienceId = {
              description = "Required. The ID of the Google audience to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the fetched Google audience.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/googleAudiences/{+googleAudienceId}",
          response = {
            ["$ref"] = "GoogleAudience",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists Google audiences. The order is defined by the order_by parameter.",
          flatPath = "v1/googleAudiences",
          httpMethod = "GET",
          id = "displayvideo.googleAudiences.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the fetched Google audiences.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by Google audience fields. Supported syntax: * Filter expressions for Google audiences currently can only contain at most one restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `displayName` Examples: * All Google audiences for which the display name contains \"Google\": `displayName : \"Google\"`. The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `googleAudienceId` (default) * `displayName` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListGoogleAudiences` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the fetched Google audiences.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/googleAudiences",
          response = {
            ["$ref"] = "ListGoogleAudiencesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    guaranteedOrders = {
      methods = {
        create = {
          description = "Creates a new guaranteed order. Returns the newly created guaranteed order if successful.",
          flatPath = "v1/guaranteedOrders",
          httpMethod = "POST",
          id = "displayvideo.guaranteedOrders.create",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/guaranteedOrders",
          request = {
            ["$ref"] = "GuaranteedOrder",
          },
          response = {
            ["$ref"] = "GuaranteedOrder",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        editGuaranteedOrderReadAccessors = {
          description = "Edits read advertisers of a guaranteed order.",
          flatPath = "v1/guaranteedOrders/{guaranteedOrdersId}:editGuaranteedOrderReadAccessors",
          httpMethod = "POST",
          id = "displayvideo.guaranteedOrders.editGuaranteedOrderReadAccessors",
          parameterOrder = {
            "guaranteedOrderId",
          },
          parameters = {
            guaranteedOrderId = {
              description = "Required. The ID of the guaranteed order to edit. The ID is of the format `{exchange}-{legacy_guaranteed_order_id}`",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/guaranteedOrders/{+guaranteedOrderId}:editGuaranteedOrderReadAccessors",
          request = {
            ["$ref"] = "EditGuaranteedOrderReadAccessorsRequest",
          },
          response = {
            ["$ref"] = "EditGuaranteedOrderReadAccessorsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets a guaranteed order.",
          flatPath = "v1/guaranteedOrders/{guaranteedOrdersId}",
          httpMethod = "GET",
          id = "displayvideo.guaranteedOrders.get",
          parameterOrder = {
            "guaranteedOrderId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the guaranteed order.",
              format = "int64",
              location = "query",
              type = "string",
            },
            guaranteedOrderId = {
              description = "Required. The ID of the guaranteed order to fetch. The ID is of the format `{exchange}-{legacy_guaranteed_order_id}`",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the guaranteed order.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/guaranteedOrders/{+guaranteedOrderId}",
          response = {
            ["$ref"] = "GuaranteedOrder",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists guaranteed orders that are accessible to the current user. The order is defined by the order_by parameter. If a filter by entity_status is not specified, guaranteed orders with entity status `ENTITY_STATUS_ARCHIVED` will not be included in the results.",
          flatPath = "v1/guaranteedOrders",
          httpMethod = "GET",
          id = "displayvideo.guaranteedOrders.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the guaranteed order.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by guaranteed order properties. * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `guaranteed_order_id` - `exchange` - `display_name` - `status.entityStatus` Examples: * All active guaranteed orders: `status.entityStatus=\"ENTITY_STATUS_ACTIVE\"` * Guaranteed orders belonging to Google Ad Manager or Rubicon exchanges: `exchange=\"EXCHANGE_GOOGLE_AD_MANAGER\" OR exchange=\"EXCHANGE_RUBICON\"` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListGuaranteedOrders` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the guaranteed order.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/guaranteedOrders",
          response = {
            ["$ref"] = "ListGuaranteedOrdersResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an existing guaranteed order. Returns the updated guaranteed order if successful.",
          flatPath = "v1/guaranteedOrders/{guaranteedOrdersId}",
          httpMethod = "PATCH",
          id = "displayvideo.guaranteedOrders.patch",
          parameterOrder = {
            "guaranteedOrderId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
            guaranteedOrderId = {
              description = "Output only. The unique identifier of the guaranteed order. The guaranteed order IDs have the format `{exchange}-{legacy_guaranteed_order_id}`.",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/guaranteedOrders/{+guaranteedOrderId}",
          request = {
            ["$ref"] = "GuaranteedOrder",
          },
          response = {
            ["$ref"] = "GuaranteedOrder",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    inventorySourceGroups = {
      methods = {
        create = {
          description = "Creates a new inventory source group. Returns the newly created inventory source group if successful.",
          flatPath = "v1/inventorySourceGroups",
          httpMethod = "POST",
          id = "displayvideo.inventorySourceGroups.create",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that owns the inventory source group. The parent partner will not have access to this group.",
              format = "int64",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that owns the inventory source group. Only this partner will have write access to this group. Only advertisers to which this group is explicitly shared will have read access to this group.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySourceGroups",
          request = {
            ["$ref"] = "InventorySourceGroup",
          },
          response = {
            ["$ref"] = "InventorySourceGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        delete = {
          description = "Deletes an inventory source group.",
          flatPath = "v1/inventorySourceGroups/{inventorySourceGroupsId}",
          httpMethod = "DELETE",
          id = "displayvideo.inventorySourceGroups.delete",
          parameterOrder = {
            "inventorySourceGroupId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that owns the inventory source group. The parent partner does not have access to this group.",
              format = "int64",
              location = "query",
              type = "string",
            },
            inventorySourceGroupId = {
              description = "Required. The ID of the inventory source group to delete.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that owns the inventory source group. Only this partner has write access to this group.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySourceGroups/{+inventorySourceGroupId}",
          response = {
            ["$ref"] = "Empty",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets an inventory source group.",
          flatPath = "v1/inventorySourceGroups/{inventorySourceGroupsId}",
          httpMethod = "GET",
          id = "displayvideo.inventorySourceGroups.get",
          parameterOrder = {
            "inventorySourceGroupId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the inventory source group. If an inventory source group is partner-owned, only advertisers to which the group is explicitly shared can access the group.",
              format = "int64",
              location = "query",
              type = "string",
            },
            inventorySourceGroupId = {
              description = "Required. The ID of the inventory source group to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the inventory source group. A partner cannot access an advertiser-owned inventory source group.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySourceGroups/{+inventorySourceGroupId}",
          response = {
            ["$ref"] = "InventorySourceGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists inventory source groups that are accessible to the current user. The order is defined by the order_by parameter.",
          flatPath = "v1/inventorySourceGroups",
          httpMethod = "GET",
          id = "displayvideo.inventorySourceGroups.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the inventory source group. If an inventory source group is partner-owned, only advertisers to which the group is explicitly shared can access the group.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by inventory source group properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `inventorySourceGroupId` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `inventorySourceGroupId` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListInventorySources` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the inventory source group. A partner cannot access advertiser-owned inventory source groups.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySourceGroups",
          response = {
            ["$ref"] = "ListInventorySourceGroupsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an inventory source group. Returns the updated inventory source group if successful.",
          flatPath = "v1/inventorySourceGroups/{inventorySourceGroupId}",
          httpMethod = "PATCH",
          id = "displayvideo.inventorySourceGroups.patch",
          parameterOrder = {
            "inventorySourceGroupId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that owns the inventory source group. The parent partner does not have access to this group.",
              format = "int64",
              location = "query",
              type = "string",
            },
            inventorySourceGroupId = {
              description = "Output only. The unique ID of the inventory source group. Assigned by the system.",
              format = "int64",
              location = "path",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that owns the inventory source group. Only this partner has write access to this group.",
              format = "int64",
              location = "query",
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySourceGroups/{inventorySourceGroupId}",
          request = {
            ["$ref"] = "InventorySourceGroup",
          },
          response = {
            ["$ref"] = "InventorySourceGroup",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
      resources = {
        assignedInventorySources = {
          methods = {
            bulkEdit = {
              description = "Bulk edits multiple assignments between inventory sources and a single inventory source group. The operation will delete the assigned inventory sources provided in BulkEditAssignedInventorySourcesRequest.deleted_assigned_inventory_sources and then create the assigned inventory sources provided in BulkEditAssignedInventorySourcesRequest.created_assigned_inventory_sources.",
              flatPath = "v1/inventorySourceGroups/{inventorySourceGroupsId}/assignedInventorySources:bulkEdit",
              httpMethod = "POST",
              id = "displayvideo.inventorySourceGroups.assignedInventorySources.bulkEdit",
              parameterOrder = {
                "inventorySourceGroupId",
              },
              parameters = {
                inventorySourceGroupId = {
                  description = "Required. The ID of the inventory source group to which the assignments are assigned.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/inventorySourceGroups/{+inventorySourceGroupId}/assignedInventorySources:bulkEdit",
              request = {
                ["$ref"] = "BulkEditAssignedInventorySourcesRequest",
              },
              response = {
                ["$ref"] = "BulkEditAssignedInventorySourcesResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            create = {
              description = "Creates an assignment between an inventory source and an inventory source group.",
              flatPath = "v1/inventorySourceGroups/{inventorySourceGroupsId}/assignedInventorySources",
              httpMethod = "POST",
              id = "displayvideo.inventorySourceGroups.assignedInventorySources.create",
              parameterOrder = {
                "inventorySourceGroupId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the parent inventory source group. The parent partner will not have access to this assigned inventory source.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                inventorySourceGroupId = {
                  description = "Required. The ID of the inventory source group to which the assignment will be assigned.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the parent inventory source group. Only this partner will have write access to this assigned inventory source.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/inventorySourceGroups/{+inventorySourceGroupId}/assignedInventorySources",
              request = {
                ["$ref"] = "AssignedInventorySource",
              },
              response = {
                ["$ref"] = "AssignedInventorySource",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            delete = {
              description = "Deletes the assignment between an inventory source and an inventory source group.",
              flatPath = "v1/inventorySourceGroups/{inventorySourceGroupsId}/assignedInventorySources/{assignedInventorySourcesId}",
              httpMethod = "DELETE",
              id = "displayvideo.inventorySourceGroups.assignedInventorySources.delete",
              parameterOrder = {
                "inventorySourceGroupId",
                "assignedInventorySourceId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the parent inventory source group. The parent partner does not have access to this assigned inventory source.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                assignedInventorySourceId = {
                  description = "Required. The ID of the assigned inventory source to delete.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                inventorySourceGroupId = {
                  description = "Required. The ID of the inventory source group to which this assignment is assigned.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the parent inventory source group. Only this partner has write access to this assigned inventory source.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/inventorySourceGroups/{+inventorySourceGroupId}/assignedInventorySources/{+assignedInventorySourceId}",
              response = {
                ["$ref"] = "Empty",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists inventory sources assigned to an inventory source group.",
              flatPath = "v1/inventorySourceGroups/{inventorySourceGroupsId}/assignedInventorySources",
              httpMethod = "GET",
              id = "displayvideo.inventorySourceGroups.assignedInventorySources.list",
              parameterOrder = {
                "inventorySourceGroupId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that has access to the assignment. If the parent inventory source group is partner-owned, only advertisers to which the parent group is explicitly shared can access the assigned inventory source.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by assigned inventory source fields. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedInventorySourceId` The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                inventorySourceGroupId = {
                  description = "Required. The ID of the inventory source group to which these assignments are assigned.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `assignedInventorySourceId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `assignedInventorySourceId desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `100`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListAssignedInventorySources` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that has access to the assignment. If the parent inventory source group is advertiser-owned, the assignment cannot be accessed via a partner.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/inventorySourceGroups/{+inventorySourceGroupId}/assignedInventorySources",
              response = {
                ["$ref"] = "ListAssignedInventorySourcesResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
        },
      },
    },
    inventorySources = {
      methods = {
        create = {
          description = "Creates a new inventory source. Returns the newly created inventory source if successful.",
          flatPath = "v1/inventorySources",
          httpMethod = "POST",
          id = "displayvideo.inventorySources.create",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySources",
          request = {
            ["$ref"] = "InventorySource",
          },
          response = {
            ["$ref"] = "InventorySource",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        editInventorySourceReadWriteAccessors = {
          description = "Edits read/write accessors of an inventory source. Returns the updated read_write_accessors for the inventory source.",
          flatPath = "v1/inventorySources/{inventorySourcesId}:editInventorySourceReadWriteAccessors",
          httpMethod = "POST",
          id = "displayvideo.inventorySources.editInventorySourceReadWriteAccessors",
          parameterOrder = {
            "inventorySourceId",
          },
          parameters = {
            inventorySourceId = {
              description = "Required. The ID of inventory source to update.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/inventorySources/{+inventorySourceId}:editInventorySourceReadWriteAccessors",
          request = {
            ["$ref"] = "EditInventorySourceReadWriteAccessorsRequest",
          },
          response = {
            ["$ref"] = "InventorySourceAccessors",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets an inventory source.",
          flatPath = "v1/inventorySources/{inventorySourcesId}",
          httpMethod = "GET",
          id = "displayvideo.inventorySources.get",
          parameterOrder = {
            "inventorySourceId",
          },
          parameters = {
            inventorySourceId = {
              description = "Required. The ID of the inventory source to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "Required. The ID of the DV360 partner to which the fetched inventory source is permissioned.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySources/{+inventorySourceId}",
          response = {
            ["$ref"] = "InventorySource",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists inventory sources that are accessible to the current user. The order is defined by the order_by parameter. If a filter by entity_status is not specified, inventory sources with entity status `ENTITY_STATUS_ARCHIVED` will not be included in the results.",
          flatPath = "v1/inventorySources",
          httpMethod = "GET",
          id = "displayvideo.inventorySources.list",
          parameterOrder = {},
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that has access to the inventory source.",
              format = "int64",
              location = "query",
              type = "string",
            },
            filter = {
              description = "Allows filtering by inventory source properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `status.entityStatus` - `commitment` - `deliveryMethod` - `rateDetails.rateType` - `exchange` Examples: * All active inventory sources: `status.entityStatus=\"ENTITY_STATUS_ACTIVE\"` * Inventory sources belonging to Google Ad Manager or Rubicon exchanges: `exchange=\"EXCHANGE_GOOGLE_AD_MANAGER\" OR exchange=\"EXCHANGE_RUBICON\"` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListInventorySources` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that has access to the inventory source.",
              format = "int64",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySources",
          response = {
            ["$ref"] = "ListInventorySourcesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        patch = {
          description = "Updates an existing inventory source. Returns the updated inventory source if successful.",
          flatPath = "v1/inventorySources/{inventorySourcesId}",
          httpMethod = "PATCH",
          id = "displayvideo.inventorySources.patch",
          parameterOrder = {
            "inventorySourceId",
          },
          parameters = {
            advertiserId = {
              description = "The ID of the advertiser that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
            inventorySourceId = {
              description = "Output only. The unique ID of the inventory source. Assigned by the system.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
            partnerId = {
              description = "The ID of the partner that the request is being made within.",
              format = "int64",
              location = "query",
              type = "string",
            },
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v1/inventorySources/{+inventorySourceId}",
          request = {
            ["$ref"] = "InventorySource",
          },
          response = {
            ["$ref"] = "InventorySource",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
    },
    media = {
      methods = {
        download = {
          description = "Downloads media. Download is supported on the URI `/download/{resource_name=**}?alt=media.` **Note**: Download requests will not be successful without including `alt=media` query string.",
          flatPath = "download/{downloadId}",
          httpMethod = "GET",
          id = "displayvideo.media.download",
          parameterOrder = {
            "resourceName",
          },
          parameters = {
            resourceName = {
              description = "Name of the media that is being downloaded. See ReadRequest.resource_name.",
              location = "path",
              pattern = "^.*$",
              required = true,
              type = "string",
            },
          },
          path = "download/{+resourceName}",
          response = {
            ["$ref"] = "GoogleBytestreamMedia",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
            "https://www.googleapis.com/auth/doubleclickbidmanager",
          },
          supportsMediaDownload = true,
        },
        upload = {
          description = "Uploads media. Upload is supported on the URI `/upload/media/{resource_name=**}?upload_type=media.` **Note**: Upload requests will not be successful without including `upload_type=media` query string.",
          flatPath = "media/{mediaId}",
          httpMethod = "POST",
          id = "displayvideo.media.upload",
          mediaUpload = {
            accept = {
              "*/*",
            },
            protocols = {
              simple = {
                multipart = true,
                path = "/upload/media/{+resourceName}",
              },
            },
          },
          parameterOrder = {
            "resourceName",
          },
          parameters = {
            resourceName = {
              description = "Name of the media that is being downloaded. See ReadRequest.resource_name.",
              location = "path",
              pattern = "^.*$",
              required = true,
              type = "string",
            },
          },
          path = "media/{+resourceName}",
          request = {
            ["$ref"] = "GoogleBytestreamMedia",
          },
          response = {
            ["$ref"] = "GoogleBytestreamMedia",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
            "https://www.googleapis.com/auth/doubleclickbidmanager",
          },
          supportsMediaUpload = true,
        },
      },
    },
    partners = {
      methods = {
        bulkEditPartnerAssignedTargetingOptions = {
          description = "Bulk edits targeting options under a single partner. The operation will delete the assigned targeting options provided in BulkEditPartnerAssignedTargetingOptionsRequest.deleteRequests and then create the assigned targeting options provided in BulkEditPartnerAssignedTargetingOptionsRequest.createRequests .",
          flatPath = "v1/partners/{partnersId}:bulkEditPartnerAssignedTargetingOptions",
          httpMethod = "POST",
          id = "displayvideo.partners.bulkEditPartnerAssignedTargetingOptions",
          parameterOrder = {
            "partnerId",
          },
          parameters = {
            partnerId = {
              description = "Required. The ID of the partner.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/partners/{+partnerId}:bulkEditPartnerAssignedTargetingOptions",
          request = {
            ["$ref"] = "BulkEditPartnerAssignedTargetingOptionsRequest",
          },
          response = {
            ["$ref"] = "BulkEditPartnerAssignedTargetingOptionsResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        get = {
          description = "Gets a partner.",
          flatPath = "v1/partners/{partnersId}",
          httpMethod = "GET",
          id = "displayvideo.partners.get",
          parameterOrder = {
            "partnerId",
          },
          parameters = {
            partnerId = {
              description = "Required. The ID of the partner to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/partners/{+partnerId}",
          response = {
            ["$ref"] = "Partner",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
        list = {
          description = "Lists partners that are accessible to the current user. The order is defined by the order_by parameter.",
          flatPath = "v1/partners",
          httpMethod = "GET",
          id = "displayvideo.partners.list",
          parameterOrder = {},
          parameters = {
            filter = {
              description = "Allows filtering by partner properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `AND` or `OR` logical operators. A sequence of restrictions implicitly uses `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `entityStatus` Examples: * All active partners: `entityStatus=\"ENTITY_STATUS_ACTIVE\"` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListPartners` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
          },
          path = "v1/partners",
          response = {
            ["$ref"] = "ListPartnersResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
      resources = {
        channels = {
          methods = {
            create = {
              description = "Creates a new channel. Returns the newly created channel if successful.",
              flatPath = "v1/partners/{partnersId}/channels",
              httpMethod = "POST",
              id = "displayvideo.partners.channels.create",
              parameterOrder = {
                "partnerId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the created channel.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the created channel.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/partners/{+partnerId}/channels",
              request = {
                ["$ref"] = "Channel",
              },
              response = {
                ["$ref"] = "Channel",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            get = {
              description = "Gets a channel for a partner or advertiser.",
              flatPath = "v1/partners/{partnersId}/channels/{channelsId}",
              httpMethod = "GET",
              id = "displayvideo.partners.channels.get",
              parameterOrder = {
                "partnerId",
                "channelId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the fetched channel.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                channelId = {
                  description = "Required. The ID of the channel to fetch.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the fetched channel.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/partners/{+partnerId}/channels/{+channelId}",
              response = {
                ["$ref"] = "Channel",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists channels for a partner or advertiser.",
              flatPath = "v1/partners/{partnersId}/channels",
              httpMethod = "GET",
              id = "displayvideo.partners.channels.list",
              parameterOrder = {
                "partnerId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the channels.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by channel fields. Supported syntax: * Filter expressions for channel currently can only contain at most one * restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `displayName` Examples: * All channels for which the display name contains \"google\": `displayName : \"google\"`. The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) * `channelId` The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `displayName desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListChannels` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the channels.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/partners/{+partnerId}/channels",
              response = {
                ["$ref"] = "ListChannelsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            patch = {
              description = "Updates a channel. Returns the updated channel if successful.",
              flatPath = "v1/partners/{partnersId}/channels/{channelId}",
              httpMethod = "PATCH",
              id = "displayvideo.partners.channels.patch",
              parameterOrder = {
                "partnerId",
                "channelId",
              },
              parameters = {
                advertiserId = {
                  description = "The ID of the advertiser that owns the created channel.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                channelId = {
                  description = "Output only. The unique ID of the channel. Assigned by the system.",
                  format = "int64",
                  location = "path",
                  required = true,
                  type = "string",
                },
                partnerId = {
                  description = "The ID of the partner that owns the created channel.",
                  format = "int64",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v1/partners/{+partnerId}/channels/{channelId}",
              request = {
                ["$ref"] = "Channel",
              },
              response = {
                ["$ref"] = "Channel",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
          resources = {
            sites = {
              methods = {
                bulkEdit = {
                  description = "Bulk edits sites under a single channel. The operation will delete the sites provided in BulkEditSitesRequest.deleted_sites and then create the sites provided in BulkEditSitesRequest.created_sites.",
                  flatPath = "v1/partners/{partnerId}/channels/{channelsId}/sites:bulkEdit",
                  httpMethod = "POST",
                  id = "displayvideo.partners.channels.sites.bulkEdit",
                  parameterOrder = {
                    "partnerId",
                    "channelId",
                  },
                  parameters = {
                    channelId = {
                      description = "Required. The ID of the parent channel to which the sites belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{partnerId}/channels/{+channelId}/sites:bulkEdit",
                  request = {
                    ["$ref"] = "BulkEditSitesRequest",
                  },
                  response = {
                    ["$ref"] = "BulkEditSitesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                create = {
                  description = "Creates a site in a channel.",
                  flatPath = "v1/partners/{partnerId}/channels/{channelsId}/sites",
                  httpMethod = "POST",
                  id = "displayvideo.partners.channels.sites.create",
                  parameterOrder = {
                    "partnerId",
                    "channelId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "query",
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel in which the site will be created.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{partnerId}/channels/{+channelId}/sites",
                  request = {
                    ["$ref"] = "Site",
                  },
                  response = {
                    ["$ref"] = "Site",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                delete = {
                  description = "Deletes a site from a channel.",
                  flatPath = "v1/partners/{partnerId}/channels/{channelsId}/sites/{sitesId}",
                  httpMethod = "DELETE",
                  id = "displayvideo.partners.channels.sites.delete",
                  parameterOrder = {
                    "partnerId",
                    "channelId",
                    "urlOrAppId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "query",
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel to which the site belongs.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                    urlOrAppId = {
                      description = "Required. The URL or app ID of the site to delete.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{partnerId}/channels/{+channelId}/sites/{+urlOrAppId}",
                  response = {
                    ["$ref"] = "Empty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                list = {
                  description = "Lists sites in a channel.",
                  flatPath = "v1/partners/{partnersId}/channels/{channelsId}/sites",
                  httpMethod = "GET",
                  id = "displayvideo.partners.channels.sites.list",
                  parameterOrder = {
                    "partnerId",
                    "channelId",
                  },
                  parameters = {
                    advertiserId = {
                      description = "The ID of the advertiser that owns the parent channel.",
                      format = "int64",
                      location = "query",
                      type = "string",
                    },
                    channelId = {
                      description = "Required. The ID of the parent channel to which the requested sites belong.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    filter = {
                      description = "Allows filtering by site fields. Supported syntax: * Filter expressions for site currently can only contain at most one * restriction. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)`. * Supported fields: - `urlOrAppId` Examples: * All sites for which the URL or app ID contains \"google\": `urlOrAppId : \"google\"`",
                      location = "query",
                      type = "string",
                    },
                    orderBy = {
                      description = "Field by which to sort the list. Acceptable values are: * `urlOrAppId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \" desc\" should be added to the field name. Example: `urlOrAppId desc`.",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Requested page size. Must be between `1` and `10000`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListSites` method. If not specified, the first page of results will be returned.",
                      location = "query",
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{+partnerId}/channels/{+channelId}/sites",
                  response = {
                    ["$ref"] = "ListSitesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                replace = {
                  description = "Replaces all of the sites under a single channel. The operation will replace the sites under a channel with the sites provided in ReplaceSitesRequest.new_sites.",
                  flatPath = "v1/partners/{partnerId}/channels/{channelsId}/sites:replace",
                  httpMethod = "POST",
                  id = "displayvideo.partners.channels.sites.replace",
                  parameterOrder = {
                    "partnerId",
                    "channelId",
                  },
                  parameters = {
                    channelId = {
                      description = "Required. The ID of the parent channel whose sites will be replaced.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "The ID of the partner that owns the parent channel.",
                      format = "int64",
                      location = "path",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{partnerId}/channels/{+channelId}/sites:replace",
                  request = {
                    ["$ref"] = "ReplaceSitesRequest",
                  },
                  response = {
                    ["$ref"] = "ReplaceSitesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
              },
            },
          },
        },
        targetingTypes = {
          resources = {
            assignedTargetingOptions = {
              methods = {
                create = {
                  description = "Assigns a targeting option to a partner. Returns the assigned targeting option if successful.",
                  flatPath = "v1/partners/{partnersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                  httpMethod = "POST",
                  id = "displayvideo.partners.targetingTypes.assignedTargetingOptions.create",
                  parameterOrder = {
                    "partnerId",
                    "targetingType",
                  },
                  parameters = {
                    partnerId = {
                      description = "Required. The ID of the partner.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_CHANNEL`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{+partnerId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                  request = {
                    ["$ref"] = "AssignedTargetingOption",
                  },
                  response = {
                    ["$ref"] = "AssignedTargetingOption",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                delete = {
                  description = "Deletes an assigned targeting option from a partner.",
                  flatPath = "v1/partners/{partnersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                  httpMethod = "DELETE",
                  id = "displayvideo.partners.targetingTypes.assignedTargetingOptions.delete",
                  parameterOrder = {
                    "partnerId",
                    "targetingType",
                    "assignedTargetingOptionId",
                  },
                  parameters = {
                    assignedTargetingOptionId = {
                      description = "Required. The ID of the assigned targeting option to delete.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "Required. The ID of the partner.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_CHANNEL`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{+partnerId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                  response = {
                    ["$ref"] = "Empty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                get = {
                  description = "Gets a single targeting option assigned to a partner.",
                  flatPath = "v1/partners/{partnersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions/{assignedTargetingOptionsId}",
                  httpMethod = "GET",
                  id = "displayvideo.partners.targetingTypes.assignedTargetingOptions.get",
                  parameterOrder = {
                    "partnerId",
                    "targetingType",
                    "assignedTargetingOptionId",
                  },
                  parameters = {
                    assignedTargetingOptionId = {
                      description = "Required. An identifier unique to the targeting type in this partner that identifies the assigned targeting option being requested.",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    partnerId = {
                      description = "Required. The ID of the partner.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of this assigned targeting option. Supported targeting types: * `TARGETING_TYPE_CHANNEL`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{+partnerId}/targetingTypes/{+targetingType}/assignedTargetingOptions/{+assignedTargetingOptionId}",
                  response = {
                    ["$ref"] = "AssignedTargetingOption",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
                list = {
                  description = "Lists the targeting options assigned to a partner.",
                  flatPath = "v1/partners/{partnersId}/targetingTypes/{targetingTypesId}/assignedTargetingOptions",
                  httpMethod = "GET",
                  id = "displayvideo.partners.targetingTypes.assignedTargetingOptions.list",
                  parameterOrder = {
                    "partnerId",
                    "targetingType",
                  },
                  parameters = {
                    filter = {
                      description = "Allows filtering by assigned targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `OR`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `EQUALS (=)`. * Supported fields: - `assignedTargetingOptionId` Examples: * AssignedTargetingOption with ID 123456 `assignedTargetingOptionId=\"123456\"` The length of this field should be no more than 500 characters.",
                      location = "query",
                      type = "string",
                    },
                    orderBy = {
                      description = "Field by which to sort the list. Acceptable values are: * `assignedTargetingOptionId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `assignedTargetingOptionId desc`.",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListPartnerAssignedTargetingOptions` method. If not specified, the first page of results will be returned.",
                      location = "query",
                      type = "string",
                    },
                    partnerId = {
                      description = "Required. The ID of the partner.",
                      format = "int64",
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                    targetingType = {
                      description = "Required. Identifies the type of assigned targeting options to list. Supported targeting types: * `TARGETING_TYPE_CHANNEL`",
                      enum = {
                        "TARGETING_TYPE_UNSPECIFIED",
                        "TARGETING_TYPE_CHANNEL",
                        "TARGETING_TYPE_APP_CATEGORY",
                        "TARGETING_TYPE_APP",
                        "TARGETING_TYPE_URL",
                        "TARGETING_TYPE_DAY_AND_TIME",
                        "TARGETING_TYPE_AGE_RANGE",
                        "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                        "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                        "TARGETING_TYPE_GENDER",
                        "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                        "TARGETING_TYPE_USER_REWARDED_CONTENT",
                        "TARGETING_TYPE_PARENTAL_STATUS",
                        "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                        "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                        "TARGETING_TYPE_DEVICE_TYPE",
                        "TARGETING_TYPE_AUDIENCE_GROUP",
                        "TARGETING_TYPE_BROWSER",
                        "TARGETING_TYPE_HOUSEHOLD_INCOME",
                        "TARGETING_TYPE_ON_SCREEN_POSITION",
                        "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                        "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                        "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                        "TARGETING_TYPE_ENVIRONMENT",
                        "TARGETING_TYPE_CARRIER_AND_ISP",
                        "TARGETING_TYPE_OPERATING_SYSTEM",
                        "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                        "TARGETING_TYPE_KEYWORD",
                        "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                        "TARGETING_TYPE_VIEWABILITY",
                        "TARGETING_TYPE_CATEGORY",
                        "TARGETING_TYPE_INVENTORY_SOURCE",
                        "TARGETING_TYPE_LANGUAGE",
                        "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                        "TARGETING_TYPE_GEO_REGION",
                        "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                        "TARGETING_TYPE_EXCHANGE",
                        "TARGETING_TYPE_SUB_EXCHANGE",
                        "TARGETING_TYPE_POI",
                        "TARGETING_TYPE_BUSINESS_CHAIN",
                        "TARGETING_TYPE_CONTENT_DURATION",
                        "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                        "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                        "TARGETING_TYPE_OMID",
                        "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                        "TARGETING_TYPE_CONTENT_GENRE",
                      },
                      enumDescriptions = {
                        "Default value when type is not specified or is unknown in this version.",
                        "Target a channel (a custom group of related websites or apps).",
                        "Target an app category (for example, education or puzzle games).",
                        "Target a specific app (for example, Angry Birds).",
                        "Target a specific url (for example, quora.com).",
                        "Target ads during a chosen time period on a specific day.",
                        "Target ads to a specific age range (for example, 18-24).",
                        "Target ads to the specified regions on a regional location list.",
                        "Target ads to the specified points of interest on a proximity location list.",
                        "Target ads to a specific gender (for example, female or male).",
                        "Target a specific video player size for video ads.",
                        "Target user rewarded content for video ads.",
                        "Target ads to a specific parental status (for example, parent or not a parent).",
                        "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                        "Target ads in a specific content outstream position.",
                        "Target ads to a specific device type (for example, tablet or connected TV).",
                        "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                        "Target ads to specific web browsers (for example, Chrome).",
                        "Target ads to a specific household income range (for example, top 10%).",
                        "Target ads in a specific on screen position.",
                        "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                        "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                        "Filter website content by sensitive categories (for example, adult).",
                        "Target ads to a specific environment (for example, web or app).",
                        "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                        "Target ads to a specific operating system (for example, macOS).",
                        "Target ads to a specific device make or model (for example, Roku or Samsung).",
                        "Target ads to a specific keyword (for example, dog or retriever).",
                        "Target ads to a specific negative keyword list.",
                        "Target ads to a specific viewability (for example, 80% viewable).",
                        "Target ads to a specific content category (for example, arts & entertainment).",
                        "Purchase impressions from specific deals and auction packages.",
                        "Target ads to a specific language (for example, English or Japanese).",
                        "Target ads to ads.txt authorized sellers.",
                        "Target ads to a specific regional location (for example, a city or state).",
                        "Purchase impressions from a group of deals and auction packages.",
                        "Purchase impressions from specific exchanges.",
                        "Purchase impressions from specific sub-exchanges.",
                        "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                        "Target ads around locations of a business chain within a specific geo region.",
                        "Target ads to a specific video content duration.",
                        "Target ads to a specific video content stream type.",
                        "Target ads to a specific native content position.",
                        "Target ads in an Open Measurement enabled inventory.",
                        "Target ads to a specific audio content type.",
                        "Target ads to a specific content genre.",
                      },
                      location = "path",
                      pattern = "^[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v1/partners/{+partnerId}/targetingTypes/{+targetingType}/assignedTargetingOptions",
                  response = {
                    ["$ref"] = "ListPartnerAssignedTargetingOptionsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/display-video",
                  },
                },
              },
            },
          },
        },
      },
    },
    sdfdownloadtasks = {
      methods = {
        create = {
          description = "Creates an SDF Download Task. Returns an Operation. An SDF Download Task is a long-running, asynchronous operation. The metadata type of this operation is SdfDownloadTaskMetadata. If the request is successful, the response type of the operation is SdfDownloadTask. The response will not include the download files, which must be retrieved with media.download. The state of operation can be retrieved with sdfdownloadtask.operations.get. Any errors can be found in the error.message. Note that error.details is expected to be empty.",
          flatPath = "v1/sdfdownloadtasks",
          httpMethod = "POST",
          id = "displayvideo.sdfdownloadtasks.create",
          parameterOrder = {},
          parameters = {},
          path = "v1/sdfdownloadtasks",
          request = {
            ["$ref"] = "CreateSdfDownloadTaskRequest",
          },
          response = {
            ["$ref"] = "Operation",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video",
          },
        },
      },
      resources = {
        operations = {
          methods = {
            get = {
              description = "Gets the latest state of an asynchronous SDF download task operation. Clients should poll this method at intervals of 30 seconds.",
              flatPath = "v1/sdfdownloadtasks/operations/{operationsId}",
              httpMethod = "GET",
              id = "displayvideo.sdfdownloadtasks.operations.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "The name of the operation resource.",
                  location = "path",
                  pattern = "^sdfdownloadtasks/operations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/{+name}",
              response = {
                ["$ref"] = "Operation",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
                "https://www.googleapis.com/auth/doubleclickbidmanager",
              },
            },
          },
        },
      },
    },
    targetingTypes = {
      resources = {
        targetingOptions = {
          methods = {
            get = {
              description = "Gets a single targeting option.",
              flatPath = "v1/targetingTypes/{targetingTypesId}/targetingOptions/{targetingOptionsId}",
              httpMethod = "GET",
              id = "displayvideo.targetingTypes.targetingOptions.get",
              parameterOrder = {
                "targetingType",
                "targetingOptionId",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The Advertiser this request is being made in the context of.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                targetingOptionId = {
                  description = "Required. The ID of the of targeting option to retrieve.",
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
                targetingType = {
                  description = "Required. The type of targeting option to retrieve. Accepted values are: * `TARGETING_TYPE_APP_CATEGORY` * `TARGETING_TYPE_AGE_RANGE` * `TARGETING_TYPE_GENDER` * `TARGETING_TYPE_VIDEO_PLAYER_SIZE` * `TARGETING_TYPE_USER_REWARDED_CONTENT` * `TARGETING_TYPE_PARENTAL_STATUS` * `TARGETING_TYPE_CONTENT_INSTREAM_POSITION` * `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION` * `TARGETING_TYPE_DEVICE_TYPE` * `TARGETING_TYPE_BROWSER` * `TARGETING_TYPE_HOUSEHOLD_INCOME` * `TARGETING_TYPE_ON_SCREEN_POSITION` * `TARGETING_TYPE_CARRIER_AND_ISP` * `TARGETING_TYPE_OPERATING_SYSTEM` * `TARGETING_TYPE_DEVICE_MAKE_MODEL` * `TARGETING_TYPE_ENVIRONMENT` * `TARGETING_TYPE_CATEGORY` * `TARGETING_TYPE_VIEWABILITY` * `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS` * `TARGETING_TYPE_LANGUAGE` * `TARGETING_TYPE_GEO_REGION` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION` * `TARGETING_TYPE_EXCHANGE` * `TARGETING_TYPE_SUB_EXCHANGE` * `TARGETING_TYPE_NATIVE_CONTENT_POSITION` * `TARGETING_TYPE_OMID`",
                  enum = {
                    "TARGETING_TYPE_UNSPECIFIED",
                    "TARGETING_TYPE_CHANNEL",
                    "TARGETING_TYPE_APP_CATEGORY",
                    "TARGETING_TYPE_APP",
                    "TARGETING_TYPE_URL",
                    "TARGETING_TYPE_DAY_AND_TIME",
                    "TARGETING_TYPE_AGE_RANGE",
                    "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                    "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                    "TARGETING_TYPE_GENDER",
                    "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                    "TARGETING_TYPE_USER_REWARDED_CONTENT",
                    "TARGETING_TYPE_PARENTAL_STATUS",
                    "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                    "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                    "TARGETING_TYPE_DEVICE_TYPE",
                    "TARGETING_TYPE_AUDIENCE_GROUP",
                    "TARGETING_TYPE_BROWSER",
                    "TARGETING_TYPE_HOUSEHOLD_INCOME",
                    "TARGETING_TYPE_ON_SCREEN_POSITION",
                    "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                    "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                    "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                    "TARGETING_TYPE_ENVIRONMENT",
                    "TARGETING_TYPE_CARRIER_AND_ISP",
                    "TARGETING_TYPE_OPERATING_SYSTEM",
                    "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                    "TARGETING_TYPE_KEYWORD",
                    "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                    "TARGETING_TYPE_VIEWABILITY",
                    "TARGETING_TYPE_CATEGORY",
                    "TARGETING_TYPE_INVENTORY_SOURCE",
                    "TARGETING_TYPE_LANGUAGE",
                    "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                    "TARGETING_TYPE_GEO_REGION",
                    "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                    "TARGETING_TYPE_EXCHANGE",
                    "TARGETING_TYPE_SUB_EXCHANGE",
                    "TARGETING_TYPE_POI",
                    "TARGETING_TYPE_BUSINESS_CHAIN",
                    "TARGETING_TYPE_CONTENT_DURATION",
                    "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                    "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                    "TARGETING_TYPE_OMID",
                    "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                    "TARGETING_TYPE_CONTENT_GENRE",
                  },
                  enumDescriptions = {
                    "Default value when type is not specified or is unknown in this version.",
                    "Target a channel (a custom group of related websites or apps).",
                    "Target an app category (for example, education or puzzle games).",
                    "Target a specific app (for example, Angry Birds).",
                    "Target a specific url (for example, quora.com).",
                    "Target ads during a chosen time period on a specific day.",
                    "Target ads to a specific age range (for example, 18-24).",
                    "Target ads to the specified regions on a regional location list.",
                    "Target ads to the specified points of interest on a proximity location list.",
                    "Target ads to a specific gender (for example, female or male).",
                    "Target a specific video player size for video ads.",
                    "Target user rewarded content for video ads.",
                    "Target ads to a specific parental status (for example, parent or not a parent).",
                    "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                    "Target ads in a specific content outstream position.",
                    "Target ads to a specific device type (for example, tablet or connected TV).",
                    "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                    "Target ads to specific web browsers (for example, Chrome).",
                    "Target ads to a specific household income range (for example, top 10%).",
                    "Target ads in a specific on screen position.",
                    "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                    "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                    "Filter website content by sensitive categories (for example, adult).",
                    "Target ads to a specific environment (for example, web or app).",
                    "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                    "Target ads to a specific operating system (for example, macOS).",
                    "Target ads to a specific device make or model (for example, Roku or Samsung).",
                    "Target ads to a specific keyword (for example, dog or retriever).",
                    "Target ads to a specific negative keyword list.",
                    "Target ads to a specific viewability (for example, 80% viewable).",
                    "Target ads to a specific content category (for example, arts & entertainment).",
                    "Purchase impressions from specific deals and auction packages.",
                    "Target ads to a specific language (for example, English or Japanese).",
                    "Target ads to ads.txt authorized sellers.",
                    "Target ads to a specific regional location (for example, a city or state).",
                    "Purchase impressions from a group of deals and auction packages.",
                    "Purchase impressions from specific exchanges.",
                    "Purchase impressions from specific sub-exchanges.",
                    "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                    "Target ads around locations of a business chain within a specific geo region.",
                    "Target ads to a specific video content duration.",
                    "Target ads to a specific video content stream type.",
                    "Target ads to a specific native content position.",
                    "Target ads in an Open Measurement enabled inventory.",
                    "Target ads to a specific audio content type.",
                    "Target ads to a specific content genre.",
                  },
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/targetingTypes/{+targetingType}/targetingOptions/{+targetingOptionId}",
              response = {
                ["$ref"] = "TargetingOption",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            list = {
              description = "Lists targeting options of a given type.",
              flatPath = "v1/targetingTypes/{targetingTypesId}/targetingOptions",
              httpMethod = "GET",
              id = "displayvideo.targetingTypes.targetingOptions.list",
              parameterOrder = {
                "targetingType",
              },
              parameters = {
                advertiserId = {
                  description = "Required. The Advertiser this request is being made in the context of.",
                  format = "int64",
                  location = "query",
                  type = "string",
                },
                filter = {
                  description = "Allows filtering by targeting option properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by `OR` logical operators. * A restriction has the form of `{field} {operator} {value}`. * The operator must be \"=\" (equal sign). * Supported fields: - `carrierAndIspDetails.type` - `geoRegionDetails.geoRegionType` - `targetingOptionId` Examples: * All `GEO REGION` targeting options that belong to sub type `GEO_REGION_TYPE_COUNTRY` or `GEO_REGION_TYPE_STATE`: `geoRegionDetails.geoRegionType=\"GEO_REGION_TYPE_COUNTRY\" OR geoRegionDetails.geoRegionType=\"GEO_REGION_TYPE_STATE\"` * All `CARRIER AND ISP` targeting options that belong to sub type `CARRIER_AND_ISP_TYPE_CARRIER`: `carrierAndIspDetails.type=\"CARRIER_AND_ISP_TYPE_CARRIER\"`. The length of this field should be no more than 500 characters.",
                  location = "query",
                  type = "string",
                },
                orderBy = {
                  description = "Field by which to sort the list. Acceptable values are: * `targetingOptionId` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. Example: `targetingOptionId desc`.",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListTargetingOptions` method. If not specified, the first page of results will be returned.",
                  location = "query",
                  type = "string",
                },
                targetingType = {
                  description = "Required. The type of targeting option to be listed. Accepted values are: * `TARGETING_TYPE_APP_CATEGORY` * `TARGETING_TYPE_AGE_RANGE` * `TARGETING_TYPE_GENDER` * `TARGETING_TYPE_VIDEO_PLAYER_SIZE` * `TARGETING_TYPE_USER_REWARDED_CONTENT` * `TARGETING_TYPE_PARENTAL_STATUS` * `TARGETING_TYPE_CONTENT_INSTREAM_POSITION` * `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION` * `TARGETING_TYPE_DEVICE_TYPE` * `TARGETING_TYPE_BROWSER` * `TARGETING_TYPE_HOUSEHOLD_INCOME` * `TARGETING_TYPE_ON_SCREEN_POSITION` * `TARGETING_TYPE_CARRIER_AND_ISP` * `TARGETING_TYPE_OPERATING_SYSTEM` * `TARGETING_TYPE_DEVICE_MAKE_MODEL` * `TARGETING_TYPE_ENVIRONMENT` * `TARGETING_TYPE_CATEGORY` * `TARGETING_TYPE_VIEWABILITY` * `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS` * `TARGETING_TYPE_LANGUAGE` * `TARGETING_TYPE_GEO_REGION` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION` * `TARGETING_TYPE_EXCHANGE` * `TARGETING_TYPE_SUB_EXCHANGE` * `TARGETING_TYPE_NATIVE_CONTENT_POSITION` * `TARGETING_TYPE_OMID`",
                  enum = {
                    "TARGETING_TYPE_UNSPECIFIED",
                    "TARGETING_TYPE_CHANNEL",
                    "TARGETING_TYPE_APP_CATEGORY",
                    "TARGETING_TYPE_APP",
                    "TARGETING_TYPE_URL",
                    "TARGETING_TYPE_DAY_AND_TIME",
                    "TARGETING_TYPE_AGE_RANGE",
                    "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                    "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                    "TARGETING_TYPE_GENDER",
                    "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                    "TARGETING_TYPE_USER_REWARDED_CONTENT",
                    "TARGETING_TYPE_PARENTAL_STATUS",
                    "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                    "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                    "TARGETING_TYPE_DEVICE_TYPE",
                    "TARGETING_TYPE_AUDIENCE_GROUP",
                    "TARGETING_TYPE_BROWSER",
                    "TARGETING_TYPE_HOUSEHOLD_INCOME",
                    "TARGETING_TYPE_ON_SCREEN_POSITION",
                    "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                    "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                    "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                    "TARGETING_TYPE_ENVIRONMENT",
                    "TARGETING_TYPE_CARRIER_AND_ISP",
                    "TARGETING_TYPE_OPERATING_SYSTEM",
                    "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                    "TARGETING_TYPE_KEYWORD",
                    "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                    "TARGETING_TYPE_VIEWABILITY",
                    "TARGETING_TYPE_CATEGORY",
                    "TARGETING_TYPE_INVENTORY_SOURCE",
                    "TARGETING_TYPE_LANGUAGE",
                    "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                    "TARGETING_TYPE_GEO_REGION",
                    "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                    "TARGETING_TYPE_EXCHANGE",
                    "TARGETING_TYPE_SUB_EXCHANGE",
                    "TARGETING_TYPE_POI",
                    "TARGETING_TYPE_BUSINESS_CHAIN",
                    "TARGETING_TYPE_CONTENT_DURATION",
                    "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                    "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                    "TARGETING_TYPE_OMID",
                    "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                    "TARGETING_TYPE_CONTENT_GENRE",
                  },
                  enumDescriptions = {
                    "Default value when type is not specified or is unknown in this version.",
                    "Target a channel (a custom group of related websites or apps).",
                    "Target an app category (for example, education or puzzle games).",
                    "Target a specific app (for example, Angry Birds).",
                    "Target a specific url (for example, quora.com).",
                    "Target ads during a chosen time period on a specific day.",
                    "Target ads to a specific age range (for example, 18-24).",
                    "Target ads to the specified regions on a regional location list.",
                    "Target ads to the specified points of interest on a proximity location list.",
                    "Target ads to a specific gender (for example, female or male).",
                    "Target a specific video player size for video ads.",
                    "Target user rewarded content for video ads.",
                    "Target ads to a specific parental status (for example, parent or not a parent).",
                    "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                    "Target ads in a specific content outstream position.",
                    "Target ads to a specific device type (for example, tablet or connected TV).",
                    "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                    "Target ads to specific web browsers (for example, Chrome).",
                    "Target ads to a specific household income range (for example, top 10%).",
                    "Target ads in a specific on screen position.",
                    "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                    "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                    "Filter website content by sensitive categories (for example, adult).",
                    "Target ads to a specific environment (for example, web or app).",
                    "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                    "Target ads to a specific operating system (for example, macOS).",
                    "Target ads to a specific device make or model (for example, Roku or Samsung).",
                    "Target ads to a specific keyword (for example, dog or retriever).",
                    "Target ads to a specific negative keyword list.",
                    "Target ads to a specific viewability (for example, 80% viewable).",
                    "Target ads to a specific content category (for example, arts & entertainment).",
                    "Purchase impressions from specific deals and auction packages.",
                    "Target ads to a specific language (for example, English or Japanese).",
                    "Target ads to ads.txt authorized sellers.",
                    "Target ads to a specific regional location (for example, a city or state).",
                    "Purchase impressions from a group of deals and auction packages.",
                    "Purchase impressions from specific exchanges.",
                    "Purchase impressions from specific sub-exchanges.",
                    "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                    "Target ads around locations of a business chain within a specific geo region.",
                    "Target ads to a specific video content duration.",
                    "Target ads to a specific video content stream type.",
                    "Target ads to a specific native content position.",
                    "Target ads in an Open Measurement enabled inventory.",
                    "Target ads to a specific audio content type.",
                    "Target ads to a specific content genre.",
                  },
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/targetingTypes/{+targetingType}/targetingOptions",
              response = {
                ["$ref"] = "ListTargetingOptionsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
            search = {
              description = "Searches for targeting options of a given type based on the given search terms.",
              flatPath = "v1/targetingTypes/{targetingTypesId}/targetingOptions:search",
              httpMethod = "POST",
              id = "displayvideo.targetingTypes.targetingOptions.search",
              parameterOrder = {
                "targetingType",
              },
              parameters = {
                targetingType = {
                  description = "Required. The type of targeting options to retrieve. Accepted values are: * `TARGETING_TYPE_GEO_REGION` * `TARGETING_TYPE_POI` * `TARGETING_TYPE_BUSINESS_CHAIN`",
                  enum = {
                    "TARGETING_TYPE_UNSPECIFIED",
                    "TARGETING_TYPE_CHANNEL",
                    "TARGETING_TYPE_APP_CATEGORY",
                    "TARGETING_TYPE_APP",
                    "TARGETING_TYPE_URL",
                    "TARGETING_TYPE_DAY_AND_TIME",
                    "TARGETING_TYPE_AGE_RANGE",
                    "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
                    "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
                    "TARGETING_TYPE_GENDER",
                    "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
                    "TARGETING_TYPE_USER_REWARDED_CONTENT",
                    "TARGETING_TYPE_PARENTAL_STATUS",
                    "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
                    "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
                    "TARGETING_TYPE_DEVICE_TYPE",
                    "TARGETING_TYPE_AUDIENCE_GROUP",
                    "TARGETING_TYPE_BROWSER",
                    "TARGETING_TYPE_HOUSEHOLD_INCOME",
                    "TARGETING_TYPE_ON_SCREEN_POSITION",
                    "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
                    "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
                    "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
                    "TARGETING_TYPE_ENVIRONMENT",
                    "TARGETING_TYPE_CARRIER_AND_ISP",
                    "TARGETING_TYPE_OPERATING_SYSTEM",
                    "TARGETING_TYPE_DEVICE_MAKE_MODEL",
                    "TARGETING_TYPE_KEYWORD",
                    "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
                    "TARGETING_TYPE_VIEWABILITY",
                    "TARGETING_TYPE_CATEGORY",
                    "TARGETING_TYPE_INVENTORY_SOURCE",
                    "TARGETING_TYPE_LANGUAGE",
                    "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
                    "TARGETING_TYPE_GEO_REGION",
                    "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
                    "TARGETING_TYPE_EXCHANGE",
                    "TARGETING_TYPE_SUB_EXCHANGE",
                    "TARGETING_TYPE_POI",
                    "TARGETING_TYPE_BUSINESS_CHAIN",
                    "TARGETING_TYPE_CONTENT_DURATION",
                    "TARGETING_TYPE_CONTENT_STREAM_TYPE",
                    "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
                    "TARGETING_TYPE_OMID",
                    "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
                    "TARGETING_TYPE_CONTENT_GENRE",
                  },
                  enumDescriptions = {
                    "Default value when type is not specified or is unknown in this version.",
                    "Target a channel (a custom group of related websites or apps).",
                    "Target an app category (for example, education or puzzle games).",
                    "Target a specific app (for example, Angry Birds).",
                    "Target a specific url (for example, quora.com).",
                    "Target ads during a chosen time period on a specific day.",
                    "Target ads to a specific age range (for example, 18-24).",
                    "Target ads to the specified regions on a regional location list.",
                    "Target ads to the specified points of interest on a proximity location list.",
                    "Target ads to a specific gender (for example, female or male).",
                    "Target a specific video player size for video ads.",
                    "Target user rewarded content for video ads.",
                    "Target ads to a specific parental status (for example, parent or not a parent).",
                    "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
                    "Target ads in a specific content outstream position.",
                    "Target ads to a specific device type (for example, tablet or connected TV).",
                    "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
                    "Target ads to specific web browsers (for example, Chrome).",
                    "Target ads to a specific household income range (for example, top 10%).",
                    "Target ads in a specific on screen position.",
                    "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
                    "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
                    "Filter website content by sensitive categories (for example, adult).",
                    "Target ads to a specific environment (for example, web or app).",
                    "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
                    "Target ads to a specific operating system (for example, macOS).",
                    "Target ads to a specific device make or model (for example, Roku or Samsung).",
                    "Target ads to a specific keyword (for example, dog or retriever).",
                    "Target ads to a specific negative keyword list.",
                    "Target ads to a specific viewability (for example, 80% viewable).",
                    "Target ads to a specific content category (for example, arts & entertainment).",
                    "Purchase impressions from specific deals and auction packages.",
                    "Target ads to a specific language (for example, English or Japanese).",
                    "Target ads to ads.txt authorized sellers.",
                    "Target ads to a specific regional location (for example, a city or state).",
                    "Purchase impressions from a group of deals and auction packages.",
                    "Purchase impressions from specific exchanges.",
                    "Purchase impressions from specific sub-exchanges.",
                    "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
                    "Target ads around locations of a business chain within a specific geo region.",
                    "Target ads to a specific video content duration.",
                    "Target ads to a specific video content stream type.",
                    "Target ads to a specific native content position.",
                    "Target ads in an Open Measurement enabled inventory.",
                    "Target ads to a specific audio content type.",
                    "Target ads to a specific content genre.",
                  },
                  location = "path",
                  pattern = "^[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v1/targetingTypes/{+targetingType}/targetingOptions:search",
              request = {
                ["$ref"] = "SearchTargetingOptionsRequest",
              },
              response = {
                ["$ref"] = "SearchTargetingOptionsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/display-video",
              },
            },
          },
        },
      },
    },
    users = {
      methods = {
        bulkEditAssignedUserRoles = {
          description = "Bulk edits user roles for a user. The operation will delete the assigned user roles provided in BulkEditAssignedUserRolesRequest.deletedAssignedUserRoles and then assign the user roles provided in BulkEditAssignedUserRolesRequest.createdAssignedUserRoles.",
          flatPath = "v1/users/{usersId}:bulkEditAssignedUserRoles",
          httpMethod = "POST",
          id = "displayvideo.users.bulkEditAssignedUserRoles",
          parameterOrder = {
            "userId",
          },
          parameters = {
            userId = {
              description = "Required. The ID of the user to which the assigned user roles belong.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/users/{+userId}:bulkEditAssignedUserRoles",
          request = {
            ["$ref"] = "BulkEditAssignedUserRolesRequest",
          },
          response = {
            ["$ref"] = "BulkEditAssignedUserRolesResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video-user-management",
          },
        },
        create = {
          description = "Creates a new user. Returns the newly created user if successful.",
          flatPath = "v1/users",
          httpMethod = "POST",
          id = "displayvideo.users.create",
          parameterOrder = {},
          parameters = {},
          path = "v1/users",
          request = {
            ["$ref"] = "User",
          },
          response = {
            ["$ref"] = "User",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video-user-management",
          },
        },
        delete = {
          description = "Deletes a user.",
          flatPath = "v1/users/{usersId}",
          httpMethod = "DELETE",
          id = "displayvideo.users.delete",
          parameterOrder = {
            "userId",
          },
          parameters = {
            userId = {
              description = "Required. The ID of the user to delete.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/users/{+userId}",
          response = {
            ["$ref"] = "Empty",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video-user-management",
          },
        },
        get = {
          description = "Gets a user.",
          flatPath = "v1/users/{usersId}",
          httpMethod = "GET",
          id = "displayvideo.users.get",
          parameterOrder = {
            "userId",
          },
          parameters = {
            userId = {
              description = "Required. The ID of the user to fetch.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/users/{+userId}",
          response = {
            ["$ref"] = "User",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video-user-management",
          },
        },
        list = {
          description = "Lists users that are accessible to the current user. If two users have user roles on the same partner or advertiser, they can access each other.",
          flatPath = "v1/users",
          httpMethod = "GET",
          id = "displayvideo.users.list",
          parameterOrder = {},
          parameters = {
            filter = {
              description = "Allows filtering by user properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator `AND`. * A restriction has the form of `{field} {operator} {value}`. * The operator must be `CONTAINS (:)` or `EQUALS (=)`. * The operator must be `CONTAINS (:)` for the following fields: - `displayName` - `email` * The operator must be `EQUALS (=)` for the following fields: - `assignedUserRole.userRole` - `assignedUserRole.partnerId` - `assignedUserRole.advertiserId` - `assignedUserRole.entityType`: A synthetic field of AssignedUserRole used for filtering. Identifies the type of entity to which the user role is assigned. Valid values are `Partner` and `Advertiser`. - `assignedUserRole.parentPartnerId`: A synthetic field of AssignedUserRole used for filtering. Identifies the parent partner of the entity to which the user role is assigned.\" Examples: * The user with displayName containing `foo`: `displayName:\"foo\"` * The user with email containing `bar`: `email:\"bar\"` * All users with standard user roles: `assignedUserRole.userRole=\"STANDARD\"` * All users with user roles for partner 123: `assignedUserRole.partnerId=\"123\"` * All users with user roles for advertiser 123: `assignedUserRole.advertiserId=\"123\"` * All users with partner level user roles: `entityType=\"PARTNER\"` * All users with user roles for partner 123 and advertisers under partner 123: `parentPartnerId=\"123\"` The length of this field should be no more than 500 characters.",
              location = "query",
              type = "string",
            },
            orderBy = {
              description = "Field by which to sort the list. Acceptable values are: * `displayName` (default) The default sorting order is ascending. To specify descending order for a field, a suffix \"desc\" should be added to the field name. For example, `displayName desc`.",
              location = "query",
              type = "string",
            },
            pageSize = {
              description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`.",
              format = "int32",
              location = "query",
              type = "integer",
            },
            pageToken = {
              description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `ListUsers` method. If not specified, the first page of results will be returned.",
              location = "query",
              type = "string",
            },
          },
          path = "v1/users",
          response = {
            ["$ref"] = "ListUsersResponse",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video-user-management",
          },
        },
        patch = {
          description = "Updates an existing user. Returns the updated user if successful.",
          flatPath = "v1/users/{usersId}",
          httpMethod = "PATCH",
          id = "displayvideo.users.patch",
          parameterOrder = {
            "userId",
          },
          parameters = {
            updateMask = {
              description = "Required. The mask to control which fields to update.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
            userId = {
              description = "Output only. The unique ID of the user. Assigned by the system.",
              format = "int64",
              location = "path",
              pattern = "^[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v1/users/{+userId}",
          request = {
            ["$ref"] = "User",
          },
          response = {
            ["$ref"] = "User",
          },
          scopes = {
            "https://www.googleapis.com/auth/display-video-user-management",
          },
        },
      },
    },
  },
  revision = "20230111",
  rootUrl = "https://displayvideo.googleapis.com/",
  schemas = {
    ActivateManualTriggerRequest = {
      description = "Request message for ManualTriggerService.ActivateManualTrigger.",
      id = "ActivateManualTriggerRequest",
      properties = {},
      type = "object",
    },
    ActiveViewVideoViewabilityMetricConfig = {
      description = "Configuration for custom Active View video viewability metrics.",
      id = "ActiveViewVideoViewabilityMetricConfig",
      properties = {
        displayName = {
          description = "Required. The display name of the custom metric.",
          type = "string",
        },
        minimumDuration = {
          description = "The minimum visible video duration required (in seconds) in order for an impression to be recorded. You must specify minimum_duration, minimum_quartile or both. If both are specified, an impression meets the metric criteria if either requirement is met (whichever happens first).",
          enum = {
            "VIDEO_DURATION_UNSPECIFIED",
            "VIDEO_DURATION_SECONDS_NONE",
            "VIDEO_DURATION_SECONDS_0",
            "VIDEO_DURATION_SECONDS_1",
            "VIDEO_DURATION_SECONDS_2",
            "VIDEO_DURATION_SECONDS_3",
            "VIDEO_DURATION_SECONDS_4",
            "VIDEO_DURATION_SECONDS_5",
            "VIDEO_DURATION_SECONDS_6",
            "VIDEO_DURATION_SECONDS_7",
            "VIDEO_DURATION_SECONDS_8",
            "VIDEO_DURATION_SECONDS_9",
            "VIDEO_DURATION_SECONDS_10",
            "VIDEO_DURATION_SECONDS_11",
            "VIDEO_DURATION_SECONDS_12",
            "VIDEO_DURATION_SECONDS_13",
            "VIDEO_DURATION_SECONDS_14",
            "VIDEO_DURATION_SECONDS_15",
            "VIDEO_DURATION_SECONDS_30",
            "VIDEO_DURATION_SECONDS_45",
            "VIDEO_DURATION_SECONDS_60",
          },
          enumDescriptions = {
            "Value is not specified or is unknown in this version.",
            "No duration value.",
            "0 seconds.",
            "1 second.",
            "2 seconds.",
            "3 seconds.",
            "4 seconds.",
            "5 seconds.",
            "6 seconds.",
            "7 seconds.",
            "8 seconds.",
            "9 seconds.",
            "10 seconds.",
            "11 seconds.",
            "12 seconds.",
            "13 seconds.",
            "14 seconds.",
            "15 seconds.",
            "30 seconds.",
            "45 seconds.",
            "60 seconds.",
          },
          type = "string",
        },
        minimumQuartile = {
          description = "The minimum visible video duration required, based on the video quartiles, in order for an impression to be recorded. You must specify minimum_duration, minimum_quartile or both. If both are specified, an impression meets the metric criteria if either requirement is met (whichever happens first).",
          enum = {
            "VIDEO_DURATION_QUARTILE_UNSPECIFIED",
            "VIDEO_DURATION_QUARTILE_NONE",
            "VIDEO_DURATION_QUARTILE_FIRST",
            "VIDEO_DURATION_QUARTILE_SECOND",
            "VIDEO_DURATION_QUARTILE_THIRD",
            "VIDEO_DURATION_QUARTILE_FOURTH",
          },
          enumDescriptions = {
            "Value is not specified or is unknown in this version.",
            "No quartile value.",
            "First quartile.",
            "Second quartile (midpoint).",
            "Third quartile.",
            "Fourth quartile (completion).",
          },
          type = "string",
        },
        minimumViewability = {
          description = "Required. The minimum percentage of the video ad's pixels visible on the screen in order for an impression to be recorded.",
          enum = {
            "VIEWABILITY_PERCENT_UNSPECIFIED",
            "VIEWABILITY_PERCENT_0",
            "VIEWABILITY_PERCENT_25",
            "VIEWABILITY_PERCENT_50",
            "VIEWABILITY_PERCENT_75",
            "VIEWABILITY_PERCENT_100",
          },
          enumDescriptions = {
            "Value is not specified or is unknown in this version.",
            "0% viewable.",
            "25% viewable.",
            "50% viewable.",
            "75% viewable.",
            "100% viewable.",
          },
          type = "string",
        },
        minimumVolume = {
          description = "Required. The minimum percentage of the video ad's volume required in order for an impression to be recorded.",
          enum = {
            "VIDEO_VOLUME_PERCENT_UNSPECIFIED",
            "VIDEO_VOLUME_PERCENT_0",
            "VIDEO_VOLUME_PERCENT_10",
          },
          enumDescriptions = {
            "Value is not specified or is unknown in this version.",
            "0% volume.",
            "10% volume.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Adloox = {
      description = "Details of Adloox settings.",
      id = "Adloox",
      properties = {
        excludedAdlooxCategories = {
          description = "Adloox's brand safety settings.",
          items = {
            enum = {
              "ADLOOX_UNSPECIFIED",
              "ADULT_CONTENT_HARD",
              "ADULT_CONTENT_SOFT",
              "ILLEGAL_CONTENT",
              "BORDERLINE_CONTENT",
              "DISCRIMINATORY_CONTENT",
              "VIOLENT_CONTENT_WEAPONS",
              "LOW_VIEWABILITY_DOMAINS",
              "FRAUD",
            },
            enumDescriptions = {
              "This enum is only a placeholder and it doesn't specify any Adloox option.",
              "Adult content (hard).",
              "Adult content (soft).",
              "Illegal content.",
              "Borderline content.",
              "Discriminatory content.",
              "Violent content & weapons.",
              "Low viewability domains.",
              "Fraud.",
            },
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    Advertiser = {
      description = "A single advertiser in Display & Video 360 (DV360).",
      id = "Advertiser",
      properties = {
        adServerConfig = {
          ["$ref"] = "AdvertiserAdServerConfig",
          description = "Required. Immutable. Ad server related settings of the advertiser.",
        },
        advertiserId = {
          description = "Output only. The unique ID of the advertiser. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        creativeConfig = {
          ["$ref"] = "AdvertiserCreativeConfig",
          description = "Required. Creative related settings of the advertiser.",
        },
        dataAccessConfig = {
          ["$ref"] = "AdvertiserDataAccessConfig",
          description = "Settings that control how advertiser data may be accessed.",
        },
        displayName = {
          description = "Required. The display name of the advertiser. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        entityStatus = {
          description = "Required. Controls whether or not insertion orders and line items of the advertiser can spend their budgets and bid on inventory. * Accepted values are `ENTITY_STATUS_ACTIVE`, `ENTITY_STATUS_PAUSED` and `ENTITY_STATUS_SCHEDULED_FOR_DELETION`. * If set to `ENTITY_STATUS_SCHEDULED_FOR_DELETION`, the advertiser will be deleted 30 days from when it was first scheduled for deletion.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        generalConfig = {
          ["$ref"] = "AdvertiserGeneralConfig",
          description = "Required. General settings of the advertiser.",
        },
        integrationDetails = {
          ["$ref"] = "IntegrationDetails",
          description = "Integration details of the advertiser. Only integrationCode is currently applicable to advertiser. Other fields of IntegrationDetails are not supported and will be ignored if provided.",
        },
        name = {
          description = "Output only. The resource name of the advertiser.",
          readOnly = true,
          type = "string",
        },
        partnerId = {
          description = "Required. Immutable. The unique ID of the partner that the advertiser belongs to.",
          format = "int64",
          type = "string",
        },
        prismaEnabled = {
          description = "Whether integration with Mediaocean (Prisma) is enabled. By enabling this, you agree to the following: On behalf of my company, I authorize Mediaocean (Prisma) to send budget segment plans to Google, and I authorize Google to send corresponding reporting and invoices from DV360 to Mediaocean for the purposes of budget planning, billing, and reconciliation for this advertiser.",
          type = "boolean",
        },
        servingConfig = {
          ["$ref"] = "AdvertiserTargetingConfig",
          description = "Targeting settings related to ad serving of the advertiser.",
        },
        updateTime = {
          description = "Output only. The timestamp when the advertiser was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    AdvertiserAdServerConfig = {
      description = "Ad server related settings of an advertiser.",
      id = "AdvertiserAdServerConfig",
      properties = {
        cmHybridConfig = {
          ["$ref"] = "CmHybridConfig",
          description = "The configuration for advertisers that use both Campaign Manager 360 (CM360) and third-party ad servers.",
        },
        thirdPartyOnlyConfig = {
          ["$ref"] = "ThirdPartyOnlyConfig",
          description = "The configuration for advertisers that use third-party ad servers only.",
        },
      },
      type = "object",
    },
    AdvertiserCreativeConfig = {
      description = "Creatives related settings of an advertiser.",
      id = "AdvertiserCreativeConfig",
      properties = {
        dynamicCreativeEnabled = {
          description = "Whether or not the advertiser is enabled for dynamic creatives.",
          type = "boolean",
        },
        iasClientId = {
          description = "An ID for configuring campaign monitoring provided by Integral Ad Service (IAS). The DV360 system will append an IAS \"Campaign Monitor\" tag containing this ID to the creative tag.",
          format = "int64",
          type = "string",
        },
        obaComplianceDisabled = {
          description = "Whether or not to use DV360's Online Behavioral Advertising (OBA) compliance. Warning: Changing OBA settings may cause the audit status of your creatives to be reset by some ad exchanges, making them ineligible to serve until they are re-approved.",
          type = "boolean",
        },
        videoCreativeDataSharingAuthorized = {
          description = "By setting this field to `true`, you, on behalf of your company, authorize Google to use video creatives associated with this Display & Video 360 advertiser to provide reporting and features related to the advertiser's television campaigns. Applicable only when the advertiser has a CM360 hybrid ad server configuration.",
          type = "boolean",
        },
      },
      type = "object",
    },
    AdvertiserDataAccessConfig = {
      description = "Settings that control how advertiser related data may be accessed.",
      id = "AdvertiserDataAccessConfig",
      properties = {
        sdfConfig = {
          ["$ref"] = "AdvertiserSdfConfig",
          description = "Structured Data Files (SDF) settings for the advertiser. If not specified, the SDF settings of the parent partner are used.",
        },
      },
      type = "object",
    },
    AdvertiserGeneralConfig = {
      description = "General settings of an advertiser.",
      id = "AdvertiserGeneralConfig",
      properties = {
        currencyCode = {
          description = "Required. Immutable. Advertiser's currency in ISO 4217 format. Accepted codes and the currencies they represent are: Currency Code : Currency Name * `ARS` : Argentine Peso * `AUD` : Australian Dollar * `BRL` : Brazilian Real * `CAD` : Canadian Dollar * `CHF` : Swiss Franc * `CLP` : Chilean Peso * `CNY` : Chinese Yuan * `COP` : Colombian Peso * `CZK` : Czech Koruna * `DKK` : Danish Krone * `EGP` : Egyption Pound * `EUR` : Euro * `GBP` : British Pound * `HKD` : Hong Kong Dollar * `HUF` : Hungarian Forint * `IDR` : Indonesian Rupiah * `ILS` : Israeli Shekel * `INR` : Indian Rupee * `JPY` : Japanese Yen * `KRW` : South Korean Won * `MXN` : Mexican Pesos * `MYR` : Malaysian Ringgit * `NGN` : Nigerian Naira * `NOK` : Norwegian Krone * `NZD` : New Zealand Dollar * `PEN` : Peruvian Nuevo Sol * `PLN` : Polish Zloty * `RON` : New Romanian Leu * `RUB` : Russian Ruble * `SEK` : Swedish Krona * `TRY` : Turkish Lira * `TWD` : New Taiwan Dollar * `USD` : US Dollar * `ZAR` : South African Rand",
          type = "string",
        },
        domainUrl = {
          description = "Required. The domain URL of the advertiser's primary website. The system will send this information to publishers that require website URL to associate a campaign with an advertiser. Provide a URL with no path or query string, beginning with `http:` or `https:`. For example, http://www.example.com",
          type = "string",
        },
        timeZone = {
          description = "Output only. The standard TZ database name of the advertiser's time zone. For example, `America/New_York`. See more at: https://en.wikipedia.org/wiki/List_of_tz_database_time_zones For CM360 hybrid advertisers, the time zone is the same as that of the associated CM360 account; for third-party only advertisers, the time zone is the same as that of the parent partner.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    AdvertiserSdfConfig = {
      description = "Structured Data Files (SDF) settings of an advertiser.",
      id = "AdvertiserSdfConfig",
      properties = {
        overridePartnerSdfConfig = {
          description = "Whether or not this advertiser overrides the SDF configuration of its parent partner. By default, an advertiser inherits the SDF configuration from the parent partner. To override the partner configuration, set this field to `true` and provide the new configuration in sdfConfig.",
          type = "boolean",
        },
        sdfConfig = {
          ["$ref"] = "SdfConfig",
          description = "The SDF configuration for the advertiser. * Required when overridePartnerSdfConfig is `true`. * Output only when overridePartnerSdfConfig is `false`.",
        },
      },
      type = "object",
    },
    AdvertiserTargetingConfig = {
      description = "Targeting settings related to ad serving of an advertiser.",
      id = "AdvertiserTargetingConfig",
      properties = {
        exemptTvFromViewabilityTargeting = {
          description = "Whether or not connected TV devices are exempt from viewability targeting for all video line items under the advertiser.",
          type = "boolean",
        },
      },
      type = "object",
    },
    AgeRangeAssignedTargetingOptionDetails = {
      description = "Represents a targetable age range. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_AGE_RANGE`.",
      id = "AgeRangeAssignedTargetingOptionDetails",
      properties = {
        ageRange = {
          description = "The age range of an audience. We only support targeting a continuous age range of an audience. Thus, the age range represented in this field can be 1) targeted solely, or, 2) part of a larger continuous age range. The reach of a continuous age range targeting can be expanded by also targeting an audience of an unknown age. Output only in v1. Required in v2.",
          enum = {
            "AGE_RANGE_UNSPECIFIED",
            "AGE_RANGE_18_24",
            "AGE_RANGE_25_34",
            "AGE_RANGE_35_44",
            "AGE_RANGE_45_54",
            "AGE_RANGE_55_64",
            "AGE_RANGE_65_PLUS",
            "AGE_RANGE_UNKNOWN",
          },
          enumDescriptions = {
            "Default value when age range is not specified in this version. This enum is a placeholder for default value and does not represent a real age range option.",
            "The age range of the audience is 18 to 24.",
            "The age range of the audience is 25 to 34.",
            "The age range of the audience is 35 to 44.",
            "The age range of the audience is 45 to 54.",
            "The age range of the audience is 55 to 64.",
            "The age range of the audience is 65 and up.",
            "The age range of the audience is unknown.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_AGE_RANGE`.",
          type = "string",
        },
      },
      type = "object",
    },
    AgeRangeTargetingOptionDetails = {
      description = "Represents a targetable age range. This will be populated in the age_range_details field when targeting_type is `TARGETING_TYPE_AGE_RANGE`.",
      id = "AgeRangeTargetingOptionDetails",
      properties = {
        ageRange = {
          description = "Output only. The age range of an audience.",
          enum = {
            "AGE_RANGE_UNSPECIFIED",
            "AGE_RANGE_18_24",
            "AGE_RANGE_25_34",
            "AGE_RANGE_35_44",
            "AGE_RANGE_45_54",
            "AGE_RANGE_55_64",
            "AGE_RANGE_65_PLUS",
            "AGE_RANGE_UNKNOWN",
          },
          enumDescriptions = {
            "Default value when age range is not specified in this version. This enum is a placeholder for default value and does not represent a real age range option.",
            "The age range of the audience is 18 to 24.",
            "The age range of the audience is 25 to 34.",
            "The age range of the audience is 35 to 44.",
            "The age range of the audience is 45 to 54.",
            "The age range of the audience is 55 to 64.",
            "The age range of the audience is 65 and up.",
            "The age range of the audience is unknown.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    AppAssignedTargetingOptionDetails = {
      description = "Details for assigned app targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_APP`.",
      id = "AppAssignedTargetingOptionDetails",
      properties = {
        appId = {
          description = "Required. The ID of the app. Android's Play store app uses bundle ID, for example `com.google.android.gm`. Apple's App store app ID uses 9 digit string, for example `422689480`.",
          type = "string",
        },
        appPlatform = {
          description = "Indicates the platform of the targeted app. If this field is not specified, the app platform will be assumed to be mobile (i.e., Android or iOS), and we will derive the appropriate mobile platform from the app ID.",
          enum = {
            "APP_PLATFORM_UNSPECIFIED",
            "APP_PLATFORM_IOS",
            "APP_PLATFORM_ANDROID",
            "APP_PLATFORM_ROKU",
            "APP_PLATFORM_AMAZON_FIRETV",
            "APP_PLATFORM_PLAYSTATION",
            "APP_PLATFORM_APPLE_TV",
            "APP_PLATFORM_XBOX",
            "APP_PLATFORM_SAMSUNG_TV",
            "APP_PLATFORM_ANDROID_TV",
            "APP_PLATFORM_GENERIC_CTV",
          },
          enumDescriptions = {
            "Default value when app platform is not specified in this version. This enum is a placeholder for default value and does not represent a real platform option.",
            "The app platform is iOS.",
            "The app platform is Android.",
            "The app platform is Roku.",
            "The app platform is Amazon FireTV.",
            "The app platform is Playstation.",
            "The app platform is Apple TV.",
            "The app platform is Xbox.",
            "The app platform is Samsung TV.",
            "The app platform is Android TV.",
            "The app platform is a CTV platform that is not explicitly listed elsewhere.",
          },
          type = "string",
        },
        displayName = {
          description = "Output only. The display name of the app.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
      },
      type = "object",
    },
    AppCategoryAssignedTargetingOptionDetails = {
      description = "Details for assigned app category targeting option. This will be populated in the app_category_details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_APP_CATEGORY`.",
      id = "AppCategoryAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the app category.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_APP_CATEGORY`.",
          type = "string",
        },
      },
      type = "object",
    },
    AppCategoryTargetingOptionDetails = {
      description = "Represents a targetable collection of apps. A collection lets you target dynamic groups of related apps that are maintained by the platform, for example `All Apps/Google Play/Games`. This will be populated in the app_category_details field when targeting_type is `TARGETING_TYPE_APP_CATEGORY`.",
      id = "AppCategoryTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The name of the app collection.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Asset = {
      description = "A single asset.",
      id = "Asset",
      properties = {
        content = {
          description = "The asset content. For uploaded assets, the content is the serving path.",
          type = "string",
        },
        mediaId = {
          description = "Media ID of the uploaded asset. This is a unique identifier for the asset. This ID can be passed to other API calls, e.g. CreateCreative to associate the asset with a creative.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    AssetAssociation = {
      description = "Asset association for the creative.",
      id = "AssetAssociation",
      properties = {
        asset = {
          ["$ref"] = "Asset",
          description = "The associated asset.",
        },
        role = {
          description = "The role of this asset for the creative.",
          enum = {
            "ASSET_ROLE_UNSPECIFIED",
            "ASSET_ROLE_MAIN",
            "ASSET_ROLE_BACKUP",
            "ASSET_ROLE_POLITE_LOAD",
            "ASSET_ROLE_HEADLINE",
            "ASSET_ROLE_LONG_HEADLINE",
            "ASSET_ROLE_BODY",
            "ASSET_ROLE_LONG_BODY",
            "ASSET_ROLE_CAPTION_URL",
            "ASSET_ROLE_CALL_TO_ACTION",
            "ASSET_ROLE_ADVERTISER_NAME",
            "ASSET_ROLE_PRICE",
            "ASSET_ROLE_ANDROID_APP_ID",
            "ASSET_ROLE_IOS_APP_ID",
            "ASSET_ROLE_RATING",
            "ASSET_ROLE_ICON",
            "ASSET_ROLE_COVER_IMAGE",
          },
          enumDescriptions = {
            "Asset role is not specified or is unknown in this version.",
            "The asset is the main asset of the creative.",
            "The asset is a backup asset of the creative.",
            "The asset is a polite load asset of the creative.",
            "Headline of a native creative. The content must be UTF-8 encoded with a length of no more than 25 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "Long headline of a native creative. The content must be UTF-8 encoded with a length of no more than 50 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "Body text of a native creative. The content must be UTF-8 encoded with a length of no more than 90 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "Long body text of a native creative. The content must be UTF-8 encoded with a length of no more than 150 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "A short, friendly version of the landing page URL to show in the creative. This URL gives people an idea of where they'll arrive after they click on the creative. The content must be UTF-8 encoded with a length of no more than 30 characters. For example, if the landing page URL is 'http://www.example.com/page', the caption URL can be 'example.com'. The protocol (http://) is optional, but the URL can't contain spaces or special characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "The text to use on the call-to-action button of a native creative. The content must be UTF-8 encoded with a length of no more than 15 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "The text that identifies the advertiser or brand name. The content must be UTF-8 encoded with a length of no more than 25 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
            "The purchase price of your app in the Google play store or iOS app store (for example, $5.99). Note that this value is not automatically synced with the actual value listed in the store. It will always be the one provided when save the creative. The content must be UTF-8 encoded with a length of no more than 15 characters. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE`",
            "The ID of an Android app in the Google play store. You can find this ID in the App’s Google Play Store URL after ‘id’. For example, in https://play.google.com/store/apps/details?id=com.company.appname the identifier is com.company.appname. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE`",
            "The ID of an iOS app in the Apple app store. This ID number can be found in the Apple App Store URL as the string of numbers directly after \"id\". For example, in https://apps.apple.com/us/app/gmail-email-by-google/id422689480 the ID is 422689480. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE`",
            "The rating of an app in the Google play store or iOS app store. Note that this value is not automatically synced with the actual rating in the store. It will always be the one provided when save the creative. This role is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE`",
            "The icon of a creative. This role is only supported and required in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE`",
            "The cover image of a native video creative. This role is only supported and required in following creative_type: * `CREATIVE_TYPE_VIDEO`",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AssignedInventorySource = {
      description = "An assignment between a targetable inventory source and an inventory source group.",
      id = "AssignedInventorySource",
      properties = {
        assignedInventorySourceId = {
          description = "Output only. The unique ID of the assigned inventory source. The ID is only unique within a given inventory source group. It may be reused in other contexts.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        inventorySourceId = {
          description = "Required. The ID of the inventory source entity being targeted.",
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the assigned inventory source.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    AssignedLocation = {
      description = "An assignment between a location list and a relevant targeting option. Currently, geo region targeting options are the only supported option for assignment.",
      id = "AssignedLocation",
      properties = {
        assignedLocationId = {
          description = "Output only. The unique ID of the assigned location. The ID is only unique within a location list. It may be reused in other contexts.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the assigned location.",
          readOnly = true,
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The ID of the targeting option assigned to the location list. Must be of type TARGETING_TYPE_GEO_REGION.",
          type = "string",
        },
      },
      type = "object",
    },
    AssignedTargetingOption = {
      description = "A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings.",
      id = "AssignedTargetingOption",
      properties = {
        ageRangeDetails = {
          ["$ref"] = "AgeRangeAssignedTargetingOptionDetails",
          description = "Age range details. This field will be populated when the targeting_type is `TARGETING_TYPE_AGE_RANGE`.",
        },
        appCategoryDetails = {
          ["$ref"] = "AppCategoryAssignedTargetingOptionDetails",
          description = "App category details. This field will be populated when the targeting_type is `TARGETING_TYPE_APP_CATEGORY`.",
        },
        appDetails = {
          ["$ref"] = "AppAssignedTargetingOptionDetails",
          description = "App details. This field will be populated when the targeting_type is `TARGETING_TYPE_APP`.",
        },
        assignedTargetingOptionId = {
          description = "Output only. The unique ID of the assigned targeting option. The ID is only unique within a given resource and targeting type. It may be reused in other contexts.",
          readOnly = true,
          type = "string",
        },
        audienceGroupDetails = {
          ["$ref"] = "AudienceGroupAssignedTargetingOptionDetails",
          description = "Audience targeting details. This field will be populated when the targeting_type is `TARGETING_TYPE_AUDIENCE_GROUP`. You can only target one audience group option per resource.",
        },
        audioContentTypeDetails = {
          ["$ref"] = "AudioContentTypeAssignedTargetingOptionDetails",
          description = "Audio content type details. This field will be populated when the targeting_type is `TARGETING_TYPE_AUDIO_CONTENT_TYPE`.",
        },
        authorizedSellerStatusDetails = {
          ["$ref"] = "AuthorizedSellerStatusAssignedTargetingOptionDetails",
          description = "Authorized seller status details. This field will be populated when the targeting_type is `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS`. You can only target one authorized seller status option per resource. If a resource doesn't have an authorized seller status option, all authorized sellers indicated as DIRECT or RESELLER in the ads.txt file are targeted by default.",
        },
        browserDetails = {
          ["$ref"] = "BrowserAssignedTargetingOptionDetails",
          description = "Browser details. This field will be populated when the targeting_type is `TARGETING_TYPE_BROWSER`.",
        },
        businessChainDetails = {
          ["$ref"] = "BusinessChainAssignedTargetingOptionDetails",
          description = "Business chain details. This field will be populated when the targeting_type is `TARGETING_TYPE_BUSINESS_CHAIN`.",
        },
        carrierAndIspDetails = {
          ["$ref"] = "CarrierAndIspAssignedTargetingOptionDetails",
          description = "Carrier and ISP details. This field will be populated when the targeting_type is `TARGETING_TYPE_CARRIER_AND_ISP`.",
        },
        categoryDetails = {
          ["$ref"] = "CategoryAssignedTargetingOptionDetails",
          description = "Category details. This field will be populated when the targeting_type is `TARGETING_TYPE_CATEGORY`. Targeting a category will also target its subcategories. If a category is excluded from targeting and a subcategory is included, the exclusion will take precedence.",
        },
        channelDetails = {
          ["$ref"] = "ChannelAssignedTargetingOptionDetails",
          description = "Channel details. This field will be populated when the targeting_type is `TARGETING_TYPE_CHANNEL`.",
        },
        contentDurationDetails = {
          ["$ref"] = "ContentDurationAssignedTargetingOptionDetails",
          description = "Content duration details. This field will be populated when the targeting_type is `TARGETING_TYPE_CONTENT_DURATION`.",
        },
        contentGenreDetails = {
          ["$ref"] = "ContentGenreAssignedTargetingOptionDetails",
          description = "Content genre details. This field will be populated when the targeting_type is `TARGETING_TYPE_CONTENT_GENRE`.",
        },
        contentInstreamPositionDetails = {
          ["$ref"] = "ContentInstreamPositionAssignedTargetingOptionDetails",
          description = "Content instream position details. This field will be populated when the targeting_type is `TARGETING_TYPE_CONTENT_INSTREAM_POSITION`.",
        },
        contentOutstreamPositionDetails = {
          ["$ref"] = "ContentOutstreamPositionAssignedTargetingOptionDetails",
          description = "Content outstream position details. This field will be populated when the targeting_type is `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION`.",
        },
        contentStreamTypeDetails = {
          ["$ref"] = "ContentStreamTypeAssignedTargetingOptionDetails",
          description = "Content duration details. This field will be populated when the TargetingType is `TARGETING_TYPE_CONTENT_STREAM_TYPE`.",
        },
        dayAndTimeDetails = {
          ["$ref"] = "DayAndTimeAssignedTargetingOptionDetails",
          description = "Day and time details. This field will be populated when the targeting_type is `TARGETING_TYPE_DAY_AND_TIME`.",
        },
        deviceMakeModelDetails = {
          ["$ref"] = "DeviceMakeModelAssignedTargetingOptionDetails",
          description = "Device make and model details. This field will be populated when the targeting_type is `TARGETING_TYPE_DEVICE_MAKE_MODEL`.",
        },
        deviceTypeDetails = {
          ["$ref"] = "DeviceTypeAssignedTargetingOptionDetails",
          description = "Device Type details. This field will be populated when the targeting_type is `TARGETING_TYPE_DEVICE_TYPE`.",
        },
        digitalContentLabelExclusionDetails = {
          ["$ref"] = "DigitalContentLabelAssignedTargetingOptionDetails",
          description = "Digital content label details. This field will be populated when the targeting_type is `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION`. Digital content labels are targeting exclusions. Advertiser level digital content label exclusions, if set, are always applied in serving (even though they aren't visible in resource settings). Resource settings can exclude content labels in addition to advertiser exclusions, but can't override them. A line item won't serve if all the digital content labels are excluded.",
        },
        environmentDetails = {
          ["$ref"] = "EnvironmentAssignedTargetingOptionDetails",
          description = "Environment details. This field will be populated when the targeting_type is `TARGETING_TYPE_ENVIRONMENT`.",
        },
        exchangeDetails = {
          ["$ref"] = "ExchangeAssignedTargetingOptionDetails",
          description = "Exchange details. This field will be populated when the targeting_type is `TARGETING_TYPE_EXCHANGE`.",
        },
        genderDetails = {
          ["$ref"] = "GenderAssignedTargetingOptionDetails",
          description = "Gender details. This field will be populated when the targeting_type is `TARGETING_TYPE_GENDER`.",
        },
        geoRegionDetails = {
          ["$ref"] = "GeoRegionAssignedTargetingOptionDetails",
          description = "Geographic region details. This field will be populated when the targeting_type is `TARGETING_TYPE_GEO_REGION`.",
        },
        householdIncomeDetails = {
          ["$ref"] = "HouseholdIncomeAssignedTargetingOptionDetails",
          description = "Household income details. This field will be populated when the targeting_type is `TARGETING_TYPE_HOUSEHOLD_INCOME`.",
        },
        inheritance = {
          description = "Output only. The inheritance status of the assigned targeting option.",
          enum = {
            "INHERITANCE_UNSPECIFIED",
            "NOT_INHERITED",
            "INHERITED_FROM_PARTNER",
            "INHERITED_FROM_ADVERTISER",
          },
          enumDescriptions = {
            "The inheritance is unspecified or unknown.",
            "The assigned targeting option is not inherited from higher level entity.",
            "The assigned targeting option is inherited from partner targeting settings.",
            "The assigned targeting option is inherited from advertiser targeting settings.",
          },
          readOnly = true,
          type = "string",
        },
        inventorySourceDetails = {
          ["$ref"] = "InventorySourceAssignedTargetingOptionDetails",
          description = "Inventory source details. This field will be populated when the targeting_type is `TARGETING_TYPE_INVENTORY_SOURCE`.",
        },
        inventorySourceGroupDetails = {
          ["$ref"] = "InventorySourceGroupAssignedTargetingOptionDetails",
          description = "Inventory source group details. This field will be populated when the targeting_type is `TARGETING_TYPE_INVENTORY_SOURCE_GROUP`.",
        },
        keywordDetails = {
          ["$ref"] = "KeywordAssignedTargetingOptionDetails",
          description = "Keyword details. This field will be populated when the targeting_type is `TARGETING_TYPE_KEYWORD`. A maximum of 5000 direct negative keywords can be assigned to a resource. No limit on number of positive keywords that can be assigned.",
        },
        languageDetails = {
          ["$ref"] = "LanguageAssignedTargetingOptionDetails",
          description = "Language details. This field will be populated when the targeting_type is `TARGETING_TYPE_LANGUAGE`.",
        },
        name = {
          description = "Output only. The resource name for this assigned targeting option.",
          readOnly = true,
          type = "string",
        },
        nativeContentPositionDetails = {
          ["$ref"] = "NativeContentPositionAssignedTargetingOptionDetails",
          description = "Native content position details. This field will be populated when the targeting_type is `TARGETING_TYPE_NATIVE_CONTENT_POSITION`.",
        },
        negativeKeywordListDetails = {
          ["$ref"] = "NegativeKeywordListAssignedTargetingOptionDetails",
          description = "Keyword details. This field will be populated when the targeting_type is `TARGETING_TYPE_NEGATIVE_KEYWORD_LIST`. A maximum of 4 negative keyword lists can be assigned to a resource.",
        },
        omidDetails = {
          ["$ref"] = "OmidAssignedTargetingOptionDetails",
          description = "Open Measurement enabled inventory details. This field will be populated when the targeting_type is `TARGETING_TYPE_OMID`.",
        },
        onScreenPositionDetails = {
          ["$ref"] = "OnScreenPositionAssignedTargetingOptionDetails",
          description = "On screen position details. This field will be populated when the targeting_type is `TARGETING_TYPE_ON_SCREEN_POSITION`.",
        },
        operatingSystemDetails = {
          ["$ref"] = "OperatingSystemAssignedTargetingOptionDetails",
          description = "Operating system details. This field will be populated when the targeting_type is `TARGETING_TYPE_OPERATING_SYSTEM`.",
        },
        parentalStatusDetails = {
          ["$ref"] = "ParentalStatusAssignedTargetingOptionDetails",
          description = "Parental status details. This field will be populated when the targeting_type is `TARGETING_TYPE_PARENTAL_STATUS`.",
        },
        poiDetails = {
          ["$ref"] = "PoiAssignedTargetingOptionDetails",
          description = "POI details. This field will be populated when the targeting_type is `TARGETING_TYPE_POI`.",
        },
        proximityLocationListDetails = {
          ["$ref"] = "ProximityLocationListAssignedTargetingOptionDetails",
          description = "Proximity location list details. This field will be populated when the targeting_type is `TARGETING_TYPE_PROXIMITY_LOCATION_LIST`.",
        },
        regionalLocationListDetails = {
          ["$ref"] = "RegionalLocationListAssignedTargetingOptionDetails",
          description = "Regional location list details. This field will be populated when the targeting_type is `TARGETING_TYPE_REGIONAL_LOCATION_LIST`.",
        },
        sensitiveCategoryExclusionDetails = {
          ["$ref"] = "SensitiveCategoryAssignedTargetingOptionDetails",
          description = "Sensitive category details. This field will be populated when the targeting_type is `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`. Sensitive categories are targeting exclusions. Advertiser level sensitive category exclusions, if set, are always applied in serving (even though they aren't visible in resource settings). Resource settings can exclude sensitive categories in addition to advertiser exclusions, but can't override them.",
        },
        subExchangeDetails = {
          ["$ref"] = "SubExchangeAssignedTargetingOptionDetails",
          description = "Sub-exchange details. This field will be populated when the targeting_type is `TARGETING_TYPE_SUB_EXCHANGE`.",
        },
        targetingType = {
          description = "Output only. Identifies the type of this assigned targeting option.",
          enum = {
            "TARGETING_TYPE_UNSPECIFIED",
            "TARGETING_TYPE_CHANNEL",
            "TARGETING_TYPE_APP_CATEGORY",
            "TARGETING_TYPE_APP",
            "TARGETING_TYPE_URL",
            "TARGETING_TYPE_DAY_AND_TIME",
            "TARGETING_TYPE_AGE_RANGE",
            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
            "TARGETING_TYPE_GENDER",
            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
            "TARGETING_TYPE_USER_REWARDED_CONTENT",
            "TARGETING_TYPE_PARENTAL_STATUS",
            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
            "TARGETING_TYPE_DEVICE_TYPE",
            "TARGETING_TYPE_AUDIENCE_GROUP",
            "TARGETING_TYPE_BROWSER",
            "TARGETING_TYPE_HOUSEHOLD_INCOME",
            "TARGETING_TYPE_ON_SCREEN_POSITION",
            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
            "TARGETING_TYPE_ENVIRONMENT",
            "TARGETING_TYPE_CARRIER_AND_ISP",
            "TARGETING_TYPE_OPERATING_SYSTEM",
            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
            "TARGETING_TYPE_KEYWORD",
            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
            "TARGETING_TYPE_VIEWABILITY",
            "TARGETING_TYPE_CATEGORY",
            "TARGETING_TYPE_INVENTORY_SOURCE",
            "TARGETING_TYPE_LANGUAGE",
            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
            "TARGETING_TYPE_GEO_REGION",
            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
            "TARGETING_TYPE_EXCHANGE",
            "TARGETING_TYPE_SUB_EXCHANGE",
            "TARGETING_TYPE_POI",
            "TARGETING_TYPE_BUSINESS_CHAIN",
            "TARGETING_TYPE_CONTENT_DURATION",
            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
            "TARGETING_TYPE_OMID",
            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
            "TARGETING_TYPE_CONTENT_GENRE",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown in this version.",
            "Target a channel (a custom group of related websites or apps).",
            "Target an app category (for example, education or puzzle games).",
            "Target a specific app (for example, Angry Birds).",
            "Target a specific url (for example, quora.com).",
            "Target ads during a chosen time period on a specific day.",
            "Target ads to a specific age range (for example, 18-24).",
            "Target ads to the specified regions on a regional location list.",
            "Target ads to the specified points of interest on a proximity location list.",
            "Target ads to a specific gender (for example, female or male).",
            "Target a specific video player size for video ads.",
            "Target user rewarded content for video ads.",
            "Target ads to a specific parental status (for example, parent or not a parent).",
            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
            "Target ads in a specific content outstream position.",
            "Target ads to a specific device type (for example, tablet or connected TV).",
            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
            "Target ads to specific web browsers (for example, Chrome).",
            "Target ads to a specific household income range (for example, top 10%).",
            "Target ads in a specific on screen position.",
            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
            "Filter website content by sensitive categories (for example, adult).",
            "Target ads to a specific environment (for example, web or app).",
            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
            "Target ads to a specific operating system (for example, macOS).",
            "Target ads to a specific device make or model (for example, Roku or Samsung).",
            "Target ads to a specific keyword (for example, dog or retriever).",
            "Target ads to a specific negative keyword list.",
            "Target ads to a specific viewability (for example, 80% viewable).",
            "Target ads to a specific content category (for example, arts & entertainment).",
            "Purchase impressions from specific deals and auction packages.",
            "Target ads to a specific language (for example, English or Japanese).",
            "Target ads to ads.txt authorized sellers.",
            "Target ads to a specific regional location (for example, a city or state).",
            "Purchase impressions from a group of deals and auction packages.",
            "Purchase impressions from specific exchanges.",
            "Purchase impressions from specific sub-exchanges.",
            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
            "Target ads around locations of a business chain within a specific geo region.",
            "Target ads to a specific video content duration.",
            "Target ads to a specific video content stream type.",
            "Target ads to a specific native content position.",
            "Target ads in an Open Measurement enabled inventory.",
            "Target ads to a specific audio content type.",
            "Target ads to a specific content genre.",
          },
          readOnly = true,
          type = "string",
        },
        thirdPartyVerifierDetails = {
          ["$ref"] = "ThirdPartyVerifierAssignedTargetingOptionDetails",
          description = "Third party verification details. This field will be populated when the targeting_type is `TARGETING_TYPE_THIRD_PARTY_VERIFIER`.",
        },
        urlDetails = {
          ["$ref"] = "UrlAssignedTargetingOptionDetails",
          description = "URL details. This field will be populated when the targeting_type is `TARGETING_TYPE_URL`.",
        },
        userRewardedContentDetails = {
          ["$ref"] = "UserRewardedContentAssignedTargetingOptionDetails",
          description = "User rewarded content details. This field will be populated when the targeting_type is `TARGETING_TYPE_USER_REWARDED_CONTENT`.",
        },
        videoPlayerSizeDetails = {
          ["$ref"] = "VideoPlayerSizeAssignedTargetingOptionDetails",
          description = "Video player size details. This field will be populated when the targeting_type is `TARGETING_TYPE_VIDEO_PLAYER_SIZE`.",
        },
        viewabilityDetails = {
          ["$ref"] = "ViewabilityAssignedTargetingOptionDetails",
          description = "Viewability details. This field will be populated when the targeting_type is `TARGETING_TYPE_VIEWABILITY`. You can only target one viewability option per resource.",
        },
      },
      type = "object",
    },
    AssignedUserRole = {
      description = "A single assigned user role, which defines a user's authorized interaction with a specified partner or advertiser.",
      id = "AssignedUserRole",
      properties = {
        advertiserId = {
          description = "The ID of the advertiser that the assigend user role applies to.",
          format = "int64",
          type = "string",
        },
        assignedUserRoleId = {
          description = "Output only. The ID of the assigned user role.",
          readOnly = true,
          type = "string",
        },
        partnerId = {
          description = "The ID of the partner that the assigned user role applies to.",
          format = "int64",
          type = "string",
        },
        userRole = {
          description = "Required. The user role to assign to a user for the entity.",
          enum = {
            "USER_ROLE_UNSPECIFIED",
            "ADMIN",
            "ADMIN_PARTNER_CLIENT",
            "STANDARD",
            "STANDARD_PLANNER",
            "STANDARD_PLANNER_LIMITED",
            "STANDARD_PARTNER_CLIENT",
            "READ_ONLY",
            "REPORTING_ONLY",
            "LIMITED_REPORTING_ONLY",
            "CREATIVE",
            "CREATIVE_ADMIN",
          },
          enumDescriptions = {
            "Default value when the user role is not specified or is unknown in this version.",
            "The user can manage campaigns, creatives, insertion orders, line items, and reports for the entity. They can view and edit billing information, create or modify users, and enable or disable exchanges. This role can only be assigned for a partner entity.",
            "The user can manage campaigns, creatives, insertion orders, line items, and reports for the entity. They can create and modify other `ADMIN_PARTNER_CLIENT` users and view billing information. They cannot view revenue models, markups, or any other reseller-sensitive fields. This role can only be assigned for a partner entity.",
            "The user can manage campaigns, creatives, insertion orders, line items, and reports for the entity. They cannot create and modify users or view billing information.",
            "The user can view all campaigns, creatives, insertion orders, line items, and reports for the entity, including all cost data. They can create and modify planning-related features, including plans and inventory.",
            "The user can view all campaigns, creatives, insertion orders, line items, and reports for the entity. They can create or modify planning-related features, including plans and inventory. They have no access to cost data and cannot start, accept, or negotiate deals.",
            "The user can manage campaigns, creatives, insertion orders, line items, and reports for the entity. They cannot create or modify other users or view billing information. They cannot view revenue models, markups, or any other reseller-sensitive fields. This role can only be assigned for an advertiser entity.",
            "The user can only build reports and view data for the entity.",
            "The user can only create and manage reports.",
            "The user can only create and manage the following client-safe reports: General, Audience Performance, Cross-Partner, Keyword, Order ID, Category, and Third-Party Data Provider.",
            "The user can view media plan information they need to collaborate, but can't view cost-related data or Marketplace.",
            "The user can view media plan information they need to collaborate, but can't view cost-related data or Marketplace. In addition, they can add other creative admins or creative users to the entity.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    AudienceGroupAssignedTargetingOptionDetails = {
      description = "Assigned audience group targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_AUDIENCE_GROUP`. The relation between each group is UNION, except for excluded_first_and_third_party_audience_group and excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION with other groups.",
      id = "AudienceGroupAssignedTargetingOptionDetails",
      properties = {
        excludedFirstAndThirdPartyAudienceGroup = {
          ["$ref"] = "FirstAndThirdPartyAudienceGroup",
          description = "The first and third party audience ids and recencies of the excluded first and third party audience group. Used for negative targeting. The COMPLEMENT of the UNION of this group and other excluded audience groups is used as an INTERSECTION to any positive audience targeting. All items are logically ‘OR’ of each other.",
        },
        excludedGoogleAudienceGroup = {
          ["$ref"] = "GoogleAudienceGroup",
          description = "The Google audience ids of the excluded Google audience group. Used for negative targeting. The COMPLEMENT of the UNION of this group and other excluded audience groups is used as an INTERSECTION to any positive audience targeting. Only contains Affinity, In-market and Installed-apps type Google audiences. All items are logically ‘OR’ of each other.",
        },
        includedCombinedAudienceGroup = {
          ["$ref"] = "CombinedAudienceGroup",
          description = "The combined audience ids of the included combined audience group. Contains combined audience ids only.",
        },
        includedCustomListGroup = {
          ["$ref"] = "CustomListGroup",
          description = "The custom list ids of the included custom list group. Contains custom list ids only.",
        },
        includedFirstAndThirdPartyAudienceGroups = {
          description = "The first and third party audience ids and recencies of included first and third party audience groups. Each first and third party audience group contains first and third party audience ids only. The relation between each first and third party audience group is INTERSECTION, and the result is UNION'ed with other audience groups. Repeated groups with same settings will be ignored.",
          items = {
            ["$ref"] = "FirstAndThirdPartyAudienceGroup",
          },
          type = "array",
        },
        includedGoogleAudienceGroup = {
          ["$ref"] = "GoogleAudienceGroup",
          description = "The Google audience ids of the included Google audience group. Contains Google audience ids only.",
        },
      },
      type = "object",
    },
    AudioContentTypeAssignedTargetingOptionDetails = {
      description = "Details for audio content type assigned targeting option. This will be populated in the audio_content_type_details field when targeting_type is `TARGETING_TYPE_AUDIO_CONTENT_TYPE`. Explicitly targeting all options is not supported. Remove all audio content type targeting options to achieve this effect.",
      id = "AudioContentTypeAssignedTargetingOptionDetails",
      properties = {
        audioContentType = {
          description = "The audio content type. Output only in v1. Required in v2.",
          enum = {
            "AUDIO_CONTENT_TYPE_UNSPECIFIED",
            "AUDIO_CONTENT_TYPE_UNKNOWN",
            "AUDIO_CONTENT_TYPE_MUSIC",
            "AUDIO_CONTENT_TYPE_BROADCAST",
            "AUDIO_CONTENT_TYPE_PODCAST",
          },
          enumDescriptions = {
            "Audio content type is not specified in this version. This enum is a place holder for a default value and does not represent a real content stream type.",
            "The audio content type is unknown.",
            "The audio content type is music.",
            "The audio content type is broadcast.",
            "The audio content type is podcast.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_AUDIO_CONTENT_TYPE`.",
          type = "string",
        },
      },
      type = "object",
    },
    AudioContentTypeTargetingOptionDetails = {
      description = "Represents a targetable audio content type. This will be populated in the audio_content_type_details field when targeting_type is `TARGETING_TYPE_AUDIO_CONTENT_TYPE`.",
      id = "AudioContentTypeTargetingOptionDetails",
      properties = {
        audioContentType = {
          description = "Output only. The audio content type.",
          enum = {
            "AUDIO_CONTENT_TYPE_UNSPECIFIED",
            "AUDIO_CONTENT_TYPE_UNKNOWN",
            "AUDIO_CONTENT_TYPE_MUSIC",
            "AUDIO_CONTENT_TYPE_BROADCAST",
            "AUDIO_CONTENT_TYPE_PODCAST",
          },
          enumDescriptions = {
            "Audio content type is not specified in this version. This enum is a place holder for a default value and does not represent a real content stream type.",
            "The audio content type is unknown.",
            "The audio content type is music.",
            "The audio content type is broadcast.",
            "The audio content type is podcast.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    AudioVideoOffset = {
      description = "The length an audio or a video has been played.",
      id = "AudioVideoOffset",
      properties = {
        percentage = {
          description = "The offset in percentage of the audio or video duration.",
          format = "int64",
          type = "string",
        },
        seconds = {
          description = "The offset in seconds from the start of the audio or video.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    AuditAdvertiserResponse = {
      description = "Response message for AdvertiserService.AuditAdvertiser.",
      id = "AuditAdvertiserResponse",
      properties = {
        adGroupCriteriaCount = {
          description = "The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser. These individual targeting options count towards the limit of 4500000 ad group targeting options per advertiser. Qualifying Targeting types: * Channels, URLs, apps, and collections * Demographic * Google Audiences, including Affinity, Custom Affinity, and In-market audiences * Inventory source * Keyword * Mobile app category * User lists * Video targeting * Viewability",
          format = "int64",
          type = "string",
        },
        campaignCriteriaCount = {
          description = "The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser. These individual targeting options count towards the limit of 900000 campaign targeting options per advertiser. Qualifying Targeting types: * Position * Browser * Connection speed * Day and time * Device and operating system * Digital content label * Sensitive categories * Environment * Geography, including business chains and proximity * ISP * Language * Third-party verification",
          format = "int64",
          type = "string",
        },
        channelsCount = {
          description = "The number of channels created under this advertiser. These channels count towards the limit of 1000 channels per advertiser.",
          format = "int64",
          type = "string",
        },
        negativeKeywordListsCount = {
          description = "The number of negative keyword lists created under this advertiser. These negative keyword lists count towards the limit of 20 negative keyword lists per advertiser.",
          format = "int64",
          type = "string",
        },
        negativelyTargetedChannelsCount = {
          description = "The number of negatively targeted channels created under this advertiser. These negatively targeted channels count towards the limit of 5 negatively targeted channels per advertiser.",
          format = "int64",
          type = "string",
        },
        usedCampaignsCount = {
          description = "The number of ACTIVE and PAUSED campaigns under this advertiser. These campaigns count towards the limit of 9999 campaigns per advertiser.",
          format = "int64",
          type = "string",
        },
        usedInsertionOrdersCount = {
          description = "The number of ACTIVE, PAUSED and DRAFT insertion orders under this advertiser. These insertion orders count towards the limit of 9999 insertion orders per advertiser.",
          format = "int64",
          type = "string",
        },
        usedLineItemsCount = {
          description = "The number of ACTIVE, PAUSED, and DRAFT line items under this advertiser. These line items count towards the limit of 9999 line items per advertiser.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    AuthorizedSellerStatusAssignedTargetingOptionDetails = {
      description = "Represents an assigned authorized seller status. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS`.",
      id = "AuthorizedSellerStatusAssignedTargetingOptionDetails",
      properties = {
        authorizedSellerStatus = {
          description = "Output only. The authorized seller status to target.",
          enum = {
            "AUTHORIZED_SELLER_STATUS_UNSPECIFIED",
            "AUTHORIZED_SELLER_STATUS_AUTHORIZED_DIRECT_SELLERS_ONLY",
            "AUTHORIZED_SELLER_STATUS_AUTHORIZED_AND_NON_PARTICIPATING_PUBLISHERS",
          },
          enumDescriptions = {
            "Default value when authorized seller status is not specified in this version. This enum is a placeholder for default value and does not represent a real authorized seller status option.",
            "Only authorized sellers that directly own the inventory being monetized, as indicated by a DIRECT declaration in the ads.txt file.",
            "All authorized sellers, including publishers that have not posted an ads.txt file. Display & Video 360 automatically disallows unauthorized sellers.",
          },
          readOnly = true,
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS`.",
          type = "string",
        },
      },
      type = "object",
    },
    AuthorizedSellerStatusTargetingOptionDetails = {
      description = "Represents a targetable authorized seller status. This will be populated in the authorized_seller_status_details field when targeting_type is `TARGETING_TYPE_AUTHORIZED_SELLER_STATUS`.",
      id = "AuthorizedSellerStatusTargetingOptionDetails",
      properties = {
        authorizedSellerStatus = {
          description = "Output only. The authorized seller status.",
          enum = {
            "AUTHORIZED_SELLER_STATUS_UNSPECIFIED",
            "AUTHORIZED_SELLER_STATUS_AUTHORIZED_DIRECT_SELLERS_ONLY",
            "AUTHORIZED_SELLER_STATUS_AUTHORIZED_AND_NON_PARTICIPATING_PUBLISHERS",
          },
          enumDescriptions = {
            "Default value when authorized seller status is not specified in this version. This enum is a placeholder for default value and does not represent a real authorized seller status option.",
            "Only authorized sellers that directly own the inventory being monetized, as indicated by a DIRECT declaration in the ads.txt file.",
            "All authorized sellers, including publishers that have not posted an ads.txt file. Display & Video 360 automatically disallows unauthorized sellers.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    BiddingStrategy = {
      description = "Settings that control the bid strategy. Bid strategy determines the bid price.",
      id = "BiddingStrategy",
      properties = {
        fixedBid = {
          ["$ref"] = "FixedBidStrategy",
          description = "A strategy that uses a fixed bid price.",
        },
        maximizeSpendAutoBid = {
          ["$ref"] = "MaximizeSpendBidStrategy",
          description = "A strategy that automatically adjusts the bid to optimize to your performance goal while spending the full budget. At insertion order level, the markup_type of line items cannot be set to `PARTNER_REVENUE_MODEL_MARKUP_TYPE_CPM`. In addition, when performance_goal_type is one of: * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA` * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC` * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_AV_VIEWED` , the line_item_type of the insertion order line items must be either: * `LINE_ITEM_TYPE_DISPLAY_DEFAULT` * `LINE_ITEM_TYPE_VIDEO_DEFAULT` , and when performance_goal_type is either: * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CIVA` * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_IVO_TEN` the line_item_type of the insertion order line items must be `LINE_ITEM_TYPE_VIDEO_DEFAULT`.",
        },
        performanceGoalAutoBid = {
          ["$ref"] = "PerformanceGoalBidStrategy",
          description = "A strategy that automatically adjusts the bid to meet or beat a specified performance goal. It is to be used only for a line item entity.",
        },
      },
      type = "object",
    },
    BrowserAssignedTargetingOptionDetails = {
      description = "Details for assigned browser targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_BROWSER`.",
      id = "BrowserAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the browser.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted. All assigned browser targeting options on the same resource must have the same value for this field.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_BROWSER`.",
          type = "string",
        },
      },
      type = "object",
    },
    BrowserTargetingOptionDetails = {
      description = "Represents a targetable browser. This will be populated in the browser_details field when targeting_type is `TARGETING_TYPE_BROWSER`.",
      id = "BrowserTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the browser.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    BudgetSummary = {
      description = "Summarized information of an individual campaign budget.",
      id = "BudgetSummary",
      properties = {
        externalBudgetId = {
          description = "Corresponds to the external_budget_id of a campaign budget. If the value is not set in the campaign budget, this field will be empty.",
          type = "string",
        },
        preTaxAmountMicros = {
          description = "The sum of charges made under this budget before taxes, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
        prismaCpeCode = {
          ["$ref"] = "PrismaCpeCode",
          description = "Relevant client, product, and estimate codes from the Mediaocean Prisma tool. Only applicable for campaign budgets with an external_budget_source of EXTERNAL_BUDGET_SOURCE_MEDIA_OCEAN.",
        },
        taxAmountMicros = {
          description = "The amount of tax applied to charges under this budget, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
        totalAmountMicros = {
          description = "The total sum of charges made under this budget, including tax, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    BulkEditAdvertiserAssignedTargetingOptionsRequest = {
      description = "Request message for BulkEditAdvertiserAssignedTargetingOptions.",
      id = "BulkEditAdvertiserAssignedTargetingOptionsRequest",
      properties = {
        createRequests = {
          description = "The assigned targeting options to create in batch, specified as a list of `CreateAssignedTargetingOptionsRequest`. Supported targeting types: * `TARGETING_TYPE_CHANNEL` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_OMID` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`",
          items = {
            ["$ref"] = "CreateAssignedTargetingOptionsRequest",
          },
          type = "array",
        },
        deleteRequests = {
          description = "The assigned targeting options to delete in batch, specified as a list of `DeleteAssignedTargetingOptionsRequest`. Supported targeting types: * `TARGETING_TYPE_CHANNEL` * `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION` * `TARGETING_TYPE_OMID` * `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`",
          items = {
            ["$ref"] = "DeleteAssignedTargetingOptionsRequest",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditAdvertiserAssignedTargetingOptionsResponse = {
      id = "BulkEditAdvertiserAssignedTargetingOptionsResponse",
      properties = {
        createdAssignedTargetingOptions = {
          description = "The list of assigned targeting options that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditAssignedInventorySourcesRequest = {
      description = "Request message for AssignedInventorySourceService.BulkEdit.",
      id = "BulkEditAssignedInventorySourcesRequest",
      properties = {
        advertiserId = {
          description = "The ID of the advertiser that owns the parent inventory source group. The parent partner does not have access to these assigned inventory sources.",
          format = "int64",
          type = "string",
        },
        createdAssignedInventorySources = {
          description = "The assigned inventory sources to create in bulk, specified as a list of AssignedInventorySources.",
          items = {
            ["$ref"] = "AssignedInventorySource",
          },
          type = "array",
        },
        deletedAssignedInventorySources = {
          description = "The IDs of the assigned inventory sources to delete in bulk, specified as a list of assigned_inventory_source_ids.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        partnerId = {
          description = "The ID of the partner that owns the inventory source group. Only this partner has write access to these assigned inventory sources.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    BulkEditAssignedInventorySourcesResponse = {
      description = "Response message for AssignedInventorySourceService.BulkEdit.",
      id = "BulkEditAssignedInventorySourcesResponse",
      properties = {
        assignedInventorySources = {
          description = "The list of assigned inventory sources that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedInventorySource",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditAssignedLocationsRequest = {
      description = "Request message for AssignedLocationService.BulkEditAssignedLocations.",
      id = "BulkEditAssignedLocationsRequest",
      properties = {
        createdAssignedLocations = {
          description = "The assigned locations to create in bulk, specified as a list of AssignedLocations.",
          items = {
            ["$ref"] = "AssignedLocation",
          },
          type = "array",
        },
        deletedAssignedLocations = {
          description = "The IDs of the assigned locations to delete in bulk, specified as a list of assigned_location_ids.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditAssignedLocationsResponse = {
      description = "Response message for AssignedLocationService.BulkEditAssignedLocations.",
      id = "BulkEditAssignedLocationsResponse",
      properties = {
        assignedLocations = {
          description = "The list of assigned locations that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedLocation",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditAssignedUserRolesRequest = {
      description = "Request message for BulkEditAssignedUserRoles.",
      id = "BulkEditAssignedUserRolesRequest",
      properties = {
        createdAssignedUserRoles = {
          description = "The assigned user roles to create in batch, specified as a list of AssignedUserRoles.",
          items = {
            ["$ref"] = "AssignedUserRole",
          },
          type = "array",
        },
        deletedAssignedUserRoles = {
          description = "The assigned user roles to delete in batch, specified as a list of assigned_user_role_ids. The format of assigned_user_role_id is `entityType-entityid`, for example `partner-123`.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditAssignedUserRolesResponse = {
      id = "BulkEditAssignedUserRolesResponse",
      properties = {
        createdAssignedUserRoles = {
          description = "The list of assigned user roles that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedUserRole",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditLineItemAssignedTargetingOptionsRequest = {
      description = "Request message for BulkEditLineItemAssignedTargetingOptions.",
      id = "BulkEditLineItemAssignedTargetingOptionsRequest",
      properties = {
        createRequests = {
          description = "The assigned targeting options to create in batch, specified as a list of `CreateAssignedTargetingOptionsRequest`.",
          items = {
            ["$ref"] = "CreateAssignedTargetingOptionsRequest",
          },
          type = "array",
        },
        deleteRequests = {
          description = "The assigned targeting options to delete in batch, specified as a list of `DeleteAssignedTargetingOptionsRequest`.",
          items = {
            ["$ref"] = "DeleteAssignedTargetingOptionsRequest",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditLineItemAssignedTargetingOptionsResponse = {
      id = "BulkEditLineItemAssignedTargetingOptionsResponse",
      properties = {
        createdAssignedTargetingOptions = {
          description = "The list of assigned targeting options that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditNegativeKeywordsRequest = {
      description = "Request message for NegativeKeywordService.BulkEditNegativeKeywords.",
      id = "BulkEditNegativeKeywordsRequest",
      properties = {
        createdNegativeKeywords = {
          description = "The negative keywords to create in batch, specified as a list of NegativeKeywords.",
          items = {
            ["$ref"] = "NegativeKeyword",
          },
          type = "array",
        },
        deletedNegativeKeywords = {
          description = "The negative keywords to delete in batch, specified as a list of keyword_values.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditNegativeKeywordsResponse = {
      description = "Response message for NegativeKeywordService.BulkEditNegativeKeywords.",
      id = "BulkEditNegativeKeywordsResponse",
      properties = {
        negativeKeywords = {
          description = "The list of negative keywords that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "NegativeKeyword",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditPartnerAssignedTargetingOptionsRequest = {
      description = "Request message for BulkEditPartnerAssignedTargetingOptions.",
      id = "BulkEditPartnerAssignedTargetingOptionsRequest",
      properties = {
        createRequests = {
          description = "The assigned targeting options to create in batch, specified as a list of `CreateAssignedTargetingOptionsRequest`. Supported targeting types: * `TARGETING_TYPE_CHANNEL`",
          items = {
            ["$ref"] = "CreateAssignedTargetingOptionsRequest",
          },
          type = "array",
        },
        deleteRequests = {
          description = "The assigned targeting options to delete in batch, specified as a list of `DeleteAssignedTargetingOptionsRequest`. Supported targeting types: * `TARGETING_TYPE_CHANNEL`",
          items = {
            ["$ref"] = "DeleteAssignedTargetingOptionsRequest",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditPartnerAssignedTargetingOptionsResponse = {
      id = "BulkEditPartnerAssignedTargetingOptionsResponse",
      properties = {
        createdAssignedTargetingOptions = {
          description = "The list of assigned targeting options that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkEditSitesRequest = {
      description = "Request message for SiteService.BulkEditSites.",
      id = "BulkEditSitesRequest",
      properties = {
        advertiserId = {
          description = "The ID of the advertiser that owns the parent channel.",
          format = "int64",
          type = "string",
        },
        createdSites = {
          description = "The sites to create in batch, specified as a list of Sites.",
          items = {
            ["$ref"] = "Site",
          },
          type = "array",
        },
        deletedSites = {
          description = "The sites to delete in batch, specified as a list of site url_or_app_ids.",
          items = {
            type = "string",
          },
          type = "array",
        },
        partnerId = {
          description = "The ID of the partner that owns the parent channel.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    BulkEditSitesResponse = {
      description = "Response message for SiteService.BulkEditSites.",
      id = "BulkEditSitesResponse",
      properties = {
        sites = {
          description = "The list of sites that have been successfully created. This list will be absent if empty.",
          items = {
            ["$ref"] = "Site",
          },
          type = "array",
        },
      },
      type = "object",
    },
    BulkListAdvertiserAssignedTargetingOptionsResponse = {
      id = "BulkListAdvertiserAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent BulkListAdvertiserAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    BulkListCampaignAssignedTargetingOptionsResponse = {
      description = "Response message for BulkListCampaignAssignedTargetingOptions.",
      id = "BulkListCampaignAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent BulkListCampaignAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    BulkListInsertionOrderAssignedTargetingOptionsResponse = {
      description = "Response message for BulkListInsertionOrderAssignedTargetingOptions.",
      id = "BulkListInsertionOrderAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent BulkListInsertionOrderAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    BulkListLineItemAssignedTargetingOptionsResponse = {
      id = "BulkListLineItemAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent BulkListLineItemAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    BusinessChainAssignedTargetingOptionDetails = {
      description = "Details for assigned Business chain targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_BUSINESS_CHAIN`.",
      id = "BusinessChainAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of a business chain, e.g. \"KFC\", \"Chase Bank\".",
          readOnly = true,
          type = "string",
        },
        proximityRadiusAmount = {
          description = "Required. The radius of the area around the business chain that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is `DISTANCE_UNIT_KILOMETERS` and 1 to 500 if unit is `DISTANCE_UNIT_MILES`. The minimum increment for both cases is 0.1. Inputs will be rounded to the nearest acceptable value if it is too granular, e.g. 15.57 will become 15.6.",
          format = "double",
          type = "number",
        },
        proximityRadiusUnit = {
          description = "Required. The unit of distance by which the targeting radius is measured.",
          enum = {
            "DISTANCE_UNIT_UNSPECIFIED",
            "DISTANCE_UNIT_MILES",
            "DISTANCE_UNIT_KILOMETERS",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Miles.",
            "Kilometers.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_BUSINESS_CHAIN`. Accepted business chain targeting option IDs can be retrieved using SearchTargetingOptions.",
          type = "string",
        },
      },
      type = "object",
    },
    BusinessChainSearchTerms = {
      description = "Search terms for Business Chain targeting options. At least one of the field should be populated.",
      id = "BusinessChainSearchTerms",
      properties = {
        businessChainQuery = {
          description = "The search query for the desired business chain. The query must be the full name of the business, e.g. \"KFC\", \"mercedes-benz\".",
          type = "string",
        },
        regionQuery = {
          description = "The search query for the desired geo region, e.g. \"Seattle\", \"United State\".",
          type = "string",
        },
      },
      type = "object",
    },
    BusinessChainTargetingOptionDetails = {
      description = "Represents a targetable business chain within a geo region. This will be populated in the business_chain_details field when targeting_type is `TARGETING_TYPE_BUSINESS_CHAIN`.",
      id = "BusinessChainTargetingOptionDetails",
      properties = {
        businessChain = {
          description = "Output only. The display name of the business chain, e.g. \"KFC\", \"Chase Bank\".",
          readOnly = true,
          type = "string",
        },
        geoRegion = {
          description = "Output only. The display name of the geographic region, e.g. \"Ontario, Canada\".",
          readOnly = true,
          type = "string",
        },
        geoRegionType = {
          description = "Output only. The type of the geographic region.",
          enum = {
            "GEO_REGION_TYPE_UNKNOWN",
            "GEO_REGION_TYPE_OTHER",
            "GEO_REGION_TYPE_COUNTRY",
            "GEO_REGION_TYPE_REGION",
            "GEO_REGION_TYPE_TERRITORY",
            "GEO_REGION_TYPE_PROVINCE",
            "GEO_REGION_TYPE_STATE",
            "GEO_REGION_TYPE_PREFECTURE",
            "GEO_REGION_TYPE_GOVERNORATE",
            "GEO_REGION_TYPE_CANTON",
            "GEO_REGION_TYPE_UNION_TERRITORY",
            "GEO_REGION_TYPE_AUTONOMOUS_COMMUNITY",
            "GEO_REGION_TYPE_DMA_REGION",
            "GEO_REGION_TYPE_METRO",
            "GEO_REGION_TYPE_CONGRESSIONAL_DISTRICT",
            "GEO_REGION_TYPE_COUNTY",
            "GEO_REGION_TYPE_MUNICIPALITY",
            "GEO_REGION_TYPE_CITY",
            "GEO_REGION_TYPE_POSTAL_CODE",
            "GEO_REGION_TYPE_DEPARTMENT",
            "GEO_REGION_TYPE_AIRPORT",
            "GEO_REGION_TYPE_TV_REGION",
            "GEO_REGION_TYPE_OKRUG",
            "GEO_REGION_TYPE_BOROUGH",
            "GEO_REGION_TYPE_CITY_REGION",
            "GEO_REGION_TYPE_ARRONDISSEMENT",
            "GEO_REGION_TYPE_NEIGHBORHOOD",
            "GEO_REGION_TYPE_UNIVERSITY",
            "GEO_REGION_TYPE_DISTRICT",
          },
          enumDescriptions = {
            "The geographic region type is unknown.",
            "The geographic region type is other.",
            "The geographic region is a country.",
            "The geographic region type is region.",
            "The geographic region is a territory.",
            "The geographic region is a province.",
            "The geographic region is a state.",
            "The geographic region is a prefecture.",
            "The geographic region is a governorate.",
            "The geographic region is a canton.",
            "The geographic region is a union territory.",
            "The geographic region is an autonomous community.",
            "The geographic region is a designated market area (DMA) region.",
            "The geographic region type is metro.",
            "The geographic region is a congressional district.",
            "The geographic region is a county.",
            "The geographic region is a municipality.",
            "The geographic region is a city.",
            "The geographic region targeting type is postal code.",
            "The geographic region targeting type is department.",
            "The geographic region is an airport.",
            "The geographic region is a TV region.",
            "The geographic region is an okrug.",
            "The geographic region is a borough.",
            "The geographic region is a city region.",
            "The geographic region is an arrondissement.",
            "The geographic region is a neighborhood.",
            "The geographic region is a university.",
            "The geographic region is a district.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Campaign = {
      description = "A single campaign.",
      id = "Campaign",
      properties = {
        advertiserId = {
          description = "Output only. The unique ID of the advertiser the campaign belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        campaignBudgets = {
          description = "The list of budgets available to this campaign. If this field is not set, the campaign uses an unlimited budget.",
          items = {
            ["$ref"] = "CampaignBudget",
          },
          type = "array",
        },
        campaignFlight = {
          ["$ref"] = "CampaignFlight",
          description = "Required. The planned spend and duration of the campaign.",
        },
        campaignGoal = {
          ["$ref"] = "CampaignGoal",
          description = "Required. The goal of the campaign.",
        },
        campaignId = {
          description = "Output only. The unique ID of the campaign. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the campaign. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        entityStatus = {
          description = "Required. Controls whether or not the insertion orders under this campaign can spend their budgets and bid on inventory. * Accepted values are `ENTITY_STATUS_ACTIVE`, `ENTITY_STATUS_ARCHIVED`, and `ENTITY_STATUS_PAUSED`. * For CreateCampaign method, `ENTITY_STATUS_ARCHIVED` is not allowed.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        frequencyCap = {
          ["$ref"] = "FrequencyCap",
          description = "Required. The frequency cap setting of the campaign.",
        },
        name = {
          description = "Output only. The resource name of the campaign.",
          readOnly = true,
          type = "string",
        },
        updateTime = {
          description = "Output only. The timestamp when the campaign was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    CampaignBudget = {
      description = "Settings that control how the campaign budget is allocated.",
      id = "CampaignBudget",
      properties = {
        budgetAmountMicros = {
          description = "Required. The total amount the linked insertion order segments can budget. The amount is in micros. Must be greater than 0. For example, 500000000 represents 500 standard units of the currency.",
          format = "int64",
          type = "string",
        },
        budgetId = {
          description = "The unique ID of the campaign budget. Assigned by the system. Do not set for new budgets. Must be included when updating or adding budgets to campaign_budgets. Otherwise, a new ID will be generated and assigned.",
          format = "int64",
          type = "string",
        },
        budgetUnit = {
          description = "Required. Immutable. Specifies whether the budget is measured in currency or impressions.",
          enum = {
            "BUDGET_UNIT_UNSPECIFIED",
            "BUDGET_UNIT_CURRENCY",
            "BUDGET_UNIT_IMPRESSIONS",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Budgeting in currency amounts.",
            "Budgeting in impression amounts.",
          },
          type = "string",
        },
        dateRange = {
          ["$ref"] = "DateRange",
          description = "Required. The date range for the campaign budget. Linked budget segments may have a different date range. They are resolved relative to the parent advertiser's time zone. Both `start_date` and `end_date` must be before the year 2037.",
        },
        displayName = {
          description = "Required. The display name of the budget. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        externalBudgetId = {
          description = "Immutable. The ID identifying this budget to the external source. If this field is set and the invoice detail level of the corresponding billing profile is set to \"Budget level PO\", all impressions served against this budget will include this ID on the invoice. Must be unique under the campaign.",
          type = "string",
        },
        externalBudgetSource = {
          description = "Required. The external source of the budget.",
          enum = {
            "EXTERNAL_BUDGET_SOURCE_UNSPECIFIED",
            "EXTERNAL_BUDGET_SOURCE_NONE",
            "EXTERNAL_BUDGET_SOURCE_MEDIA_OCEAN",
          },
          enumDescriptions = {
            "External budget source value is not specified or unknown in this version.",
            "Budget has no external source.",
            "Budget source is Mediaocean.",
          },
          type = "string",
        },
        invoiceGroupingId = {
          description = "Immutable. The ID used to group budgets to be included the same invoice. If this field is set and the invoice level of the corresponding billing profile is set to \"Budget invoice grouping ID\", all external_budget_id sharing the same invoice_grouping_id will be grouped in the same invoice.",
          type = "string",
        },
        prismaConfig = {
          ["$ref"] = "PrismaConfig",
          description = "Additional metadata for use by the Mediaocean Prisma tool. Required for Mediaocean budgets. Only applicable to prisma_enabled advertisers.",
        },
      },
      type = "object",
    },
    CampaignFlight = {
      description = "Settings that track the planned spend and duration of a campaign.",
      id = "CampaignFlight",
      properties = {
        plannedDates = {
          ["$ref"] = "DateRange",
          description = "Required. The dates that the campaign is expected to run. They are resolved relative to the parent advertiser's time zone. * The dates specified here will not affect serving. They are used to generate alerts and warnings. For example, if the flight date of any child insertion order is outside the range of these dates, the user interface will show a warning. * `start_date` is required and must be the current date or later. * `end_date` is optional. If specified, it must be the `start_date` or later. * Any specified date must be before the year 2037.",
        },
        plannedSpendAmountMicros = {
          description = "The amount the campaign is expected to spend for its given planned_dates. This will not limit serving, but will be used for tracking spend in the DV360 UI. The amount is in micros. Must be greater than or equal to 0. For example, 500000000 represents 500 standard units of the currency.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    CampaignGoal = {
      description = "Settings that control the goal of a campaign.",
      id = "CampaignGoal",
      properties = {
        campaignGoalType = {
          description = "Required. The type of the campaign goal.",
          enum = {
            "CAMPAIGN_GOAL_TYPE_UNSPECIFIED",
            "CAMPAIGN_GOAL_TYPE_APP_INSTALL",
            "CAMPAIGN_GOAL_TYPE_BRAND_AWARENESS",
            "CAMPAIGN_GOAL_TYPE_OFFLINE_ACTION",
            "CAMPAIGN_GOAL_TYPE_ONLINE_ACTION",
          },
          enumDescriptions = {
            "Goal value is not specified or unknown in this version.",
            "Drive app installs or engagements.",
            "Raise awareness of a brand or product.",
            "Drive offline or in-store sales.",
            "Drive online action or visits.",
          },
          type = "string",
        },
        performanceGoal = {
          ["$ref"] = "PerformanceGoal",
          description = "Required. The performance goal of the campaign. Acceptable values for performance_goal_type are: * `PERFORMANCE_GOAL_TYPE_CPM` * `PERFORMANCE_GOAL_TYPE_CPC` * `PERFORMANCE_GOAL_TYPE_CPA` * `PERFORMANCE_GOAL_TYPE_CPIAVC` * `PERFORMANCE_GOAL_TYPE_CTR` * `PERFORMANCE_GOAL_TYPE_VIEWABILITY` * `PERFORMANCE_GOAL_TYPE_OTHER`",
        },
      },
      type = "object",
    },
    CarrierAndIspAssignedTargetingOptionDetails = {
      description = "Details for assigned carrier and ISP targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_CARRIER_AND_ISP`.",
      id = "CarrierAndIspAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the carrier or ISP.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted. All assigned carrier and ISP targeting options on the same resource must have the same value for this field.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_CARRIER_AND_ISP`.",
          type = "string",
        },
      },
      type = "object",
    },
    CarrierAndIspTargetingOptionDetails = {
      description = "Represents a targetable carrier or ISP. This will be populated in the carrier_and_isp_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_CARRIER_AND_ISP`.",
      id = "CarrierAndIspTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the carrier or ISP.",
          readOnly = true,
          type = "string",
        },
        type = {
          description = "Output only. The type indicating if it's carrier or ISP.",
          enum = {
            "CARRIER_AND_ISP_TYPE_UNSPECIFIED",
            "CARRIER_AND_ISP_TYPE_ISP",
            "CARRIER_AND_ISP_TYPE_CARRIER",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown in this version.",
            "Indicates this targeting resource refers to an ISP.",
            "Indicates this targeting resource refers to a mobile carrier.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    CategoryAssignedTargetingOptionDetails = {
      description = "Assigned category targeting option details. This will be populated in the category_details field when targeting_type is `TARGETING_TYPE_CATEGORY`.",
      id = "CategoryAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the category.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_CATEGORY`.",
          type = "string",
        },
      },
      type = "object",
    },
    CategoryTargetingOptionDetails = {
      description = "Represents a targetable category. This will be populated in the category_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_CATEGORY`.",
      id = "CategoryTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the category.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Channel = {
      description = "A single channel. Channels are custom groups of related websites and apps.",
      id = "Channel",
      properties = {
        advertiserId = {
          description = "The ID of the advertiser that owns the channel.",
          format = "int64",
          type = "string",
        },
        channelId = {
          description = "Output only. The unique ID of the channel. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the channel. Must be UTF-8 encoded with a maximum length of 240 bytes.",
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the channel.",
          readOnly = true,
          type = "string",
        },
        negativelyTargetedLineItemCount = {
          description = "Output only. Number of line items that are directly targeting this channel negatively.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        partnerId = {
          description = "The ID of the partner that owns the channel.",
          format = "int64",
          type = "string",
        },
        positivelyTargetedLineItemCount = {
          description = "Output only. Number of line items that are directly targeting this channel positively.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ChannelAssignedTargetingOptionDetails = {
      description = "Details for assigned channel targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_CHANNEL`.",
      id = "ChannelAssignedTargetingOptionDetails",
      properties = {
        channelId = {
          description = "Required. ID of the channel. Should refer to the channel ID field on a [Partner-owned channel](partners.channels#Channel.FIELDS.channel_id) or [advertiser-owned channel](advertisers.channels#Channel.FIELDS.channel_id) resource.",
          format = "int64",
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted. For advertiser level assigned targeting option, this field must be true.",
          type = "boolean",
        },
      },
      type = "object",
    },
    CmHybridConfig = {
      description = "Settings for advertisers that use both Campaign Manager 360 (CM360) and third-party ad servers.",
      id = "CmHybridConfig",
      properties = {
        cmAccountId = {
          description = "Required. Immutable. Account ID of the CM360 Floodlight configuration linked with the DV360 advertiser.",
          format = "int64",
          type = "string",
        },
        cmFloodlightConfigId = {
          description = "Required. Immutable. ID of the CM360 Floodlight configuration linked with the DV360 advertiser.",
          format = "int64",
          type = "string",
        },
        cmFloodlightLinkingAuthorized = {
          description = "Required. Immutable. By setting this field to `true`, you, on behalf of your company, authorize the sharing of information from the given Floodlight configuration to this Display & Video 360 advertiser.",
          type = "boolean",
        },
        cmSyncableSiteIds = {
          description = "A list of CM360 sites whose placements will be synced to DV360 as creatives. If absent or empty in CreateAdvertiser method, the system will automatically create a CM360 site. Removing sites from this list may cause DV360 creatives synced from CM360 to be deleted. At least one site must be specified.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        dv360ToCmCostReportingEnabled = {
          description = "Whether or not to report DV360 cost to CM360.",
          type = "boolean",
        },
        dv360ToCmDataSharingEnabled = {
          description = "Whether or not to include DV360 data in CM360 data transfer reports.",
          type = "boolean",
        },
      },
      type = "object",
    },
    CmTrackingAd = {
      description = "A Campaign Manager 360 tracking ad.",
      id = "CmTrackingAd",
      properties = {
        cmAdId = {
          description = "The ad ID of the campaign manager 360 tracking Ad.",
          format = "int64",
          type = "string",
        },
        cmCreativeId = {
          description = "The creative ID of the campaign manager 360 tracking Ad.",
          format = "int64",
          type = "string",
        },
        cmPlacementId = {
          description = "The placement ID of the campaign manager 360 tracking Ad.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    CombinedAudience = {
      description = "Describes a combined audience resource.",
      id = "CombinedAudience",
      properties = {
        combinedAudienceId = {
          description = "Output only. The unique ID of the combined audience. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Output only. The display name of the combined audience. .",
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the combined audience.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    CombinedAudienceGroup = {
      description = "Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.",
      id = "CombinedAudienceGroup",
      properties = {
        settings = {
          description = "Required. All combined audience targeting settings in combined audience group. Repeated settings with same id will be ignored. The number of combined audience settings should be no more than five, error will be thrown otherwise.",
          items = {
            ["$ref"] = "CombinedAudienceTargetingSetting",
          },
          type = "array",
        },
      },
      type = "object",
    },
    CombinedAudienceTargetingSetting = {
      description = "Details of combined audience targeting setting.",
      id = "CombinedAudienceTargetingSetting",
      properties = {
        combinedAudienceId = {
          description = "Required. Combined audience id of combined audience targeting setting. This id is combined_audience_id.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ContactInfo = {
      description = "Contact information defining a Customer Match audience member.",
      id = "ContactInfo",
      properties = {
        countryCode = {
          description = "Country code of the member. Must also be set with the following fields: * hashed_first_name * hashed_last_name * zip_codes",
          type = "string",
        },
        hashedEmails = {
          description = "A list of SHA256 hashed email of the member. Before hashing, remove all whitespace and make sure the string is all lowercase.",
          items = {
            type = "string",
          },
          type = "array",
        },
        hashedFirstName = {
          description = "SHA256 hashed first name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_last_name * zip_codes",
          type = "string",
        },
        hashedLastName = {
          description = "SHA256 hashed last name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_first_name * zip_codes",
          type = "string",
        },
        hashedPhoneNumbers = {
          description = "A list of SHA256 hashed phone numbers of the member. Before hashing, all phone numbers must be formatted using the [E.164 format](//en.wikipedia.org/wiki/E.164) and include the country calling code.",
          items = {
            type = "string",
          },
          type = "array",
        },
        zipCodes = {
          description = "A list of zip codes of the member. Must also be set with the following fields: * country_code * hashed_first_name * hashed_last_name",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ContactInfoList = {
      description = "Wrapper message for a list of contact information defining Customer Match audience members.",
      id = "ContactInfoList",
      properties = {
        contactInfos = {
          description = "A list of ContactInfo objects defining Customer Match audience members. The size of members after splitting the contact_infos mustn't be greater than 500,000.",
          items = {
            ["$ref"] = "ContactInfo",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ContentDurationAssignedTargetingOptionDetails = {
      description = "Details for content duration assigned targeting option. This will be populated in the content_duration_details field when targeting_type is `TARGETING_TYPE_CONTENT_DURATION`. Explicitly targeting all options is not supported. Remove all content duration targeting options to achieve this effect.",
      id = "ContentDurationAssignedTargetingOptionDetails",
      properties = {
        contentDuration = {
          description = "Output only. The content duration.",
          enum = {
            "CONTENT_DURATION_UNSPECIFIED",
            "CONTENT_DURATION_UNKNOWN",
            "CONTENT_DURATION_0_TO_1_MIN",
            "CONTENT_DURATION_1_TO_5_MIN",
            "CONTENT_DURATION_5_TO_15_MIN",
            "CONTENT_DURATION_15_TO_30_MIN",
            "CONTENT_DURATION_30_TO_60_MIN",
            "CONTENT_DURATION_OVER_60_MIN",
          },
          enumDescriptions = {
            "Content duration is not specified in this version. This enum is a place holder for a default value and does not represent a real content duration.",
            "The content duration is unknown.",
            "Content is 0-1 minute long.",
            "Content is 1-5 minutes long.",
            "Content is 5-15 minutes long.",
            "Content is 15-30 minutes long.",
            "Content is 30-60 minutes long.",
            "Content is over 60 minutes long.",
          },
          readOnly = true,
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_CONTENT_DURATION`.",
          type = "string",
        },
      },
      type = "object",
    },
    ContentDurationTargetingOptionDetails = {
      description = "Represents a targetable content duration. This will be populated in the content_duration_details field when targeting_type is `TARGETING_TYPE_CONTENT_DURATION`.",
      id = "ContentDurationTargetingOptionDetails",
      properties = {
        contentDuration = {
          description = "Output only. The content duration.",
          enum = {
            "CONTENT_DURATION_UNSPECIFIED",
            "CONTENT_DURATION_UNKNOWN",
            "CONTENT_DURATION_0_TO_1_MIN",
            "CONTENT_DURATION_1_TO_5_MIN",
            "CONTENT_DURATION_5_TO_15_MIN",
            "CONTENT_DURATION_15_TO_30_MIN",
            "CONTENT_DURATION_30_TO_60_MIN",
            "CONTENT_DURATION_OVER_60_MIN",
          },
          enumDescriptions = {
            "Content duration is not specified in this version. This enum is a place holder for a default value and does not represent a real content duration.",
            "The content duration is unknown.",
            "Content is 0-1 minute long.",
            "Content is 1-5 minutes long.",
            "Content is 5-15 minutes long.",
            "Content is 15-30 minutes long.",
            "Content is 30-60 minutes long.",
            "Content is over 60 minutes long.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ContentGenreAssignedTargetingOptionDetails = {
      description = "Details for content genre assigned targeting option. This will be populated in the content_genre_details field when targeting_type is `TARGETING_TYPE_CONTENT_GENRE`. Explicitly targeting all options is not supported. Remove all content genre targeting options to achieve this effect.",
      id = "ContentGenreAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the content genre.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_CONTENT_GENRE`.",
          type = "string",
        },
      },
      type = "object",
    },
    ContentGenreTargetingOptionDetails = {
      description = "Represents a targetable content genre. This will be populated in the content_genre_details field when targeting_type is `TARGETING_TYPE_CONTENT_GENRE`.",
      id = "ContentGenreTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the content genre",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ContentInstreamPositionAssignedTargetingOptionDetails = {
      description = "Assigned content instream position targeting option details. This will be populated in the content_instream_position_details field when targeting_type is `TARGETING_TYPE_CONTENT_INSTREAM_POSITION`.",
      id = "ContentInstreamPositionAssignedTargetingOptionDetails",
      properties = {
        adType = {
          description = "Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * `AD_TYPE_VIDEO`, the setting will be inherited by new line item when line_item_type is `LINE_ITEM_TYPE_VIDEO_DEFAULT`. * `AD_TYPE_AUDIO`, the setting will be inherited by new line item when line_item_type is `LINE_ITEM_TYPE_AUDIO_DEFAULT`.",
          enum = {
            "AD_TYPE_UNSPECIFIED",
            "AD_TYPE_DISPLAY",
            "AD_TYPE_VIDEO",
            "AD_TYPE_AUDIO",
          },
          enumDescriptions = {
            "Ad type is not specified or is unknown in this version.",
            "Display creatives, e.g. image and HTML5.",
            "Video creatives, e.g. video ads that play during streaming content in video players.",
            "Audio creatives, e.g. audio ads that play during audio content.",
          },
          readOnly = true,
          type = "string",
        },
        contentInstreamPosition = {
          description = "The content instream position for video or audio ads. Output only in v1. Required in v2.",
          enum = {
            "CONTENT_INSTREAM_POSITION_UNSPECIFIED",
            "CONTENT_INSTREAM_POSITION_PRE_ROLL",
            "CONTENT_INSTREAM_POSITION_MID_ROLL",
            "CONTENT_INSTREAM_POSITION_POST_ROLL",
            "CONTENT_INSTREAM_POSITION_UNKNOWN",
          },
          enumDescriptions = {
            "Content instream position is not specified in this version. This enum is a place holder for a default value and does not represent a real in stream ad position.",
            "Ads that play before streaming content.",
            "Ads that play between the beginning and end of streaming content.",
            "Ads that play at the end of streaming content.",
            "Ads instream position is unknown.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_CONTENT_INSTREAM_POSITION`.",
          type = "string",
        },
      },
      type = "object",
    },
    ContentInstreamPositionTargetingOptionDetails = {
      description = "Represents a targetable content instream position, which could be used by video and audio ads. This will be populated in the content_instream_position_details field when targeting_type is `TARGETING_TYPE_CONTENT_INSTREAM_POSITION`.",
      id = "ContentInstreamPositionTargetingOptionDetails",
      properties = {
        contentInstreamPosition = {
          description = "Output only. The content instream position.",
          enum = {
            "CONTENT_INSTREAM_POSITION_UNSPECIFIED",
            "CONTENT_INSTREAM_POSITION_PRE_ROLL",
            "CONTENT_INSTREAM_POSITION_MID_ROLL",
            "CONTENT_INSTREAM_POSITION_POST_ROLL",
            "CONTENT_INSTREAM_POSITION_UNKNOWN",
          },
          enumDescriptions = {
            "Content instream position is not specified in this version. This enum is a place holder for a default value and does not represent a real in stream ad position.",
            "Ads that play before streaming content.",
            "Ads that play between the beginning and end of streaming content.",
            "Ads that play at the end of streaming content.",
            "Ads instream position is unknown.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ContentOutstreamPositionAssignedTargetingOptionDetails = {
      description = "Assigned content outstream position targeting option details. This will be populated in the content_outstream_position_details field when targeting_type is `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION`.",
      id = "ContentOutstreamPositionAssignedTargetingOptionDetails",
      properties = {
        adType = {
          description = "Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * `AD_TYPE_DISPLAY`, the setting will be inherited by new line item when line_item_type is `LINE_ITEM_TYPE_DISPLAY_DEFAULT`. * `AD_TYPE_VIDEO`, the setting will be inherited by new line item when line_item_type is `LINE_ITEM_TYPE_VIDEO_DEFAULT`.",
          enum = {
            "AD_TYPE_UNSPECIFIED",
            "AD_TYPE_DISPLAY",
            "AD_TYPE_VIDEO",
            "AD_TYPE_AUDIO",
          },
          enumDescriptions = {
            "Ad type is not specified or is unknown in this version.",
            "Display creatives, e.g. image and HTML5.",
            "Video creatives, e.g. video ads that play during streaming content in video players.",
            "Audio creatives, e.g. audio ads that play during audio content.",
          },
          readOnly = true,
          type = "string",
        },
        contentOutstreamPosition = {
          description = "The content outstream position. Output only in v1. Required in v2.",
          enum = {
            "CONTENT_OUTSTREAM_POSITION_UNSPECIFIED",
            "CONTENT_OUTSTREAM_POSITION_UNKNOWN",
            "CONTENT_OUTSTREAM_POSITION_IN_ARTICLE",
            "CONTENT_OUTSTREAM_POSITION_IN_BANNER",
            "CONTENT_OUTSTREAM_POSITION_IN_FEED",
            "CONTENT_OUTSTREAM_POSITION_INTERSTITIAL",
          },
          enumDescriptions = {
            "Content outstream position is not specified in this version. This enum is a place holder for a default value and does not represent a real content outstream position.",
            "The ad position is unknown in the content outstream.",
            "Ads that appear between the paragraphs of your pages.",
            "Ads that display on the top and the sides of a page.",
            "Ads that appear in a scrollable stream of content. A feed is typically editorial (e.g. a list of articles or news) or listings (e.g. a list of products or services).",
            "Ads shown before or between content loads.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION`.",
          type = "string",
        },
      },
      type = "object",
    },
    ContentOutstreamPositionTargetingOptionDetails = {
      description = "Represents a targetable content outstream position, which could be used by display and video ads. This will be populated in the content_outstream_position_details field when targeting_type is `TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION`.",
      id = "ContentOutstreamPositionTargetingOptionDetails",
      properties = {
        contentOutstreamPosition = {
          description = "Output only. The content outstream position.",
          enum = {
            "CONTENT_OUTSTREAM_POSITION_UNSPECIFIED",
            "CONTENT_OUTSTREAM_POSITION_UNKNOWN",
            "CONTENT_OUTSTREAM_POSITION_IN_ARTICLE",
            "CONTENT_OUTSTREAM_POSITION_IN_BANNER",
            "CONTENT_OUTSTREAM_POSITION_IN_FEED",
            "CONTENT_OUTSTREAM_POSITION_INTERSTITIAL",
          },
          enumDescriptions = {
            "Content outstream position is not specified in this version. This enum is a place holder for a default value and does not represent a real content outstream position.",
            "The ad position is unknown in the content outstream.",
            "Ads that appear between the paragraphs of your pages.",
            "Ads that display on the top and the sides of a page.",
            "Ads that appear in a scrollable stream of content. A feed is typically editorial (e.g. a list of articles or news) or listings (e.g. a list of products or services).",
            "Ads shown before or between content loads.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ContentStreamTypeAssignedTargetingOptionDetails = {
      description = "Details for content stream type assigned targeting option. This will be populated in the content_stream_type_details field when targeting_type is `TARGETING_TYPE_CONTENT_STREAM_TYPE`. Explicitly targeting all options is not supported. Remove all content stream type targeting options to achieve this effect.",
      id = "ContentStreamTypeAssignedTargetingOptionDetails",
      properties = {
        contentStreamType = {
          description = "Output only. The content stream type.",
          enum = {
            "CONTENT_STREAM_TYPE_UNSPECIFIED",
            "CONTENT_LIVE_STREAM",
            "CONTENT_ON_DEMAND",
          },
          enumDescriptions = {
            "Content stream type is not specified in this version. This enum is a place holder for a default value and does not represent a real content stream type.",
            "The content is being live-streamed.",
            "The content is viewed on-demand.",
          },
          readOnly = true,
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_CONTENT_STREAM_TYPE`.",
          type = "string",
        },
      },
      type = "object",
    },
    ContentStreamTypeTargetingOptionDetails = {
      description = "Represents a targetable content stream type. This will be populated in the content_stream_type_details field when targeting_type is `TARGETING_TYPE_CONTENT_STREAM_TYPE`.",
      id = "ContentStreamTypeTargetingOptionDetails",
      properties = {
        contentStreamType = {
          description = "Output only. The content stream type.",
          enum = {
            "CONTENT_STREAM_TYPE_UNSPECIFIED",
            "CONTENT_LIVE_STREAM",
            "CONTENT_ON_DEMAND",
          },
          enumDescriptions = {
            "Content stream type is not specified in this version. This enum is a place holder for a default value and does not represent a real content stream type.",
            "The content is being live-streamed.",
            "The content is viewed on-demand.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ConversionCountingConfig = {
      description = "Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting.",
      id = "ConversionCountingConfig",
      properties = {
        floodlightActivityConfigs = {
          description = "The Floodlight activity configs used to track conversions. The number of conversions counted is the sum of all of the conversions counted by all of the Floodlight activity IDs specified in this field.",
          items = {
            ["$ref"] = "TrackingFloodlightActivityConfig",
          },
          type = "array",
        },
        postViewCountPercentageMillis = {
          description = "The percentage of post-view conversions to count, in millis (1/1000 of a percent). Must be between 0 and 100000 inclusive. For example, to track 50% of the post-click conversions, set a value of 50000.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    CounterEvent = {
      description = "Counter event of the creative.",
      id = "CounterEvent",
      properties = {
        name = {
          description = "Required. The name of the counter event.",
          type = "string",
        },
        reportingName = {
          description = "Required. The name used to identify this counter event in reports.",
          type = "string",
        },
      },
      type = "object",
    },
    CreateAssetRequest = {
      description = "A request message for CreateAsset.",
      id = "CreateAssetRequest",
      properties = {
        filename = {
          description = "Required. The filename of the asset, including the file extension. The filename must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
      },
      type = "object",
    },
    CreateAssetResponse = {
      description = "A response message for CreateAsset.",
      id = "CreateAssetResponse",
      properties = {
        asset = {
          ["$ref"] = "Asset",
          description = "The uploaded asset, if successful.",
        },
      },
      type = "object",
    },
    CreateAssignedTargetingOptionsRequest = {
      description = "A request listing which assigned targeting options of a given targeting type should be created and added.",
      id = "CreateAssignedTargetingOptionsRequest",
      properties = {
        assignedTargetingOptions = {
          description = "Required. The assigned targeting options to create and add.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        targetingType = {
          description = "Required. Identifies the type of this assigned targeting option.",
          enum = {
            "TARGETING_TYPE_UNSPECIFIED",
            "TARGETING_TYPE_CHANNEL",
            "TARGETING_TYPE_APP_CATEGORY",
            "TARGETING_TYPE_APP",
            "TARGETING_TYPE_URL",
            "TARGETING_TYPE_DAY_AND_TIME",
            "TARGETING_TYPE_AGE_RANGE",
            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
            "TARGETING_TYPE_GENDER",
            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
            "TARGETING_TYPE_USER_REWARDED_CONTENT",
            "TARGETING_TYPE_PARENTAL_STATUS",
            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
            "TARGETING_TYPE_DEVICE_TYPE",
            "TARGETING_TYPE_AUDIENCE_GROUP",
            "TARGETING_TYPE_BROWSER",
            "TARGETING_TYPE_HOUSEHOLD_INCOME",
            "TARGETING_TYPE_ON_SCREEN_POSITION",
            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
            "TARGETING_TYPE_ENVIRONMENT",
            "TARGETING_TYPE_CARRIER_AND_ISP",
            "TARGETING_TYPE_OPERATING_SYSTEM",
            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
            "TARGETING_TYPE_KEYWORD",
            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
            "TARGETING_TYPE_VIEWABILITY",
            "TARGETING_TYPE_CATEGORY",
            "TARGETING_TYPE_INVENTORY_SOURCE",
            "TARGETING_TYPE_LANGUAGE",
            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
            "TARGETING_TYPE_GEO_REGION",
            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
            "TARGETING_TYPE_EXCHANGE",
            "TARGETING_TYPE_SUB_EXCHANGE",
            "TARGETING_TYPE_POI",
            "TARGETING_TYPE_BUSINESS_CHAIN",
            "TARGETING_TYPE_CONTENT_DURATION",
            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
            "TARGETING_TYPE_OMID",
            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
            "TARGETING_TYPE_CONTENT_GENRE",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown in this version.",
            "Target a channel (a custom group of related websites or apps).",
            "Target an app category (for example, education or puzzle games).",
            "Target a specific app (for example, Angry Birds).",
            "Target a specific url (for example, quora.com).",
            "Target ads during a chosen time period on a specific day.",
            "Target ads to a specific age range (for example, 18-24).",
            "Target ads to the specified regions on a regional location list.",
            "Target ads to the specified points of interest on a proximity location list.",
            "Target ads to a specific gender (for example, female or male).",
            "Target a specific video player size for video ads.",
            "Target user rewarded content for video ads.",
            "Target ads to a specific parental status (for example, parent or not a parent).",
            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
            "Target ads in a specific content outstream position.",
            "Target ads to a specific device type (for example, tablet or connected TV).",
            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
            "Target ads to specific web browsers (for example, Chrome).",
            "Target ads to a specific household income range (for example, top 10%).",
            "Target ads in a specific on screen position.",
            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
            "Filter website content by sensitive categories (for example, adult).",
            "Target ads to a specific environment (for example, web or app).",
            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
            "Target ads to a specific operating system (for example, macOS).",
            "Target ads to a specific device make or model (for example, Roku or Samsung).",
            "Target ads to a specific keyword (for example, dog or retriever).",
            "Target ads to a specific negative keyword list.",
            "Target ads to a specific viewability (for example, 80% viewable).",
            "Target ads to a specific content category (for example, arts & entertainment).",
            "Purchase impressions from specific deals and auction packages.",
            "Target ads to a specific language (for example, English or Japanese).",
            "Target ads to ads.txt authorized sellers.",
            "Target ads to a specific regional location (for example, a city or state).",
            "Purchase impressions from a group of deals and auction packages.",
            "Purchase impressions from specific exchanges.",
            "Purchase impressions from specific sub-exchanges.",
            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
            "Target ads around locations of a business chain within a specific geo region.",
            "Target ads to a specific video content duration.",
            "Target ads to a specific video content stream type.",
            "Target ads to a specific native content position.",
            "Target ads in an Open Measurement enabled inventory.",
            "Target ads to a specific audio content type.",
            "Target ads to a specific content genre.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    CreateSdfDownloadTaskRequest = {
      description = "Request message for [SdfDownloadTaskService.CreateSdfDownloadTask].",
      id = "CreateSdfDownloadTaskRequest",
      properties = {
        advertiserId = {
          description = "The ID of the advertiser to download SDF for.",
          format = "int64",
          type = "string",
        },
        idFilter = {
          ["$ref"] = "IdFilter",
          description = "Filters on entities by their entity IDs.",
        },
        inventorySourceFilter = {
          ["$ref"] = "InventorySourceFilter",
          description = "Filters on Inventory Sources by their IDs.",
        },
        parentEntityFilter = {
          ["$ref"] = "ParentEntityFilter",
          description = "Filters on selected file types. The entities in each file are filtered by a chosen set of filter entities. The filter entities must be the same type as, or a parent type of, the selected file types.",
        },
        partnerId = {
          description = "The ID of the partner to download SDF for.",
          format = "int64",
          type = "string",
        },
        version = {
          description = "Required. The SDF version of the downloaded file. If set to `SDF_VERSION_UNSPECIFIED`, this will default to the version specified by the advertiser or partner identified by `root_id`. An advertiser inherits its SDF version from its partner unless configured otherwise.",
          enum = {
            "SDF_VERSION_UNSPECIFIED",
            "SDF_VERSION_3_1",
            "SDF_VERSION_4",
            "SDF_VERSION_4_1",
            "SDF_VERSION_4_2",
            "SDF_VERSION_5",
            "SDF_VERSION_5_1",
            "SDF_VERSION_5_2",
            "SDF_VERSION_5_3",
            "SDF_VERSION_5_4",
            "SDF_VERSION_5_5",
          },
          enumDescriptions = {
            "SDF version value is not specified or is unknown in this version.",
            "SDF version 3.1",
            "SDF version 4",
            "SDF version 4.1",
            "SDF version 4.2",
            "SDF version 5.",
            "SDF version 5.1",
            "SDF version 5.2",
            "SDF version 5.3",
            "SDF version 5.4",
            "SDF version 5.5",
          },
          type = "string",
        },
      },
      type = "object",
    },
    Creative = {
      description = "A single Creative.",
      id = "Creative",
      properties = {
        additionalDimensions = {
          description = "Additional dimensions. Applicable when creative_type is one of: * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_EXPANDABLE` * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_TEMPLATED_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_LIGHTBOX` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_PUBLISHER_HOSTED` If this field is specified, width_pixels and height_pixels are both required and must be greater than or equal to 0.",
          items = {
            ["$ref"] = "Dimensions",
          },
          type = "array",
        },
        advertiserId = {
          description = "Output only. The unique ID of the advertiser the creative belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        appendedTag = {
          description = "Third-party HTML tracking tag to be appended to the creative tag.",
          type = "string",
        },
        assets = {
          description = "Required. Assets associated to this creative. Assets can be associated to the creative in one of following roles: * `ASSET_ROLE_UNSPECIFIED` * `ASSET_ROLE_MAIN` * `ASSET_ROLE_BACKUP` * `ASSET_ROLE_POLITE_LOAD`",
          items = {
            ["$ref"] = "AssetAssociation",
          },
          type = "array",
        },
        cmPlacementId = {
          description = "Output only. The unique ID of the Campaign Manager 360 placement associated with the creative. This field is only applicable for creatives that are synced from Campaign Manager.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        cmTrackingAd = {
          ["$ref"] = "CmTrackingAd",
          description = "The Campaign Manager 360 tracking ad associated with the creative. Optional for the following creative_type when created by an advertiser that uses both Campaign Manager 360 and third-party ad serving: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` Output only for other cases.",
        },
        companionCreativeIds = {
          description = "The IDs of companion creatives for a video creative. You can assign existing display creatives (with image or HTML5 assets) to serve surrounding the publisher's video player. Companions display around the video player while the video is playing and remain after the video has completed. Creatives contain additional dimensions can not be companion creatives. This field is only supported for following creative_type: * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_VIDEO`",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        counterEvents = {
          description = "Counter events for a rich media creative. Counters track the number of times that a user interacts with any part of a rich media creative in a specified way (mouse-overs, mouse-outs, clicks, taps, data loading, keyboard entries, etc.). Any event that can be captured in the creative can be recorded as a counter. Leave it empty or unset for creatives containing image assets only.",
          items = {
            ["$ref"] = "CounterEvent",
          },
          type = "array",
        },
        createTime = {
          description = "Output only. The timestamp when the creative was created. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        creativeAttributes = {
          description = "Output only. A list of attributes of the creative that is generated by the system.",
          items = {
            enum = {
              "CREATIVE_ATTRIBUTE_UNSPECIFIED",
              "CREATIVE_ATTRIBUTE_VAST",
              "CREATIVE_ATTRIBUTE_VPAID_LINEAR",
              "CREATIVE_ATTRIBUTE_VPAID_NON_LINEAR",
            },
            enumDescriptions = {
              "The creative attribute is not specified or is unknown in this version.",
              "The creative is a VAST creative.",
              "The creative is a linear VPAID creative.",
              "The creative is a non-linear VPAID creative.",
            },
            type = "string",
          },
          readOnly = true,
          type = "array",
        },
        creativeId = {
          description = "Output only. The unique ID of the creative. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        creativeType = {
          description = "Required. Immutable. The type of the creative.",
          enum = {
            "CREATIVE_TYPE_UNSPECIFIED",
            "CREATIVE_TYPE_STANDARD",
            "CREATIVE_TYPE_EXPANDABLE",
            "CREATIVE_TYPE_VIDEO",
            "CREATIVE_TYPE_NATIVE",
            "CREATIVE_TYPE_TEMPLATED_APP_INSTALL",
            "CREATIVE_TYPE_NATIVE_SITE_SQUARE",
            "CREATIVE_TYPE_TEMPLATED_APP_INSTALL_INTERSTITIAL",
            "CREATIVE_TYPE_LIGHTBOX",
            "CREATIVE_TYPE_NATIVE_APP_INSTALL",
            "CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE",
            "CREATIVE_TYPE_AUDIO",
            "CREATIVE_TYPE_PUBLISHER_HOSTED",
            "CREATIVE_TYPE_NATIVE_VIDEO",
            "CREATIVE_TYPE_TEMPLATED_APP_INSTALL_VIDEO",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Standard display creative. Create and update methods are supported for this creative type if the hosting_source is one of the following: * `HOSTING_SOURCE_HOSTED` * `HOSTING_SOURCE_THIRD_PARTY`",
            "Expandable creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_THIRD_PARTY`",
            "Video creative. Create and update methods are supported for this creative type if the hosting_source is one of the following: * `HOSTING_SOURCE_HOSTED` * `HOSTING_SOURCE_THIRD_PARTY`",
            "Native creative rendered by publishers with assets from advertiser. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Templated app install mobile creative (banner). Create and update methods are **not** supported for this creative type.",
            "Square native creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Interstitial creative including both display and video. Create and update methods are **not** supported for this creative type.",
            "Responsive and expandable Lightbox creative. Create and update methods are **not** supported for this creative type.",
            "Native app install creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Square native app install creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Audio creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Publisher hosted creative. Create and update methods are **not** supported for this creative type.",
            "Native video creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Templated app install mobile video creative. Create and update methods are **not** supported for this creative type.",
          },
          type = "string",
        },
        dimensions = {
          ["$ref"] = "Dimensions",
          description = "Required. Primary dimensions of the creative. Applicable to all creative types. The value of width_pixels and height_pixels defaults to `0` when creative_type is one of: * `CREATIVE_TYPE_VIDEO` * `CREATIVE_TYPE_TEMPLATED_APP_INSTALL_INTERSTITIAL` * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_NATIVE_VIDEO` * `CREATIVE_TYPE_TEMPLATED_APP_INSTALL_VIDEO`",
        },
        displayName = {
          description = "Required. The display name of the creative. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        dynamic = {
          description = "Output only. Indicates whether the creative is dynamic.",
          readOnly = true,
          type = "boolean",
        },
        entityStatus = {
          description = "Required. Controls whether or not the creative can serve. Accepted values are: * `ENTITY_STATUS_ACTIVE` * `ENTITY_STATUS_ARCHIVED` * `ENTITY_STATUS_PAUSED`",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        exitEvents = {
          description = "Required. Exit events for this creative. An exit (also known as a click tag) is any area in your creative that someone can click or tap to open an advertiser's landing page. Every creative must include at least one exit. You can add an exit to your creative in any of the following ways: * Use Google Web Designer's tap area. * Define a JavaScript variable called \"clickTag\". * Use the Enabler (Enabler.exit()) to track exits in rich media formats.",
          items = {
            ["$ref"] = "ExitEvent",
          },
          type = "array",
        },
        expandOnHover = {
          description = "Optional. Indicates the creative will automatically expand on hover. Optional and only valid for third-party expandable creatives. Third-party expandable creatives are creatives with following hosting source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_EXPANDABLE`",
          type = "boolean",
        },
        expandingDirection = {
          description = "Optional. Specifies the expanding direction of the creative. Required and only valid for third-party expandable creatives. Third-party expandable creatives are creatives with following hosting source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_EXPANDABLE`",
          enum = {
            "EXPANDING_DIRECTION_UNSPECIFIED",
            "EXPANDING_DIRECTION_NONE",
            "EXPANDING_DIRECTION_UP",
            "EXPANDING_DIRECTION_DOWN",
            "EXPANDING_DIRECTION_LEFT",
            "EXPANDING_DIRECTION_RIGHT",
            "EXPANDING_DIRECTION_UP_AND_LEFT",
            "EXPANDING_DIRECTION_UP_AND_RIGHT",
            "EXPANDING_DIRECTION_DOWN_AND_LEFT",
            "EXPANDING_DIRECTION_DOWN_AND_RIGHT",
            "EXPANDING_DIRECTION_UP_OR_DOWN",
            "EXPANDING_DIRECTION_LEFT_OR_RIGHT",
            "EXPANDING_DIRECTION_ANY_DIAGONAL",
          },
          enumDescriptions = {
            "The expanding direction is not specified.",
            "Does not expand in any direction.",
            "Expands up.",
            "Expands down.",
            "Expands left.",
            "Expands right.",
            "Expands up and to the left side.",
            "Expands up and to the right side.",
            "Expands down and to the left side.",
            "Expands down and to the right side.",
            "Expands either up or down.",
            "Expands to either the left or the right side.",
            "Can expand in any diagonal direction.",
          },
          type = "string",
        },
        hostingSource = {
          description = "Required. Indicates where the creative is hosted.",
          enum = {
            "HOSTING_SOURCE_UNSPECIFIED",
            "HOSTING_SOURCE_CM",
            "HOSTING_SOURCE_THIRD_PARTY",
            "HOSTING_SOURCE_HOSTED",
            "HOSTING_SOURCE_RICH_MEDIA",
          },
          enumDescriptions = {
            "Hosting source is not specified or is unknown in this version.",
            "A creative synced from Campaign Manager 360. Create and update methods are **not** supported for this hosting type.",
            "A creative hosted by a third-party ad server (3PAS). Create and update methods are supported for this hosting type if the creative_type is one of the following: * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_EXPANDABLE` * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_VIDEO`",
            "A creative created in DV360 and hosted by Campaign Manager 360. Create and update methods are supported for this hosting type if the creative_type is one of the following: * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO` * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_VIDEO`",
            "A rich media creative created in Studio and hosted by Campaign Manager 360. Create and update methods are **not** supported for this hosting type.",
          },
          type = "string",
        },
        html5Video = {
          description = "Output only. Indicates the third-party VAST tag creative requires HTML5 Video support. Output only and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_VIDEO`",
          readOnly = true,
          type = "boolean",
        },
        iasCampaignMonitoring = {
          description = "Indicates whether Integral Ad Science (IAS) campaign monitoring is enabled. To enable this for the creative, make sure the Advertiser.creative_config.ias_client_id has been set to your IAS client ID.",
          type = "boolean",
        },
        integrationCode = {
          description = "ID information used to link this creative to an external system. Must be UTF-8 encoded with a length of no more than 10,000 characters.",
          type = "string",
        },
        jsTrackerUrl = {
          description = "JavaScript measurement URL from supported third-party verification providers (ComScore, DoubleVerify, IAS, Moat). HTML script tags are not supported. This field is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
          type = "string",
        },
        lineItemIds = {
          description = "Output only. The IDs of the line items this creative is associated with. To associate a creative to a line item, use LineItem.creative_ids instead.",
          items = {
            format = "int64",
            type = "string",
          },
          readOnly = true,
          type = "array",
        },
        mediaDuration = {
          description = "Output only. Media duration of the creative. Applicable when creative_type is one of: * `CREATIVE_TYPE_VIDEO` * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_NATIVE_VIDEO` * `CREATIVE_TYPE_PUBLISHER_HOSTED`",
          format = "google-duration",
          readOnly = true,
          type = "string",
        },
        mp3Audio = {
          description = "Output only. Indicates the third-party audio creative supports MP3. Output only and only valid for third-party audio creatives. Third-party audio creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_AUDIO`",
          readOnly = true,
          type = "boolean",
        },
        name = {
          description = "Output only. The resource name of the creative.",
          readOnly = true,
          type = "string",
        },
        notes = {
          description = "User notes for this creative. Must be UTF-8 encoded with a length of no more than 20,000 characters.",
          type = "string",
        },
        obaIcon = {
          ["$ref"] = "ObaIcon",
          description = "Specifies the OBA icon for a video creative. This field is only supported in following creative_type: * `CREATIVE_TYPE_VIDEO`",
        },
        oggAudio = {
          description = "Output only. Indicates the third-party audio creative supports OGG. Output only and only valid for third-party audio creatives. Third-party audio creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_AUDIO`",
          readOnly = true,
          type = "boolean",
        },
        progressOffset = {
          ["$ref"] = "AudioVideoOffset",
          description = "Amount of time to play the video before counting a view. This field is required when skippable is true. This field is only supported for the following creative_type: * `CREATIVE_TYPE_VIDEO`",
        },
        requireHtml5 = {
          description = "Optional. Indicates that the creative relies on HTML5 to render properly. Optional and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_EXPANDABLE`",
          type = "boolean",
        },
        requireMraid = {
          description = "Optional. Indicates that the creative requires MRAID (Mobile Rich Media Ad Interface Definitions system). Set this if the creative relies on mobile gestures for interactivity, such as swiping or tapping. Optional and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_EXPANDABLE`",
          type = "boolean",
        },
        requirePingForAttribution = {
          description = "Optional. Indicates that the creative will wait for a return ping for attribution. Only valid when using a Campaign Manager 360 tracking ad with a third-party ad server parameter and the ${DC_DBM_TOKEN} macro. Optional and only valid for third-party tag creatives or third-party VAST tag creatives. Third-party tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_EXPANDABLE` Third-party VAST tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_VIDEO`",
          type = "boolean",
        },
        reviewStatus = {
          ["$ref"] = "ReviewStatusInfo",
          description = "Output only. The current status of the creative review process.",
          readOnly = true,
        },
        skipOffset = {
          ["$ref"] = "AudioVideoOffset",
          description = "Amount of time to play the video before the skip button appears. This field is required when skippable is true. This field is only supported for the following creative_type: * `CREATIVE_TYPE_VIDEO`",
        },
        skippable = {
          description = "Whether the user can choose to skip a video creative. This field is only supported for the following creative_type: * `CREATIVE_TYPE_VIDEO`",
          type = "boolean",
        },
        thirdPartyTag = {
          description = "Optional. The original third-party tag used for the creative. Required and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_EXPANDABLE`",
          type = "string",
        },
        thirdPartyUrls = {
          description = "Tracking URLs from third parties to track interactions with a video creative. This field is only supported for the following creative_type: * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_VIDEO` * `CREATIVE_TYPE_NATIVE_VIDEO`",
          items = {
            ["$ref"] = "ThirdPartyUrl",
          },
          type = "array",
        },
        timerEvents = {
          description = "Timer custom events for a rich media creative. Timers track the time during which a user views and interacts with a specified part of a rich media creative. A creative can have multiple timer events, each timed independently. Leave it empty or unset for creatives containing image assets only.",
          items = {
            ["$ref"] = "TimerEvent",
          },
          type = "array",
        },
        trackerUrls = {
          description = "Tracking URLs for analytics providers or third-party ad technology vendors. The URLs must start with https (except on inventory that doesn't require SSL compliance). If using macros in your URL, use only macros supported by Display & Video 360. Standard URLs only, no IMG or SCRIPT tags. This field is only supported in following creative_type: * `CREATIVE_TYPE_NATIVE` * `CREATIVE_TYPE_NATIVE_SITE_SQUARE` * `CREATIVE_TYPE_NATIVE_APP_INSTALL` * `CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE` * `CREATIVE_TYPE_NATIVE_VIDEO`",
          items = {
            type = "string",
          },
          type = "array",
        },
        transcodes = {
          description = "Output only. Audio/Video transcodes. Display & Video 360 transcodes the main asset into a number of alternative versions that use different file formats or have different properties (resolution, audio bit rate, and video bit rate), each designed for specific video players or bandwidths. These transcodes give a publisher's system more options to choose from for each impression on your video and ensures that the appropriate file serves based on the viewer’s connection and screen size. This field is only supported in following creative_type: * `CREATIVE_TYPE_VIDEO` * `CREATIVE_TYPE_NATIVE_VIDEO` * `CREATIVE_TYPE_AUDIO`",
          items = {
            ["$ref"] = "Transcode",
          },
          readOnly = true,
          type = "array",
        },
        universalAdId = {
          ["$ref"] = "UniversalAdId",
          description = "Optional. An optional creative identifier provided by a registry that is unique across all platforms. Universal Ad ID is part of the VAST 4.0 standard. It can be modified after the creative is created. This field is only supported for the following creative_type: * `CREATIVE_TYPE_VIDEO`",
        },
        updateTime = {
          description = "Output only. The timestamp when the creative was last updated, either by the user or system (e.g. creative review). Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        vastTagUrl = {
          description = "Optional. The URL of the VAST tag for a third-party VAST tag creative. Required and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_AUDIO` * `CREATIVE_TYPE_VIDEO`",
          type = "string",
        },
        vpaid = {
          description = "Output only. Indicates the third-party VAST tag creative requires VPAID (Digital Video Player-Ad Interface). Output only and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * `HOSTING_SOURCE_THIRD_PARTY` combined with following creative_type: * `CREATIVE_TYPE_VIDEO`",
          readOnly = true,
          type = "boolean",
        },
      },
      type = "object",
    },
    CreativeConfig = {
      description = "Creative requirements configuration for the inventory source.",
      id = "CreativeConfig",
      properties = {
        creativeType = {
          description = "The type of creative that can be assigned to the inventory source. Only the following types are supported: * `CREATIVE_TYPE_STANDARD` * `CREATIVE_TYPE_VIDEO`",
          enum = {
            "CREATIVE_TYPE_UNSPECIFIED",
            "CREATIVE_TYPE_STANDARD",
            "CREATIVE_TYPE_EXPANDABLE",
            "CREATIVE_TYPE_VIDEO",
            "CREATIVE_TYPE_NATIVE",
            "CREATIVE_TYPE_TEMPLATED_APP_INSTALL",
            "CREATIVE_TYPE_NATIVE_SITE_SQUARE",
            "CREATIVE_TYPE_TEMPLATED_APP_INSTALL_INTERSTITIAL",
            "CREATIVE_TYPE_LIGHTBOX",
            "CREATIVE_TYPE_NATIVE_APP_INSTALL",
            "CREATIVE_TYPE_NATIVE_APP_INSTALL_SQUARE",
            "CREATIVE_TYPE_AUDIO",
            "CREATIVE_TYPE_PUBLISHER_HOSTED",
            "CREATIVE_TYPE_NATIVE_VIDEO",
            "CREATIVE_TYPE_TEMPLATED_APP_INSTALL_VIDEO",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Standard display creative. Create and update methods are supported for this creative type if the hosting_source is one of the following: * `HOSTING_SOURCE_HOSTED` * `HOSTING_SOURCE_THIRD_PARTY`",
            "Expandable creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_THIRD_PARTY`",
            "Video creative. Create and update methods are supported for this creative type if the hosting_source is one of the following: * `HOSTING_SOURCE_HOSTED` * `HOSTING_SOURCE_THIRD_PARTY`",
            "Native creative rendered by publishers with assets from advertiser. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Templated app install mobile creative (banner). Create and update methods are **not** supported for this creative type.",
            "Square native creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Interstitial creative including both display and video. Create and update methods are **not** supported for this creative type.",
            "Responsive and expandable Lightbox creative. Create and update methods are **not** supported for this creative type.",
            "Native app install creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Square native app install creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Audio creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Publisher hosted creative. Create and update methods are **not** supported for this creative type.",
            "Native video creative. Create and update methods are supported for this creative type if the hosting_source is `HOSTING_SOURCE_HOSTED`",
            "Templated app install mobile video creative. Create and update methods are **not** supported for this creative type.",
          },
          type = "string",
        },
        displayCreativeConfig = {
          ["$ref"] = "InventorySourceDisplayCreativeConfig",
          description = "The configuration for display creatives. Applicable when creative_type is `CREATIVE_TYPE_STANDARD`.",
        },
        videoCreativeConfig = {
          ["$ref"] = "InventorySourceVideoCreativeConfig",
          description = "The configuration for video creatives. Applicable when creative_type is `CREATIVE_TYPE_VIDEO`.",
        },
      },
      type = "object",
    },
    CustomBiddingAlgorithm = {
      description = "A single custom bidding algorithm.",
      id = "CustomBiddingAlgorithm",
      properties = {
        advertiserId = {
          description = "Immutable. The unique ID of the advertiser that owns the custom bidding algorithm.",
          format = "int64",
          type = "string",
        },
        customBiddingAlgorithmId = {
          description = "Output only. The unique ID of the custom bidding algorithm. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        customBiddingAlgorithmState = {
          description = "Output only. The status of custom bidding algorithm.",
          enum = {
            "STATE_UNSPECIFIED",
            "ENABLED",
            "DORMANT",
            "SUSPENDED",
          },
          enumDescriptions = {
            "State is not specified or is unknown in this version.",
            "Algorithm is enabled, either recently used, currently used or scheduled to be used. The algorithm is actively scoring impressions.",
            "Algorithm has not been used recently. Although the algorithm still acts as `ENABLED`, it will eventually be suspended if not used.",
            "Algorithm is susepended from scoring impressions and doesn't have a serving model trained. If the algorithm is assigned to a line item or otherwise updated, it will switch back to the `ENABLED` state and require time to prepare the serving model again.",
          },
          readOnly = true,
          type = "string",
        },
        customBiddingAlgorithmType = {
          description = "Required. Immutable. The type of custom bidding algorithm.",
          enum = {
            "CUSTOM_BIDDING_ALGORITHM_TYPE_UNSPECIFIED",
            "SCRIPT_BASED",
            "ADS_DATA_HUB_BASED",
            "GOAL_BUILDER_BASED",
          },
          enumDescriptions = {
            "Algorithm type is not specified or is unknown in this version.",
            "Algorithm generated through customer-uploaded custom bidding script files.",
            "Algorithm created through Ads Data Hub product.",
            "Algorithm created through goal builder in DV3 UI.",
          },
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the custom bidding algorithm. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        entityStatus = {
          description = "Controls whether or not the custom bidding algorithm can be used as a bidding strategy. Accepted values are: * `ENTITY_STATUS_ACTIVE` * `ENTITY_STATUS_ARCHIVED`",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        modelReadiness = {
          description = "Output only. The state of custom bidding model readiness for each advertiser who has access. This field may only include the state of the queried advertiser if the algorithm [`owner`](/display-video/api/reference/rest/v1/customBiddingAlgorithms#CustomBiddingAlgorithm.FIELDS.oneof_owner) is a partner and is being retrieved using an advertiser [`accessor`](/display-video/api/reference/rest/v1/customBiddingAlgorithms/list#body.QUERY_PARAMETERS.oneof_accessor).",
          items = {
            ["$ref"] = "CustomBiddingModelReadinessState",
          },
          readOnly = true,
          type = "array",
        },
        name = {
          description = "Output only. The resource name of the custom bidding algorithm.",
          readOnly = true,
          type = "string",
        },
        partnerId = {
          description = "Immutable. The unique ID of the partner that owns the custom bidding algorithm.",
          format = "int64",
          type = "string",
        },
        sharedAdvertiserIds = {
          description = "The IDs of the advertisers who have access to this algorithm. If advertiser_id is set, this field will only consist of that value. This field will not be set if the algorithm [`owner`](/display-video/api/reference/rest/v1/customBiddingAlgorithms#CustomBiddingAlgorithm.FIELDS.oneof_owner) is a partner and is being retrieved using an advertiser [`accessor`](/display-video/api/reference/rest/v1/customBiddingAlgorithms/list#body.QUERY_PARAMETERS.oneof_accessor).",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    CustomBiddingModelReadinessState = {
      description = "The custom bidding algorithm model readiness state for a single shared advertiser.",
      id = "CustomBiddingModelReadinessState",
      properties = {
        advertiserId = {
          description = "The unique ID of the relevant advertiser.",
          format = "int64",
          type = "string",
        },
        readinessState = {
          description = "The readiness state of custom bidding model.",
          enum = {
            "READINESS_STATE_UNSPECIFIED",
            "READINESS_STATE_ACTIVE",
            "READINESS_STATE_INSUFFICIENT_DATA",
            "READINESS_STATE_TRAINING",
            "READINESS_STATE_NO_VALID_SCRIPT",
          },
          enumDescriptions = {
            "State is not specified or is unknown in this version.",
            "The model is trained and ready for serving.",
            "There is not enough data to train the serving model.",
            "The model is training and not ready for serving.",
            "A valid custom bidding script has not been provided with which to train the model. This state will only be applied to algorithms whose `custom_bidding_algorithm_type` is `SCRIPT_BASED`.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    CustomBiddingScript = {
      description = "A single custom bidding script.",
      id = "CustomBiddingScript",
      properties = {
        active = {
          description = "Output only. Whether the script is currently being used for scoring by the parent algorithm.",
          readOnly = true,
          type = "boolean",
        },
        createTime = {
          description = "Output only. The time when the script was created.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        customBiddingAlgorithmId = {
          description = "Output only. The unique ID of the custom bidding algorithm the script belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        customBiddingScriptId = {
          description = "Output only. The unique ID of the custom bidding script.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        errors = {
          description = "Output only. Error details of a rejected custom bidding script. This field will only be populated when Script.state is REJECTED.",
          items = {
            ["$ref"] = "ScriptError",
          },
          readOnly = true,
          type = "array",
        },
        name = {
          description = "Output only. The resource name of the custom bidding script.",
          readOnly = true,
          type = "string",
        },
        script = {
          ["$ref"] = "CustomBiddingScriptRef",
          description = "The reference to the uploaded script file.",
        },
        state = {
          description = "Output only. The state of the custom bidding script.",
          enum = {
            "STATE_UNSPECIFIED",
            "ACCEPTED",
            "REJECTED",
            "PENDING",
          },
          enumDescriptions = {
            "The script state is not specified or is unknown in this version.",
            "The script has been accepted for scoring impressions.",
            "The script has been rejected by backend pipelines. It may have errors.",
            "The script is being processed for backend pipelines.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    CustomBiddingScriptRef = {
      description = "The reference to the uploaded custom bidding script file.",
      id = "CustomBiddingScriptRef",
      properties = {
        resourceName = {
          description = "A resource name to be used in media.download to Download the script files. Or media.upload to Upload the script files. Resource names have the format `customBiddingAlgorithms/{custom_bidding_algorithm_id}/scriptRef/{ref_id}`.",
          type = "string",
        },
      },
      type = "object",
    },
    CustomList = {
      description = "Describes a custom list entity, such as a custom affinity or custom intent audience list.",
      id = "CustomList",
      properties = {
        customListId = {
          description = "Output only. The unique ID of the custom list. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Output only. The display name of the custom list. .",
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the custom list.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    CustomListGroup = {
      description = "Details of custom list group. All custom list targeting settings are logically ‘OR’ of each other.",
      id = "CustomListGroup",
      properties = {
        settings = {
          description = "Required. All custom list targeting settings in custom list group. Repeated settings with same id will be ignored.",
          items = {
            ["$ref"] = "CustomListTargetingSetting",
          },
          type = "array",
        },
      },
      type = "object",
    },
    CustomListTargetingSetting = {
      description = "Details of custom list targeting setting.",
      id = "CustomListTargetingSetting",
      properties = {
        customListId = {
          description = "Required. Custom id of custom list targeting setting. This id is custom_list_id.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    Date = {
      description = "Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type.TimeOfDay * google.type.DateTime * google.protobuf.Timestamp",
      id = "Date",
      properties = {
        day = {
          description = "Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.",
          format = "int32",
          type = "integer",
        },
        month = {
          description = "Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.",
          format = "int32",
          type = "integer",
        },
        year = {
          description = "Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    DateRange = {
      description = "A date range.",
      id = "DateRange",
      properties = {
        endDate = {
          ["$ref"] = "Date",
          description = "The upper bound of the date range, inclusive. Must specify a positive value for `year`, `month`, and `day`.",
        },
        startDate = {
          ["$ref"] = "Date",
          description = "The lower bound of the date range, inclusive. Must specify a positive value for `year`, `month`, and `day`.",
        },
      },
      type = "object",
    },
    DayAndTimeAssignedTargetingOptionDetails = {
      description = "Representation of a segment of time defined on a specific day of the week and with a start and end time. The time represented by `start_hour` must be before the time represented by `end_hour`.",
      id = "DayAndTimeAssignedTargetingOptionDetails",
      properties = {
        dayOfWeek = {
          description = "Required. The day of the week for this day and time targeting setting.",
          enum = {
            "DAY_OF_WEEK_UNSPECIFIED",
            "MONDAY",
            "TUESDAY",
            "WEDNESDAY",
            "THURSDAY",
            "FRIDAY",
            "SATURDAY",
            "SUNDAY",
          },
          enumDescriptions = {
            "The day of the week is unspecified.",
            "Monday",
            "Tuesday",
            "Wednesday",
            "Thursday",
            "Friday",
            "Saturday",
            "Sunday",
          },
          type = "string",
        },
        endHour = {
          description = "Required. The end hour for day and time targeting. Must be between 1 (1 hour after start of day) and 24 (end of day).",
          format = "int32",
          type = "integer",
        },
        startHour = {
          description = "Required. The start hour for day and time targeting. Must be between 0 (start of day) and 23 (1 hour before end of day).",
          format = "int32",
          type = "integer",
        },
        timeZoneResolution = {
          description = "Required. The mechanism used to determine which timezone to use for this day and time targeting setting.",
          enum = {
            "TIME_ZONE_RESOLUTION_UNSPECIFIED",
            "TIME_ZONE_RESOLUTION_END_USER",
            "TIME_ZONE_RESOLUTION_ADVERTISER",
          },
          enumDescriptions = {
            "Time zone resolution is either unspecific or unknown.",
            "Times are resolved in the time zone of the user that saw the ad.",
            "Times are resolved in the time zone of the advertiser that served the ad.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    DeactivateManualTriggerRequest = {
      description = "Request message for ManualTriggerService.DeactivateManualTrigger.",
      id = "DeactivateManualTriggerRequest",
      properties = {},
      type = "object",
    },
    DeleteAssignedTargetingOptionsRequest = {
      description = "A request listing which assigned targeting options of a given targeting type should be deleted.",
      id = "DeleteAssignedTargetingOptionsRequest",
      properties = {
        assignedTargetingOptionIds = {
          description = "Required. The assigned targeting option IDs to delete.",
          items = {
            type = "string",
          },
          type = "array",
        },
        targetingType = {
          description = "Required. Identifies the type of this assigned targeting option.",
          enum = {
            "TARGETING_TYPE_UNSPECIFIED",
            "TARGETING_TYPE_CHANNEL",
            "TARGETING_TYPE_APP_CATEGORY",
            "TARGETING_TYPE_APP",
            "TARGETING_TYPE_URL",
            "TARGETING_TYPE_DAY_AND_TIME",
            "TARGETING_TYPE_AGE_RANGE",
            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
            "TARGETING_TYPE_GENDER",
            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
            "TARGETING_TYPE_USER_REWARDED_CONTENT",
            "TARGETING_TYPE_PARENTAL_STATUS",
            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
            "TARGETING_TYPE_DEVICE_TYPE",
            "TARGETING_TYPE_AUDIENCE_GROUP",
            "TARGETING_TYPE_BROWSER",
            "TARGETING_TYPE_HOUSEHOLD_INCOME",
            "TARGETING_TYPE_ON_SCREEN_POSITION",
            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
            "TARGETING_TYPE_ENVIRONMENT",
            "TARGETING_TYPE_CARRIER_AND_ISP",
            "TARGETING_TYPE_OPERATING_SYSTEM",
            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
            "TARGETING_TYPE_KEYWORD",
            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
            "TARGETING_TYPE_VIEWABILITY",
            "TARGETING_TYPE_CATEGORY",
            "TARGETING_TYPE_INVENTORY_SOURCE",
            "TARGETING_TYPE_LANGUAGE",
            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
            "TARGETING_TYPE_GEO_REGION",
            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
            "TARGETING_TYPE_EXCHANGE",
            "TARGETING_TYPE_SUB_EXCHANGE",
            "TARGETING_TYPE_POI",
            "TARGETING_TYPE_BUSINESS_CHAIN",
            "TARGETING_TYPE_CONTENT_DURATION",
            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
            "TARGETING_TYPE_OMID",
            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
            "TARGETING_TYPE_CONTENT_GENRE",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown in this version.",
            "Target a channel (a custom group of related websites or apps).",
            "Target an app category (for example, education or puzzle games).",
            "Target a specific app (for example, Angry Birds).",
            "Target a specific url (for example, quora.com).",
            "Target ads during a chosen time period on a specific day.",
            "Target ads to a specific age range (for example, 18-24).",
            "Target ads to the specified regions on a regional location list.",
            "Target ads to the specified points of interest on a proximity location list.",
            "Target ads to a specific gender (for example, female or male).",
            "Target a specific video player size for video ads.",
            "Target user rewarded content for video ads.",
            "Target ads to a specific parental status (for example, parent or not a parent).",
            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
            "Target ads in a specific content outstream position.",
            "Target ads to a specific device type (for example, tablet or connected TV).",
            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
            "Target ads to specific web browsers (for example, Chrome).",
            "Target ads to a specific household income range (for example, top 10%).",
            "Target ads in a specific on screen position.",
            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
            "Filter website content by sensitive categories (for example, adult).",
            "Target ads to a specific environment (for example, web or app).",
            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
            "Target ads to a specific operating system (for example, macOS).",
            "Target ads to a specific device make or model (for example, Roku or Samsung).",
            "Target ads to a specific keyword (for example, dog or retriever).",
            "Target ads to a specific negative keyword list.",
            "Target ads to a specific viewability (for example, 80% viewable).",
            "Target ads to a specific content category (for example, arts & entertainment).",
            "Purchase impressions from specific deals and auction packages.",
            "Target ads to a specific language (for example, English or Japanese).",
            "Target ads to ads.txt authorized sellers.",
            "Target ads to a specific regional location (for example, a city or state).",
            "Purchase impressions from a group of deals and auction packages.",
            "Purchase impressions from specific exchanges.",
            "Purchase impressions from specific sub-exchanges.",
            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
            "Target ads around locations of a business chain within a specific geo region.",
            "Target ads to a specific video content duration.",
            "Target ads to a specific video content stream type.",
            "Target ads to a specific native content position.",
            "Target ads in an Open Measurement enabled inventory.",
            "Target ads to a specific audio content type.",
            "Target ads to a specific content genre.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    DeviceMakeModelAssignedTargetingOptionDetails = {
      description = "Assigned device make and model targeting option details. This will be populated in the device_make_model_details field when targeting_type is `TARGETING_TYPE_DEVICE_MAKE_MODEL`.",
      id = "DeviceMakeModelAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the device make and model.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_DEVICE_MAKE_MODEL`.",
          type = "string",
        },
      },
      type = "object",
    },
    DeviceMakeModelTargetingOptionDetails = {
      description = "Represents a targetable device make and model. This will be populated in the device_make_model_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_DEVICE_MAKE_MODEL`.",
      id = "DeviceMakeModelTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the device make and model.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    DeviceTypeAssignedTargetingOptionDetails = {
      description = "Targeting details for device type. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_DEVICE_TYPE`.",
      id = "DeviceTypeAssignedTargetingOptionDetails",
      properties = {
        deviceType = {
          description = "The display name of the device type. Output only in v1. Required in v2.",
          enum = {
            "DEVICE_TYPE_UNSPECIFIED",
            "DEVICE_TYPE_COMPUTER",
            "DEVICE_TYPE_CONNECTED_TV",
            "DEVICE_TYPE_SMART_PHONE",
            "DEVICE_TYPE_TABLET",
          },
          enumDescriptions = {
            "Default value when device type is not specified in this version. This enum is a placeholder for default value and does not represent a real device type option.",
            "The device type is computer.",
            "The device type is connected TV.",
            "The device type is smart phone..",
            "The device type is tablet.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. ID of the device type.",
          type = "string",
        },
      },
      type = "object",
    },
    DeviceTypeTargetingOptionDetails = {
      description = "Represents a targetable device type. This will be populated in the device_type_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_DEVICE_TYPE`.",
      id = "DeviceTypeTargetingOptionDetails",
      properties = {
        deviceType = {
          description = "Output only. The device type that is used to be targeted.",
          enum = {
            "DEVICE_TYPE_UNSPECIFIED",
            "DEVICE_TYPE_COMPUTER",
            "DEVICE_TYPE_CONNECTED_TV",
            "DEVICE_TYPE_SMART_PHONE",
            "DEVICE_TYPE_TABLET",
          },
          enumDescriptions = {
            "Default value when device type is not specified in this version. This enum is a placeholder for default value and does not represent a real device type option.",
            "The device type is computer.",
            "The device type is connected TV.",
            "The device type is smart phone..",
            "The device type is tablet.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    DigitalContentLabelAssignedTargetingOptionDetails = {
      description = "Targeting details for digital content label. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION`.",
      id = "DigitalContentLabelAssignedTargetingOptionDetails",
      properties = {
        contentRatingTier = {
          description = "Output only. The display name of the digital content label rating tier.",
          enum = {
            "CONTENT_RATING_TIER_UNSPECIFIED",
            "CONTENT_RATING_TIER_UNRATED",
            "CONTENT_RATING_TIER_GENERAL",
            "CONTENT_RATING_TIER_PARENTAL_GUIDANCE",
            "CONTENT_RATING_TIER_TEENS",
            "CONTENT_RATING_TIER_MATURE",
          },
          enumDescriptions = {
            "Content label is not specified in this version. This enum is a place holder for a default value and does not represent a real content rating.",
            "Content that has not been labeled.",
            "Content suitable for general audiences.",
            "Content suitable for most audiences with parental guidance.",
            "Content suitable for teen and older audiences.",
            "Content suitable only for mature audiences.",
          },
          readOnly = true,
          type = "string",
        },
        excludedTargetingOptionId = {
          description = "Required. ID of the digital content label to be EXCLUDED.",
          type = "string",
        },
      },
      type = "object",
    },
    DigitalContentLabelTargetingOptionDetails = {
      description = "Represents a targetable digital content label rating tier. This will be populated in the digital_content_label_details field of the TargetingOption when targeting_type is `TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION`.",
      id = "DigitalContentLabelTargetingOptionDetails",
      properties = {
        contentRatingTier = {
          description = "Output only. An enum for the content label brand safety tiers.",
          enum = {
            "CONTENT_RATING_TIER_UNSPECIFIED",
            "CONTENT_RATING_TIER_UNRATED",
            "CONTENT_RATING_TIER_GENERAL",
            "CONTENT_RATING_TIER_PARENTAL_GUIDANCE",
            "CONTENT_RATING_TIER_TEENS",
            "CONTENT_RATING_TIER_MATURE",
          },
          enumDescriptions = {
            "Content label is not specified in this version. This enum is a place holder for a default value and does not represent a real content rating.",
            "Content that has not been labeled.",
            "Content suitable for general audiences.",
            "Content suitable for most audiences with parental guidance.",
            "Content suitable for teen and older audiences.",
            "Content suitable only for mature audiences.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Dimensions = {
      description = "Dimensions.",
      id = "Dimensions",
      properties = {
        heightPixels = {
          description = "The height in pixels.",
          format = "int32",
          type = "integer",
        },
        widthPixels = {
          description = "The width in pixels.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    DoubleVerify = {
      description = "Details of DoubleVerify settings.",
      id = "DoubleVerify",
      properties = {
        appStarRating = {
          ["$ref"] = "DoubleVerifyAppStarRating",
          description = "Avoid bidding on apps with the star ratings.",
        },
        avoidedAgeRatings = {
          description = "Avoid bidding on apps with the age rating.",
          items = {
            enum = {
              "AGE_RATING_UNSPECIFIED",
              "APP_AGE_RATE_UNKNOWN",
              "APP_AGE_RATE_4_PLUS",
              "APP_AGE_RATE_9_PLUS",
              "APP_AGE_RATE_12_PLUS",
              "APP_AGE_RATE_17_PLUS",
              "APP_AGE_RATE_18_PLUS",
            },
            enumDescriptions = {
              "This enum is only a placeholder and it doesn't specify any age rating options.",
              "Apps with unknown age rating.",
              "Apps rated for Everyone (4+).",
              "Apps rated for Everyone (9+).",
              "Apps rated for Teens (12+).",
              "Apps rated for Mature (17+).",
              "Apps rated for Adults Only (18+).",
            },
            type = "string",
          },
          type = "array",
        },
        brandSafetyCategories = {
          ["$ref"] = "DoubleVerifyBrandSafetyCategories",
          description = "DV Brand Safety Controls.",
        },
        customSegmentId = {
          description = "The custom segment ID provided by DoubleVerify. The ID must start with \"51\" and consist of eight digits. Custom segment ID cannot be specified along with any of the following fields: * brand_safety_categories * avoided_age_ratings * app_star_rating * fraud_invalid_traffic",
          format = "int64",
          type = "string",
        },
        displayViewability = {
          ["$ref"] = "DoubleVerifyDisplayViewability",
          description = "Display viewability settings (applicable to display line items only).",
        },
        fraudInvalidTraffic = {
          ["$ref"] = "DoubleVerifyFraudInvalidTraffic",
          description = "Avoid Sites and Apps with historical Fraud & IVT Rates.",
        },
        videoViewability = {
          ["$ref"] = "DoubleVerifyVideoViewability",
          description = "Video viewability settings (applicable to video line items only).",
        },
      },
      type = "object",
    },
    DoubleVerifyAppStarRating = {
      description = "Details of DoubleVerify star ratings settings.",
      id = "DoubleVerifyAppStarRating",
      properties = {
        avoidInsufficientStarRating = {
          description = "Avoid bidding on apps with insufficient star ratings.",
          type = "boolean",
        },
        avoidedStarRating = {
          description = "Avoid bidding on apps with the star ratings.",
          enum = {
            "APP_STAR_RATE_UNSPECIFIED",
            "APP_STAR_RATE_1_POINT_5_LESS",
            "APP_STAR_RATE_2_LESS",
            "APP_STAR_RATE_2_POINT_5_LESS",
            "APP_STAR_RATE_3_LESS",
            "APP_STAR_RATE_3_POINT_5_LESS",
            "APP_STAR_RATE_4_LESS",
            "APP_STAR_RATE_4_POINT_5_LESS",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any app star rating options.",
            "Official Apps with rating < 1.5 Stars.",
            "Official Apps with rating < 2 Stars.",
            "Official Apps with rating < 2.5 Stars.",
            "Official Apps with rating < 3 Stars.",
            "Official Apps with rating < 3.5 Stars.",
            "Official Apps with rating < 4 Stars.",
            "Official Apps with rating < 4.5 Stars.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    DoubleVerifyBrandSafetyCategories = {
      description = "Settings for brand safety controls.",
      id = "DoubleVerifyBrandSafetyCategories",
      properties = {
        avoidUnknownBrandSafetyCategory = {
          description = "Unknown or unrateable.",
          type = "boolean",
        },
        avoidedHighSeverityCategories = {
          description = "Brand safety high severity avoidance categories.",
          items = {
            enum = {
              "HIGHER_SEVERITY_UNSPECIFIED",
              "ADULT_CONTENT_PORNOGRAPHY",
              "COPYRIGHT_INFRINGEMENT",
              "SUBSTANCE_ABUSE",
              "GRAPHIC_VIOLENCE_WEAPONS",
              "HATE_PROFANITY",
              "CRIMINAL_SKILLS",
              "NUISANCE_INCENTIVIZED_MALWARE_CLUTTER",
            },
            enumDescriptions = {
              "This enum is only a placeholder and it doesn't specify any high severity categories.",
              "Adult Content: Pornography, Mature Topics & Nudity.",
              "Copyright Infringement.",
              "Drugs/Alcohol/Controlled Substances: Substance Abuse.",
              "Extreme Graphic/Explicit Violence/Weapons.",
              "Hate/Profanity.",
              "Illegal Activities: Criminal Skills.",
              "Incentivized/Malware/Clutter.",
            },
            type = "string",
          },
          type = "array",
        },
        avoidedMediumSeverityCategories = {
          description = "Brand safety medium severity avoidance categories.",
          items = {
            enum = {
              "MEDIUM_SEVERITY_UNSPECIFIED",
              "AD_SERVERS",
              "ADULT_CONTENT_SWIMSUIT",
              "ALTERNATIVE_LIFESTYLES",
              "CELEBRITY_GOSSIP",
              "GAMBLING",
              "OCCULT",
              "SEX_EDUCATION",
              "DISASTER_AVIATION",
              "DISASTER_MAN_MADE",
              "DISASTER_NATURAL",
              "DISASTER_TERRORIST_EVENTS",
              "DISASTER_VEHICLE",
              "ALCOHOL",
              "SMOKING",
              "NEGATIVE_NEWS_FINANCIAL",
              "NON_ENGLISH",
              "PARKING_PAGE",
              "UNMODERATED_UGC",
              "INFLAMMATORY_POLITICS_AND_NEWS",
              "NEGATIVE_NEWS_PHARMACEUTICAL",
            },
            enumDescriptions = {
              "This enum is only a placeholder and it doesn't specify any medium severity categories.",
              "Ad Servers.",
              "Adult Content: Swimsuit.",
              "Controversial Subjects: Alternative Lifestyles.",
              "Controversial Subjects: Celebrity Gossip.",
              "Controversial Subjects: Gambling.",
              "Controversial Subjects: Occult.",
              "Controversial Subjects: Sex Education.",
              "Disaster: Aviation.",
              "Disaster: Man-made.",
              "Disaster: Natural.",
              "Disaster: Terrorist Events.",
              "Disaster: Vehicle.",
              "Drugs/Alcohol/Controlled Substances: Alcohol.",
              "Drugs/Alcohol/Controlled Substances: Smoking.",
              "Negative News: Financial.",
              "Non-Std Content: Non-English.",
              "Non-Std Content: Parking Page.",
              "Unmoderated UGC: Forums, Images & Video.",
              "Controversial Subjects: Inflammatory Politics and News.",
              "Negative News: Pharmaceutical.",
            },
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    DoubleVerifyDisplayViewability = {
      description = "Details of DoubleVerify display viewability settings.",
      id = "DoubleVerifyDisplayViewability",
      properties = {
        iab = {
          description = "Target web and app inventory to maximize IAB viewable rate.",
          enum = {
            "IAB_VIEWED_RATE_UNSPECIFIED",
            "IAB_VIEWED_RATE_80_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_75_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_70_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_65_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_60_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_55_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_50_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_40_PERCENT_HIGHER",
            "IAB_VIEWED_RATE_30_PERCENT_HIGHER",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any IAB viewed rate options.",
            "Target web and app inventory to maximize IAB viewable rate 80% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 75% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 70% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 65% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 60% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 55% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 50% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 40% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 30% or higher.",
          },
          type = "string",
        },
        viewableDuring = {
          description = "Target web and app inventory to maximize 100% viewable duration.",
          enum = {
            "AVERAGE_VIEW_DURATION_UNSPECIFIED",
            "AVERAGE_VIEW_DURATION_5_SEC",
            "AVERAGE_VIEW_DURATION_10_SEC",
            "AVERAGE_VIEW_DURATION_15_SEC",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any average view duration options.",
            "Target web and app inventory to maximize 100% viewable duration 5 seconds or more.",
            "Target web and app inventory to maximize 100% viewable duration 10 seconds or more.",
            "Target web and app inventory to maximize 100% viewable duration 15 seconds or more.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    DoubleVerifyFraudInvalidTraffic = {
      description = "DoubleVerify Fraud & Invalid Traffic settings.",
      id = "DoubleVerifyFraudInvalidTraffic",
      properties = {
        avoidInsufficientOption = {
          description = "Insufficient Historical Fraud & IVT Stats.",
          type = "boolean",
        },
        avoidedFraudOption = {
          description = "Avoid Sites and Apps with historical Fraud & IVT.",
          enum = {
            "FRAUD_UNSPECIFIED",
            "AD_IMPRESSION_FRAUD_100",
            "AD_IMPRESSION_FRAUD_50",
            "AD_IMPRESSION_FRAUD_25",
            "AD_IMPRESSION_FRAUD_10",
            "AD_IMPRESSION_FRAUD_8",
            "AD_IMPRESSION_FRAUD_6",
            "AD_IMPRESSION_FRAUD_4",
            "AD_IMPRESSION_FRAUD_2",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any fraud and invalid traffic options.",
            "100% Fraud & IVT.",
            "50% or Higher Fraud & IVT.",
            "25% or Higher Fraud & IVT.",
            "10% or Higher Fraud & IVT.",
            "8% or Higher Fraud & IVT.",
            "6% or Higher Fraud & IVT.",
            "4% or Higher Fraud & IVT.",
            "2% or Higher Fraud & IVT.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    DoubleVerifyVideoViewability = {
      description = "Details of DoubleVerify video viewability settings.",
      id = "DoubleVerifyVideoViewability",
      properties = {
        playerImpressionRate = {
          description = "Target inventory to maximize impressions with 400x300 or greater player size.",
          enum = {
            "PLAYER_SIZE_400X300_UNSPECIFIED",
            "PLAYER_SIZE_400X300_95",
            "PLAYER_SIZE_400X300_70",
            "PLAYER_SIZE_400X300_25",
            "PLAYER_SIZE_400X300_5",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any impressions options.",
            "Sites with 95%+ of impressions.",
            "Sites with 70%+ of impressions.",
            "Sites with 25%+ of impressions.",
            "Sites with 5%+ of impressions.",
          },
          type = "string",
        },
        videoIab = {
          description = "Target web inventory to maximize IAB viewable rate.",
          enum = {
            "VIDEO_IAB_UNSPECIFIED",
            "IAB_VIEWABILITY_80_PERCENT_HIGHER",
            "IAB_VIEWABILITY_75_PERCENT_HIGHER",
            "IAB_VIEWABILITY_70_PERCENT_HIGHER",
            "IAB_VIEWABILITY_65_PERCENT_HIHGER",
            "IAB_VIEWABILITY_60_PERCENT_HIGHER",
            "IAB_VIEWABILITY_55_PERCENT_HIHGER",
            "IAB_VIEWABILITY_50_PERCENT_HIGHER",
            "IAB_VIEWABILITY_40_PERCENT_HIHGER",
            "IAB_VIEWABILITY_30_PERCENT_HIHGER",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any video IAB viewable rate options.",
            "Target web and app inventory to maximize IAB viewable rate 80% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 75% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 70% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 65% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 60% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 55% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 50% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 40% or higher.",
            "Target web and app inventory to maximize IAB viewable rate 30% or higher.",
          },
          type = "string",
        },
        videoViewableRate = {
          description = "Target web inventory to maximize fully viewable rate.",
          enum = {
            "VIDEO_VIEWABLE_RATE_UNSPECIFIED",
            "VIEWED_PERFORMANCE_40_PERCENT_HIGHER",
            "VIEWED_PERFORMANCE_35_PERCENT_HIGHER",
            "VIEWED_PERFORMANCE_30_PERCENT_HIGHER",
            "VIEWED_PERFORMANCE_25_PERCENT_HIGHER",
            "VIEWED_PERFORMANCE_20_PERCENT_HIGHER",
            "VIEWED_PERFORMANCE_10_PERCENT_HIGHER",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any video viewable rate options.",
            "Target web inventory to maximize fully viewable rate 40% or higher.",
            "Target web inventory to maximize fully viewable rate 35% or higher.",
            "Target web inventory to maximize fully viewable rate 30% or higher.",
            "Target web inventory to maximize fully viewable rate 25% or higher.",
            "Target web inventory to maximize fully viewable rate 20% or higher.",
            "Target web inventory to maximize fully viewable rate 10% or higher.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    EditCustomerMatchMembersRequest = {
      description = "Request message for FirstAndThirdPartyAudienceService.EditCustomerMatchMembers.",
      id = "EditCustomerMatchMembersRequest",
      properties = {
        addedContactInfoList = {
          ["$ref"] = "ContactInfoList",
          description = "Input only. A list of contact information to define the members to be added.",
        },
        addedMobileDeviceIdList = {
          ["$ref"] = "MobileDeviceIdList",
          description = "Input only. A list of mobile device IDs to define the members to be added.",
        },
        advertiserId = {
          description = "Required. The ID of the owner advertiser of the updated Customer Match FirstAndThirdPartyAudience.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    EditCustomerMatchMembersResponse = {
      description = "The response of FirstAndThirdPartyAudienceService.EditCustomerMatchMembers.",
      id = "EditCustomerMatchMembersResponse",
      properties = {
        firstAndThirdPartyAudienceId = {
          description = "Required. The ID of the updated Customer Match FirstAndThirdPartyAudience.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    EditGuaranteedOrderReadAccessorsRequest = {
      description = "Request message for GuaranteedOrderService.EditGuaranteedOrderReadAccessors.",
      id = "EditGuaranteedOrderReadAccessorsRequest",
      properties = {
        addedAdvertisers = {
          description = "The advertisers to add as read accessors to the guaranteed order.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        partnerId = {
          description = "Required. The partner context in which the change is being made.",
          format = "int64",
          type = "string",
        },
        readAccessInherited = {
          description = "Whether to give all advertisers of the read/write accessor partner read access to the guaranteed order. Only applicable if read_write_partner_id is set in the guaranteed order.",
          type = "boolean",
        },
        removedAdvertisers = {
          description = "The advertisers to remove as read accessors to the guaranteed order.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    EditGuaranteedOrderReadAccessorsResponse = {
      id = "EditGuaranteedOrderReadAccessorsResponse",
      properties = {
        readAccessInherited = {
          description = "Whether all advertisers of read_write_partner_id have read access to the guaranteed order.",
          type = "boolean",
        },
        readAdvertiserIds = {
          description = "The IDs of advertisers with read access to the guaranteed order.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    EditInventorySourceReadWriteAccessorsRequest = {
      description = "Request message for InventorySourceService.EditInventorySourceReadWriteAccessors.",
      id = "EditInventorySourceReadWriteAccessorsRequest",
      properties = {
        advertisersUpdate = {
          ["$ref"] = "EditInventorySourceReadWriteAccessorsRequestAdvertisersUpdate",
          description = "The advertisers to add or remove from the list of advertisers that have read/write access to the inventory source. This change will remove an existing partner read/write accessor.",
        },
        assignPartner = {
          description = "Set the partner context as read/write accessor of the inventory source. This will remove all other current read/write advertiser accessors.",
          type = "boolean",
        },
        partnerId = {
          description = "Required. The partner context by which the accessors change is being made.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    EditInventorySourceReadWriteAccessorsRequestAdvertisersUpdate = {
      description = "Update to the list of advertisers with read/write access to the inventory source.",
      id = "EditInventorySourceReadWriteAccessorsRequestAdvertisersUpdate",
      properties = {
        addedAdvertisers = {
          description = "The advertisers to add.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        removedAdvertisers = {
          description = "The advertisers to remove.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    Empty = {
      description = "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }",
      id = "Empty",
      properties = {},
      type = "object",
    },
    EnvironmentAssignedTargetingOptionDetails = {
      description = "Assigned environment targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_ENVIRONMENT`.",
      id = "EnvironmentAssignedTargetingOptionDetails",
      properties = {
        environment = {
          description = "The serving environment. Output only in v1. Required in v2.",
          enum = {
            "ENVIRONMENT_UNSPECIFIED",
            "ENVIRONMENT_WEB_OPTIMIZED",
            "ENVIRONMENT_WEB_NOT_OPTIMIZED",
            "ENVIRONMENT_APP",
          },
          enumDescriptions = {
            "Default value when environment is not specified in this version. This enum is a placeholder for default value and does not represent a real environment option.",
            "Target inventory displayed in browsers. This includes inventory that was designed for the device it was viewed on, such as mobile websites viewed on a mobile device. ENVIRONMENT_WEB_NOT_OPTIMIZED, if targeted, should be deleted prior to the deletion of this targeting option.",
            "Target inventory displayed in browsers. This includes inventory that was not designed for the device but viewed on it, such as websites optimized for desktop but viewed on a mobile device. ENVIRONMENT_WEB_OPTIMIZED should be targeted prior to the addition of this targeting option.",
            "Target inventory displayed in apps.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_ENVIRONMENT` (e.g., \"508010\" for targeting the `ENVIRONMENT_WEB_OPTIMIZED` option).",
          type = "string",
        },
      },
      type = "object",
    },
    EnvironmentTargetingOptionDetails = {
      description = "Represents a targetable environment. This will be populated in the environment_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_ENVIRONMENT`.",
      id = "EnvironmentTargetingOptionDetails",
      properties = {
        environment = {
          description = "Output only. The serving environment.",
          enum = {
            "ENVIRONMENT_UNSPECIFIED",
            "ENVIRONMENT_WEB_OPTIMIZED",
            "ENVIRONMENT_WEB_NOT_OPTIMIZED",
            "ENVIRONMENT_APP",
          },
          enumDescriptions = {
            "Default value when environment is not specified in this version. This enum is a placeholder for default value and does not represent a real environment option.",
            "Target inventory displayed in browsers. This includes inventory that was designed for the device it was viewed on, such as mobile websites viewed on a mobile device. ENVIRONMENT_WEB_NOT_OPTIMIZED, if targeted, should be deleted prior to the deletion of this targeting option.",
            "Target inventory displayed in browsers. This includes inventory that was not designed for the device but viewed on it, such as websites optimized for desktop but viewed on a mobile device. ENVIRONMENT_WEB_OPTIMIZED should be targeted prior to the addition of this targeting option.",
            "Target inventory displayed in apps.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ExchangeAssignedTargetingOptionDetails = {
      description = "Details for assigned exchange targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_EXCHANGE`.",
      id = "ExchangeAssignedTargetingOptionDetails",
      properties = {
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_EXCHANGE`.",
          type = "string",
        },
      },
      type = "object",
    },
    ExchangeConfig = {
      description = "Settings that control which exchanges are enabled for a partner.",
      id = "ExchangeConfig",
      properties = {
        enabledExchanges = {
          description = "All enabled exchanges in the partner. Duplicate enabled exchanges will be ignored.",
          items = {
            ["$ref"] = "ExchangeConfigEnabledExchange",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ExchangeConfigEnabledExchange = {
      description = "An enabled exchange in the partner.",
      id = "ExchangeConfigEnabledExchange",
      properties = {
        exchange = {
          description = "The enabled exchange.",
          enum = {
            "EXCHANGE_UNSPECIFIED",
            "EXCHANGE_GOOGLE_AD_MANAGER",
            "EXCHANGE_APPNEXUS",
            "EXCHANGE_BRIGHTROLL",
            "EXCHANGE_ADFORM",
            "EXCHANGE_ADMETA",
            "EXCHANGE_ADMIXER",
            "EXCHANGE_ADSMOGO",
            "EXCHANGE_ADSWIZZ",
            "EXCHANGE_BIDSWITCH",
            "EXCHANGE_BRIGHTROLL_DISPLAY",
            "EXCHANGE_CADREON",
            "EXCHANGE_DAILYMOTION",
            "EXCHANGE_FIVE",
            "EXCHANGE_FLUCT",
            "EXCHANGE_FREEWHEEL",
            "EXCHANGE_GENIEE",
            "EXCHANGE_GUMGUM",
            "EXCHANGE_IMOBILE",
            "EXCHANGE_IBILLBOARD",
            "EXCHANGE_IMPROVE_DIGITAL",
            "EXCHANGE_INDEX",
            "EXCHANGE_KARGO",
            "EXCHANGE_MICROAD",
            "EXCHANGE_MOPUB",
            "EXCHANGE_NEND",
            "EXCHANGE_ONE_BY_AOL_DISPLAY",
            "EXCHANGE_ONE_BY_AOL_MOBILE",
            "EXCHANGE_ONE_BY_AOL_VIDEO",
            "EXCHANGE_OOYALA",
            "EXCHANGE_OPENX",
            "EXCHANGE_PERMODO",
            "EXCHANGE_PLATFORMONE",
            "EXCHANGE_PLATFORMID",
            "EXCHANGE_PUBMATIC",
            "EXCHANGE_PULSEPOINT",
            "EXCHANGE_REVENUEMAX",
            "EXCHANGE_RUBICON",
            "EXCHANGE_SMARTCLIP",
            "EXCHANGE_SMARTRTB",
            "EXCHANGE_SMARTSTREAMTV",
            "EXCHANGE_SOVRN",
            "EXCHANGE_SPOTXCHANGE",
            "EXCHANGE_STROER",
            "EXCHANGE_TEADSTV",
            "EXCHANGE_TELARIA",
            "EXCHANGE_TVN",
            "EXCHANGE_UNITED",
            "EXCHANGE_YIELDLAB",
            "EXCHANGE_YIELDMO",
            "EXCHANGE_UNRULYX",
            "EXCHANGE_OPEN8",
            "EXCHANGE_TRITON",
            "EXCHANGE_TRIPLELIFT",
            "EXCHANGE_TABOOLA",
            "EXCHANGE_INMOBI",
            "EXCHANGE_SMAATO",
            "EXCHANGE_AJA",
            "EXCHANGE_SUPERSHIP",
            "EXCHANGE_NEXSTAR_DIGITAL",
            "EXCHANGE_WAZE",
            "EXCHANGE_SOUNDCAST",
            "EXCHANGE_SHARETHROUGH",
            "EXCHANGE_FYBER",
            "EXCHANGE_RED_FOR_PUBLISHERS",
            "EXCHANGE_MEDIANET",
            "EXCHANGE_TAPJOY",
            "EXCHANGE_VISTAR",
            "EXCHANGE_DAX",
            "EXCHANGE_JCD",
            "EXCHANGE_PLACE_EXCHANGE",
            "EXCHANGE_APPLOVIN",
            "EXCHANGE_CONNATIX",
          },
          enumDescriptions = {
            "Exchange is not specified or is unknown in this version.",
            "Google Ad Manager.",
            "AppNexus.",
            "BrightRoll Exchange for Video from Yahoo!.",
            "Adform.",
            "Admeta.",
            "Admixer.",
            "AdsMogo.",
            "AdsWizz.",
            "BidSwitch.",
            "BrightRoll Exchange for Display from Yahoo!.",
            "Cadreon.",
            "Dailymotion.",
            "Five.",
            "Fluct.",
            "FreeWheel SSP.",
            "Geniee.",
            "GumGum.",
            "i-mobile.",
            "iBILLBOARD.",
            "Improve Digital.",
            "Index Exchange.",
            "Kargo.",
            "MicroAd.",
            "MoPub.",
            "Nend.",
            "ONE by AOL: Display Market Place.",
            "ONE by AOL: Mobile.",
            "ONE by AOL: Video.",
            "Ooyala.",
            "OpenX.",
            "Permodo.",
            "Platform One.",
            "PlatformId.",
            "PubMatic.",
            "PulsePoint.",
            "RevenueMax.",
            "Rubicon.",
            "SmartClip.",
            "SmartRTB+.",
            "SmartstreamTv.",
            "Sovrn.",
            "SpotXchange.",
            "Ströer SSP.",
            "TeadsTv.",
            "Telaria.",
            "TVN.",
            "United.",
            "Yieldlab.",
            "Yieldmo.",
            "UnrulyX.",
            "Open8.",
            "Triton.",
            "TripleLift.",
            "Taboola.",
            "InMobi.",
            "Smaato.",
            "Aja.",
            "Supership.",
            "Nexstar Digital.",
            "Waze.",
            "SoundCast.",
            "Sharethrough.",
            "Fyber.",
            "Red For Publishers.",
            "Media.net.",
            "Tapjoy.",
            "Vistar.",
            "DAX.",
            "JCD.",
            "Place Exchange.",
            "AppLovin.",
            "Connatix.",
          },
          type = "string",
        },
        googleAdManagerAgencyId = {
          description = "Output only. Agency ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange.",
          readOnly = true,
          type = "string",
        },
        googleAdManagerBuyerNetworkId = {
          description = "Output only. Network ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange.",
          readOnly = true,
          type = "string",
        },
        seatId = {
          description = "Output only. Seat ID of the enabled exchange.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ExchangeReviewStatus = {
      description = "Exchange review status for the creative.",
      id = "ExchangeReviewStatus",
      properties = {
        exchange = {
          description = "The exchange reviewing the creative.",
          enum = {
            "EXCHANGE_UNSPECIFIED",
            "EXCHANGE_GOOGLE_AD_MANAGER",
            "EXCHANGE_APPNEXUS",
            "EXCHANGE_BRIGHTROLL",
            "EXCHANGE_ADFORM",
            "EXCHANGE_ADMETA",
            "EXCHANGE_ADMIXER",
            "EXCHANGE_ADSMOGO",
            "EXCHANGE_ADSWIZZ",
            "EXCHANGE_BIDSWITCH",
            "EXCHANGE_BRIGHTROLL_DISPLAY",
            "EXCHANGE_CADREON",
            "EXCHANGE_DAILYMOTION",
            "EXCHANGE_FIVE",
            "EXCHANGE_FLUCT",
            "EXCHANGE_FREEWHEEL",
            "EXCHANGE_GENIEE",
            "EXCHANGE_GUMGUM",
            "EXCHANGE_IMOBILE",
            "EXCHANGE_IBILLBOARD",
            "EXCHANGE_IMPROVE_DIGITAL",
            "EXCHANGE_INDEX",
            "EXCHANGE_KARGO",
            "EXCHANGE_MICROAD",
            "EXCHANGE_MOPUB",
            "EXCHANGE_NEND",
            "EXCHANGE_ONE_BY_AOL_DISPLAY",
            "EXCHANGE_ONE_BY_AOL_MOBILE",
            "EXCHANGE_ONE_BY_AOL_VIDEO",
            "EXCHANGE_OOYALA",
            "EXCHANGE_OPENX",
            "EXCHANGE_PERMODO",
            "EXCHANGE_PLATFORMONE",
            "EXCHANGE_PLATFORMID",
            "EXCHANGE_PUBMATIC",
            "EXCHANGE_PULSEPOINT",
            "EXCHANGE_REVENUEMAX",
            "EXCHANGE_RUBICON",
            "EXCHANGE_SMARTCLIP",
            "EXCHANGE_SMARTRTB",
            "EXCHANGE_SMARTSTREAMTV",
            "EXCHANGE_SOVRN",
            "EXCHANGE_SPOTXCHANGE",
            "EXCHANGE_STROER",
            "EXCHANGE_TEADSTV",
            "EXCHANGE_TELARIA",
            "EXCHANGE_TVN",
            "EXCHANGE_UNITED",
            "EXCHANGE_YIELDLAB",
            "EXCHANGE_YIELDMO",
            "EXCHANGE_UNRULYX",
            "EXCHANGE_OPEN8",
            "EXCHANGE_TRITON",
            "EXCHANGE_TRIPLELIFT",
            "EXCHANGE_TABOOLA",
            "EXCHANGE_INMOBI",
            "EXCHANGE_SMAATO",
            "EXCHANGE_AJA",
            "EXCHANGE_SUPERSHIP",
            "EXCHANGE_NEXSTAR_DIGITAL",
            "EXCHANGE_WAZE",
            "EXCHANGE_SOUNDCAST",
            "EXCHANGE_SHARETHROUGH",
            "EXCHANGE_FYBER",
            "EXCHANGE_RED_FOR_PUBLISHERS",
            "EXCHANGE_MEDIANET",
            "EXCHANGE_TAPJOY",
            "EXCHANGE_VISTAR",
            "EXCHANGE_DAX",
            "EXCHANGE_JCD",
            "EXCHANGE_PLACE_EXCHANGE",
            "EXCHANGE_APPLOVIN",
            "EXCHANGE_CONNATIX",
          },
          enumDescriptions = {
            "Exchange is not specified or is unknown in this version.",
            "Google Ad Manager.",
            "AppNexus.",
            "BrightRoll Exchange for Video from Yahoo!.",
            "Adform.",
            "Admeta.",
            "Admixer.",
            "AdsMogo.",
            "AdsWizz.",
            "BidSwitch.",
            "BrightRoll Exchange for Display from Yahoo!.",
            "Cadreon.",
            "Dailymotion.",
            "Five.",
            "Fluct.",
            "FreeWheel SSP.",
            "Geniee.",
            "GumGum.",
            "i-mobile.",
            "iBILLBOARD.",
            "Improve Digital.",
            "Index Exchange.",
            "Kargo.",
            "MicroAd.",
            "MoPub.",
            "Nend.",
            "ONE by AOL: Display Market Place.",
            "ONE by AOL: Mobile.",
            "ONE by AOL: Video.",
            "Ooyala.",
            "OpenX.",
            "Permodo.",
            "Platform One.",
            "PlatformId.",
            "PubMatic.",
            "PulsePoint.",
            "RevenueMax.",
            "Rubicon.",
            "SmartClip.",
            "SmartRTB+.",
            "SmartstreamTv.",
            "Sovrn.",
            "SpotXchange.",
            "Ströer SSP.",
            "TeadsTv.",
            "Telaria.",
            "TVN.",
            "United.",
            "Yieldlab.",
            "Yieldmo.",
            "UnrulyX.",
            "Open8.",
            "Triton.",
            "TripleLift.",
            "Taboola.",
            "InMobi.",
            "Smaato.",
            "Aja.",
            "Supership.",
            "Nexstar Digital.",
            "Waze.",
            "SoundCast.",
            "Sharethrough.",
            "Fyber.",
            "Red For Publishers.",
            "Media.net.",
            "Tapjoy.",
            "Vistar.",
            "DAX.",
            "JCD.",
            "Place Exchange.",
            "AppLovin.",
            "Connatix.",
          },
          type = "string",
        },
        status = {
          description = "Status of the exchange review.",
          enum = {
            "REVIEW_STATUS_UNSPECIFIED",
            "REVIEW_STATUS_APPROVED",
            "REVIEW_STATUS_REJECTED",
            "REVIEW_STATUS_PENDING",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The creative is approved.",
            "The creative is rejected.",
            "The creative is pending review.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ExchangeTargetingOptionDetails = {
      description = "Represents a targetable exchange. This will be populated in the exchange_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_EXCHANGE`.",
      id = "ExchangeTargetingOptionDetails",
      properties = {
        exchange = {
          description = "Output only. The type of exchange.",
          enum = {
            "EXCHANGE_UNSPECIFIED",
            "EXCHANGE_GOOGLE_AD_MANAGER",
            "EXCHANGE_APPNEXUS",
            "EXCHANGE_BRIGHTROLL",
            "EXCHANGE_ADFORM",
            "EXCHANGE_ADMETA",
            "EXCHANGE_ADMIXER",
            "EXCHANGE_ADSMOGO",
            "EXCHANGE_ADSWIZZ",
            "EXCHANGE_BIDSWITCH",
            "EXCHANGE_BRIGHTROLL_DISPLAY",
            "EXCHANGE_CADREON",
            "EXCHANGE_DAILYMOTION",
            "EXCHANGE_FIVE",
            "EXCHANGE_FLUCT",
            "EXCHANGE_FREEWHEEL",
            "EXCHANGE_GENIEE",
            "EXCHANGE_GUMGUM",
            "EXCHANGE_IMOBILE",
            "EXCHANGE_IBILLBOARD",
            "EXCHANGE_IMPROVE_DIGITAL",
            "EXCHANGE_INDEX",
            "EXCHANGE_KARGO",
            "EXCHANGE_MICROAD",
            "EXCHANGE_MOPUB",
            "EXCHANGE_NEND",
            "EXCHANGE_ONE_BY_AOL_DISPLAY",
            "EXCHANGE_ONE_BY_AOL_MOBILE",
            "EXCHANGE_ONE_BY_AOL_VIDEO",
            "EXCHANGE_OOYALA",
            "EXCHANGE_OPENX",
            "EXCHANGE_PERMODO",
            "EXCHANGE_PLATFORMONE",
            "EXCHANGE_PLATFORMID",
            "EXCHANGE_PUBMATIC",
            "EXCHANGE_PULSEPOINT",
            "EXCHANGE_REVENUEMAX",
            "EXCHANGE_RUBICON",
            "EXCHANGE_SMARTCLIP",
            "EXCHANGE_SMARTRTB",
            "EXCHANGE_SMARTSTREAMTV",
            "EXCHANGE_SOVRN",
            "EXCHANGE_SPOTXCHANGE",
            "EXCHANGE_STROER",
            "EXCHANGE_TEADSTV",
            "EXCHANGE_TELARIA",
            "EXCHANGE_TVN",
            "EXCHANGE_UNITED",
            "EXCHANGE_YIELDLAB",
            "EXCHANGE_YIELDMO",
            "EXCHANGE_UNRULYX",
            "EXCHANGE_OPEN8",
            "EXCHANGE_TRITON",
            "EXCHANGE_TRIPLELIFT",
            "EXCHANGE_TABOOLA",
            "EXCHANGE_INMOBI",
            "EXCHANGE_SMAATO",
            "EXCHANGE_AJA",
            "EXCHANGE_SUPERSHIP",
            "EXCHANGE_NEXSTAR_DIGITAL",
            "EXCHANGE_WAZE",
            "EXCHANGE_SOUNDCAST",
            "EXCHANGE_SHARETHROUGH",
            "EXCHANGE_FYBER",
            "EXCHANGE_RED_FOR_PUBLISHERS",
            "EXCHANGE_MEDIANET",
            "EXCHANGE_TAPJOY",
            "EXCHANGE_VISTAR",
            "EXCHANGE_DAX",
            "EXCHANGE_JCD",
            "EXCHANGE_PLACE_EXCHANGE",
            "EXCHANGE_APPLOVIN",
            "EXCHANGE_CONNATIX",
          },
          enumDescriptions = {
            "Exchange is not specified or is unknown in this version.",
            "Google Ad Manager.",
            "AppNexus.",
            "BrightRoll Exchange for Video from Yahoo!.",
            "Adform.",
            "Admeta.",
            "Admixer.",
            "AdsMogo.",
            "AdsWizz.",
            "BidSwitch.",
            "BrightRoll Exchange for Display from Yahoo!.",
            "Cadreon.",
            "Dailymotion.",
            "Five.",
            "Fluct.",
            "FreeWheel SSP.",
            "Geniee.",
            "GumGum.",
            "i-mobile.",
            "iBILLBOARD.",
            "Improve Digital.",
            "Index Exchange.",
            "Kargo.",
            "MicroAd.",
            "MoPub.",
            "Nend.",
            "ONE by AOL: Display Market Place.",
            "ONE by AOL: Mobile.",
            "ONE by AOL: Video.",
            "Ooyala.",
            "OpenX.",
            "Permodo.",
            "Platform One.",
            "PlatformId.",
            "PubMatic.",
            "PulsePoint.",
            "RevenueMax.",
            "Rubicon.",
            "SmartClip.",
            "SmartRTB+.",
            "SmartstreamTv.",
            "Sovrn.",
            "SpotXchange.",
            "Ströer SSP.",
            "TeadsTv.",
            "Telaria.",
            "TVN.",
            "United.",
            "Yieldlab.",
            "Yieldmo.",
            "UnrulyX.",
            "Open8.",
            "Triton.",
            "TripleLift.",
            "Taboola.",
            "InMobi.",
            "Smaato.",
            "Aja.",
            "Supership.",
            "Nexstar Digital.",
            "Waze.",
            "SoundCast.",
            "Sharethrough.",
            "Fyber.",
            "Red For Publishers.",
            "Media.net.",
            "Tapjoy.",
            "Vistar.",
            "DAX.",
            "JCD.",
            "Place Exchange.",
            "AppLovin.",
            "Connatix.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ExitEvent = {
      description = "Exit event of the creative.",
      id = "ExitEvent",
      properties = {
        name = {
          description = "The name of the click tag of the exit event. The name must be unique within one creative. Leave it empty or unset for creatives containing image assets only.",
          type = "string",
        },
        reportingName = {
          description = "The name used to identify this event in reports. Leave it empty or unset for creatives containing image assets only.",
          type = "string",
        },
        type = {
          description = "Required. The type of the exit event.",
          enum = {
            "EXIT_EVENT_TYPE_UNSPECIFIED",
            "EXIT_EVENT_TYPE_DEFAULT",
            "EXIT_EVENT_TYPE_BACKUP",
          },
          enumDescriptions = {
            "Exit event type is not specified or is unknown in this version.",
            "The exit event is the default one.",
            "The exit event is a backup exit event. There could be multiple backup exit events in a creative.",
          },
          type = "string",
        },
        url = {
          description = "Required. The click through URL of the exit event. This is required when type is: * `EXIT_EVENT_TYPE_DEFAULT` * `EXIT_EVENT_TYPE_BACKUP`",
          type = "string",
        },
      },
      type = "object",
    },
    FirstAndThirdPartyAudience = {
      description = "Describes a first or third party audience list used for targeting. First party audiences are created via usage of client data. Third party audiences are provided by Third Party data providers and can only be licensed to customers.",
      id = "FirstAndThirdPartyAudience",
      properties = {
        activeDisplayAudienceSize = {
          description = "Output only. The estimated audience size for the Display network in the past month. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        appId = {
          description = "The app_id matches with the type of the mobile_device_ids being uploaded. Only applicable to audience_type `CUSTOMER_MATCH_DEVICE_ID`",
          type = "string",
        },
        audienceSource = {
          description = "Output only. The source of the audience.",
          enum = {
            "AUDIENCE_SOURCE_UNSPECIFIED",
            "DISPLAY_VIDEO_360",
            "CAMPAIGN_MANAGER",
            "AD_MANAGER",
            "SEARCH_ADS_360",
            "YOUTUBE",
            "ADS_DATA_HUB",
          },
          enumDescriptions = {
            "Default value when audience source is not specified or is unknown.",
            "Originated from Display & Video 360.",
            "Originated from Campaign Manager 360.",
            "Originated from Google Ad Manager.",
            "Originated from Search Ads 360.",
            "Originated from Youtube.",
            "Originated from Ads Data Hub.",
          },
          readOnly = true,
          type = "string",
        },
        audienceType = {
          description = "The type of the audience.",
          enum = {
            "AUDIENCE_TYPE_UNSPECIFIED",
            "CUSTOMER_MATCH_CONTACT_INFO",
            "CUSTOMER_MATCH_DEVICE_ID",
            "CUSTOMER_MATCH_USER_ID",
            "ACTIVITY_BASED",
            "FREQUENCY_CAP",
            "TAG_BASED",
            "YOUTUBE_USERS",
            "LICENSED",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown.",
            "Audience was generated through matching customers to known contact information.",
            "Audience was generated through matching customers to known Mobile device IDs.",
            "Audience was generated through matching customers to known User IDs.",
            "Audience was created based on campaign activity.",
            "Audience was created based on excluding the number of impressions they were served.",
            "Audience was created based on custom variables attached to pixel.",
            "Audience was created based on past interactions with videos, YouTube ads, or YouTube channel.",
            "Subtype of third party audience type.",
          },
          type = "string",
        },
        contactInfoList = {
          ["$ref"] = "ContactInfoList",
          description = "Input only. A list of contact information to define the initial audience members. Only applicable to audience_type `CUSTOMER_MATCH_CONTACT_INFO`",
        },
        description = {
          description = "The user-provided description of the audience. Only applicable to first party audiences.",
          type = "string",
        },
        displayAudienceSize = {
          description = "Output only. The estimated audience size for the Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayDesktopAudienceSize = {
          description = "Output only. The estimated desktop audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayMobileAppAudienceSize = {
          description = "Output only. The estimated mobile app audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayMobileWebAudienceSize = {
          description = "Output only. The estimated mobile web audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "The display name of the first and third party audience.",
          type = "string",
        },
        firstAndThirdPartyAudienceId = {
          description = "Output only. The unique ID of the first and third party audience. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        firstAndThirdPartyAudienceType = {
          description = "Whether the audience is a first or third party audience.",
          enum = {
            "FIRST_AND_THIRD_PARTY_AUDIENCE_TYPE_UNSPECIFIED",
            "FIRST_AND_THIRD_PARTY_AUDIENCE_TYPE_FIRST_PARTY",
            "FIRST_AND_THIRD_PARTY_AUDIENCE_TYPE_THIRD_PARTY",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown.",
            "Audience that is created via usage of client data.",
            "Audience that is provided by Third Party data providers.",
          },
          type = "string",
        },
        gmailAudienceSize = {
          description = "Output only. The estimated audience size for Gmail network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        membershipDurationDays = {
          description = "The duration in days that an entry remains in the audience after the qualifying event. If the audience has no expiration, set the value of this field to 10000. Otherwise, the set value must be greater than 0 and less than or equal to 540. Only applicable to first party audiences. This field is required if one of the following audience_type is used: * `CUSTOMER_MATCH_CONTACT_INFO` * `CUSTOMER_MATCH_DEVICE_ID`",
          format = "int64",
          type = "string",
        },
        mobileDeviceIdList = {
          ["$ref"] = "MobileDeviceIdList",
          description = "Input only. A list of mobile device IDs to define the initial audience members. Only applicable to audience_type `CUSTOMER_MATCH_DEVICE_ID`",
        },
        name = {
          description = "Output only. The resource name of the first and third party audience.",
          readOnly = true,
          type = "string",
        },
        youtubeAudienceSize = {
          description = "Output only. The estimated audience size for YouTube network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    FirstAndThirdPartyAudienceGroup = {
      description = "Details of first and third party audience group. All first and third party audience targeting settings are logically ‘OR’ of each other.",
      id = "FirstAndThirdPartyAudienceGroup",
      properties = {
        settings = {
          description = "Required. All first and third party audience targeting settings in first and third party audience group. Repeated settings with same id are not allowed.",
          items = {
            ["$ref"] = "FirstAndThirdPartyAudienceTargetingSetting",
          },
          type = "array",
        },
      },
      type = "object",
    },
    FirstAndThirdPartyAudienceTargetingSetting = {
      description = "Details of first and third party audience targeting setting.",
      id = "FirstAndThirdPartyAudienceTargetingSetting",
      properties = {
        firstAndThirdPartyAudienceId = {
          description = "Required. First and third party audience id of the first and third party audience targeting setting. This id is first_and_third_party_audience_id.",
          format = "int64",
          type = "string",
        },
        recency = {
          description = "The recency of the first and third party audience targeting setting. Only applicable to first party audiences, otherwise will be ignored. For more info, refer to https://support.google.com/displayvideo/answer/2949947#recency When unspecified, no recency limit will be used.",
          enum = {
            "RECENCY_NO_LIMIT",
            "RECENCY_1_MINUTE",
            "RECENCY_5_MINUTES",
            "RECENCY_10_MINUTES",
            "RECENCY_15_MINUTES",
            "RECENCY_30_MINUTES",
            "RECENCY_1_HOUR",
            "RECENCY_2_HOURS",
            "RECENCY_3_HOURS",
            "RECENCY_6_HOURS",
            "RECENCY_12_HOURS",
            "RECENCY_1_DAY",
            "RECENCY_2_DAYS",
            "RECENCY_3_DAYS",
            "RECENCY_5_DAYS",
            "RECENCY_7_DAYS",
            "RECENCY_10_DAYS",
            "RECENCY_14_DAYS",
            "RECENCY_15_DAYS",
            "RECENCY_21_DAYS",
            "RECENCY_28_DAYS",
            "RECENCY_30_DAYS",
            "RECENCY_40_DAYS",
            "RECENCY_45_DAYS",
            "RECENCY_60_DAYS",
            "RECENCY_90_DAYS",
            "RECENCY_120_DAYS",
            "RECENCY_180_DAYS",
            "RECENCY_270_DAYS",
            "RECENCY_365_DAYS",
          },
          enumDescriptions = {
            "No limit of recency.",
            "Recency is 1 minute.",
            "Recency is 5 minutes.",
            "Recency is 10 minutes.",
            "Recency is 15 minutes.",
            "Recency is 30 minutes.",
            "Recency is 1 hour.",
            "Recency is 2 hours.",
            "Recency is 3 hours.",
            "Recency is 6 hours.",
            "Recency is 12 hours.",
            "Recency is 1 day.",
            "Recency is 2 days.",
            "Recency is 3 days.",
            "Recency is 5 days.",
            "Recency is 7 days.",
            "Recency is 10 days.",
            "Recency is 14 days.",
            "Recency is 15 days.",
            "Recency is 21 days.",
            "Recency is 28 days.",
            "Recency is 30 days.",
            "Recency is 40 days.",
            "Recency is 45 days.",
            "Recency is 60 days.",
            "Recency is 90 days.",
            "Recency is 120 days.",
            "Recency is 180 days.",
            "Recency is 270 days.",
            "Recency is 365 days.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    FixedBidStrategy = {
      description = "A strategy that uses a fixed bidding price.",
      id = "FixedBidStrategy",
      properties = {
        bidAmountMicros = {
          description = "The fixed bid amount, in micros of the advertiser's currency. For insertion order entity, bid_amount_micros should be set as 0. For line item entity, bid_amount_micros must be greater than or equal to billable unit of the given currency and smaller than or equal to the upper limit 1000000000. For example, 1500000 represents 1.5 standard units of the currency.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    FloodlightGroup = {
      description = "A single Floodlight group.",
      id = "FloodlightGroup",
      properties = {
        activeViewConfig = {
          ["$ref"] = "ActiveViewVideoViewabilityMetricConfig",
          description = "The Active View video viewability metric configuration for the Floodlight group.",
        },
        customVariables = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "User-defined custom variables owned by the Floodlight group. Use custom Floodlight variables to create reporting data that is tailored to your unique business needs. Custom Floodlight variables use the keys `U1=`, `U2=`, and so on, and can take any values that you choose to pass to them. You can use them to track virtually any type of data that you collect about your customers, such as the genre of movie that a customer purchases, the country to which the item is shipped, and so on. Custom Floodlight variables may not be used to pass any data that could be used or recognized as personally identifiable information (PII). Example: `custom_variables { fields { \"U1\": value { number_value: 123.4 }, \"U2\": value { string_value: \"MyVariable2\" }, \"U3\": value { string_value: \"MyVariable3\" } } }` Acceptable values for keys are \"U1\" through \"U100\", inclusive. String values must be less than 64 characters long, and cannot contain the following characters: `\"<>`.",
          type = "object",
        },
        displayName = {
          description = "Required. The display name of the Floodlight group.",
          type = "string",
        },
        floodlightGroupId = {
          description = "Output only. The unique ID of the Floodlight group. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        lookbackWindow = {
          ["$ref"] = "LookbackWindow",
          description = "Required. The lookback window for the Floodlight group. Both click_days and impression_days are required. Acceptable values for both are `0` to `90`, inclusive.",
        },
        name = {
          description = "Output only. The resource name of the Floodlight group.",
          readOnly = true,
          type = "string",
        },
        webTagType = {
          description = "Required. The web tag type enabled for the Floodlight group.",
          enum = {
            "WEB_TAG_TYPE_UNSPECIFIED",
            "WEB_TAG_TYPE_NONE",
            "WEB_TAG_TYPE_IMAGE",
            "WEB_TAG_TYPE_DYNAMIC",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "No tag type.",
            "Image tag.",
            "Dynamic tag.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    FrequencyCap = {
      description = "Settings that control the number of times a user may be shown with the same ad during a given time period.",
      id = "FrequencyCap",
      properties = {
        maxImpressions = {
          description = "The maximum number of times a user may be shown the same ad during this period. Must be greater than 0. Required when unlimited is `false` and max_views is not set.",
          format = "int32",
          type = "integer",
        },
        timeUnit = {
          description = "The time unit in which the frequency cap will be applied. Required when unlimited is `false`.",
          enum = {
            "TIME_UNIT_UNSPECIFIED",
            "TIME_UNIT_LIFETIME",
            "TIME_UNIT_MONTHS",
            "TIME_UNIT_WEEKS",
            "TIME_UNIT_DAYS",
            "TIME_UNIT_HOURS",
            "TIME_UNIT_MINUTES",
          },
          enumDescriptions = {
            "Time unit value is not specified or is unknown in this version.",
            "The frequency cap will be applied to the whole life time of the line item.",
            "The frequency cap will be applied to a number of months.",
            "The frequency cap will be applied to a number of weeks.",
            "The frequency cap will be applied to a number of days.",
            "The frequency cap will be applied to a number of hours.",
            "The frequency cap will be applied to a number of minutes.",
          },
          type = "string",
        },
        timeUnitCount = {
          description = "The number of time_unit the frequency cap will last. Required when unlimited is `false`. The following restrictions apply based on the value of time_unit: * `TIME_UNIT_LIFETIME` - this field is output only and will default to 1 * `TIME_UNIT_MONTHS` - must be between 1 and 2 * `TIME_UNIT_WEEKS` - must be between 1 and 4 * `TIME_UNIT_DAYS` - must be between 1 and 6 * `TIME_UNIT_HOURS` - must be between 1 and 23 * `TIME_UNIT_MINUTES` - must be between 1 and 59",
          format = "int32",
          type = "integer",
        },
        unlimited = {
          description = "Whether unlimited frequency capping is applied. When this field is set to `true`, the remaining frequency cap fields are not applicable.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GenderAssignedTargetingOptionDetails = {
      description = "Details for assigned gender targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_GENDER`.",
      id = "GenderAssignedTargetingOptionDetails",
      properties = {
        gender = {
          description = "The gender of the audience. Output only in v1. Required in v2.",
          enum = {
            "GENDER_UNSPECIFIED",
            "GENDER_MALE",
            "GENDER_FEMALE",
            "GENDER_UNKNOWN",
          },
          enumDescriptions = {
            "Default value when gender is not specified in this version. This enum is a place holder for default value and does not represent a real gender option.",
            "The audience gender is male.",
            "The audience gender is female.",
            "The audience gender is unknown.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_GENDER`.",
          type = "string",
        },
      },
      type = "object",
    },
    GenderTargetingOptionDetails = {
      description = "Represents a targetable gender. This will be populated in the gender_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_GENDER`.",
      id = "GenderTargetingOptionDetails",
      properties = {
        gender = {
          description = "Output only. The gender of an audience.",
          enum = {
            "GENDER_UNSPECIFIED",
            "GENDER_MALE",
            "GENDER_FEMALE",
            "GENDER_UNKNOWN",
          },
          enumDescriptions = {
            "Default value when gender is not specified in this version. This enum is a place holder for default value and does not represent a real gender option.",
            "The audience gender is male.",
            "The audience gender is female.",
            "The audience gender is unknown.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GenerateDefaultLineItemRequest = {
      description = "Request message for LineItemService.GenerateDefaultLineItem.",
      id = "GenerateDefaultLineItemRequest",
      properties = {
        displayName = {
          description = "Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        insertionOrderId = {
          description = "Required. The unique ID of the insertion order that the line item belongs to.",
          format = "int64",
          type = "string",
        },
        lineItemType = {
          description = "Required. The type of the line item.",
          enum = {
            "LINE_ITEM_TYPE_UNSPECIFIED",
            "LINE_ITEM_TYPE_DISPLAY_DEFAULT",
            "LINE_ITEM_TYPE_DISPLAY_MOBILE_APP_INSTALL",
            "LINE_ITEM_TYPE_VIDEO_DEFAULT",
            "LINE_ITEM_TYPE_VIDEO_MOBILE_APP_INSTALL",
            "LINE_ITEM_TYPE_DISPLAY_MOBILE_APP_INVENTORY",
            "LINE_ITEM_TYPE_VIDEO_MOBILE_APP_INVENTORY",
            "LINE_ITEM_TYPE_AUDIO_DEFAULT",
            "LINE_ITEM_TYPE_VIDEO_OVER_THE_TOP",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version. Line items of this type and their targeting cannot be created or updated using the API.",
            "Image, HTML5, native, or rich media ads.",
            "Display ads that drive installs of an app.",
            "Video ads sold on a CPM basis for a variety of environments.",
            "Video ads that drive installs of an app.",
            "Display ads served on mobile app inventory. Line items of this type and their targeting cannot be created or updated using the API.",
            "Video ads served on mobile app inventory. Line items of this type and their targeting cannot be created or updated using the API.",
            "RTB Audio ads sold for a variety of environments.",
            "Over-the-top ads present in OTT insertion orders. This type is only applicable to line items with an insertion order of insertion_order_type `OVER_THE_TOP`.",
          },
          type = "string",
        },
        mobileApp = {
          ["$ref"] = "MobileApp",
          description = "The mobile app promoted by the line item. This is applicable only when line_item_type is either `LINE_ITEM_TYPE_DISPLAY_MOBILE_APP_INSTALL` or `LINE_ITEM_TYPE_VIDEO_MOBILE_APP_INSTALL`.",
        },
      },
      type = "object",
    },
    GeoRegionAssignedTargetingOptionDetails = {
      description = "Details for assigned geographic region targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_GEO_REGION`.",
      id = "GeoRegionAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the geographic region (e.g., \"Ontario, Canada\").",
          readOnly = true,
          type = "string",
        },
        geoRegionType = {
          description = "Output only. The type of geographic region targeting.",
          enum = {
            "GEO_REGION_TYPE_UNKNOWN",
            "GEO_REGION_TYPE_OTHER",
            "GEO_REGION_TYPE_COUNTRY",
            "GEO_REGION_TYPE_REGION",
            "GEO_REGION_TYPE_TERRITORY",
            "GEO_REGION_TYPE_PROVINCE",
            "GEO_REGION_TYPE_STATE",
            "GEO_REGION_TYPE_PREFECTURE",
            "GEO_REGION_TYPE_GOVERNORATE",
            "GEO_REGION_TYPE_CANTON",
            "GEO_REGION_TYPE_UNION_TERRITORY",
            "GEO_REGION_TYPE_AUTONOMOUS_COMMUNITY",
            "GEO_REGION_TYPE_DMA_REGION",
            "GEO_REGION_TYPE_METRO",
            "GEO_REGION_TYPE_CONGRESSIONAL_DISTRICT",
            "GEO_REGION_TYPE_COUNTY",
            "GEO_REGION_TYPE_MUNICIPALITY",
            "GEO_REGION_TYPE_CITY",
            "GEO_REGION_TYPE_POSTAL_CODE",
            "GEO_REGION_TYPE_DEPARTMENT",
            "GEO_REGION_TYPE_AIRPORT",
            "GEO_REGION_TYPE_TV_REGION",
            "GEO_REGION_TYPE_OKRUG",
            "GEO_REGION_TYPE_BOROUGH",
            "GEO_REGION_TYPE_CITY_REGION",
            "GEO_REGION_TYPE_ARRONDISSEMENT",
            "GEO_REGION_TYPE_NEIGHBORHOOD",
            "GEO_REGION_TYPE_UNIVERSITY",
            "GEO_REGION_TYPE_DISTRICT",
          },
          enumDescriptions = {
            "The geographic region type is unknown.",
            "The geographic region type is other.",
            "The geographic region is a country.",
            "The geographic region type is region.",
            "The geographic region is a territory.",
            "The geographic region is a province.",
            "The geographic region is a state.",
            "The geographic region is a prefecture.",
            "The geographic region is a governorate.",
            "The geographic region is a canton.",
            "The geographic region is a union territory.",
            "The geographic region is an autonomous community.",
            "The geographic region is a designated market area (DMA) region.",
            "The geographic region type is metro.",
            "The geographic region is a congressional district.",
            "The geographic region is a county.",
            "The geographic region is a municipality.",
            "The geographic region is a city.",
            "The geographic region targeting type is postal code.",
            "The geographic region targeting type is department.",
            "The geographic region is an airport.",
            "The geographic region is a TV region.",
            "The geographic region is an okrug.",
            "The geographic region is a borough.",
            "The geographic region is a city region.",
            "The geographic region is an arrondissement.",
            "The geographic region is a neighborhood.",
            "The geographic region is a university.",
            "The geographic region is a district.",
          },
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_GEO_REGION`.",
          type = "string",
        },
      },
      type = "object",
    },
    GeoRegionSearchTerms = {
      description = "Search terms for geo region targeting options.",
      id = "GeoRegionSearchTerms",
      properties = {
        geoRegionQuery = {
          description = "The search query for the desired geo region. The query can be a prefix, e.g. \"New Yor\", \"Seattle\", \"USA\", etc.",
          type = "string",
        },
      },
      type = "object",
    },
    GeoRegionTargetingOptionDetails = {
      description = "Represents a targetable geographic region. This will be populated in the geo_region_details field when targeting_type is `TARGETING_TYPE_GEO_REGION`.",
      id = "GeoRegionTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the geographic region (e.g., \"Ontario, Canada\").",
          readOnly = true,
          type = "string",
        },
        geoRegionType = {
          description = "Output only. The type of geographic region targeting.",
          enum = {
            "GEO_REGION_TYPE_UNKNOWN",
            "GEO_REGION_TYPE_OTHER",
            "GEO_REGION_TYPE_COUNTRY",
            "GEO_REGION_TYPE_REGION",
            "GEO_REGION_TYPE_TERRITORY",
            "GEO_REGION_TYPE_PROVINCE",
            "GEO_REGION_TYPE_STATE",
            "GEO_REGION_TYPE_PREFECTURE",
            "GEO_REGION_TYPE_GOVERNORATE",
            "GEO_REGION_TYPE_CANTON",
            "GEO_REGION_TYPE_UNION_TERRITORY",
            "GEO_REGION_TYPE_AUTONOMOUS_COMMUNITY",
            "GEO_REGION_TYPE_DMA_REGION",
            "GEO_REGION_TYPE_METRO",
            "GEO_REGION_TYPE_CONGRESSIONAL_DISTRICT",
            "GEO_REGION_TYPE_COUNTY",
            "GEO_REGION_TYPE_MUNICIPALITY",
            "GEO_REGION_TYPE_CITY",
            "GEO_REGION_TYPE_POSTAL_CODE",
            "GEO_REGION_TYPE_DEPARTMENT",
            "GEO_REGION_TYPE_AIRPORT",
            "GEO_REGION_TYPE_TV_REGION",
            "GEO_REGION_TYPE_OKRUG",
            "GEO_REGION_TYPE_BOROUGH",
            "GEO_REGION_TYPE_CITY_REGION",
            "GEO_REGION_TYPE_ARRONDISSEMENT",
            "GEO_REGION_TYPE_NEIGHBORHOOD",
            "GEO_REGION_TYPE_UNIVERSITY",
            "GEO_REGION_TYPE_DISTRICT",
          },
          enumDescriptions = {
            "The geographic region type is unknown.",
            "The geographic region type is other.",
            "The geographic region is a country.",
            "The geographic region type is region.",
            "The geographic region is a territory.",
            "The geographic region is a province.",
            "The geographic region is a state.",
            "The geographic region is a prefecture.",
            "The geographic region is a governorate.",
            "The geographic region is a canton.",
            "The geographic region is a union territory.",
            "The geographic region is an autonomous community.",
            "The geographic region is a designated market area (DMA) region.",
            "The geographic region type is metro.",
            "The geographic region is a congressional district.",
            "The geographic region is a county.",
            "The geographic region is a municipality.",
            "The geographic region is a city.",
            "The geographic region targeting type is postal code.",
            "The geographic region targeting type is department.",
            "The geographic region is an airport.",
            "The geographic region is a TV region.",
            "The geographic region is an okrug.",
            "The geographic region is a borough.",
            "The geographic region is a city region.",
            "The geographic region is an arrondissement.",
            "The geographic region is a neighborhood.",
            "The geographic region is a university.",
            "The geographic region is a district.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleAudience = {
      description = "Describes a Google audience resource. Includes Google audience lists.",
      id = "GoogleAudience",
      properties = {
        displayName = {
          description = "Output only. The display name of the Google audience. .",
          readOnly = true,
          type = "string",
        },
        googleAudienceId = {
          description = "Output only. The unique ID of the Google audience. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        googleAudienceType = {
          description = "Output only. The type of Google audience. .",
          enum = {
            "GOOGLE_AUDIENCE_TYPE_UNSPECIFIED",
            "GOOGLE_AUDIENCE_TYPE_AFFINITY",
            "GOOGLE_AUDIENCE_TYPE_IN_MARKET",
            "GOOGLE_AUDIENCE_TYPE_INSTALLED_APPS",
            "GOOGLE_AUDIENCE_TYPE_NEW_MOBILE_DEVICES",
            "GOOGLE_AUDIENCE_TYPE_LIFE_EVENT",
            "GOOGLE_AUDIENCE_TYPE_EXTENDED_DEMOGRAPHIC",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown.",
            "Affinity type Google audience.",
            "In-Market type Google audience.",
            "Installed-Apps type Google audience.",
            "New-Mobile-Devices type Google audience.",
            "Life-Event type Google audience.",
            "Extended-Demographic type Google audience.",
          },
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the google audience.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleAudienceGroup = {
      description = "Details of Google audience group. All Google audience targeting settings are logically ‘OR’ of each other.",
      id = "GoogleAudienceGroup",
      properties = {
        settings = {
          description = "Required. All Google audience targeting settings in Google audience group. Repeated settings with same id will be ignored.",
          items = {
            ["$ref"] = "GoogleAudienceTargetingSetting",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleAudienceTargetingSetting = {
      description = "Details of Google audience targeting setting.",
      id = "GoogleAudienceTargetingSetting",
      properties = {
        googleAudienceId = {
          description = "Required. Google audience id of the Google audience targeting setting. This id is google_audience_id.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleBytestreamMedia = {
      description = "Media resource.",
      id = "GoogleBytestreamMedia",
      properties = {
        resourceName = {
          description = "Name of the media resource.",
          type = "string",
        },
      },
      type = "object",
    },
    GuaranteedOrder = {
      description = "A guaranteed order. Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.",
      id = "GuaranteedOrder",
      properties = {
        defaultAdvertiserId = {
          description = "Output only. The ID of default advertiser of the guaranteed order. The default advertiser is either the read_write_advertiser_id or, if that is not set, the first advertiser listed in read_advertiser_ids. Otherwise, there is no default advertiser.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        defaultCampaignId = {
          description = "The ID of the default campaign that is assigned to the guaranteed order. The default campaign must belong to the default advertiser.",
          format = "int64",
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the guaranteed order. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        exchange = {
          description = "Required. Immutable. The exchange where the guaranteed order originated.",
          enum = {
            "EXCHANGE_UNSPECIFIED",
            "EXCHANGE_GOOGLE_AD_MANAGER",
            "EXCHANGE_APPNEXUS",
            "EXCHANGE_BRIGHTROLL",
            "EXCHANGE_ADFORM",
            "EXCHANGE_ADMETA",
            "EXCHANGE_ADMIXER",
            "EXCHANGE_ADSMOGO",
            "EXCHANGE_ADSWIZZ",
            "EXCHANGE_BIDSWITCH",
            "EXCHANGE_BRIGHTROLL_DISPLAY",
            "EXCHANGE_CADREON",
            "EXCHANGE_DAILYMOTION",
            "EXCHANGE_FIVE",
            "EXCHANGE_FLUCT",
            "EXCHANGE_FREEWHEEL",
            "EXCHANGE_GENIEE",
            "EXCHANGE_GUMGUM",
            "EXCHANGE_IMOBILE",
            "EXCHANGE_IBILLBOARD",
            "EXCHANGE_IMPROVE_DIGITAL",
            "EXCHANGE_INDEX",
            "EXCHANGE_KARGO",
            "EXCHANGE_MICROAD",
            "EXCHANGE_MOPUB",
            "EXCHANGE_NEND",
            "EXCHANGE_ONE_BY_AOL_DISPLAY",
            "EXCHANGE_ONE_BY_AOL_MOBILE",
            "EXCHANGE_ONE_BY_AOL_VIDEO",
            "EXCHANGE_OOYALA",
            "EXCHANGE_OPENX",
            "EXCHANGE_PERMODO",
            "EXCHANGE_PLATFORMONE",
            "EXCHANGE_PLATFORMID",
            "EXCHANGE_PUBMATIC",
            "EXCHANGE_PULSEPOINT",
            "EXCHANGE_REVENUEMAX",
            "EXCHANGE_RUBICON",
            "EXCHANGE_SMARTCLIP",
            "EXCHANGE_SMARTRTB",
            "EXCHANGE_SMARTSTREAMTV",
            "EXCHANGE_SOVRN",
            "EXCHANGE_SPOTXCHANGE",
            "EXCHANGE_STROER",
            "EXCHANGE_TEADSTV",
            "EXCHANGE_TELARIA",
            "EXCHANGE_TVN",
            "EXCHANGE_UNITED",
            "EXCHANGE_YIELDLAB",
            "EXCHANGE_YIELDMO",
            "EXCHANGE_UNRULYX",
            "EXCHANGE_OPEN8",
            "EXCHANGE_TRITON",
            "EXCHANGE_TRIPLELIFT",
            "EXCHANGE_TABOOLA",
            "EXCHANGE_INMOBI",
            "EXCHANGE_SMAATO",
            "EXCHANGE_AJA",
            "EXCHANGE_SUPERSHIP",
            "EXCHANGE_NEXSTAR_DIGITAL",
            "EXCHANGE_WAZE",
            "EXCHANGE_SOUNDCAST",
            "EXCHANGE_SHARETHROUGH",
            "EXCHANGE_FYBER",
            "EXCHANGE_RED_FOR_PUBLISHERS",
            "EXCHANGE_MEDIANET",
            "EXCHANGE_TAPJOY",
            "EXCHANGE_VISTAR",
            "EXCHANGE_DAX",
            "EXCHANGE_JCD",
            "EXCHANGE_PLACE_EXCHANGE",
            "EXCHANGE_APPLOVIN",
            "EXCHANGE_CONNATIX",
          },
          enumDescriptions = {
            "Exchange is not specified or is unknown in this version.",
            "Google Ad Manager.",
            "AppNexus.",
            "BrightRoll Exchange for Video from Yahoo!.",
            "Adform.",
            "Admeta.",
            "Admixer.",
            "AdsMogo.",
            "AdsWizz.",
            "BidSwitch.",
            "BrightRoll Exchange for Display from Yahoo!.",
            "Cadreon.",
            "Dailymotion.",
            "Five.",
            "Fluct.",
            "FreeWheel SSP.",
            "Geniee.",
            "GumGum.",
            "i-mobile.",
            "iBILLBOARD.",
            "Improve Digital.",
            "Index Exchange.",
            "Kargo.",
            "MicroAd.",
            "MoPub.",
            "Nend.",
            "ONE by AOL: Display Market Place.",
            "ONE by AOL: Mobile.",
            "ONE by AOL: Video.",
            "Ooyala.",
            "OpenX.",
            "Permodo.",
            "Platform One.",
            "PlatformId.",
            "PubMatic.",
            "PulsePoint.",
            "RevenueMax.",
            "Rubicon.",
            "SmartClip.",
            "SmartRTB+.",
            "SmartstreamTv.",
            "Sovrn.",
            "SpotXchange.",
            "Ströer SSP.",
            "TeadsTv.",
            "Telaria.",
            "TVN.",
            "United.",
            "Yieldlab.",
            "Yieldmo.",
            "UnrulyX.",
            "Open8.",
            "Triton.",
            "TripleLift.",
            "Taboola.",
            "InMobi.",
            "Smaato.",
            "Aja.",
            "Supership.",
            "Nexstar Digital.",
            "Waze.",
            "SoundCast.",
            "Sharethrough.",
            "Fyber.",
            "Red For Publishers.",
            "Media.net.",
            "Tapjoy.",
            "Vistar.",
            "DAX.",
            "JCD.",
            "Place Exchange.",
            "AppLovin.",
            "Connatix.",
          },
          type = "string",
        },
        guaranteedOrderId = {
          description = "Output only. The unique identifier of the guaranteed order. The guaranteed order IDs have the format `{exchange}-{legacy_guaranteed_order_id}`.",
          readOnly = true,
          type = "string",
        },
        legacyGuaranteedOrderId = {
          description = "Output only. The legacy ID of the guaranteed order. Assigned by the original exchange. The legacy ID is unique within one exchange, but is not guaranteed to be unique across all guaranteed orders. This ID is used in SDF and UI.",
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the guaranteed order.",
          readOnly = true,
          type = "string",
        },
        publisherName = {
          description = "Required. The publisher name of the guaranteed order. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        readAccessInherited = {
          description = "Whether all advertisers of read_write_partner_id have read access to the guaranteed order. Only applicable if read_write_partner_id is set. If True, overrides read_advertiser_ids.",
          type = "boolean",
        },
        readAdvertiserIds = {
          description = "The IDs of advertisers with read access to the guaranteed order. This field must not include the advertiser assigned to read_write_advertiser_id if it is set. All advertisers in this field must belong to read_write_partner_id or the same partner as read_write_advertiser_id.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        readWriteAdvertiserId = {
          description = "The advertiser with read/write access to the guaranteed order. This is also the default advertiser of the guaranteed order.",
          format = "int64",
          type = "string",
        },
        readWritePartnerId = {
          description = "The partner with read/write access to the guaranteed order.",
          format = "int64",
          type = "string",
        },
        status = {
          ["$ref"] = "GuaranteedOrderStatus",
          description = "The status settings of the guaranteed order.",
        },
        updateTime = {
          description = "Output only. The timestamp when the guaranteed order was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GuaranteedOrderStatus = {
      description = "The status settings of the guaranteed order.",
      id = "GuaranteedOrderStatus",
      properties = {
        configStatus = {
          description = "Output only. The configuration status of the guaranteed order. Acceptable values are `PENDING` and `COMPLETED`. A guaranteed order must be configured (fill in the required fields, choose creatives, and select a default campaign) before it can serve. Currently the configuration action can only be performed via UI.",
          enum = {
            "GUARANTEED_ORDER_CONFIG_STATUS_UNSPECIFIED",
            "PENDING",
            "COMPLETED",
          },
          enumDescriptions = {
            "The approval status is not specified or is unknown in this version.",
            "The beginning state of a guaranteed order. The guaranteed order in this state needs to be configured before it can serve.",
            "The state after the buyer configures a guaranteed order.",
          },
          readOnly = true,
          type = "string",
        },
        entityPauseReason = {
          description = "The user-provided reason for pausing this guaranteed order. Must be UTF-8 encoded with a maximum length of 100 bytes. Only applicable when entity_status is set to `ENTITY_STATUS_PAUSED`.",
          type = "string",
        },
        entityStatus = {
          description = "Whether or not the guaranteed order is servable. Acceptable values are `ENTITY_STATUS_ACTIVE`, `ENTITY_STATUS_ARCHIVED`, and `ENTITY_STATUS_PAUSED`. Default value is `ENTITY_STATUS_ACTIVE`.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    HouseholdIncomeAssignedTargetingOptionDetails = {
      description = "Details for assigned household income targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_HOUSEHOLD_INCOME`.",
      id = "HouseholdIncomeAssignedTargetingOptionDetails",
      properties = {
        householdIncome = {
          description = "The household income of the audience. Output only in v1. Required in v2.",
          enum = {
            "HOUSEHOLD_INCOME_UNSPECIFIED",
            "HOUSEHOLD_INCOME_UNKNOWN",
            "HOUSEHOLD_INCOME_LOWER_50_PERCENT",
            "HOUSEHOLD_INCOME_TOP_41_TO_50_PERCENT",
            "HOUSEHOLD_INCOME_TOP_31_TO_40_PERCENT",
            "HOUSEHOLD_INCOME_TOP_21_TO_30_PERCENT",
            "HOUSEHOLD_INCOME_TOP_11_TO_20_PERCENT",
            "HOUSEHOLD_INCOME_TOP_10_PERCENT",
          },
          enumDescriptions = {
            "Default value when household income is not specified in this version. This enum is a placeholder for default value and does not represent a real household income option.",
            "The household income of the audience is unknown.",
            "The audience is in the lower 50% of U.S. household incomes.",
            "The audience is in the top 41-50% of U.S. household incomes.",
            "The audience is in the top 31-40% of U.S. household incomes.",
            "The audience is in the top 21-30% of U.S. household incomes.",
            "The audience is in the top 11-20% of U.S. household incomes.",
            "The audience is in the top 10% of U.S. household incomes.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_HOUSEHOLD_INCOME`.",
          type = "string",
        },
      },
      type = "object",
    },
    HouseholdIncomeTargetingOptionDetails = {
      description = "Represents a targetable household income. This will be populated in the household_income_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_HOUSEHOLD_INCOME`.",
      id = "HouseholdIncomeTargetingOptionDetails",
      properties = {
        householdIncome = {
          description = "Output only. The household income of an audience.",
          enum = {
            "HOUSEHOLD_INCOME_UNSPECIFIED",
            "HOUSEHOLD_INCOME_UNKNOWN",
            "HOUSEHOLD_INCOME_LOWER_50_PERCENT",
            "HOUSEHOLD_INCOME_TOP_41_TO_50_PERCENT",
            "HOUSEHOLD_INCOME_TOP_31_TO_40_PERCENT",
            "HOUSEHOLD_INCOME_TOP_21_TO_30_PERCENT",
            "HOUSEHOLD_INCOME_TOP_11_TO_20_PERCENT",
            "HOUSEHOLD_INCOME_TOP_10_PERCENT",
          },
          enumDescriptions = {
            "Default value when household income is not specified in this version. This enum is a placeholder for default value and does not represent a real household income option.",
            "The household income of the audience is unknown.",
            "The audience is in the lower 50% of U.S. household incomes.",
            "The audience is in the top 41-50% of U.S. household incomes.",
            "The audience is in the top 31-40% of U.S. household incomes.",
            "The audience is in the top 21-30% of U.S. household incomes.",
            "The audience is in the top 11-20% of U.S. household incomes.",
            "The audience is in the top 10% of U.S. household incomes.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    IdFilter = {
      description = "A filtering option that filters entities by their entity IDs.",
      id = "IdFilter",
      properties = {
        adGroupAdIds = {
          description = "YouTube Ads to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        adGroupIds = {
          description = "YouTube Ad Groups to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        campaignIds = {
          description = "Campaigns to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        insertionOrderIds = {
          description = "Insertion Orders to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        lineItemIds = {
          description = "Line Items to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        mediaProductIds = {
          description = "Media Products to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InsertionOrder = {
      description = "A single insertion order.",
      id = "InsertionOrder",
      properties = {
        advertiserId = {
          description = "Output only. The unique ID of the advertiser the insertion order belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        bidStrategy = {
          ["$ref"] = "BiddingStrategy",
          description = "The bidding strategy of the insertion order. By default, fixed_bid is set.",
        },
        billableOutcome = {
          description = "Immutable. The billable outcome of the insertion order.",
          enum = {
            "BILLABLE_OUTCOME_UNSPECIFIED",
            "BILLABLE_OUTCOME_PAY_PER_IMPRESSION",
            "BILLABLE_OUTCOME_PAY_PER_CLICK",
            "BILLABLE_OUTCOME_PAY_PER_VIEWABLE_IMPRESSION",
          },
          enumDescriptions = {
            "Unspecified billable outcome.",
            "Pay per impressions.",
            "Pay per click.",
            "Pay per active view.",
          },
          type = "string",
        },
        budget = {
          ["$ref"] = "InsertionOrderBudget",
          description = "Required. The budget allocation settings of the insertion order.",
        },
        campaignId = {
          description = "Required. Immutable. The unique ID of the campaign that the insertion order belongs to.",
          format = "int64",
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the insertion order. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        entityStatus = {
          description = "Required. Controls whether or not the insertion order can spend its budget and bid on inventory. * For CreateInsertionOrder method, only `ENTITY_STATUS_DRAFT` is allowed. To activate an insertion order, use UpdateInsertionOrder method and update the status to `ENTITY_STATUS_ACTIVE` after creation. * An insertion order cannot be changed back to `ENTITY_STATUS_DRAFT` status from any other status. * An insertion order cannot be set to `ENTITY_STATUS_ACTIVE` if its parent campaign is not active.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        frequencyCap = {
          ["$ref"] = "FrequencyCap",
          description = "Required. The frequency capping setting of the insertion order.",
        },
        insertionOrderId = {
          description = "Output only. The unique ID of the insertion order. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        insertionOrderType = {
          description = "The type of insertion order. If this field is unspecified in creation, the value defaults to `RTB`.",
          enum = {
            "INSERTION_ORDER_TYPE_UNSPECIFIED",
            "RTB",
            "OVER_THE_TOP",
          },
          enumDescriptions = {
            "Insertion order type is not specified or is unknown.",
            "Real-time bidding.",
            "Over-the-top.",
          },
          type = "string",
        },
        integrationDetails = {
          ["$ref"] = "IntegrationDetails",
          description = "Additional integration details of the insertion order.",
        },
        name = {
          description = "Output only. The resource name of the insertion order.",
          readOnly = true,
          type = "string",
        },
        pacing = {
          ["$ref"] = "Pacing",
          description = "Required. The budget spending speed setting of the insertion order.",
        },
        partnerCosts = {
          description = "The partner costs associated with the insertion order. If absent or empty in CreateInsertionOrder method, the newly created insertion order will inherit partner costs from the partner settings.",
          items = {
            ["$ref"] = "PartnerCost",
          },
          type = "array",
        },
        performanceGoal = {
          ["$ref"] = "PerformanceGoal",
          description = "Required. Performance goal of the insertion order.",
        },
        reservationType = {
          description = "Output only. The reservation type of the insertion order.",
          enum = {
            "RESERVATION_TYPE_UNSPECIFIED",
            "RESERVATION_TYPE_NOT_GUARANTEED",
            "RESERVATION_TYPE_PROGRAMMATIC_GUARANTEED",
            "RESERVATION_TYPE_TAG_GUARANTEED",
          },
          enumDescriptions = {
            "Reservation type value is not specified or is unknown in this version.",
            "Not created through a guaranteed inventory source.",
            "Created through a programmatic guaranteed inventory source.",
            "Created through a tag guaranteed inventory source.",
          },
          readOnly = true,
          type = "string",
        },
        updateTime = {
          description = "Output only. The timestamp when the insertion order was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    InsertionOrderBudget = {
      description = "Settings that control how insertion order budget is allocated.",
      id = "InsertionOrderBudget",
      properties = {
        automationType = {
          description = "The type of automation used to manage bid and budget for the insertion order. If this field is unspecified in creation, the value defaults to `INSERTION_ORDER_AUTOMATION_TYPE_NONE`.",
          enum = {
            "INSERTION_ORDER_AUTOMATION_TYPE_UNSPECIFIED",
            "INSERTION_ORDER_AUTOMATION_TYPE_BUDGET",
            "INSERTION_ORDER_AUTOMATION_TYPE_NONE",
            "INSERTION_ORDER_AUTOMATION_TYPE_BID_BUDGET",
          },
          enumDescriptions = {
            "Insertion order automation option is not specified or is unknown in this version.",
            "Automatic budget allocation. Allow the system to automatically shift budget to owning line items to optimize performance defined by performance_goal. No automation on bid settings.",
            "No automation of bid or budget on insertion order level. Bid and budget must be manually configured at the line item level.",
            "Allow the system to automatically adjust bids and shift budget to owning line items to optimize performance defined by performance_goal.",
          },
          type = "string",
        },
        budgetSegments = {
          description = "Required. The list of budget segments. Use a budget segment to specify a specific budget for a given period of time an insertion order is running.",
          items = {
            ["$ref"] = "InsertionOrderBudgetSegment",
          },
          type = "array",
        },
        budgetUnit = {
          description = "Required. Immutable. The budget unit specifies whether the budget is currency based or impression based.",
          enum = {
            "BUDGET_UNIT_UNSPECIFIED",
            "BUDGET_UNIT_CURRENCY",
            "BUDGET_UNIT_IMPRESSIONS",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Budgeting in currency amounts.",
            "Budgeting in impression amounts.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    InsertionOrderBudgetSegment = {
      description = "Settings that control the budget of a single budget segment.",
      id = "InsertionOrderBudgetSegment",
      properties = {
        budgetAmountMicros = {
          description = "Required. The budget amount the insertion order will spend for the given date_range. The amount is in micros. Must be greater than 0. For example, 500000000 represents 500 standard units of the currency.",
          format = "int64",
          type = "string",
        },
        campaignBudgetId = {
          description = "The budget_id of the campaign budget that this insertion order budget segment is a part of.",
          format = "int64",
          type = "string",
        },
        dateRange = {
          ["$ref"] = "DateRange",
          description = "Required. The start and end date settings of the budget segment. They are resolved relative to the parent advertiser's time zone. * When creating a new budget segment, both `start_date` and `end_date` must be in the future. * An existing budget segment with a `start_date` in the past has a mutable `end_date` but an immutable `start_date`. * `end_date` must be the `start_date` or later, both before the year 2037.",
        },
        description = {
          description = "The budget segment description. It can be used to enter Purchase Order information for each budget segment and have that information printed on the invoices. Must be UTF-8 encoded.",
          type = "string",
        },
      },
      type = "object",
    },
    IntegralAdScience = {
      description = "Details of Integral Ad Science settings.",
      id = "IntegralAdScience",
      properties = {
        customSegmentId = {
          description = "The custom segment ID provided by Integral Ad Science. The ID must be between `1000001` and `1999999`, inclusive.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        displayViewability = {
          description = "Display Viewability section (applicable to display line items only).",
          enum = {
            "PERFORMANCE_VIEWABILITY_UNSPECIFIED",
            "PERFORMANCE_VIEWABILITY_40",
            "PERFORMANCE_VIEWABILITY_50",
            "PERFORMANCE_VIEWABILITY_60",
            "PERFORMANCE_VIEWABILITY_70",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any display viewability options.",
            "Target 40% Viewability or Higher.",
            "Target 50% Viewability or Higher.",
            "Target 60% Viewability or Higher.",
            "Target 70% Viewability or Higher.",
          },
          type = "string",
        },
        excludeUnrateable = {
          description = "Brand Safety - **Unrateable**.",
          type = "boolean",
        },
        excludedAdFraudRisk = {
          description = "Ad Fraud settings.",
          enum = {
            "SUSPICIOUS_ACTIVITY_UNSPECIFIED",
            "SUSPICIOUS_ACTIVITY_HR",
            "SUSPICIOUS_ACTIVITY_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any ad fraud prevention options.",
            "Ad Fraud - Exclude High Risk.",
            "Ad Fraud - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedAdultRisk = {
          description = "Brand Safety - **Adult content**.",
          enum = {
            "ADULT_UNSPECIFIED",
            "ADULT_HR",
            "ADULT_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any adult options.",
            "Adult - Exclude High Risk.",
            "Adult - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedAlcoholRisk = {
          description = "Brand Safety - **Alcohol**.",
          enum = {
            "ALCOHOL_UNSPECIFIED",
            "ALCOHOL_HR",
            "ALCOHOL_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any alcohol options.",
            "Alcohol - Exclude High Risk.",
            "Alcohol - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedDrugsRisk = {
          description = "Brand Safety - **Drugs**.",
          enum = {
            "DRUGS_UNSPECIFIED",
            "DRUGS_HR",
            "DRUGS_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any drugs options.",
            "Drugs - Exclude High Risk.",
            "Drugs - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedGamblingRisk = {
          description = "Brand Safety - **Gambling**.",
          enum = {
            "GAMBLING_UNSPECIFIED",
            "GAMBLING_HR",
            "GAMBLING_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any gambling options.",
            "Gambling - Exclude High Risk.",
            "Gambling - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedHateSpeechRisk = {
          description = "Brand Safety - **Hate speech**.",
          enum = {
            "HATE_SPEECH_UNSPECIFIED",
            "HATE_SPEECH_HR",
            "HATE_SPEECH_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any hate speech options.",
            "Hate Speech - Exclude High Risk.",
            "Hate Speech - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedIllegalDownloadsRisk = {
          description = "Brand Safety - **Illegal downloads**.",
          enum = {
            "ILLEGAL_DOWNLOADS_UNSPECIFIED",
            "ILLEGAL_DOWNLOADS_HR",
            "ILLEGAL_DOWNLOADS_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any illegal downloads options.",
            "Illegal Downloads - Exclude High Risk.",
            "Illegal Downloads - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedOffensiveLanguageRisk = {
          description = "Brand Safety - **Offensive language**.",
          enum = {
            "OFFENSIVE_LANGUAGE_UNSPECIFIED",
            "OFFENSIVE_LANGUAGE_HR",
            "OFFENSIVE_LANGUAGE_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any language options.",
            "Offensive Language - Exclude High Risk.",
            "Offensive Language - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        excludedViolenceRisk = {
          description = "Brand Safety - **Violence**.",
          enum = {
            "VIOLENCE_UNSPECIFIED",
            "VIOLENCE_HR",
            "VIOLENCE_HMR",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any violence options.",
            "Violence - Exclude High Risk.",
            "Violence - Exclude High and Moderate Risk.",
          },
          type = "string",
        },
        traqScoreOption = {
          description = "True advertising quality (applicable to Display line items only).",
          enum = {
            "TRAQ_UNSPECIFIED",
            "TRAQ_250",
            "TRAQ_500",
            "TRAQ_600",
            "TRAQ_700",
            "TRAQ_750",
            "TRAQ_875",
            "TRAQ_1000",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any true advertising quality scores.",
            "TRAQ score 250-1000.",
            "TRAQ score 500-1000.",
            "TRAQ score 600-1000.",
            "TRAQ score 700-1000.",
            "TRAQ score 750-1000.",
            "TRAQ score 875-1000.",
            "TRAQ score 1000.",
          },
          type = "string",
        },
        videoViewability = {
          description = "Video Viewability Section (applicable to video line items only).",
          enum = {
            "VIDEO_VIEWABILITY_UNSPECIFIED",
            "VIDEO_VIEWABILITY_40",
            "VIDEO_VIEWABILITY_50",
            "VIDEO_VIEWABILITY_60",
            "VIDEO_VIEWABILITY_70",
          },
          enumDescriptions = {
            "This enum is only a placeholder and it doesn't specify any video viewability options.",
            "40%+ in view (IAB video viewability standard).",
            "50%+ in view (IAB video viewability standard).",
            "60%+ in view (IAB video viewability standard).",
            "70%+ in view (IAB video viewability standard).",
          },
          type = "string",
        },
      },
      type = "object",
    },
    IntegrationDetails = {
      description = "Integration details of an entry.",
      id = "IntegrationDetails",
      properties = {
        details = {
          description = "Additional details of the entry in string format. Must be UTF-8 encoded with a length of no more than 1000 characters.",
          type = "string",
        },
        integrationCode = {
          description = "An external identifier to be associated with the entry. The integration code will show up together with the entry in many places in the system, for example, reporting. Must be UTF-8 encoded with a length of no more than 500 characters.",
          type = "string",
        },
      },
      type = "object",
    },
    InventorySource = {
      description = "An inventory source.",
      id = "InventorySource",
      properties = {
        commitment = {
          description = "Whether the inventory source has a guaranteed or non-guaranteed delivery.",
          enum = {
            "INVENTORY_SOURCE_COMMITMENT_UNSPECIFIED",
            "INVENTORY_SOURCE_COMMITMENT_GUARANTEED",
            "INVENTORY_SOURCE_COMMITMENT_NON_GUARANTEED",
          },
          enumDescriptions = {
            "The commitment is not specified or is unknown in this version.",
            "The commitment is guaranteed delivery.",
            "The commitment is non-guaranteed delivery.",
          },
          type = "string",
        },
        creativeConfigs = {
          description = "The creative requirements of the inventory source. Not applicable for auction packages.",
          items = {
            ["$ref"] = "CreativeConfig",
          },
          type = "array",
        },
        dealId = {
          description = "The ID in the exchange space that uniquely identifies the inventory source. Must be unique across buyers within each exchange but not necessarily unique across exchanges.",
          type = "string",
        },
        deliveryMethod = {
          description = "The delivery method of the inventory source. * For non-guaranteed inventory sources, the only acceptable value is `INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC`. * For guaranteed inventory sources, acceptable values are `INVENTORY_SOURCE_DELIVERY_METHOD_TAG` and `INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC`.",
          enum = {
            "INVENTORY_SOURCE_DELIVERY_METHOD_UNSPECIFIED",
            "INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC",
            "INVENTORY_SOURCE_DELIVERY_METHOD_TAG",
          },
          enumDescriptions = {
            "The delivery method is not specified or is unknown in this version.",
            "The delivery method is programmatic.",
            "The delivery method is tag.",
          },
          type = "string",
        },
        displayName = {
          description = "The display name of the inventory source. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        exchange = {
          description = "The exchange to which the inventory source belongs.",
          enum = {
            "EXCHANGE_UNSPECIFIED",
            "EXCHANGE_GOOGLE_AD_MANAGER",
            "EXCHANGE_APPNEXUS",
            "EXCHANGE_BRIGHTROLL",
            "EXCHANGE_ADFORM",
            "EXCHANGE_ADMETA",
            "EXCHANGE_ADMIXER",
            "EXCHANGE_ADSMOGO",
            "EXCHANGE_ADSWIZZ",
            "EXCHANGE_BIDSWITCH",
            "EXCHANGE_BRIGHTROLL_DISPLAY",
            "EXCHANGE_CADREON",
            "EXCHANGE_DAILYMOTION",
            "EXCHANGE_FIVE",
            "EXCHANGE_FLUCT",
            "EXCHANGE_FREEWHEEL",
            "EXCHANGE_GENIEE",
            "EXCHANGE_GUMGUM",
            "EXCHANGE_IMOBILE",
            "EXCHANGE_IBILLBOARD",
            "EXCHANGE_IMPROVE_DIGITAL",
            "EXCHANGE_INDEX",
            "EXCHANGE_KARGO",
            "EXCHANGE_MICROAD",
            "EXCHANGE_MOPUB",
            "EXCHANGE_NEND",
            "EXCHANGE_ONE_BY_AOL_DISPLAY",
            "EXCHANGE_ONE_BY_AOL_MOBILE",
            "EXCHANGE_ONE_BY_AOL_VIDEO",
            "EXCHANGE_OOYALA",
            "EXCHANGE_OPENX",
            "EXCHANGE_PERMODO",
            "EXCHANGE_PLATFORMONE",
            "EXCHANGE_PLATFORMID",
            "EXCHANGE_PUBMATIC",
            "EXCHANGE_PULSEPOINT",
            "EXCHANGE_REVENUEMAX",
            "EXCHANGE_RUBICON",
            "EXCHANGE_SMARTCLIP",
            "EXCHANGE_SMARTRTB",
            "EXCHANGE_SMARTSTREAMTV",
            "EXCHANGE_SOVRN",
            "EXCHANGE_SPOTXCHANGE",
            "EXCHANGE_STROER",
            "EXCHANGE_TEADSTV",
            "EXCHANGE_TELARIA",
            "EXCHANGE_TVN",
            "EXCHANGE_UNITED",
            "EXCHANGE_YIELDLAB",
            "EXCHANGE_YIELDMO",
            "EXCHANGE_UNRULYX",
            "EXCHANGE_OPEN8",
            "EXCHANGE_TRITON",
            "EXCHANGE_TRIPLELIFT",
            "EXCHANGE_TABOOLA",
            "EXCHANGE_INMOBI",
            "EXCHANGE_SMAATO",
            "EXCHANGE_AJA",
            "EXCHANGE_SUPERSHIP",
            "EXCHANGE_NEXSTAR_DIGITAL",
            "EXCHANGE_WAZE",
            "EXCHANGE_SOUNDCAST",
            "EXCHANGE_SHARETHROUGH",
            "EXCHANGE_FYBER",
            "EXCHANGE_RED_FOR_PUBLISHERS",
            "EXCHANGE_MEDIANET",
            "EXCHANGE_TAPJOY",
            "EXCHANGE_VISTAR",
            "EXCHANGE_DAX",
            "EXCHANGE_JCD",
            "EXCHANGE_PLACE_EXCHANGE",
            "EXCHANGE_APPLOVIN",
            "EXCHANGE_CONNATIX",
          },
          enumDescriptions = {
            "Exchange is not specified or is unknown in this version.",
            "Google Ad Manager.",
            "AppNexus.",
            "BrightRoll Exchange for Video from Yahoo!.",
            "Adform.",
            "Admeta.",
            "Admixer.",
            "AdsMogo.",
            "AdsWizz.",
            "BidSwitch.",
            "BrightRoll Exchange for Display from Yahoo!.",
            "Cadreon.",
            "Dailymotion.",
            "Five.",
            "Fluct.",
            "FreeWheel SSP.",
            "Geniee.",
            "GumGum.",
            "i-mobile.",
            "iBILLBOARD.",
            "Improve Digital.",
            "Index Exchange.",
            "Kargo.",
            "MicroAd.",
            "MoPub.",
            "Nend.",
            "ONE by AOL: Display Market Place.",
            "ONE by AOL: Mobile.",
            "ONE by AOL: Video.",
            "Ooyala.",
            "OpenX.",
            "Permodo.",
            "Platform One.",
            "PlatformId.",
            "PubMatic.",
            "PulsePoint.",
            "RevenueMax.",
            "Rubicon.",
            "SmartClip.",
            "SmartRTB+.",
            "SmartstreamTv.",
            "Sovrn.",
            "SpotXchange.",
            "Ströer SSP.",
            "TeadsTv.",
            "Telaria.",
            "TVN.",
            "United.",
            "Yieldlab.",
            "Yieldmo.",
            "UnrulyX.",
            "Open8.",
            "Triton.",
            "TripleLift.",
            "Taboola.",
            "InMobi.",
            "Smaato.",
            "Aja.",
            "Supership.",
            "Nexstar Digital.",
            "Waze.",
            "SoundCast.",
            "Sharethrough.",
            "Fyber.",
            "Red For Publishers.",
            "Media.net.",
            "Tapjoy.",
            "Vistar.",
            "DAX.",
            "JCD.",
            "Place Exchange.",
            "AppLovin.",
            "Connatix.",
          },
          type = "string",
        },
        guaranteedOrderId = {
          description = "Immutable. The ID of the guaranteed order that this inventory source belongs to. Only applicable when commitment is `INVENTORY_SOURCE_COMMITMENT_GUARANTEED`.",
          type = "string",
        },
        inventorySourceId = {
          description = "Output only. The unique ID of the inventory source. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        inventorySourceProductType = {
          description = "Output only. The product type of the inventory source, denoting the way through which it sells inventory.",
          enum = {
            "INVENTORY_SOURCE_PRODUCT_TYPE_UNSPECIFIED",
            "PREFERRED_DEAL",
            "PRIVATE_AUCTION",
            "PROGRAMMATIC_GUARANTEED",
            "TAG_GUARANTEED",
            "YOUTUBE_RESERVE",
            "INSTANT_RESERVE",
            "GUARANTEED_PACKAGE",
            "PROGRAMMATIC_TV",
            "AUCTION_PACKAGE",
          },
          enumDescriptions = {
            "The product type is not specified or is unknown in this version. Modifying inventory sources of this product type are not supported via API.",
            "The inventory source sells inventory through Preferred Deal.",
            "The inventory source sells inventory through Private Auction.",
            "The inventory source sells inventory through Programmatic Guaranteed.",
            "The inventory source sells inventory through Tag Guaranteed.",
            "The inventory source sells inventory through YouTube Reserve.",
            "The inventory source sells inventory through Instant Reserve. Modifying inventory sources of this product type are not supported via API.",
            "The inventory source sells inventory through Guaranteed Package. Modifying inventory sources of this product type are not supported via API.",
            "The inventory source sells inventory through Programmtic TV. Modifying inventory sources of this product type are not supported via API.",
            "The inventory source sells inventory through Auction Package. Modifying inventory sources of this product type are not supported via API.",
          },
          readOnly = true,
          type = "string",
        },
        inventorySourceType = {
          description = "Denotes the type of the inventory source.",
          enum = {
            "INVENTORY_SOURCE_TYPE_UNSPECIFIED",
            "INVENTORY_SOURCE_TYPE_PRIVATE",
            "INVENTORY_SOURCE_TYPE_AUCTION_PACKAGE",
          },
          enumDescriptions = {
            "The inventory source type is not specified or is unknown in this version.",
            "Private inventory source.",
            "Auction package.",
          },
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the inventory source.",
          readOnly = true,
          type = "string",
        },
        publisherName = {
          description = "The publisher/seller name of the inventory source.",
          type = "string",
        },
        rateDetails = {
          ["$ref"] = "RateDetails",
          description = "Required. The rate details of the inventory source.",
        },
        readAdvertiserIds = {
          description = "Output only. The IDs of advertisers with read-only access to the inventory source.",
          items = {
            format = "int64",
            type = "string",
          },
          readOnly = true,
          type = "array",
        },
        readPartnerIds = {
          description = "Output only. The IDs of partners with read-only access to the inventory source. All advertisers of partners in this field inherit read-only access to the inventory source.",
          items = {
            format = "int64",
            type = "string",
          },
          readOnly = true,
          type = "array",
        },
        readWriteAccessors = {
          ["$ref"] = "InventorySourceAccessors",
          description = "The partner or advertisers that have read/write access to the inventory source. Output only when commitment is `INVENTORY_SOURCE_COMMITMENT_GUARANTEED`, in which case the read/write accessors are inherited from the parent guaranteed order. Required when commitment is `INVENTORY_SOURCE_COMMITMENT_NON_GUARANTEED`. If commitment is `INVENTORY_SOURCE_COMMITMENT_NON_GUARANTEED` and a partner is set in this field, all advertisers under this partner will automatically have read-only access to the inventory source. These advertisers will not be included in read_advertiser_ids.",
        },
        status = {
          ["$ref"] = "InventorySourceStatus",
          description = "The status settings of the inventory source.",
        },
        subSitePropertyId = {
          description = "Immutable. The unique ID of the sub-site property assigned to this inventory source.",
          format = "int64",
          type = "string",
        },
        timeRange = {
          ["$ref"] = "TimeRange",
          description = "The time range when this inventory source starts and stops serving.",
        },
        updateTime = {
          description = "Output only. The timestamp when the inventory source was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    InventorySourceAccessors = {
      description = "The partner or advertisers with access to the inventory source.",
      id = "InventorySourceAccessors",
      properties = {
        advertisers = {
          ["$ref"] = "InventorySourceAccessorsAdvertiserAccessors",
          description = "The advertisers with access to the inventory source. All advertisers must belong to the same partner.",
        },
        partner = {
          ["$ref"] = "InventorySourceAccessorsPartnerAccessor",
          description = "The partner with access to the inventory source.",
        },
      },
      type = "object",
    },
    InventorySourceAccessorsAdvertiserAccessors = {
      description = "The advertisers with access to the inventory source.",
      id = "InventorySourceAccessorsAdvertiserAccessors",
      properties = {
        advertiserIds = {
          description = "The IDs of the advertisers.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InventorySourceAccessorsPartnerAccessor = {
      description = "The partner with access to the inventory source.",
      id = "InventorySourceAccessorsPartnerAccessor",
      properties = {
        partnerId = {
          description = "The ID of the partner.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    InventorySourceAssignedTargetingOptionDetails = {
      description = "Targeting details for inventory source. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_INVENTORY_SOURCE`.",
      id = "InventorySourceAssignedTargetingOptionDetails",
      properties = {
        inventorySourceId = {
          description = "Required. ID of the inventory source. Should refer to the inventory_source_id field of an InventorySource resource.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    InventorySourceDisplayCreativeConfig = {
      description = "The configuration for display creatives.",
      id = "InventorySourceDisplayCreativeConfig",
      properties = {
        creativeSize = {
          ["$ref"] = "Dimensions",
          description = "The size requirements for display creatives that can be assigned to the inventory source.",
        },
      },
      type = "object",
    },
    InventorySourceFilter = {
      description = "A filtering option for filtering on Inventory Source entities.",
      id = "InventorySourceFilter",
      properties = {
        inventorySourceIds = {
          description = "Inventory Sources to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest. Leave empty to download all Inventory Sources for the selected Advertiser or Partner.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    InventorySourceGroup = {
      description = "A collection of targetable inventory sources.",
      id = "InventorySourceGroup",
      properties = {
        displayName = {
          description = "Required. The display name of the inventory source group. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        inventorySourceGroupId = {
          description = "Output only. The unique ID of the inventory source group. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the inventory source group.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    InventorySourceGroupAssignedTargetingOptionDetails = {
      description = "Targeting details for inventory source group. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_INVENTORY_SOURCE_GROUP`.",
      id = "InventorySourceGroupAssignedTargetingOptionDetails",
      properties = {
        inventorySourceGroupId = {
          description = "Required. ID of the inventory source group. Should refer to the inventory_source_group_id field of an InventorySourceGroup resource.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    InventorySourceStatus = {
      description = "The status related settings of the inventory source.",
      id = "InventorySourceStatus",
      properties = {
        configStatus = {
          description = "Output only. The configuration status of the inventory source. Only applicable for guaranteed inventory sources. Acceptable values are `INVENTORY_SOURCE_CONFIG_STATUS_PENDING` and `INVENTORY_SOURCE_CONFIG_STATUS_COMPLETED`. An inventory source must be configured (fill in the required fields, choose creatives, and select a default campaign) before it can serve.",
          enum = {
            "INVENTORY_SOURCE_CONFIG_STATUS_UNSPECIFIED",
            "INVENTORY_SOURCE_CONFIG_STATUS_PENDING",
            "INVENTORY_SOURCE_CONFIG_STATUS_COMPLETED",
          },
          enumDescriptions = {
            "The approval status is not specified or is unknown in this version.",
            "The beginning state of a guaranteed inventory source. The inventory source in this state needs to be configured.",
            "The state after the buyer configures a guaranteed inventory source.",
          },
          readOnly = true,
          type = "string",
        },
        entityPauseReason = {
          description = "The user-provided reason for pausing this inventory source. Must not exceed 100 characters. Only applicable when entity_status is set to `ENTITY_STATUS_PAUSED`.",
          type = "string",
        },
        entityStatus = {
          description = "Whether or not the inventory source is servable. Acceptable values are `ENTITY_STATUS_ACTIVE`, `ENTITY_STATUS_ARCHIVED`, and `ENTITY_STATUS_PAUSED`. Default value is `ENTITY_STATUS_ACTIVE`.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        sellerPauseReason = {
          description = "Output only. The seller-provided reason for pausing this inventory source. Only applicable for inventory sources synced directly from the publishers and when seller_status is set to `ENTITY_STATUS_PAUSED`.",
          readOnly = true,
          type = "string",
        },
        sellerStatus = {
          description = "Output only. The status set by the seller for the inventory source. Only applicable for inventory sources synced directly from the publishers. Acceptable values are `ENTITY_STATUS_ACTIVE` and `ENTITY_STATUS_PAUSED`.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    InventorySourceVideoCreativeConfig = {
      description = "The configuration for video creatives.",
      id = "InventorySourceVideoCreativeConfig",
      properties = {
        duration = {
          description = "The duration requirements for the video creatives that can be assigned to the inventory source.",
          format = "google-duration",
          type = "string",
        },
      },
      type = "object",
    },
    Invoice = {
      description = "A single invoice.",
      id = "Invoice",
      properties = {
        budgetInvoiceGroupingId = {
          description = "The budget grouping ID for this invoice. This field will only be set if the invoice level of the corresponding billing profile was set to \"Budget invoice grouping ID\".",
          type = "string",
        },
        budgetSummaries = {
          description = "The list of summarized information for each budget associated with this invoice. This field will only be set if the invoice detail level of the corresponding billing profile was set to \"Budget level PO\".",
          items = {
            ["$ref"] = "BudgetSummary",
          },
          type = "array",
        },
        correctedInvoiceId = {
          description = "The ID of the original invoice being adjusted by this invoice, if applicable. May appear on the invoice PDF as `Reference invoice number`. If replaced_invoice_ids is set, this field will be empty.",
          type = "string",
        },
        currencyCode = {
          description = "The currency used in the invoice in ISO 4217 format.",
          type = "string",
        },
        displayName = {
          description = "The display name of the invoice.",
          type = "string",
        },
        dueDate = {
          ["$ref"] = "Date",
          description = "The date when the invoice is due.",
        },
        invoiceId = {
          description = "The unique ID of the invoice.",
          type = "string",
        },
        invoiceType = {
          description = "The type of invoice document.",
          enum = {
            "INVOICE_TYPE_UNSPECIFIED",
            "INVOICE_TYPE_CREDIT",
            "INVOICE_TYPE_INVOICE",
          },
          enumDescriptions = {
            "Not specified or is unknown in this version.",
            "The invoice has a negative amount.",
            "The invoice has a positive amount.",
          },
          type = "string",
        },
        issueDate = {
          ["$ref"] = "Date",
          description = "The date when the invoice was issued.",
        },
        name = {
          description = "The resource name of the invoice.",
          type = "string",
        },
        nonBudgetMicros = {
          description = "The total amount of costs or adjustments not tied to a particular budget, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
        paymentsAccountId = {
          description = "The ID of the payments account the invoice belongs to. Appears on the invoice PDF as `Billing Account Number`.",
          type = "string",
        },
        paymentsProfileId = {
          description = "The ID of the payments profile the invoice belongs to. Appears on the invoice PDF as `Billing ID`.",
          type = "string",
        },
        pdfUrl = {
          description = "The URL to download a PDF copy of the invoice. This URL is user specific and requires a valid OAuth 2.0 access token to access. The access token must be provided in an `Authorization: Bearer` HTTP header and be authorized for one of the following scopes: * `https://www.googleapis.com/auth/display-video-mediaplanning` * `https://www.googleapis.com/auth/display-video` The URL will be valid for 7 days after retrieval of this invoice object or until this invoice is retrieved again.",
          type = "string",
        },
        purchaseOrderNumber = {
          description = "Purchase order number associated with the invoice.",
          type = "string",
        },
        replacedInvoiceIds = {
          description = "The ID(s) of any originally issued invoice that is being cancelled by this invoice, if applicable. Multiple invoices may be listed if those invoices are being consolidated into a single invoice. May appear on invoice PDF as `Replaced invoice numbers`. If corrected_invoice_id is set, this field will be empty.",
          items = {
            type = "string",
          },
          type = "array",
        },
        serviceDateRange = {
          ["$ref"] = "DateRange",
          description = "The service start and end dates which are covered by this invoice.",
        },
        subtotalAmountMicros = {
          description = "The pre-tax subtotal amount, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
        totalAmountMicros = {
          description = "The invoice total amount, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
        totalTaxAmountMicros = {
          description = "The sum of all taxes in invoice, in micros of the invoice's currency. For example, if currency_code is `USD`, then 1000000 represents one US dollar.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    KeywordAssignedTargetingOptionDetails = {
      description = "Details for assigned keyword targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_KEYWORD`.",
      id = "KeywordAssignedTargetingOptionDetails",
      properties = {
        keyword = {
          description = "Required. The keyword, for example `car insurance`. Positive keyword cannot be offensive word. Must be UTF-8 encoded with a maximum size of 255 bytes. Maximum number of characters is 80. Maximum number of words is 10.",
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
      },
      type = "object",
    },
    LanguageAssignedTargetingOptionDetails = {
      description = "Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_LANGUAGE`.",
      id = "LanguageAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the language (e.g., \"French\").",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted. All assigned language targeting options on the same resource must have the same value for this field.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_LANGUAGE`.",
          type = "string",
        },
      },
      type = "object",
    },
    LanguageTargetingOptionDetails = {
      description = "Represents a targetable language. This will be populated in the language_details field when targeting_type is `TARGETING_TYPE_LANGUAGE`.",
      id = "LanguageTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the language (e.g., \"French\").",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    LineItem = {
      description = "A single line item.",
      id = "LineItem",
      properties = {
        advertiserId = {
          description = "Output only. The unique ID of the advertiser the line item belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        bidStrategy = {
          ["$ref"] = "BiddingStrategy",
          description = "Required. The bidding strategy of the line item.",
        },
        budget = {
          ["$ref"] = "LineItemBudget",
          description = "Required. The budget allocation setting of the line item.",
        },
        campaignId = {
          description = "Output only. The unique ID of the campaign that the line item belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        conversionCounting = {
          ["$ref"] = "ConversionCountingConfig",
          description = "The conversion tracking setting of the line item.",
        },
        creativeIds = {
          description = "The IDs of the creatives associated with the line item.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        displayName = {
          description = "Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        entityStatus = {
          description = "Required. Controls whether or not the line item can spend its budget and bid on inventory. * For CreateLineItem method, only `ENTITY_STATUS_DRAFT` is allowed. To activate a line item, use UpdateLineItem method and update the status to `ENTITY_STATUS_ACTIVE` after creation. * A line item cannot be changed back to `ENTITY_STATUS_DRAFT` status from any other status. * If the line item's parent insertion order is not active, the line item can't spend its budget even if its own status is `ENTITY_STATUS_ACTIVE`.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          type = "string",
        },
        excludeNewExchanges = {
          description = "Whether to exclude new exchanges from automatically being targeted by the line item. This field is false by default.",
          type = "boolean",
        },
        flight = {
          ["$ref"] = "LineItemFlight",
          description = "Required. The start and end time of the line item's flight.",
        },
        frequencyCap = {
          ["$ref"] = "FrequencyCap",
          description = "Required. The impression frequency cap settings of the line item. The max_impressions field in this settings object must be used if assigning a limited cap.",
        },
        insertionOrderId = {
          description = "Required. Immutable. The unique ID of the insertion order that the line item belongs to.",
          format = "int64",
          type = "string",
        },
        integrationDetails = {
          ["$ref"] = "IntegrationDetails",
          description = "Integration details of the line item.",
        },
        inventorySourceIds = {
          description = "The IDs of the private inventory sources assigned to the line item.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        lineItemId = {
          description = "Output only. The unique ID of the line item. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        lineItemType = {
          description = "Required. Immutable. The type of the line item.",
          enum = {
            "LINE_ITEM_TYPE_UNSPECIFIED",
            "LINE_ITEM_TYPE_DISPLAY_DEFAULT",
            "LINE_ITEM_TYPE_DISPLAY_MOBILE_APP_INSTALL",
            "LINE_ITEM_TYPE_VIDEO_DEFAULT",
            "LINE_ITEM_TYPE_VIDEO_MOBILE_APP_INSTALL",
            "LINE_ITEM_TYPE_DISPLAY_MOBILE_APP_INVENTORY",
            "LINE_ITEM_TYPE_VIDEO_MOBILE_APP_INVENTORY",
            "LINE_ITEM_TYPE_AUDIO_DEFAULT",
            "LINE_ITEM_TYPE_VIDEO_OVER_THE_TOP",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version. Line items of this type and their targeting cannot be created or updated using the API.",
            "Image, HTML5, native, or rich media ads.",
            "Display ads that drive installs of an app.",
            "Video ads sold on a CPM basis for a variety of environments.",
            "Video ads that drive installs of an app.",
            "Display ads served on mobile app inventory. Line items of this type and their targeting cannot be created or updated using the API.",
            "Video ads served on mobile app inventory. Line items of this type and their targeting cannot be created or updated using the API.",
            "RTB Audio ads sold for a variety of environments.",
            "Over-the-top ads present in OTT insertion orders. This type is only applicable to line items with an insertion order of insertion_order_type `OVER_THE_TOP`.",
          },
          type = "string",
        },
        mobileApp = {
          ["$ref"] = "MobileApp",
          description = "The mobile app promoted by the line item. This is applicable only when line_item_type is either `LINE_ITEM_TYPE_DISPLAY_MOBILE_APP_INSTALL` or `LINE_ITEM_TYPE_VIDEO_MOBILE_APP_INSTALL`.",
        },
        name = {
          description = "Output only. The resource name of the line item.",
          readOnly = true,
          type = "string",
        },
        pacing = {
          ["$ref"] = "Pacing",
          description = "Required. The budget spending speed setting of the line item.",
        },
        partnerCosts = {
          description = "The partner costs associated with the line item. If absent or empty in CreateLineItem method, the newly created line item will inherit partner costs from its parent insertion order.",
          items = {
            ["$ref"] = "PartnerCost",
          },
          type = "array",
        },
        partnerRevenueModel = {
          ["$ref"] = "PartnerRevenueModel",
          description = "Required. The partner revenue model setting of the line item.",
        },
        reservationType = {
          description = "Output only. The reservation type of the line item.",
          enum = {
            "RESERVATION_TYPE_UNSPECIFIED",
            "RESERVATION_TYPE_NOT_GUARANTEED",
            "RESERVATION_TYPE_PROGRAMMATIC_GUARANTEED",
            "RESERVATION_TYPE_TAG_GUARANTEED",
          },
          enumDescriptions = {
            "Reservation type value is not specified or is unknown in this version.",
            "Not created through a guaranteed inventory source.",
            "Created through a programmatic guaranteed inventory source.",
            "Created through a tag guaranteed inventory source.",
          },
          readOnly = true,
          type = "string",
        },
        targetingExpansion = {
          ["$ref"] = "TargetingExpansionConfig",
          description = "The [targeting expansion](//support.google.com/displayvideo/answer/10191558) settings of the line item. This config is only applicable when eligible audience list targeting is assigned to the line item. Beginning November 7, 2022, these settings may represent the [optimized targeting feature](//support.google.com/displayvideo/answer/12060859) in place of targeting expansion. This feature will be rolled out to all partners by November 9, 2022.",
        },
        updateTime = {
          description = "Output only. The timestamp when the line item was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        warningMessages = {
          description = "Output only. The warning messages generated by the line item. These warnings do not block saving the line item, but some may block the line item from running.",
          items = {
            enum = {
              "LINE_ITEM_WARNING_MESSAGE_UNSPECIFIED",
              "INVALID_FLIGHT_DATES",
              "EXPIRED",
              "PENDING_FLIGHT",
              "ALL_PARTNER_ENABLED_EXCHANGES_NEGATIVELY_TARGETED",
              "INVALID_INVENTORY_SOURCE",
              "APP_INVENTORY_INVALID_SITE_TARGETING",
              "APP_INVENTORY_INVALID_AUDIENCE_LISTS",
              "NO_VALID_CREATIVE",
              "PARENT_INSERTION_ORDER_PAUSED",
              "PARENT_INSERTION_ORDER_EXPIRED",
              "NO_POSITIVE_AUDIENCE_LIST_TARGETED",
              "APP_INSTALL_NO_CONVERSION_PIXEL",
              "TARGETING_REVOKED_OR_CLOSED_USER_LIST",
              "APP_INSTALL_NO_OPTIMAL_BIDDING_STRATEGY",
              "CREATIVE_SIZE_NOT_IN_USE_FOR_TARGETED_DEALS",
              "NO_CREATIVE_FOR_TARGETED_DEALS",
              "TARGETING_DEPRECATED_GEO_TARGET",
            },
            enumDescriptions = {
              "Not specified or is unknown.",
              "This line item has invalid flight dates. The line item will not run.",
              "This line item's end date is in the past.",
              "This line item will begin running in the future.",
              "All partner enabled exchanges are negatively targeted. The line item will not run.",
              "No active inventory sources are being targeted. The line item will not run.",
              "This line item's Apps & URLs targeting doesn't include any mobile apps. This line item's type requires you to include mobile apps in your channel, sitelist, or apps targeting. The line item will not run.",
              "This line item isn't targeting any mobile users. This line item's type requires you to target a user list with mobile users. The line item will not run.",
              "This line item does not contain any valid creative. The line item will not run.",
              "The insertion order of this line item is paused. The line item will not run.",
              "The insertion order of this line item has its end date set in the past. The line item will not run.",
              "This line item does not target any audience lists, which may result in spending your budget too quickly.",
              "This app install line item does not have any conversion pixel set up.",
              "This line item targets one or more user lists that are no longer available. In the future, this will prevent the line item from serving, so consider removing these lists from your targeting.",
              "This app install line item does not have an optimal bidding strategy.",
              "Deals targeted by this line item accept creative sizes which are not in use. This may limit the line item's delivery or performance.",
              "This line item does not contain any creative for the targeted deals.",
              "This line item targets a geo target that is deprecated.",
            },
            type = "string",
          },
          readOnly = true,
          type = "array",
        },
      },
      type = "object",
    },
    LineItemBudget = {
      description = "Settings that control how budget is allocated.",
      id = "LineItemBudget",
      properties = {
        budgetAllocationType = {
          description = "Required. The type of the budget allocation. `LINE_ITEM_BUDGET_ALLOCATION_TYPE_AUTOMATIC` is only applicable when automatic budget allocation is enabled for the parent insertion order.",
          enum = {
            "LINE_ITEM_BUDGET_ALLOCATION_TYPE_UNSPECIFIED",
            "LINE_ITEM_BUDGET_ALLOCATION_TYPE_AUTOMATIC",
            "LINE_ITEM_BUDGET_ALLOCATION_TYPE_FIXED",
            "LINE_ITEM_BUDGET_ALLOCATION_TYPE_UNLIMITED",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Automatic budget allocation is enabled for the line item.",
            "A fixed max budget amount is allocated for the line item.",
            "No budget limit is applied to the line item.",
          },
          type = "string",
        },
        budgetUnit = {
          description = "Output only. The budget unit specifies whether the budget is currency based or impression based. This value is inherited from the parent insertion order.",
          enum = {
            "BUDGET_UNIT_UNSPECIFIED",
            "BUDGET_UNIT_CURRENCY",
            "BUDGET_UNIT_IMPRESSIONS",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Budgeting in currency amounts.",
            "Budgeting in impression amounts.",
          },
          readOnly = true,
          type = "string",
        },
        maxAmount = {
          description = "The maximum budget amount the line item will spend. Must be greater than 0. When budget_allocation_type is: * `LINE_ITEM_BUDGET_ALLOCATION_TYPE_AUTOMATIC`, this field is immutable and is set by the system. * `LINE_ITEM_BUDGET_ALLOCATION_TYPE_FIXED`, if budget_unit is: - `BUDGET_UNIT_CURRENCY`, this field represents maximum budget amount to spend, in micros of the advertiser's currency. For example, 1500000 represents 1.5 standard units of the currency. - `BUDGET_UNIT_IMPRESSIONS`, this field represents the maximum number of impressions to serve. * `LINE_ITEM_BUDGET_ALLOCATION_TYPE_UNLIMITED`, this field is not applicable and will be ignored by the system.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    LineItemFlight = {
      description = "Settings that control the active duration of a line item.",
      id = "LineItemFlight",
      properties = {
        dateRange = {
          ["$ref"] = "DateRange",
          description = "The flight start and end dates of the line item. They are resolved relative to the parent advertiser's time zone. * Required when flight_date_type is `LINE_ITEM_FLIGHT_DATE_TYPE_CUSTOM`. Output only otherwise. * When creating a new flight, both `start_date` and `end_date` must be in the future. * An existing flight with a `start_date` in the past has a mutable `end_date` but an immutable `start_date`. * `end_date` must be the `start_date` or later, both before the year 2037.",
        },
        flightDateType = {
          description = "Required. The type of the line item's flight dates.",
          enum = {
            "LINE_ITEM_FLIGHT_DATE_TYPE_UNSPECIFIED",
            "LINE_ITEM_FLIGHT_DATE_TYPE_INHERITED",
            "LINE_ITEM_FLIGHT_DATE_TYPE_CUSTOM",
            "LINE_ITEM_FLIGHT_DATE_TYPE_TRIGGER",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The line item's flight dates are inherited from its parent insertion order.",
            "The line item uses its own custom flight dates.",
            "The line item uses a trigger.",
          },
          type = "string",
        },
        triggerId = {
          description = "The ID of the manual trigger associated with the line item. * Required when flight_date_type is `LINE_ITEM_FLIGHT_DATE_TYPE_TRIGGER`. Must not be set otherwise. * When set, the line item's flight dates are inherited from its parent insertion order. * Active line items will spend when the selected trigger is activated within the parent insertion order's flight dates.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ListAdvertiserAssignedTargetingOptionsResponse = {
      description = "Response message for ListAdvertiserAssignedTargetingOptions.",
      id = "ListAdvertiserAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent ListAdvertiserAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    ListAdvertisersResponse = {
      id = "ListAdvertisersResponse",
      properties = {
        advertisers = {
          description = "The list of advertisers. This list will be absent if empty.",
          items = {
            ["$ref"] = "Advertiser",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListAdvertisers` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListAssignedInventorySourcesResponse = {
      description = "Response message for AssignedInventorySourceService.ListAssignedInventorySources.",
      id = "ListAssignedInventorySourcesResponse",
      properties = {
        assignedInventorySources = {
          description = "The list of assigned inventory sources. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedInventorySource",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListAssignedInventorySources` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListAssignedLocationsResponse = {
      description = "Response message for AssignedLocationService.ListAssignedLocations.",
      id = "ListAssignedLocationsResponse",
      properties = {
        assignedLocations = {
          description = "The list of assigned locations. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedLocation",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListAssignedLocations` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCampaignAssignedTargetingOptionsResponse = {
      description = "Response message for ListCampaignAssignedTargetingOptions.",
      id = "ListCampaignAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent ListCampaignAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCampaignsResponse = {
      id = "ListCampaignsResponse",
      properties = {
        campaigns = {
          description = "The list of campaigns. This list will be absent if empty.",
          items = {
            ["$ref"] = "Campaign",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListCampaigns` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListChannelsResponse = {
      id = "ListChannelsResponse",
      properties = {
        channels = {
          description = "The list of channels. This list will be absent if empty.",
          items = {
            ["$ref"] = "Channel",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListChannels` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCombinedAudiencesResponse = {
      id = "ListCombinedAudiencesResponse",
      properties = {
        combinedAudiences = {
          description = "The list of combined audiences. This list will be absent if empty.",
          items = {
            ["$ref"] = "CombinedAudience",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListCombinedAudiences` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCreativesResponse = {
      id = "ListCreativesResponse",
      properties = {
        creatives = {
          description = "The list of creatives. This list will be absent if empty.",
          items = {
            ["$ref"] = "Creative",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListCreativesRequest` method to retrieve the next page of results. If this field is null, it means this is the last page.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCustomBiddingAlgorithmsResponse = {
      id = "ListCustomBiddingAlgorithmsResponse",
      properties = {
        customBiddingAlgorithms = {
          description = "The list of custom bidding algorithms. This list will be absent if empty.",
          items = {
            ["$ref"] = "CustomBiddingAlgorithm",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListCustomBiddingAlgorithmsRequest` method to retrieve the next page of results. If this field is null, it means this is the last page.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCustomBiddingScriptsResponse = {
      id = "ListCustomBiddingScriptsResponse",
      properties = {
        customBiddingScripts = {
          description = "The list of custom bidding scripts. This list will be absent if empty.",
          items = {
            ["$ref"] = "CustomBiddingScript",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListCustomBiddingScriptsRequest` method to retrieve the next page of results. If this field is null, it means this is the last page.",
          type = "string",
        },
      },
      type = "object",
    },
    ListCustomListsResponse = {
      id = "ListCustomListsResponse",
      properties = {
        customLists = {
          description = "The list of custom lists. This list will be absent if empty.",
          items = {
            ["$ref"] = "CustomList",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListCustomLists` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListFirstAndThirdPartyAudiencesResponse = {
      id = "ListFirstAndThirdPartyAudiencesResponse",
      properties = {
        firstAndThirdPartyAudiences = {
          description = "The list of first and third party audiences. Audience size properties will not be included. This list will be absent if empty.",
          items = {
            ["$ref"] = "FirstAndThirdPartyAudience",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListFirstAndThirdPartyAudiences` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListGoogleAudiencesResponse = {
      id = "ListGoogleAudiencesResponse",
      properties = {
        googleAudiences = {
          description = "The list of Google audiences. This list will be absent if empty.",
          items = {
            ["$ref"] = "GoogleAudience",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListGoogleAudiences` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListGuaranteedOrdersResponse = {
      id = "ListGuaranteedOrdersResponse",
      properties = {
        guaranteedOrders = {
          description = "The list of guaranteed orders. This list will be absent if empty.",
          items = {
            ["$ref"] = "GuaranteedOrder",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListGuaranteedOrders` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListInsertionOrderAssignedTargetingOptionsResponse = {
      description = "Response message for ListInsertionOrderAssignedTargetingOptions.",
      id = "ListInsertionOrderAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent ListInsertionOrderAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    ListInsertionOrdersResponse = {
      id = "ListInsertionOrdersResponse",
      properties = {
        insertionOrders = {
          description = "The list of insertion orders. This list will be absent if empty.",
          items = {
            ["$ref"] = "InsertionOrder",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListInsertionOrders` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListInventorySourceGroupsResponse = {
      description = "Response message for InventorySourceGroupService.ListInventorySourceGroups.",
      id = "ListInventorySourceGroupsResponse",
      properties = {
        inventorySourceGroups = {
          description = "The list of inventory source groups. This list will be absent if empty.",
          items = {
            ["$ref"] = "InventorySourceGroup",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListInventorySourceGroups` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListInventorySourcesResponse = {
      id = "ListInventorySourcesResponse",
      properties = {
        inventorySources = {
          description = "The list of inventory sources. This list will be absent if empty.",
          items = {
            ["$ref"] = "InventorySource",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListInventorySources` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListInvoicesResponse = {
      id = "ListInvoicesResponse",
      properties = {
        invoices = {
          description = "The list of invoices. This list will be absent if empty.",
          items = {
            ["$ref"] = "Invoice",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListInvoices` method to retrieve the next page of results. This token will be absent if there are no more invoices to return.",
          type = "string",
        },
      },
      type = "object",
    },
    ListLineItemAssignedTargetingOptionsResponse = {
      description = "Response message for ListLineItemAssignedTargetingOptions.",
      id = "ListLineItemAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent ListLineItemAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    ListLineItemsResponse = {
      id = "ListLineItemsResponse",
      properties = {
        lineItems = {
          description = "The list of line items. This list will be absent if empty.",
          items = {
            ["$ref"] = "LineItem",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListLineItems` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListLocationListsResponse = {
      id = "ListLocationListsResponse",
      properties = {
        locationLists = {
          description = "The list of location lists. This list will be absent if empty.",
          items = {
            ["$ref"] = "LocationList",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListLocationLists` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListManualTriggersResponse = {
      id = "ListManualTriggersResponse",
      properties = {
        manualTriggers = {
          description = "The list of manual triggers. This list will be absent if empty.",
          items = {
            ["$ref"] = "ManualTrigger",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListManualTriggers` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListNegativeKeywordListsResponse = {
      description = "Response message for NegativeKeywordListService.ListNegativeKeywordLists.",
      id = "ListNegativeKeywordListsResponse",
      properties = {
        negativeKeywordLists = {
          description = "The list of negative keyword lists. This list will be absent if empty.",
          items = {
            ["$ref"] = "NegativeKeywordList",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListNegativeKeywordLists` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListNegativeKeywordsResponse = {
      description = "Response message for NegativeKeywordService.ListNegativeKeywords.",
      id = "ListNegativeKeywordsResponse",
      properties = {
        negativeKeywords = {
          description = "The list of negative keywords. This list will be absent if empty.",
          items = {
            ["$ref"] = "NegativeKeyword",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListNegativeKeywords` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    ListPartnerAssignedTargetingOptionsResponse = {
      id = "ListPartnerAssignedTargetingOptionsResponse",
      properties = {
        assignedTargetingOptions = {
          description = "The list of assigned targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "AssignedTargetingOption",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token identifying the next page of results. This value should be specified as the pageToken in a subsequent ListPartnerAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.",
          type = "string",
        },
      },
      type = "object",
    },
    ListPartnersResponse = {
      id = "ListPartnersResponse",
      properties = {
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListPartners` method to retrieve the next page of results.",
          type = "string",
        },
        partners = {
          description = "The list of partners. This list will be absent if empty.",
          items = {
            ["$ref"] = "Partner",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ListSitesResponse = {
      description = "Response message for SiteService.ListSites.",
      id = "ListSitesResponse",
      properties = {
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListSites` method to retrieve the next page of results.",
          type = "string",
        },
        sites = {
          description = "The list of sites. This list will be absent if empty.",
          items = {
            ["$ref"] = "Site",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ListTargetingOptionsResponse = {
      description = "Response message for ListTargetingOptions.",
      id = "ListTargetingOptionsResponse",
      properties = {
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListTargetingOptions` method to retrieve the next page of results.",
          type = "string",
        },
        targetingOptions = {
          description = "The list of targeting options. This list will be absent if empty.",
          items = {
            ["$ref"] = "TargetingOption",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ListUsersResponse = {
      id = "ListUsersResponse",
      properties = {
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `ListUsers` method to retrieve the next page of results. This token will be absent if there are no more results to return.",
          type = "string",
        },
        users = {
          description = "The list of users. This list will be absent if empty.",
          items = {
            ["$ref"] = "User",
          },
          type = "array",
        },
      },
      type = "object",
    },
    LocationList = {
      description = "A list of locations used for targeting.",
      id = "LocationList",
      properties = {
        advertiserId = {
          description = "Required. Immutable. The unique ID of the advertiser the location list belongs to.",
          format = "int64",
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the location list. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        locationListId = {
          description = "Output only. The unique ID of the location list. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        locationType = {
          description = "Required. Immutable. The type of location. All locations in the list will share this type.",
          enum = {
            "TARGETING_LOCATION_TYPE_UNSPECIFIED",
            "TARGETING_LOCATION_TYPE_PROXIMITY",
            "TARGETING_LOCATION_TYPE_REGIONAL",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown.",
            "The type for proximity geo location.",
            "The type for regional geo location.",
          },
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the location list.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    LookbackWindow = {
      description = "Specifies how many days into the past to look when determining whether to record a conversion.",
      id = "LookbackWindow",
      properties = {
        clickDays = {
          description = "Lookback window, in days, from the last time a given user clicked on one of your ads.",
          format = "int32",
          type = "integer",
        },
        impressionDays = {
          description = "Lookback window, in days, from the last time a given user viewed one of your ads.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    LookupInvoiceCurrencyResponse = {
      id = "LookupInvoiceCurrencyResponse",
      properties = {
        currencyCode = {
          description = "Currency used by the advertiser in ISO 4217 format.",
          type = "string",
        },
      },
      type = "object",
    },
    ManualTrigger = {
      description = "A single manual trigger in Display & Video 360.",
      id = "ManualTrigger",
      properties = {
        activationDurationMinutes = {
          description = "Required. The maximum duration of each activation in minutes. Must be between 1 and 360 inclusive. After this duration, the trigger will be automatically deactivated.",
          format = "int64",
          type = "string",
        },
        advertiserId = {
          description = "Required. Immutable. The unique ID of the advertiser that the manual trigger belongs to.",
          format = "int64",
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the manual trigger. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        latestActivationTime = {
          description = "Output only. The timestamp of the trigger's latest activation.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the manual trigger.",
          readOnly = true,
          type = "string",
        },
        state = {
          description = "Output only. The state of the manual trigger. Will be set to the `INACTIVE` state upon creation.",
          enum = {
            "STATE_UNSPECIFIED",
            "INACTIVE",
            "ACTIVE",
          },
          enumDescriptions = {
            "Default value when state is not specified or is unknown in this version.",
            "The trigger is currently inactive and ready to be activated.",
            "The trigger is currently active (activated).",
          },
          readOnly = true,
          type = "string",
        },
        triggerId = {
          description = "Output only. The unique ID of the manual trigger.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    MaximizeSpendBidStrategy = {
      description = "A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget.",
      id = "MaximizeSpendBidStrategy",
      properties = {
        customBiddingAlgorithmId = {
          description = "The ID of the Custom Bidding Algorithm used by this strategy. Only applicable when performance_goal_type is set to `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO`.",
          format = "int64",
          type = "string",
        },
        maxAverageCpmBidAmountMicros = {
          description = "The maximum average CPM that may be bid, in micros of the advertiser's currency. Must be greater than or equal to a billable unit of the given currency. For example, 1500000 represents 1.5 standard units of the currency.",
          format = "int64",
          type = "string",
        },
        performanceGoalType = {
          description = "Required. The type of the performance goal that the bidding strategy tries to minimize while spending the full budget. `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM` is not supported for this strategy.",
          enum = {
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_UNSPECIFIED",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CIVA",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_IVO_TEN",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_AV_VIEWED",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Cost per action.",
            "Cost per click.",
            "Viewable CPM.",
            "Custom bidding algorithm.",
            "Completed inview and audible views.",
            "Inview time over 10 secs views.",
            "Viewable impressions.",
          },
          type = "string",
        },
        raiseBidForDeals = {
          description = "Whether the strategy takes deal floor prices into account.",
          type = "boolean",
        },
      },
      type = "object",
    },
    MeasurementConfig = {
      description = "Measurement settings of a partner.",
      id = "MeasurementConfig",
      properties = {
        dv360ToCmCostReportingEnabled = {
          description = "Whether or not to report DV360 cost to CM360.",
          type = "boolean",
        },
        dv360ToCmDataSharingEnabled = {
          description = "Whether or not to include DV360 data in CM360 data transfer reports.",
          type = "boolean",
        },
      },
      type = "object",
    },
    MobileApp = {
      description = "A mobile app promoted by a mobile app install line item.",
      id = "MobileApp",
      properties = {
        appId = {
          description = "Required. The ID of the app provided by the platform store. Android apps are identified by the bundle ID used by Android's Play store, such as `com.google.android.gm`. iOS apps are identified by a nine-digit app ID used by Apple's App store, such as `422689480`.",
          type = "string",
        },
        displayName = {
          description = "Output only. The app name.",
          readOnly = true,
          type = "string",
        },
        platform = {
          description = "Output only. The app platform.",
          enum = {
            "PLATFORM_UNSPECIFIED",
            "IOS",
            "ANDROID",
          },
          enumDescriptions = {
            "Platform is not specified.",
            "iOS platform.",
            "Android platform.",
          },
          readOnly = true,
          type = "string",
        },
        publisher = {
          description = "Output only. The app publisher.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    MobileDeviceIdList = {
      description = "Wrapper message for a list of mobile device IDs defining Customer Match audience members.",
      id = "MobileDeviceIdList",
      properties = {
        mobileDeviceIds = {
          description = "A list of mobile device IDs defining Customer Match audience members. The size of mobile_device_ids mustn't be greater than 500,000.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    Money = {
      description = "Represents an amount of money with its currency type.",
      id = "Money",
      properties = {
        currencyCode = {
          description = "The three-letter currency code defined in ISO 4217.",
          type = "string",
        },
        nanos = {
          description = "Number of nano (10^-9) units of the amount. The value must be between -999,999,999 and +999,999,999 inclusive. If `units` is positive, `nanos` must be positive or zero. If `units` is zero, `nanos` can be positive, zero, or negative. If `units` is negative, `nanos` must be negative or zero. For example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.",
          format = "int32",
          type = "integer",
        },
        units = {
          description = "The whole units of the amount. For example if `currencyCode` is `\"USD\"`, then 1 unit is one US dollar.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    NativeContentPositionAssignedTargetingOptionDetails = {
      description = "Details for native content position assigned targeting option. This will be populated in the native_content_position_details field when targeting_type is `TARGETING_TYPE_NATIVE_CONTENT_POSITION`. Explicitly targeting all options is not supported. Remove all native content position targeting options to achieve this effect.",
      id = "NativeContentPositionAssignedTargetingOptionDetails",
      properties = {
        contentPosition = {
          description = "The content position. Output only in v1. Required in v2.",
          enum = {
            "NATIVE_CONTENT_POSITION_UNSPECIFIED",
            "NATIVE_CONTENT_POSITION_UNKNOWN",
            "NATIVE_CONTENT_POSITION_IN_ARTICLE",
            "NATIVE_CONTENT_POSITION_IN_FEED",
            "NATIVE_CONTENT_POSITION_PERIPHERAL",
            "NATIVE_CONTENT_POSITION_RECOMMENDATION",
          },
          enumDescriptions = {
            "Native content position is not specified in this version. This enum is a place holder for a default value and does not represent a real native content position.",
            "The native content position is unknown.",
            "Native content position is in-article, i.e., ads appear between the paragraphs of pages.",
            "Native content position is in-feed, i.e., ads appear in a scrollable stream of content. A feed is typically editorial (e.g. a list of articles or news) or listings (e.g. a list of products or services).",
            "Native content position is peripheral, i.e., ads appear outside of core content on pages, such as the right- or left-hand side of the page.",
            "Native content position is recommendation, i.e., ads appear in sections for recommended content.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_NATIVE_CONTENT_POSITION`.",
          type = "string",
        },
      },
      type = "object",
    },
    NativeContentPositionTargetingOptionDetails = {
      description = "Represents a targetable native content position. This will be populated in the native_content_position_details field when targeting_type is `TARGETING_TYPE_NATIVE_CONTENT_POSITION`.",
      id = "NativeContentPositionTargetingOptionDetails",
      properties = {
        contentPosition = {
          description = "Output only. The content position.",
          enum = {
            "NATIVE_CONTENT_POSITION_UNSPECIFIED",
            "NATIVE_CONTENT_POSITION_UNKNOWN",
            "NATIVE_CONTENT_POSITION_IN_ARTICLE",
            "NATIVE_CONTENT_POSITION_IN_FEED",
            "NATIVE_CONTENT_POSITION_PERIPHERAL",
            "NATIVE_CONTENT_POSITION_RECOMMENDATION",
          },
          enumDescriptions = {
            "Native content position is not specified in this version. This enum is a place holder for a default value and does not represent a real native content position.",
            "The native content position is unknown.",
            "Native content position is in-article, i.e., ads appear between the paragraphs of pages.",
            "Native content position is in-feed, i.e., ads appear in a scrollable stream of content. A feed is typically editorial (e.g. a list of articles or news) or listings (e.g. a list of products or services).",
            "Native content position is peripheral, i.e., ads appear outside of core content on pages, such as the right- or left-hand side of the page.",
            "Native content position is recommendation, i.e., ads appear in sections for recommended content.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    NegativeKeyword = {
      description = "A negatively targeted keyword that belongs to a negative keyword list.",
      id = "NegativeKeyword",
      properties = {
        keywordValue = {
          description = "Required. Immutable. The negatively targeted keyword, for example `car insurance`. Must be UTF-8 encoded with a maximum size of 255 bytes. Maximum number of characters is 80. Maximum number of words is 10. Valid characters are restricted to ASCII characters only. The only URL-escaping permitted is for representing whitespace between words. Leading or trailing whitespace is ignored.",
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the negative keyword.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    NegativeKeywordList = {
      description = "A list of negative keywords used for targeting.",
      id = "NegativeKeywordList",
      properties = {
        advertiserId = {
          description = "Output only. The unique ID of the advertiser the negative keyword list belongs to.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the negative keyword list. Must be UTF-8 encoded with a maximum size of 255 bytes.",
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the negative keyword list.",
          readOnly = true,
          type = "string",
        },
        negativeKeywordListId = {
          description = "Output only. The unique ID of the negative keyword list. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        targetedLineItemCount = {
          description = "Output only. Number of line items that are directly targeting this negative keyword list.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    NegativeKeywordListAssignedTargetingOptionDetails = {
      description = "Targeting details for negative keyword list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_NEGATIVE_KEYWORD_LIST`.",
      id = "NegativeKeywordListAssignedTargetingOptionDetails",
      properties = {
        negativeKeywordListId = {
          description = "Required. ID of the negative keyword list. Should refer to the negative_keyword_list_id field of a NegativeKeywordList resource.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ObaIcon = {
      description = "OBA Icon for a Creative",
      id = "ObaIcon",
      properties = {
        clickTrackingUrl = {
          description = "Required. The click tracking URL of the OBA icon. Only URLs of the following domains are allowed: * https://info.evidon.com * https://l.betrad.com",
          type = "string",
        },
        dimensions = {
          ["$ref"] = "Dimensions",
          description = "The dimensions of the OBA icon.",
        },
        landingPageUrl = {
          description = "Required. The landing page URL of the OBA icon. Only URLs of the following domains are allowed: * https://info.evidon.com * https://l.betrad.com",
          type = "string",
        },
        position = {
          description = "The position of the OBA icon on the creative.",
          enum = {
            "OBA_ICON_POSITION_UNSPECIFIED",
            "OBA_ICON_POSITION_UPPER_RIGHT",
            "OBA_ICON_POSITION_UPPER_LEFT",
            "OBA_ICON_POSITION_LOWER_RIGHT",
            "OBA_ICON_POSITION_LOWER_LEFT",
          },
          enumDescriptions = {
            "The OBA icon position is not specified.",
            "At the upper right side of the creative.",
            "At the upper left side of the creative.",
            "At the lower right side of the creative.",
            "At the lower left side of the creative.",
          },
          type = "string",
        },
        program = {
          description = "The program of the OBA icon. For example: “AdChoices”.",
          type = "string",
        },
        resourceMimeType = {
          description = "The MIME type of the OBA icon resource.",
          type = "string",
        },
        resourceUrl = {
          description = "The URL of the OBA icon resource.",
          type = "string",
        },
        viewTrackingUrl = {
          description = "Required. The view tracking URL of the OBA icon. Only URLs of the following domains are allowed: * https://info.evidon.com * https://l.betrad.com",
          type = "string",
        },
      },
      type = "object",
    },
    OmidAssignedTargetingOptionDetails = {
      description = "Represents a targetable Open Measurement enabled inventory type. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_OMID`.",
      id = "OmidAssignedTargetingOptionDetails",
      properties = {
        omid = {
          description = "The type of Open Measurement enabled inventory. Output only in v1. Required in v2.",
          enum = {
            "OMID_UNSPECIFIED",
            "OMID_FOR_MOBILE_DISPLAY_ADS",
          },
          enumDescriptions = {
            "Default value when omid targeting is not specified in this version.",
            "Open Measurement enabled mobile display inventory.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_OMID`.",
          type = "string",
        },
      },
      type = "object",
    },
    OmidTargetingOptionDetails = {
      description = "Represents a targetable Open Measurement enabled inventory type. This will be populated in the omid_details field when targeting_type is `TARGETING_TYPE_OMID`.",
      id = "OmidTargetingOptionDetails",
      properties = {
        omid = {
          description = "Output only. The type of Open Measurement enabled inventory.",
          enum = {
            "OMID_UNSPECIFIED",
            "OMID_FOR_MOBILE_DISPLAY_ADS",
          },
          enumDescriptions = {
            "Default value when omid targeting is not specified in this version.",
            "Open Measurement enabled mobile display inventory.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    OnScreenPositionAssignedTargetingOptionDetails = {
      description = "On screen position targeting option details. This will be populated in the on_screen_position_details field when targeting_type is `TARGETING_TYPE_ON_SCREEN_POSITION`.",
      id = "OnScreenPositionAssignedTargetingOptionDetails",
      properties = {
        adType = {
          description = "Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * `AD_TYPE_DISPLAY`, the setting will be inherited by new line item when line_item_type is `LINE_ITEM_TYPE_DISPLAY_DEFAULT`. * `AD_TYPE_VIDEO`, the setting will be inherited by new line item when line_item_type is `LINE_ITEM_TYPE_VIDEO_DEFAULT`.",
          enum = {
            "AD_TYPE_UNSPECIFIED",
            "AD_TYPE_DISPLAY",
            "AD_TYPE_VIDEO",
            "AD_TYPE_AUDIO",
          },
          enumDescriptions = {
            "Ad type is not specified or is unknown in this version.",
            "Display creatives, e.g. image and HTML5.",
            "Video creatives, e.g. video ads that play during streaming content in video players.",
            "Audio creatives, e.g. audio ads that play during audio content.",
          },
          readOnly = true,
          type = "string",
        },
        onScreenPosition = {
          description = "Output only. The on screen position.",
          enum = {
            "ON_SCREEN_POSITION_UNSPECIFIED",
            "ON_SCREEN_POSITION_UNKNOWN",
            "ON_SCREEN_POSITION_ABOVE_THE_FOLD",
            "ON_SCREEN_POSITION_BELOW_THE_FOLD",
          },
          enumDescriptions = {
            "On screen position is not specified in this version. This enum is a place holder for a default value and does not represent a real on screen position.",
            "The ad position is unknown on the screen.",
            "The ad is located above the fold.",
            "The ad is located below the fold.",
          },
          readOnly = true,
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_ON_SCREEN_POSITION`.",
          type = "string",
        },
      },
      type = "object",
    },
    OnScreenPositionTargetingOptionDetails = {
      description = "Represents a targetable on screen position, which could be used by display and video ads. This will be populated in the on_screen_position_details field when targeting_type is `TARGETING_TYPE_ON_SCREEN_POSITION`.",
      id = "OnScreenPositionTargetingOptionDetails",
      properties = {
        onScreenPosition = {
          description = "Output only. The on screen position.",
          enum = {
            "ON_SCREEN_POSITION_UNSPECIFIED",
            "ON_SCREEN_POSITION_UNKNOWN",
            "ON_SCREEN_POSITION_ABOVE_THE_FOLD",
            "ON_SCREEN_POSITION_BELOW_THE_FOLD",
          },
          enumDescriptions = {
            "On screen position is not specified in this version. This enum is a place holder for a default value and does not represent a real on screen position.",
            "The ad position is unknown on the screen.",
            "The ad is located above the fold.",
            "The ad is located below the fold.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    OperatingSystemAssignedTargetingOptionDetails = {
      description = "Assigned operating system targeting option details. This will be populated in the operating_system_details field when targeting_type is `TARGETING_TYPE_OPERATING_SYSTEM`.",
      id = "OperatingSystemAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the operating system.",
          readOnly = true,
          type = "string",
        },
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        targetingOptionId = {
          description = "Required. The targeting option ID populated in targeting_option_id field when targeting_type is `TARGETING_TYPE_OPERATING_SYSTEM`.",
          type = "string",
        },
      },
      type = "object",
    },
    OperatingSystemTargetingOptionDetails = {
      description = "Represents a targetable operating system. This will be populated in the operating_system_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_OPERATING_SYSTEM`.",
      id = "OperatingSystemTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the operating system.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Operation = {
      description = "This resource represents a long-running operation that is the result of a network API call.",
      id = "Operation",
      properties = {
        done = {
          description = "If the value is `false`, it means the operation is still in progress. If `true`, the operation is completed, and either `error` or `response` is available.",
          type = "boolean",
        },
        error = {
          ["$ref"] = "Status",
          description = "The error result of the operation in case of failure or cancellation.",
        },
        metadata = {
          additionalProperties = {
            description = "Properties of the object. Contains field @type with type URL.",
            type = "any",
          },
          description = "Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.",
          type = "object",
        },
        name = {
          description = "The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should be a resource name ending with `operations/{unique_id}`.",
          type = "string",
        },
        response = {
          additionalProperties = {
            description = "Properties of the object. Contains field @type with type URL.",
            type = "any",
          },
          description = "The normal response of the operation in case of success. If the original method returns no data on success, such as `Delete`, the response is `google.protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`, the response should be the resource. For other methods, the response should have the type `XxxResponse`, where `Xxx` is the original method name. For example, if the original method name is `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.",
          type = "object",
        },
      },
      type = "object",
    },
    Pacing = {
      description = "Settings that control the rate at which a budget is spent.",
      id = "Pacing",
      properties = {
        dailyMaxImpressions = {
          description = "Maximum number of impressions to serve every day. Applicable when the budget is impression based. Must be greater than 0.",
          format = "int64",
          type = "string",
        },
        dailyMaxMicros = {
          description = "Maximum currency amount to spend every day in micros of advertiser's currency. Applicable when the budget is currency based. Must be greater than 0. For example, for 1.5 standard unit of the currency, set this field to 1500000. The value assigned will be rounded to whole billable units for the relevant currency by the following rules: any positive value less than a single billable unit will be rounded up to one billable unit and any value larger than a single billable unit will be rounded down to the nearest billable value. For example, if the currency's billable unit is 0.01, and this field is set to 10257770, it will round down to 10250000, a value of 10.25. If set to 505, it will round up to 10000, a value of 0.01.",
          format = "int64",
          type = "string",
        },
        pacingPeriod = {
          description = "Required. The time period in which the pacing budget will be spent. When automatic budget allocation is enabled at the insertion order via auto_budget_allocation, this field is output only and defaults to `PACING_PERIOD_FLIGHT`.",
          enum = {
            "PACING_PERIOD_UNSPECIFIED",
            "PACING_PERIOD_DAILY",
            "PACING_PERIOD_FLIGHT",
          },
          enumDescriptions = {
            "Period value is not specified or is unknown in this version.",
            "The pacing setting will be applied on daily basis.",
            "The pacing setting will be applied to the whole flight duration.",
          },
          type = "string",
        },
        pacingType = {
          description = "Required. The type of pacing that defines how the budget amount will be spent across the pacing_period.",
          enum = {
            "PACING_TYPE_UNSPECIFIED",
            "PACING_TYPE_AHEAD",
            "PACING_TYPE_ASAP",
            "PACING_TYPE_EVEN",
          },
          enumDescriptions = {
            "Pacing mode value is not specified or is unknown in this version.",
            "Only applicable to `PACING_PERIOD_FLIGHT` pacing period. Ahead pacing attempts to spend faster than evenly, to make sure the entire budget is spent by the end of the flight.",
            "Spend all of pacing budget amount as quick as possible.",
            "Spend a consistent budget amount every period of time.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ParentEntityFilter = {
      description = "A filtering option that filters on selected file types belonging to a chosen set of filter entities.",
      id = "ParentEntityFilter",
      properties = {
        fileType = {
          description = "Required. File types that will be returned.",
          items = {
            enum = {
              "FILE_TYPE_UNSPECIFIED",
              "FILE_TYPE_CAMPAIGN",
              "FILE_TYPE_MEDIA_PRODUCT",
              "FILE_TYPE_INSERTION_ORDER",
              "FILE_TYPE_LINE_ITEM",
              "FILE_TYPE_AD_GROUP",
              "FILE_TYPE_AD",
            },
            enumDescriptions = {
              "Default value when type is unspecified or is unknown in this version.",
              "Campaign.",
              "Media Product.",
              "Insertion Order.",
              "Line Item.",
              "YouTube Ad Group.",
              "YouTube Ad.",
            },
            type = "string",
          },
          type = "array",
        },
        filterIds = {
          description = "The IDs of the specified filter type. This is used to filter entities to fetch. If filter type is not `FILTER_TYPE_NONE`, at least one ID must be specified.",
          items = {
            format = "int64",
            type = "string",
          },
          type = "array",
        },
        filterType = {
          description = "Required. Filter type used to filter fetched entities.",
          enum = {
            "FILTER_TYPE_UNSPECIFIED",
            "FILTER_TYPE_NONE",
            "FILTER_TYPE_ADVERTISER_ID",
            "FILTER_TYPE_CAMPAIGN_ID",
            "FILTER_TYPE_MEDIA_PRODUCT_ID",
            "FILTER_TYPE_INSERTION_ORDER_ID",
            "FILTER_TYPE_LINE_ITEM_ID",
          },
          enumDescriptions = {
            "Default value when type is unspecified or is unknown in this version.",
            "If selected, no filter will be applied to the download. Can only be used if an Advertiser is specified in CreateSdfDownloadTaskRequest.",
            "Advertiser ID. If selected, all filter IDs must be Advertiser IDs that belong to the Partner specified in CreateSdfDownloadTaskRequest.",
            "Campaign ID. If selected, all filter IDs must be Campaign IDs that belong to the Advertiser or Partner specified in CreateSdfDownloadTaskRequest.",
            "Media Product ID. If selected, all filter IDs must be Media Product IDs that belong to the Advertiser or Partner specified in CreateSdfDownloadTaskRequest. Can only be used for downloading `FILE_TYPE_MEDIA_PRODUCT`.",
            "Insertion Order ID. If selected, all filter IDs must be Insertion Order IDs that belong to the Advertiser or Partner specified in CreateSdfDownloadTaskRequest. Can only be used for downloading `FILE_TYPE_INSERTION_ORDER`, `FILE_TYPE_LINE_ITEM`, `FILE_TYPE_AD_GROUP`, and `FILE_TYPE_AD`.",
            "Line Item ID. If selected, all filter IDs must be Line Item IDs that belong to the Advertiser or Partner specified in CreateSdfDownloadTaskRequest. Can only be used for downloading `FILE_TYPE_LINE_ITEM`, `FILE_TYPE_AD_GROUP`, and `FILE_TYPE_AD`.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ParentalStatusAssignedTargetingOptionDetails = {
      description = "Details for assigned parental status targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_PARENTAL_STATUS`.",
      id = "ParentalStatusAssignedTargetingOptionDetails",
      properties = {
        parentalStatus = {
          description = "The parental status of the audience. Output only in v1. Required in v2.",
          enum = {
            "PARENTAL_STATUS_UNSPECIFIED",
            "PARENTAL_STATUS_PARENT",
            "PARENTAL_STATUS_NOT_A_PARENT",
            "PARENTAL_STATUS_UNKNOWN",
          },
          enumDescriptions = {
            "Default value when parental status is not specified in this version. This enum is a place holder for default value and does not represent a real parental status option.",
            "The audience is a parent.",
            "The audience is not a parent.",
            "The parental status of the audience is unknown.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_PARENTAL_STATUS`.",
          type = "string",
        },
      },
      type = "object",
    },
    ParentalStatusTargetingOptionDetails = {
      description = "Represents a targetable parental status. This will be populated in the parental_status_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_PARENTAL_STATUS`.",
      id = "ParentalStatusTargetingOptionDetails",
      properties = {
        parentalStatus = {
          description = "Output only. The parental status of an audience.",
          enum = {
            "PARENTAL_STATUS_UNSPECIFIED",
            "PARENTAL_STATUS_PARENT",
            "PARENTAL_STATUS_NOT_A_PARENT",
            "PARENTAL_STATUS_UNKNOWN",
          },
          enumDescriptions = {
            "Default value when parental status is not specified in this version. This enum is a place holder for default value and does not represent a real parental status option.",
            "The audience is a parent.",
            "The audience is not a parent.",
            "The parental status of the audience is unknown.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Partner = {
      description = "A single partner in Display & Video 360 (DV360).",
      id = "Partner",
      properties = {
        adServerConfig = {
          ["$ref"] = "PartnerAdServerConfig",
          description = "Ad server related settings of the partner.",
        },
        dataAccessConfig = {
          ["$ref"] = "PartnerDataAccessConfig",
          description = "Settings that control how partner data may be accessed.",
        },
        displayName = {
          description = "The display name of the partner. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        entityStatus = {
          description = "Output only. The status of the partner.",
          enum = {
            "ENTITY_STATUS_UNSPECIFIED",
            "ENTITY_STATUS_ACTIVE",
            "ENTITY_STATUS_ARCHIVED",
            "ENTITY_STATUS_DRAFT",
            "ENTITY_STATUS_PAUSED",
            "ENTITY_STATUS_SCHEDULED_FOR_DELETION",
          },
          enumDescriptions = {
            "Default value when status is not specified or is unknown in this version.",
            "The entity is enabled to bid and spend budget.",
            "The entity is archived. Bidding and budget spending are disabled. An entity can be deleted after archived. Deleted entities cannot be retrieved.",
            "The entity is under draft. Bidding and budget spending are disabled.",
            "Bidding and budget spending are paused for the entity.",
            "The entity is scheduled for deletion.",
          },
          readOnly = true,
          type = "string",
        },
        exchangeConfig = {
          ["$ref"] = "ExchangeConfig",
          description = "Settings that control which exchanges are enabled for the partner.",
        },
        generalConfig = {
          ["$ref"] = "PartnerGeneralConfig",
          description = "General settings of the partner.",
        },
        name = {
          description = "Output only. The resource name of the partner.",
          readOnly = true,
          type = "string",
        },
        partnerId = {
          description = "Output only. The unique ID of the partner. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        updateTime = {
          description = "Output only. The timestamp when the partner was last updated. Assigned by the system.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    PartnerAdServerConfig = {
      description = "Ad server related settings of a partner.",
      id = "PartnerAdServerConfig",
      properties = {
        measurementConfig = {
          ["$ref"] = "MeasurementConfig",
          description = "Measurement settings of a partner.",
        },
      },
      type = "object",
    },
    PartnerCost = {
      description = "Settings that control a partner cost. A partner cost is any type of expense involved in running a campaign, other than the costs of purchasing impressions (which is called the media cost) and using third-party audience segment data (data fee). Some examples of partner costs include the fees for using DV360, a third-party ad server, or a third-party ad serving verification service.",
      id = "PartnerCost",
      properties = {
        costType = {
          description = "Required. The type of the partner cost.",
          enum = {
            "PARTNER_COST_TYPE_UNSPECIFIED",
            "PARTNER_COST_TYPE_ADLOOX",
            "PARTNER_COST_TYPE_ADLOOX_PREBID",
            "PARTNER_COST_TYPE_ADSAFE",
            "PARTNER_COST_TYPE_ADXPOSE",
            "PARTNER_COST_TYPE_AGGREGATE_KNOWLEDGE",
            "PARTNER_COST_TYPE_AGENCY_TRADING_DESK",
            "PARTNER_COST_TYPE_DV360_FEE",
            "PARTNER_COST_TYPE_COMSCORE_VCE",
            "PARTNER_COST_TYPE_DATA_MANAGEMENT_PLATFORM",
            "PARTNER_COST_TYPE_DEFAULT",
            "PARTNER_COST_TYPE_DOUBLE_VERIFY",
            "PARTNER_COST_TYPE_DOUBLE_VERIFY_PREBID",
            "PARTNER_COST_TYPE_EVIDON",
            "PARTNER_COST_TYPE_INTEGRAL_AD_SCIENCE_VIDEO",
            "PARTNER_COST_TYPE_INTEGRAL_AD_SCIENCE_PREBID",
            "PARTNER_COST_TYPE_MEDIA_COST_DATA",
            "PARTNER_COST_TYPE_MOAT_VIDEO",
            "PARTNER_COST_TYPE_NIELSEN_DAR",
            "PARTNER_COST_TYPE_SHOP_LOCAL",
            "PARTNER_COST_TYPE_TERACENT",
            "PARTNER_COST_TYPE_THIRD_PARTY_AD_SERVER",
            "PARTNER_COST_TYPE_TRUST_METRICS",
            "PARTNER_COST_TYPE_VIZU",
            "PARTNER_COST_TYPE_ADLINGO_FEE",
            "PARTNER_COST_TYPE_CUSTOM_FEE_1",
            "PARTNER_COST_TYPE_CUSTOM_FEE_2",
            "PARTNER_COST_TYPE_CUSTOM_FEE_3",
            "PARTNER_COST_TYPE_CUSTOM_FEE_4",
            "PARTNER_COST_TYPE_CUSTOM_FEE_5",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The cost is charged for using Adloox.",
            "The cost is charged for using Adloox Pre-Bid.",
            "The cost is charged for using AdSafe.",
            "The cost is charged for using AdExpose.",
            "The cost is charged for using Aggregate Knowledge.",
            "The cost is charged for using an Agency Trading Desk.",
            "The cost is charged for using DV360.",
            "The cost is charged for using comScore vCE.",
            "The cost is charged for using a Data Management Platform.",
            "The default cost type.",
            "The cost is charged for using DoubleVerify.",
            "The cost is charged for using DoubleVerify Pre-Bid.",
            "The cost is charged for using Evidon.",
            "The cost is charged for using Integral Ad Science Video.",
            "The cost is charged for using Integral Ad Science Pre-Bid.",
            "The cost is charged for using media cost data.",
            "The cost is charged for using MOAT Video.",
            "The cost is charged for using Nielsen Digital Ad Ratings.",
            "The cost is charged for using ShopLocal.",
            "The cost is charged for using Teracent.",
            "The cost is charged for using a third-party ad server.",
            "The cost is charged for using TrustMetrics.",
            "The cost is charged for using Vizu.",
            "The cost is charged for using AdLingo.",
            "The cost is charged as custom fee 1.",
            "The cost is charged as custom fee 2.",
            "The cost is charged as custom fee 3.",
            "The cost is charged as custom fee 4.",
            "The cost is charged as custom fee 5.",
          },
          type = "string",
        },
        feeAmount = {
          description = "The CPM fee amount in micros of advertiser's currency. Applicable when the fee_type is `PARTNER_FEE_TYPE_CPM_FEE`. Must be greater than or equal to 0. For example, for 1.5 standard unit of the advertiser's currency, set this field to 1500000.",
          format = "int64",
          type = "string",
        },
        feePercentageMillis = {
          description = "The media fee percentage in millis (1/1000 of a percent). Applicable when the fee_type is `PARTNER_FEE_TYPE_MEDIA_FEE`. Must be greater than or equal to 0. For example: 100 represents 0.1%.",
          format = "int64",
          type = "string",
        },
        feeType = {
          description = "Required. The fee type for this partner cost.",
          enum = {
            "PARTNER_COST_FEE_TYPE_UNSPECIFIED",
            "PARTNER_COST_FEE_TYPE_CPM_FEE",
            "PARTNER_COST_FEE_TYPE_MEDIA_FEE",
          },
          enumDescriptions = {
            "Value is not specified or is unknown in this version.",
            "The partner cost is a fixed CPM fee. Not applicable when the partner cost cost_type is one of: * `PARTNER_COST_TYPE_MEDIA_COST_DATA` * `PARTNER_COST_TYPE_DV360_FEE`.",
            "The partner cost is a percentage surcharge based on the media cost. Not applicable when the partner cost_type is one of: * `PARTNER_COST_TYPE_SHOP_LOCAL` * `PARTNER_COST_TYPE_TRUST_METRICS` * `PARTNER_COST_TYPE_INTEGRAL_AD_SCIENCE_VIDEO` * `PARTNER_COST_TYPE_MOAT_VIDEO`.",
          },
          type = "string",
        },
        invoiceType = {
          description = "The invoice type for this partner cost. * Required when cost_type is one of: - `PARTNER_COST_TYPE_ADLOOX` - `PARTNER_COST_TYPE_DOUBLE_VERIFY` - `PARTNER_COST_TYPE_INTEGRAL_AD_SCIENCE`. * Output only for other types.",
          enum = {
            "PARTNER_COST_INVOICE_TYPE_UNSPECIFIED",
            "PARTNER_COST_INVOICE_TYPE_DV360",
            "PARTNER_COST_INVOICE_TYPE_PARTNER",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Partner cost is billed through DV360.",
            "Partner cost is billed by the partner.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PartnerDataAccessConfig = {
      description = "Settings that control how partner related data may be accessed.",
      id = "PartnerDataAccessConfig",
      properties = {
        sdfConfig = {
          ["$ref"] = "SdfConfig",
          description = "Structured Data Files (SDF) settings for the partner. The SDF configuration for the partner.",
        },
      },
      type = "object",
    },
    PartnerGeneralConfig = {
      description = "General settings of a partner.",
      id = "PartnerGeneralConfig",
      properties = {
        currencyCode = {
          description = "Immutable. Partner's currency in ISO 4217 format.",
          type = "string",
        },
        timeZone = {
          description = "Immutable. The standard TZ database name of the partner's time zone. For example, `America/New_York`. See more at: https://en.wikipedia.org/wiki/List_of_tz_database_time_zones",
          type = "string",
        },
      },
      type = "object",
    },
    PartnerRevenueModel = {
      description = "Settings that control how partner revenue is calculated.",
      id = "PartnerRevenueModel",
      properties = {
        markupAmount = {
          description = "Required. The markup amount of the partner revenue model. Must be greater than or equal to 0. * When the markup_type is set to be `PARTNER_REVENUE_MODEL_MARKUP_TYPE_CPM`, this field represents the CPM markup in micros of advertiser's currency. For example, 1500000 represents 1.5 standard units of the currency. * When the markup_type is set to be `PARTNER_REVENUE_MODEL_MARKUP_TYPE_MEDIA_COST_MARKUP`, this field represents the media cost percent markup in millis. For example, 100 represents 0.1% (decimal 0.001). * When the markup_type is set to be `PARTNER_REVENUE_MODEL_MARKUP_TYPE_TOTAL_MEDIA_COST_MARKUP`, this field represents the total media cost percent markup in millis. For example, 100 represents 0.1% (decimal 0.001).",
          format = "int64",
          type = "string",
        },
        markupType = {
          description = "Required. The markup type of the partner revenue model.",
          enum = {
            "PARTNER_REVENUE_MODEL_MARKUP_TYPE_UNSPECIFIED",
            "PARTNER_REVENUE_MODEL_MARKUP_TYPE_CPM",
            "PARTNER_REVENUE_MODEL_MARKUP_TYPE_MEDIA_COST_MARKUP",
            "PARTNER_REVENUE_MODEL_MARKUP_TYPE_TOTAL_MEDIA_COST_MARKUP",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Calculate the partner revenue based on a fixed CPM.",
            "Calculate the partner revenue based on a percentage surcharge of its media cost.",
            "Calculate the partner revenue based on a percentage surcharge of its total media cost, which includes all partner costs and data costs.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PerformanceGoal = {
      description = "Settings that control the performance goal of a campaign or insertion order.",
      id = "PerformanceGoal",
      properties = {
        performanceGoalAmountMicros = {
          description = "The goal amount, in micros of the advertiser's currency. Applicable when performance_goal_type is one of: * `PERFORMANCE_GOAL_TYPE_CPM` * `PERFORMANCE_GOAL_TYPE_CPC` * `PERFORMANCE_GOAL_TYPE_CPA` * `PERFORMANCE_GOAL_TYPE_CPIAVC` * `PERFORMANCE_GOAL_TYPE_VCPM` For example 1500000 represents 1.5 standard units of the currency.",
          format = "int64",
          type = "string",
        },
        performanceGoalPercentageMicros = {
          description = "The decimal representation of the goal percentage in micros. Applicable when performance_goal_type is one of: * `PERFORMANCE_GOAL_TYPE_CTR` * `PERFORMANCE_GOAL_TYPE_VIEWABILITY` * `PERFORMANCE_GOAL_TYPE_CLICK_CVR` * `PERFORMANCE_GOAL_TYPE_IMPRESSION_CVR` * `PERFORMANCE_GOAL_TYPE_VTR` * `PERFORMANCE_GOAL_TYPE_AUDIO_COMPLETION_RATE` * `PERFORMANCE_GOAL_TYPE_VIDEO_COMPLETION_RATE` For example, 70000 represents 7% (decimal 0.07).",
          format = "int64",
          type = "string",
        },
        performanceGoalString = {
          description = "A key performance indicator (KPI) string, which can be empty. Must be UTF-8 encoded with a length of no more than 100 characters. Applicable when performance_goal_type is set to `PERFORMANCE_GOAL_TYPE_OTHER`.",
          type = "string",
        },
        performanceGoalType = {
          description = "Required. The type of the performance goal.",
          enum = {
            "PERFORMANCE_GOAL_TYPE_UNSPECIFIED",
            "PERFORMANCE_GOAL_TYPE_CPM",
            "PERFORMANCE_GOAL_TYPE_CPC",
            "PERFORMANCE_GOAL_TYPE_CPA",
            "PERFORMANCE_GOAL_TYPE_CTR",
            "PERFORMANCE_GOAL_TYPE_VIEWABILITY",
            "PERFORMANCE_GOAL_TYPE_CPIAVC",
            "PERFORMANCE_GOAL_TYPE_CPE",
            "PERFORMANCE_GOAL_TYPE_CLICK_CVR",
            "PERFORMANCE_GOAL_TYPE_IMPRESSION_CVR",
            "PERFORMANCE_GOAL_TYPE_VCPM",
            "PERFORMANCE_GOAL_TYPE_VTR",
            "PERFORMANCE_GOAL_TYPE_AUDIO_COMPLETION_RATE",
            "PERFORMANCE_GOAL_TYPE_VIDEO_COMPLETION_RATE",
            "PERFORMANCE_GOAL_TYPE_OTHER",
          },
          enumDescriptions = {
            "Performance goal type is not specified or is unknown in this version.",
            "The performance goal is set in CPM (cost per mille).",
            "The performance goal is set in CPC (cost per click).",
            "The performance goal is set in CPA (cost per action).",
            "The performance goal is set in CTR (click-through rate) percentage.",
            "The performance goal is set in Viewability percentage.",
            "The performance goal is set as CPIAVC (cost per impression audible and visible at completion).",
            "The performance goal is set in CPE (cost per engagement).",
            "The performance goal is set in click conversion rate (conversions per click) percentage.",
            "The performance goal is set in impression conversion rate (conversions per impression) percentage.",
            "The performance goal is set in VCPM (cost per thousand viewable impressions).",
            "The performance goal is set in YouTube view rate (YouTube views per impression) percentage.",
            "The performance goal is set in audio completion rate (complete audio listens per impression) percentage.",
            "The performance goal is set in video completion rate (complete video views per impression) percentage.",
            "The performance goal is set to Other.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PerformanceGoalBidStrategy = {
      description = "A strategy that automatically adjusts the bid to meet or beat a specified performance goal.",
      id = "PerformanceGoalBidStrategy",
      properties = {
        customBiddingAlgorithmId = {
          description = "The ID of the Custom Bidding Algorithm used by this strategy. Only applicable when performance_goal_type is set to `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO`.",
          format = "int64",
          type = "string",
        },
        maxAverageCpmBidAmountMicros = {
          description = "The maximum average CPM that may be bid, in micros of the advertiser's currency. Must be greater than or equal to a billable unit of the given currency. Not applicable when performance_goal_type is set to `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM`. For example, 1500000 represents 1.5 standard units of the currency.",
          format = "int64",
          type = "string",
        },
        performanceGoalAmountMicros = {
          description = "Required. The performance goal the bidding strategy will attempt to meet or beat, in micros of the advertiser's currency or in micro of the ROAS (Return On Advertising Spend) value which is also based on advertiser's currency. Must be greater than or equal to a billable unit of the given currency and smaller or equal to upper bounds. Each performance_goal_type has its upper bound: * when performance_goal_type is `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA`, upper bound is 10000.00 USD. * when performance_goal_type is `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC`, upper bound is 1000.00 USD. * when performance_goal_type is `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM`, upper bound is 1000.00 USD. * when performance_goal_type is `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO`, upper bound is 1000.00 and lower bound is 0.01. Example: If set to `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM`, the bid price will be based on the probability that each available impression will be viewable. For example, if viewable CPM target is $2 and an impression is 40% likely to be viewable, the bid price will be $0.80 CPM (40% of $2). For example, 1500000 represents 1.5 standard units of the currency or ROAS value.",
          format = "int64",
          type = "string",
        },
        performanceGoalType = {
          description = "Required. The type of the performance goal that the bidding strategy will try to meet or beat. For line item level usage, the value must be one of: * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA` * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC` * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM` * `BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO`.",
          enum = {
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_UNSPECIFIED",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CIVA",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_IVO_TEN",
            "BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_AV_VIEWED",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Cost per action.",
            "Cost per click.",
            "Viewable CPM.",
            "Custom bidding algorithm.",
            "Completed inview and audible views.",
            "Inview time over 10 secs views.",
            "Viewable impressions.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PoiAssignedTargetingOptionDetails = {
      description = "Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_POI`.",
      id = "PoiAssignedTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of a POI, e.g. \"Times Square\", \"Space Needle\", followed by its full address if available.",
          readOnly = true,
          type = "string",
        },
        latitude = {
          description = "Output only. Latitude of the POI rounding to 6th decimal place.",
          format = "double",
          readOnly = true,
          type = "number",
        },
        longitude = {
          description = "Output only. Longitude of the POI rounding to 6th decimal place.",
          format = "double",
          readOnly = true,
          type = "number",
        },
        proximityRadiusAmount = {
          description = "Required. The radius of the area around the POI that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is `DISTANCE_UNIT_KILOMETERS` and 1 to 500 if unit is `DISTANCE_UNIT_MILES`.",
          format = "double",
          type = "number",
        },
        proximityRadiusUnit = {
          description = "Required. The unit of distance by which the targeting radius is measured.",
          enum = {
            "DISTANCE_UNIT_UNSPECIFIED",
            "DISTANCE_UNIT_MILES",
            "DISTANCE_UNIT_KILOMETERS",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "Miles.",
            "Kilometers.",
          },
          type = "string",
        },
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_POI`. Accepted POI targeting option IDs can be retrieved using SearchTargetingOptions. If targeting a specific latitude/longitude coordinate removed from an address or POI name, you can generate the necessary targeting option ID by rounding the desired coordinate values to the 6th decimal place, removing the decimals, and concatenating the string values separated by a semicolon. For example, you can target the latitude/longitude pair of 40.7414691, -74.003387 using the targeting option ID \"40741469;-74003387\".",
          type = "string",
        },
      },
      type = "object",
    },
    PoiSearchTerms = {
      description = "Search terms for POI targeting options.",
      id = "PoiSearchTerms",
      properties = {
        poiQuery = {
          description = "The search query for the desired POI name, street address, or coordinate of the desired POI. The query can be a prefix, e.g. \"Times squar\", \"40.7505045,-73.99562\", \"315 W 44th St\", etc.",
          type = "string",
        },
      },
      type = "object",
    },
    PoiTargetingOptionDetails = {
      description = "Represents a targetable point of interest(POI). This will be populated in the poi_details field when targeting_type is `TARGETING_TYPE_POI`.",
      id = "PoiTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of a POI(e.g. \"Times Square\", \"Space Needle\"), followed by its full address if available.",
          readOnly = true,
          type = "string",
        },
        latitude = {
          description = "Output only. Latitude of the POI rounding to 6th decimal place.",
          format = "double",
          readOnly = true,
          type = "number",
        },
        longitude = {
          description = "Output only. Longitude of the POI rounding to 6th decimal place.",
          format = "double",
          readOnly = true,
          type = "number",
        },
      },
      type = "object",
    },
    PrismaConfig = {
      description = "Settings specific to the Mediaocean Prisma tool.",
      id = "PrismaConfig",
      properties = {
        prismaCpeCode = {
          ["$ref"] = "PrismaCpeCode",
          description = "Required. Relevant client, product, and estimate codes from the Mediaocean Prisma tool.",
        },
        prismaType = {
          description = "Required. The Prisma type.",
          enum = {
            "PRISMA_TYPE_UNSPECIFIED",
            "PRISMA_TYPE_DISPLAY",
            "PRISMA_TYPE_SEARCH",
            "PRISMA_TYPE_VIDEO",
            "PRISMA_TYPE_AUDIO",
            "PRISMA_TYPE_SOCIAL",
            "PRISMA_TYPE_FEE",
          },
          enumDescriptions = {
            "Type is not specified or unknown in this version.",
            "Display type.",
            "Search type.",
            "Video type.",
            "Audio type.",
            "Social type.",
            "Fee type.",
          },
          type = "string",
        },
        supplier = {
          description = "Required. The entity allocated this budget (DSP, site, etc.).",
          type = "string",
        },
      },
      type = "object",
    },
    PrismaCpeCode = {
      description = "Google Payments Center supports searching and filtering on the component fields of this code.",
      id = "PrismaCpeCode",
      properties = {
        prismaClientCode = {
          description = "The Prisma client code.",
          type = "string",
        },
        prismaEstimateCode = {
          description = "The Prisma estimate code.",
          type = "string",
        },
        prismaProductCode = {
          description = "The Prisma product code.",
          type = "string",
        },
      },
      type = "object",
    },
    ProximityLocationListAssignedTargetingOptionDetails = {
      description = "Targeting details for proximity location list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_PROXIMITY_LOCATION_LIST`.",
      id = "ProximityLocationListAssignedTargetingOptionDetails",
      properties = {
        proximityLocationListId = {
          description = "Required. ID of the proximity location list. Should refer to the location_list_id field of a LocationList resource whose type is `TARGETING_LOCATION_TYPE_PROXIMITY`.",
          format = "int64",
          type = "string",
        },
        proximityRadiusRange = {
          description = "Required. Radius range for proximity location list. This represents the size of the area around a chosen location that will be targeted. `All` proximity location targeting under a single resource must have the same radius range value. Set this value to match any existing targeting. If updated, this field will change the radius range for all proximity targeting under the resource.",
          enum = {
            "PROXIMITY_RADIUS_RANGE_UNSPECIFIED",
            "PROXIMITY_RADIUS_RANGE_SMALL",
            "PROXIMITY_RADIUS_RANGE_MEDIUM",
            "PROXIMITY_RADIUS_RANGE_LARGE",
          },
          enumDescriptions = {
            "The targeted radius range is not specified or is unknown. Default value when radius range is not specified in this version. This enum is a placeholder for default value and does not represent a real radius range option.",
            "The targeted radius range is small.",
            "The targeted radius range is medium.",
            "The targeted radius range is large.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    PublisherReviewStatus = {
      description = "Publisher review status for the creative.",
      id = "PublisherReviewStatus",
      properties = {
        publisherName = {
          description = "The publisher reviewing the creative.",
          type = "string",
        },
        status = {
          description = "Status of the publisher review.",
          enum = {
            "REVIEW_STATUS_UNSPECIFIED",
            "REVIEW_STATUS_APPROVED",
            "REVIEW_STATUS_REJECTED",
            "REVIEW_STATUS_PENDING",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The creative is approved.",
            "The creative is rejected.",
            "The creative is pending review.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    RateDetails = {
      description = "The rate related settings of the inventory source.",
      id = "RateDetails",
      properties = {
        inventorySourceRateType = {
          description = "The rate type. Acceptable values are `INVENTORY_SOURCE_RATE_TYPE_CPM_FIXED`, `INVENTORY_SOURCE_RATE_TYPE_CPM_FLOOR`, and `INVENTORY_SOURCE_RATE_TYPE_CPD`.",
          enum = {
            "INVENTORY_SOURCE_RATE_TYPE_UNSPECIFIED",
            "INVENTORY_SOURCE_RATE_TYPE_CPM_FIXED",
            "INVENTORY_SOURCE_RATE_TYPE_CPM_FLOOR",
            "INVENTORY_SOURCE_RATE_TYPE_CPD",
            "INVENTORY_SOURCE_RATE_TYPE_FLAT",
          },
          enumDescriptions = {
            "The rate type is not specified or is unknown in this version.",
            "The rate type is CPM (Fixed).",
            "The rate type is CPM (Floor).",
            "The rate type is Cost per Day.",
            "The rate type is Flat.",
          },
          type = "string",
        },
        minimumSpend = {
          ["$ref"] = "Money",
          description = "Output only. The amount that the buyer has committed to spending on the inventory source up front. Only applicable for guaranteed inventory sources.",
          readOnly = true,
        },
        rate = {
          ["$ref"] = "Money",
          description = "The rate for the inventory source.",
        },
        unitsPurchased = {
          description = "Required for guaranteed inventory sources. The number of impressions guaranteed by the seller.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    RegionalLocationListAssignedTargetingOptionDetails = {
      description = "Targeting details for regional location list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_REGIONAL_LOCATION_LIST`.",
      id = "RegionalLocationListAssignedTargetingOptionDetails",
      properties = {
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        regionalLocationListId = {
          description = "Required. ID of the regional location list. Should refer to the location_list_id field of a LocationList resource whose type is `TARGETING_LOCATION_TYPE_REGIONAL`.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ReplaceNegativeKeywordsRequest = {
      description = "Request message for NegativeKeywordService.ReplaceNegativeKeywords.",
      id = "ReplaceNegativeKeywordsRequest",
      properties = {
        newNegativeKeywords = {
          description = "The negative keywords that will replace the existing keywords in the negative keyword list, specified as a list of NegativeKeywords.",
          items = {
            ["$ref"] = "NegativeKeyword",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ReplaceNegativeKeywordsResponse = {
      description = "Response message for NegativeKeywordService.ReplaceNegativeKeywords.",
      id = "ReplaceNegativeKeywordsResponse",
      properties = {
        negativeKeywords = {
          description = "The full list of negative keywords now present in the negative keyword list.",
          items = {
            ["$ref"] = "NegativeKeyword",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ReplaceSitesRequest = {
      description = "Request message for SiteService.ReplaceSites.",
      id = "ReplaceSitesRequest",
      properties = {
        advertiserId = {
          description = "The ID of the advertiser that owns the parent channel.",
          format = "int64",
          type = "string",
        },
        newSites = {
          description = "The sites that will replace the existing sites assigned to the channel, specified as a list of Sites.",
          items = {
            ["$ref"] = "Site",
          },
          type = "array",
        },
        partnerId = {
          description = "The ID of the partner that owns the parent channel.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    ReplaceSitesResponse = {
      description = "Response message for SiteService.ReplaceSites.",
      id = "ReplaceSitesResponse",
      properties = {
        sites = {
          description = "The list of sites in the channel after replacing.",
          items = {
            ["$ref"] = "Site",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ReviewStatusInfo = {
      description = "Review statuses for the creative.",
      id = "ReviewStatusInfo",
      properties = {
        approvalStatus = {
          description = "Represents the basic approval needed for a creative to begin serving. Summary of creative_and_landing_page_review_status and content_and_policy_review_status.",
          enum = {
            "APPROVAL_STATUS_UNSPECIFIED",
            "APPROVAL_STATUS_PENDING_NOT_SERVABLE",
            "APPROVAL_STATUS_PENDING_SERVABLE",
            "APPROVAL_STATUS_APPROVED_SERVABLE",
            "APPROVAL_STATUS_REJECTED_NOT_SERVABLE",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The creative is still under review and not servable.",
            "The creative has passed creative & landing page review and is servable, but is awaiting additional content & policy review.",
            "Both creative & landing page review and content & policy review are approved. The creative is servable.",
            "There is an issue with the creative that must be fixed before it can serve.",
          },
          type = "string",
        },
        contentAndPolicyReviewStatus = {
          description = "Content and policy review status for the creative.",
          enum = {
            "REVIEW_STATUS_UNSPECIFIED",
            "REVIEW_STATUS_APPROVED",
            "REVIEW_STATUS_REJECTED",
            "REVIEW_STATUS_PENDING",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The creative is approved.",
            "The creative is rejected.",
            "The creative is pending review.",
          },
          type = "string",
        },
        creativeAndLandingPageReviewStatus = {
          description = "Creative and landing page review status for the creative.",
          enum = {
            "REVIEW_STATUS_UNSPECIFIED",
            "REVIEW_STATUS_APPROVED",
            "REVIEW_STATUS_REJECTED",
            "REVIEW_STATUS_PENDING",
          },
          enumDescriptions = {
            "Type value is not specified or is unknown in this version.",
            "The creative is approved.",
            "The creative is rejected.",
            "The creative is pending review.",
          },
          type = "string",
        },
        exchangeReviewStatuses = {
          description = "Exchange review statuses for the creative.",
          items = {
            ["$ref"] = "ExchangeReviewStatus",
          },
          type = "array",
        },
        publisherReviewStatuses = {
          description = "Publisher review statuses for the creative.",
          items = {
            ["$ref"] = "PublisherReviewStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    ScriptError = {
      description = "An error message for a custom bidding script.",
      id = "ScriptError",
      properties = {
        column = {
          description = "The column number in the script where the error was thrown.",
          format = "int64",
          type = "string",
        },
        errorCode = {
          description = "The type of error.",
          enum = {
            "ERROR_CODE_UNSPECIFIED",
            "SYNTAX_ERROR",
            "DEPRECATED_SYNTAX",
            "INTERNAL_ERROR",
          },
          enumDescriptions = {
            "The script error is not specified or is unknown in this version.",
            "The script has a syntax error.",
            "The script uses deprecated syntax.",
            "Internal errors were thrown while processing the script.",
          },
          type = "string",
        },
        errorMessage = {
          description = "The detailed error message.",
          type = "string",
        },
        line = {
          description = "The line number in the script where the error was thrown.",
          format = "int64",
          type = "string",
        },
      },
      type = "object",
    },
    SdfConfig = {
      description = "Structured Data File (SDF) related settings.",
      id = "SdfConfig",
      properties = {
        adminEmail = {
          description = "An administrator email address to which the SDF processing status reports will be sent.",
          type = "string",
        },
        version = {
          description = "Required. The version of SDF being used.",
          enum = {
            "SDF_VERSION_UNSPECIFIED",
            "SDF_VERSION_3_1",
            "SDF_VERSION_4",
            "SDF_VERSION_4_1",
            "SDF_VERSION_4_2",
            "SDF_VERSION_5",
            "SDF_VERSION_5_1",
            "SDF_VERSION_5_2",
            "SDF_VERSION_5_3",
            "SDF_VERSION_5_4",
            "SDF_VERSION_5_5",
          },
          enumDescriptions = {
            "SDF version value is not specified or is unknown in this version.",
            "SDF version 3.1",
            "SDF version 4",
            "SDF version 4.1",
            "SDF version 4.2",
            "SDF version 5.",
            "SDF version 5.1",
            "SDF version 5.2",
            "SDF version 5.3",
            "SDF version 5.4",
            "SDF version 5.5",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SdfDownloadTask = {
      description = "Type for the response returned by [SdfDownloadTaskService.CreateSdfDownloadTask].",
      id = "SdfDownloadTask",
      properties = {
        resourceName = {
          description = "A resource name to be used in media.download to Download the prepared files. Resource names have the format `download/sdfdownloadtasks/media/{media_id}`. `media_id` will be made available by the long running operation service once the task status is done.",
          type = "string",
        },
      },
      type = "object",
    },
    SdfDownloadTaskMetadata = {
      description = "Type for the metadata returned by [SdfDownloadTaskService.CreateSdfDownloadTask].",
      id = "SdfDownloadTaskMetadata",
      properties = {
        createTime = {
          description = "The time when the operation was created.",
          format = "google-datetime",
          type = "string",
        },
        endTime = {
          description = "The time when execution was completed.",
          format = "google-datetime",
          type = "string",
        },
        version = {
          description = "The SDF version used to execute this download task.",
          enum = {
            "SDF_VERSION_UNSPECIFIED",
            "SDF_VERSION_3_1",
            "SDF_VERSION_4",
            "SDF_VERSION_4_1",
            "SDF_VERSION_4_2",
            "SDF_VERSION_5",
            "SDF_VERSION_5_1",
            "SDF_VERSION_5_2",
            "SDF_VERSION_5_3",
            "SDF_VERSION_5_4",
            "SDF_VERSION_5_5",
          },
          enumDescriptions = {
            "SDF version value is not specified or is unknown in this version.",
            "SDF version 3.1",
            "SDF version 4",
            "SDF version 4.1",
            "SDF version 4.2",
            "SDF version 5.",
            "SDF version 5.1",
            "SDF version 5.2",
            "SDF version 5.3",
            "SDF version 5.4",
            "SDF version 5.5",
          },
          type = "string",
        },
      },
      type = "object",
    },
    SearchTargetingOptionsRequest = {
      description = "Request message for SearchTargetingOptions.",
      id = "SearchTargetingOptionsRequest",
      properties = {
        advertiserId = {
          description = "Required. The Advertiser this request is being made in the context of.",
          format = "int64",
          type = "string",
        },
        businessChainSearchTerms = {
          ["$ref"] = "BusinessChainSearchTerms",
          description = "Search terms for Business Chain targeting options. Can only be used when targeting_type is `TARGETING_TYPE_BUSINESS_CHAIN`.",
        },
        geoRegionSearchTerms = {
          ["$ref"] = "GeoRegionSearchTerms",
          description = "Search terms for geo region targeting options. Can only be used when targeting_type is `TARGETING_TYPE_GEO_REGION`.",
        },
        pageSize = {
          description = "Requested page size. Must be between `1` and `200`. If unspecified will default to `100`. Returns error code `INVALID_ARGUMENT` if an invalid value is specified.",
          format = "int32",
          type = "integer",
        },
        pageToken = {
          description = "A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to `SearchTargetingOptions` method. If not specified, the first page of results will be returned.",
          type = "string",
        },
        poiSearchTerms = {
          ["$ref"] = "PoiSearchTerms",
          description = "Search terms for POI targeting options. Can only be used when targeting_type is `TARGETING_TYPE_POI`.",
        },
      },
      type = "object",
    },
    SearchTargetingOptionsResponse = {
      description = "Response message for SearchTargetingOptions.",
      id = "SearchTargetingOptionsResponse",
      properties = {
        nextPageToken = {
          description = "A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to `SearchTargetingOptions` method to retrieve the next page of results.",
          type = "string",
        },
        targetingOptions = {
          description = "The list of targeting options that match the search criteria. This list will be absent if empty.",
          items = {
            ["$ref"] = "TargetingOption",
          },
          type = "array",
        },
      },
      type = "object",
    },
    SensitiveCategoryAssignedTargetingOptionDetails = {
      description = "Targeting details for sensitive category. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`.",
      id = "SensitiveCategoryAssignedTargetingOptionDetails",
      properties = {
        excludedTargetingOptionId = {
          description = "Required. ID of the sensitive category to be EXCLUDED.",
          type = "string",
        },
        sensitiveCategory = {
          description = "Output only. An enum for the DV360 Sensitive category content classifier.",
          enum = {
            "SENSITIVE_CATEGORY_UNSPECIFIED",
            "SENSITIVE_CATEGORY_ADULT",
            "SENSITIVE_CATEGORY_DEROGATORY",
            "SENSITIVE_CATEGORY_DOWNLOADS_SHARING",
            "SENSITIVE_CATEGORY_WEAPONS",
            "SENSITIVE_CATEGORY_GAMBLING",
            "SENSITIVE_CATEGORY_VIOLENCE",
            "SENSITIVE_CATEGORY_SUGGESTIVE",
            "SENSITIVE_CATEGORY_PROFANITY",
            "SENSITIVE_CATEGORY_ALCOHOL",
            "SENSITIVE_CATEGORY_DRUGS",
            "SENSITIVE_CATEGORY_TOBACCO",
            "SENSITIVE_CATEGORY_POLITICS",
            "SENSITIVE_CATEGORY_RELIGION",
            "SENSITIVE_CATEGORY_TRAGEDY",
            "SENSITIVE_CATEGORY_TRANSPORTATION_ACCIDENTS",
            "SENSITIVE_CATEGORY_SENSITIVE_SOCIAL_ISSUES",
            "SENSITIVE_CATEGORY_SHOCKING",
          },
          enumDescriptions = {
            "This enum is only a placeholder and doesn't specify a DV360 sensitive category.",
            "Adult or pornographic text, image, or video content.",
            "Content that may be construed as biased against individuals, groups, or organizations based on criteria such as race, religion, disability, sex, age, veteran status, sexual orientation, gender identity, or political affiliation. May also indicate discussion of such content, for instance, in an academic or journalistic context.",
            "Content related to audio, video, or software downloads.",
            "Contains content related to personal weapons, including knives, guns, small firearms, and ammunition. Selecting either \"weapons\" or \"sensitive social issues\" will result in selecting both.",
            "Contains content related to betting or wagering in a real-world or online setting.",
            "Content which may be considered graphically violent, gory, gruesome, or shocking, such as street fighting videos, accident photos, descriptions of torture, etc.",
            "Adult content, as well as suggestive content that's not explicitly pornographic. This category includes all pages categorized as adult.",
            "Prominent use of words considered indecent, such as curse words and sexual slang. Pages with only very occasional usage, such as news sites that might include such words in a quotation, are not included.",
            "Contains content related to alcoholic beverages, alcohol brands, recipes, etc.",
            "Contains content related to the recreational use of legal or illegal drugs, as well as to drug paraphernalia or cultivation.",
            "Contains content related to tobacco and tobacco accessories, including lighters, humidors, ashtrays, etc.",
            "Political news and media, including discussions of social, governmental, and public policy.",
            "Content related to religious thought or beliefs.",
            "Content related to death, disasters, accidents, war, etc.",
            "Content related to motor vehicle, aviation or other transportation accidents.",
            "Issues that evoke strong, opposing views and spark debate. These include issues that are controversial in most countries and markets (such as abortion), as well as those that are controversial in specific countries and markets (such as immigration reform in the United States).",
            "Content which may be considered shocking or disturbing, such as violent news stories, stunts, or toilet humor.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    SensitiveCategoryTargetingOptionDetails = {
      description = "Represents a targetable sensitive category. This will be populated in the sensitive_category_details field of the TargetingOption when targeting_type is `TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION`.",
      id = "SensitiveCategoryTargetingOptionDetails",
      properties = {
        sensitiveCategory = {
          description = "Output only. An enum for the DV360 Sensitive category content classifier.",
          enum = {
            "SENSITIVE_CATEGORY_UNSPECIFIED",
            "SENSITIVE_CATEGORY_ADULT",
            "SENSITIVE_CATEGORY_DEROGATORY",
            "SENSITIVE_CATEGORY_DOWNLOADS_SHARING",
            "SENSITIVE_CATEGORY_WEAPONS",
            "SENSITIVE_CATEGORY_GAMBLING",
            "SENSITIVE_CATEGORY_VIOLENCE",
            "SENSITIVE_CATEGORY_SUGGESTIVE",
            "SENSITIVE_CATEGORY_PROFANITY",
            "SENSITIVE_CATEGORY_ALCOHOL",
            "SENSITIVE_CATEGORY_DRUGS",
            "SENSITIVE_CATEGORY_TOBACCO",
            "SENSITIVE_CATEGORY_POLITICS",
            "SENSITIVE_CATEGORY_RELIGION",
            "SENSITIVE_CATEGORY_TRAGEDY",
            "SENSITIVE_CATEGORY_TRANSPORTATION_ACCIDENTS",
            "SENSITIVE_CATEGORY_SENSITIVE_SOCIAL_ISSUES",
            "SENSITIVE_CATEGORY_SHOCKING",
          },
          enumDescriptions = {
            "This enum is only a placeholder and doesn't specify a DV360 sensitive category.",
            "Adult or pornographic text, image, or video content.",
            "Content that may be construed as biased against individuals, groups, or organizations based on criteria such as race, religion, disability, sex, age, veteran status, sexual orientation, gender identity, or political affiliation. May also indicate discussion of such content, for instance, in an academic or journalistic context.",
            "Content related to audio, video, or software downloads.",
            "Contains content related to personal weapons, including knives, guns, small firearms, and ammunition. Selecting either \"weapons\" or \"sensitive social issues\" will result in selecting both.",
            "Contains content related to betting or wagering in a real-world or online setting.",
            "Content which may be considered graphically violent, gory, gruesome, or shocking, such as street fighting videos, accident photos, descriptions of torture, etc.",
            "Adult content, as well as suggestive content that's not explicitly pornographic. This category includes all pages categorized as adult.",
            "Prominent use of words considered indecent, such as curse words and sexual slang. Pages with only very occasional usage, such as news sites that might include such words in a quotation, are not included.",
            "Contains content related to alcoholic beverages, alcohol brands, recipes, etc.",
            "Contains content related to the recreational use of legal or illegal drugs, as well as to drug paraphernalia or cultivation.",
            "Contains content related to tobacco and tobacco accessories, including lighters, humidors, ashtrays, etc.",
            "Political news and media, including discussions of social, governmental, and public policy.",
            "Content related to religious thought or beliefs.",
            "Content related to death, disasters, accidents, war, etc.",
            "Content related to motor vehicle, aviation or other transportation accidents.",
            "Issues that evoke strong, opposing views and spark debate. These include issues that are controversial in most countries and markets (such as abortion), as well as those that are controversial in specific countries and markets (such as immigration reform in the United States).",
            "Content which may be considered shocking or disturbing, such as violent news stories, stunts, or toilet humor.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    Site = {
      description = "A single site. Sites are apps or websites belonging to a channel.",
      id = "Site",
      properties = {
        name = {
          description = "Output only. The resource name of the site.",
          readOnly = true,
          type = "string",
        },
        urlOrAppId = {
          description = "Required. The app ID or URL of the site. Must be UTF-8 encoded with a maximum length of 240 bytes.",
          type = "string",
        },
      },
      type = "object",
    },
    Status = {
      description = "The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).",
      id = "Status",
      properties = {
        code = {
          description = "The status code, which should be an enum value of google.rpc.Code.",
          format = "int32",
          type = "integer",
        },
        details = {
          description = "A list of messages that carry the error details. There is a common set of message types for APIs to use.",
          items = {
            additionalProperties = {
              description = "Properties of the object. Contains field @type with type URL.",
              type = "any",
            },
            type = "object",
          },
          type = "array",
        },
        message = {
          description = "A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client.",
          type = "string",
        },
      },
      type = "object",
    },
    SubExchangeAssignedTargetingOptionDetails = {
      description = "Details for assigned sub-exchange targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_SUB_EXCHANGE`.",
      id = "SubExchangeAssignedTargetingOptionDetails",
      properties = {
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_SUB_EXCHANGE`.",
          type = "string",
        },
      },
      type = "object",
    },
    SubExchangeTargetingOptionDetails = {
      description = "Represents a targetable sub-exchange. This will be populated in the sub_exchange_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_SUB_EXCHANGE`.",
      id = "SubExchangeTargetingOptionDetails",
      properties = {
        displayName = {
          description = "Output only. The display name of the sub-exchange.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    TargetingExpansionConfig = {
      description = "Settings that control the targeting expansion of the line item. Targeting expansion allows the line item to reach a larger audience based on the original audience list and the targeting expansion level. Beginning November 7, 2022, these settings may represent the [optimized targeting feature](//support.google.com/displayvideo/answer/12060859) in place of targeting expansion. This feature will be rolled out to all partners by November 9, 2022.",
      id = "TargetingExpansionConfig",
      properties = {
        excludeFirstPartyAudience = {
          description = "Required. Whether to exclude first-party audiences from use in targeting expansion or optimized targeting. Similar audiences of the excluded first-party lists will not be excluded. Only applicable when a first-party audience is positively targeted (directly or included in a combined audience), otherwise this selection will be ignored.",
          type = "boolean",
        },
        targetingExpansionLevel = {
          description = "Required. Magnitude of expansion for applicable targeting under this line item. Beginning November 7, 2022, the behavior of this field will change in the following ways with the replacement of targeting expansion with [optimized targeting](//support.google.com/displayvideo/answer/12060859): * This field will represent the optimized targeting checkbox, with a `NO_EXPANSION` value representing optimized targeting turned off and a `LEAST_EXPANSION` value representing optimized targeting turned on. * `NO_EXPANSION` will be the default value for the field and will be automatically assigned if you do not set the field. * If you set the field to any value other than `NO_EXPANSION`, it will automatically be set to `LEAST_EXPANSION`.",
          enum = {
            "TARGETING_EXPANSION_LEVEL_UNSPECIFIED",
            "NO_EXPANSION",
            "LEAST_EXPANSION",
            "SOME_EXPANSION",
            "BALANCED_EXPANSION",
            "MORE_EXPANSION",
            "MOST_EXPANSION",
          },
          enumDescriptions = {
            "Targeting expansion level is not specified or is unknown in this version.",
            "Targeting expansion off.",
            "Conservative targeting expansion, lowest reach.",
            "Moderately conservative targeting expansion, lower reach.",
            "Moderate targeting expansion, medium reach.",
            "Moderately aggressive targeting expansion, higher reach.",
            "Aggressive targeting expansion, highest reach.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    TargetingOption = {
      description = "Represents a single targeting option, which is a targetable concept in DV360.",
      id = "TargetingOption",
      properties = {
        ageRangeDetails = {
          ["$ref"] = "AgeRangeTargetingOptionDetails",
          description = "Age range details.",
        },
        appCategoryDetails = {
          ["$ref"] = "AppCategoryTargetingOptionDetails",
          description = "App category details.",
        },
        audioContentTypeDetails = {
          ["$ref"] = "AudioContentTypeTargetingOptionDetails",
          description = "Audio content type details.",
        },
        authorizedSellerStatusDetails = {
          ["$ref"] = "AuthorizedSellerStatusTargetingOptionDetails",
          description = "Authorized seller status resource details.",
        },
        browserDetails = {
          ["$ref"] = "BrowserTargetingOptionDetails",
          description = "Browser details.",
        },
        businessChainDetails = {
          ["$ref"] = "BusinessChainTargetingOptionDetails",
          description = "Business chain resource details.",
        },
        carrierAndIspDetails = {
          ["$ref"] = "CarrierAndIspTargetingOptionDetails",
          description = "Carrier and ISP details.",
        },
        categoryDetails = {
          ["$ref"] = "CategoryTargetingOptionDetails",
          description = "Category resource details.",
        },
        contentDurationDetails = {
          ["$ref"] = "ContentDurationTargetingOptionDetails",
          description = "Content duration resource details.",
        },
        contentGenreDetails = {
          ["$ref"] = "ContentGenreTargetingOptionDetails",
          description = "Content genre resource details.",
        },
        contentInstreamPositionDetails = {
          ["$ref"] = "ContentInstreamPositionTargetingOptionDetails",
          description = "Content instream position details.",
        },
        contentOutstreamPositionDetails = {
          ["$ref"] = "ContentOutstreamPositionTargetingOptionDetails",
          description = "Content outstream position details.",
        },
        contentStreamTypeDetails = {
          ["$ref"] = "ContentStreamTypeTargetingOptionDetails",
          description = "Content stream type resource details.",
        },
        deviceMakeModelDetails = {
          ["$ref"] = "DeviceMakeModelTargetingOptionDetails",
          description = "Device make and model resource details.",
        },
        deviceTypeDetails = {
          ["$ref"] = "DeviceTypeTargetingOptionDetails",
          description = "Device type details.",
        },
        digitalContentLabelDetails = {
          ["$ref"] = "DigitalContentLabelTargetingOptionDetails",
          description = "Digital content label details.",
        },
        environmentDetails = {
          ["$ref"] = "EnvironmentTargetingOptionDetails",
          description = "Environment details.",
        },
        exchangeDetails = {
          ["$ref"] = "ExchangeTargetingOptionDetails",
          description = "Exchange details.",
        },
        genderDetails = {
          ["$ref"] = "GenderTargetingOptionDetails",
          description = "Gender details.",
        },
        geoRegionDetails = {
          ["$ref"] = "GeoRegionTargetingOptionDetails",
          description = "Geographic region resource details.",
        },
        householdIncomeDetails = {
          ["$ref"] = "HouseholdIncomeTargetingOptionDetails",
          description = "Household income details.",
        },
        languageDetails = {
          ["$ref"] = "LanguageTargetingOptionDetails",
          description = "Language resource details.",
        },
        name = {
          description = "Output only. The resource name for this targeting option.",
          readOnly = true,
          type = "string",
        },
        nativeContentPositionDetails = {
          ["$ref"] = "NativeContentPositionTargetingOptionDetails",
          description = "Native content position details.",
        },
        omidDetails = {
          ["$ref"] = "OmidTargetingOptionDetails",
          description = "Open Measurement enabled inventory details.",
        },
        onScreenPositionDetails = {
          ["$ref"] = "OnScreenPositionTargetingOptionDetails",
          description = "On screen position details.",
        },
        operatingSystemDetails = {
          ["$ref"] = "OperatingSystemTargetingOptionDetails",
          description = "Operating system resources details.",
        },
        parentalStatusDetails = {
          ["$ref"] = "ParentalStatusTargetingOptionDetails",
          description = "Parental status details.",
        },
        poiDetails = {
          ["$ref"] = "PoiTargetingOptionDetails",
          description = "POI resource details.",
        },
        sensitiveCategoryDetails = {
          ["$ref"] = "SensitiveCategoryTargetingOptionDetails",
          description = "Sensitive Category details.",
        },
        subExchangeDetails = {
          ["$ref"] = "SubExchangeTargetingOptionDetails",
          description = "Sub-exchange details.",
        },
        targetingOptionId = {
          description = "Output only. A unique identifier for this targeting option. The tuple {`targeting_type`, `targeting_option_id`} will be unique.",
          readOnly = true,
          type = "string",
        },
        targetingType = {
          description = "Output only. The type of this targeting option.",
          enum = {
            "TARGETING_TYPE_UNSPECIFIED",
            "TARGETING_TYPE_CHANNEL",
            "TARGETING_TYPE_APP_CATEGORY",
            "TARGETING_TYPE_APP",
            "TARGETING_TYPE_URL",
            "TARGETING_TYPE_DAY_AND_TIME",
            "TARGETING_TYPE_AGE_RANGE",
            "TARGETING_TYPE_REGIONAL_LOCATION_LIST",
            "TARGETING_TYPE_PROXIMITY_LOCATION_LIST",
            "TARGETING_TYPE_GENDER",
            "TARGETING_TYPE_VIDEO_PLAYER_SIZE",
            "TARGETING_TYPE_USER_REWARDED_CONTENT",
            "TARGETING_TYPE_PARENTAL_STATUS",
            "TARGETING_TYPE_CONTENT_INSTREAM_POSITION",
            "TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION",
            "TARGETING_TYPE_DEVICE_TYPE",
            "TARGETING_TYPE_AUDIENCE_GROUP",
            "TARGETING_TYPE_BROWSER",
            "TARGETING_TYPE_HOUSEHOLD_INCOME",
            "TARGETING_TYPE_ON_SCREEN_POSITION",
            "TARGETING_TYPE_THIRD_PARTY_VERIFIER",
            "TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION",
            "TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION",
            "TARGETING_TYPE_ENVIRONMENT",
            "TARGETING_TYPE_CARRIER_AND_ISP",
            "TARGETING_TYPE_OPERATING_SYSTEM",
            "TARGETING_TYPE_DEVICE_MAKE_MODEL",
            "TARGETING_TYPE_KEYWORD",
            "TARGETING_TYPE_NEGATIVE_KEYWORD_LIST",
            "TARGETING_TYPE_VIEWABILITY",
            "TARGETING_TYPE_CATEGORY",
            "TARGETING_TYPE_INVENTORY_SOURCE",
            "TARGETING_TYPE_LANGUAGE",
            "TARGETING_TYPE_AUTHORIZED_SELLER_STATUS",
            "TARGETING_TYPE_GEO_REGION",
            "TARGETING_TYPE_INVENTORY_SOURCE_GROUP",
            "TARGETING_TYPE_EXCHANGE",
            "TARGETING_TYPE_SUB_EXCHANGE",
            "TARGETING_TYPE_POI",
            "TARGETING_TYPE_BUSINESS_CHAIN",
            "TARGETING_TYPE_CONTENT_DURATION",
            "TARGETING_TYPE_CONTENT_STREAM_TYPE",
            "TARGETING_TYPE_NATIVE_CONTENT_POSITION",
            "TARGETING_TYPE_OMID",
            "TARGETING_TYPE_AUDIO_CONTENT_TYPE",
            "TARGETING_TYPE_CONTENT_GENRE",
          },
          enumDescriptions = {
            "Default value when type is not specified or is unknown in this version.",
            "Target a channel (a custom group of related websites or apps).",
            "Target an app category (for example, education or puzzle games).",
            "Target a specific app (for example, Angry Birds).",
            "Target a specific url (for example, quora.com).",
            "Target ads during a chosen time period on a specific day.",
            "Target ads to a specific age range (for example, 18-24).",
            "Target ads to the specified regions on a regional location list.",
            "Target ads to the specified points of interest on a proximity location list.",
            "Target ads to a specific gender (for example, female or male).",
            "Target a specific video player size for video ads.",
            "Target user rewarded content for video ads.",
            "Target ads to a specific parental status (for example, parent or not a parent).",
            "Target video or audio ads in a specific content instream position (for example, pre-roll, mid-roll, or post-roll).",
            "Target ads in a specific content outstream position.",
            "Target ads to a specific device type (for example, tablet or connected TV).",
            "Target ads to an audience or groups of audiences. Singleton field, at most one can exist on a single Lineitem at a time.",
            "Target ads to specific web browsers (for example, Chrome).",
            "Target ads to a specific household income range (for example, top 10%).",
            "Target ads in a specific on screen position.",
            "Filter web sites through third party verification (for example, IAS or DoubleVerify).",
            "Filter web sites by specific digital content label ratings (for example, DL-MA: suitable only for mature audiences).",
            "Filter website content by sensitive categories (for example, adult).",
            "Target ads to a specific environment (for example, web or app).",
            "Target ads to a specific network carrier or internet service provider (ISP) (for example, Comcast or Orange).",
            "Target ads to a specific operating system (for example, macOS).",
            "Target ads to a specific device make or model (for example, Roku or Samsung).",
            "Target ads to a specific keyword (for example, dog or retriever).",
            "Target ads to a specific negative keyword list.",
            "Target ads to a specific viewability (for example, 80% viewable).",
            "Target ads to a specific content category (for example, arts & entertainment).",
            "Purchase impressions from specific deals and auction packages.",
            "Target ads to a specific language (for example, English or Japanese).",
            "Target ads to ads.txt authorized sellers.",
            "Target ads to a specific regional location (for example, a city or state).",
            "Purchase impressions from a group of deals and auction packages.",
            "Purchase impressions from specific exchanges.",
            "Purchase impressions from specific sub-exchanges.",
            "Target ads around a specific point of interest, such as a notable building, a street address, or latitude/longitude coordinates.",
            "Target ads around locations of a business chain within a specific geo region.",
            "Target ads to a specific video content duration.",
            "Target ads to a specific video content stream type.",
            "Target ads to a specific native content position.",
            "Target ads in an Open Measurement enabled inventory.",
            "Target ads to a specific audio content type.",
            "Target ads to a specific content genre.",
          },
          readOnly = true,
          type = "string",
        },
        userRewardedContentDetails = {
          ["$ref"] = "UserRewardedContentTargetingOptionDetails",
          description = "User rewarded content details.",
        },
        videoPlayerSizeDetails = {
          ["$ref"] = "VideoPlayerSizeTargetingOptionDetails",
          description = "Video player size details.",
        },
        viewabilityDetails = {
          ["$ref"] = "ViewabilityTargetingOptionDetails",
          description = "Viewability resource details.",
        },
      },
      type = "object",
    },
    ThirdPartyOnlyConfig = {
      description = "Settings for advertisers that use third-party ad servers only.",
      id = "ThirdPartyOnlyConfig",
      properties = {
        pixelOrderIdReportingEnabled = {
          description = "Whether or not order ID reporting for pixels is enabled. This value cannot be changed once set to `true`.",
          type = "boolean",
        },
      },
      type = "object",
    },
    ThirdPartyUrl = {
      description = "Tracking URLs from third parties to track interactions with an audio or a video creative.",
      id = "ThirdPartyUrl",
      properties = {
        type = {
          description = "The type of interaction needs to be tracked by the tracking URL",
          enum = {
            "THIRD_PARTY_URL_TYPE_UNSPECIFIED",
            "THIRD_PARTY_URL_TYPE_IMPRESSION",
            "THIRD_PARTY_URL_TYPE_CLICK_TRACKING",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_START",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_FIRST_QUARTILE",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_MIDPOINT",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_THIRD_QUARTILE",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_COMPLETE",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_MUTE",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_PAUSE",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_REWIND",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_FULLSCREEN",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_STOP",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_CUSTOM",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_SKIP",
            "THIRD_PARTY_URL_TYPE_AUDIO_VIDEO_PROGRESS",
          },
          enumDescriptions = {
            "The type of third-party URL is unspecified or is unknown in this version.",
            "Used to count impressions of the creative after the audio or video buffering is complete.",
            "Used to track user clicks on the audio or video.",
            "Used to track the number of times a user starts the audio or video.",
            "Used to track the number of times the audio or video plays to 25% of its length.",
            "Used to track the number of times the audio or video plays to 50% of its length.",
            "Used to track the number of times the audio or video plays to 75% of its length.",
            "Used to track the number of times the audio or video plays to the end.",
            "Used to track the number of times a user mutes the audio or video.",
            "Used to track the number of times a user pauses the audio or video.",
            "Used to track the number of times a user replays the audio or video.",
            "Used to track the number of times a user expands the player to full-screen size.",
            "Used to track the number of times a user stops the audio or video.",
            "Used to track the number of times a user performs a custom click, such as clicking on a video hot spot.",
            "Used to track the number of times the audio or video was skipped.",
            "Used to track the number of times the audio or video plays to an offset determined by the progress_offset.",
          },
          type = "string",
        },
        url = {
          description = "Tracking URL used to track the interaction. Provide a URL with optional path or query string, beginning with `https:`. For example, https://www.example.com/path",
          type = "string",
        },
      },
      type = "object",
    },
    ThirdPartyVerifierAssignedTargetingOptionDetails = {
      description = "Assigned third party verifier targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_THIRD_PARTY_VERIFIER`.",
      id = "ThirdPartyVerifierAssignedTargetingOptionDetails",
      properties = {
        adloox = {
          ["$ref"] = "Adloox",
          description = "Third party brand verifier -- Adloox.",
        },
        doubleVerify = {
          ["$ref"] = "DoubleVerify",
          description = "Third party brand verifier -- DoubleVerify.",
        },
        integralAdScience = {
          ["$ref"] = "IntegralAdScience",
          description = "Third party brand verifier -- Integral Ad Science.",
        },
      },
      type = "object",
    },
    TimeRange = {
      description = "A time range.",
      id = "TimeRange",
      properties = {
        endTime = {
          description = "Required. The upper bound of a time range, inclusive.",
          format = "google-datetime",
          type = "string",
        },
        startTime = {
          description = "Required. The lower bound of a time range, inclusive.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    TimerEvent = {
      description = "Timer event of the creative.",
      id = "TimerEvent",
      properties = {
        name = {
          description = "Required. The name of the timer event.",
          type = "string",
        },
        reportingName = {
          description = "Required. The name used to identify this timer event in reports.",
          type = "string",
        },
      },
      type = "object",
    },
    TrackingFloodlightActivityConfig = {
      description = "Settings that control the behavior of a single Floodlight activity config.",
      id = "TrackingFloodlightActivityConfig",
      properties = {
        floodlightActivityId = {
          description = "Required. The ID of the Floodlight activity.",
          format = "int64",
          type = "string",
        },
        postClickLookbackWindowDays = {
          description = "Required. The number of days after an ad has been clicked in which a conversion may be counted. Must be between 0 and 90 inclusive.",
          format = "int32",
          type = "integer",
        },
        postViewLookbackWindowDays = {
          description = "Required. The number of days after an ad has been viewed in which a conversion may be counted. Must be between 0 and 90 inclusive.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    Transcode = {
      description = "Represents information about the transcoded audio or video file.",
      id = "Transcode",
      properties = {
        audioBitRateKbps = {
          description = "The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second.",
          format = "int64",
          type = "string",
        },
        audioSampleRateHz = {
          description = "The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz.",
          format = "int64",
          type = "string",
        },
        bitRateKbps = {
          description = "The transcoding bit rate of the transcoded video, in kilobits per second.",
          format = "int64",
          type = "string",
        },
        dimensions = {
          ["$ref"] = "Dimensions",
          description = "The dimensions of the transcoded video.",
        },
        fileSizeBytes = {
          description = "The size of the transcoded file, in bytes.",
          format = "int64",
          type = "string",
        },
        frameRate = {
          description = "The frame rate of the transcoded video, in frames per second.",
          format = "float",
          type = "number",
        },
        mimeType = {
          description = "The MIME type of the transcoded file.",
          type = "string",
        },
        name = {
          description = "The name of the transcoded file.",
          type = "string",
        },
        transcoded = {
          description = "Indicates if the transcoding was successful.",
          type = "boolean",
        },
      },
      type = "object",
    },
    UniversalAdId = {
      description = "A creative identifier provided by a registry that is unique across all platforms. This is part of the VAST 4.0 standard.",
      id = "UniversalAdId",
      properties = {
        id = {
          description = "The unique creative identifier.",
          type = "string",
        },
        registry = {
          description = "The registry provides unique creative identifiers.",
          enum = {
            "UNIVERSAL_AD_REGISTRY_UNSPECIFIED",
            "UNIVERSAL_AD_REGISTRY_OTHER",
            "UNIVERSAL_AD_REGISTRY_AD_ID",
            "UNIVERSAL_AD_REGISTRY_CLEARCAST",
            "UNIVERSAL_AD_REGISTRY_DV360",
            "UNIVERSAL_AD_REGISTRY_CM",
          },
          enumDescriptions = {
            "The Universal Ad registry is unspecified or is unknown in this version.",
            "Use a custom provider to provide the Universal Ad ID.",
            "Use Ad-ID to provide the Universal Ad ID.",
            "Use clearcast.co.uk to provide the Universal Ad ID.",
            "Use Display & Video 360 to provide the Universal Ad ID.",
            "Use Campaign Manager 360 to provide the Universal Ad ID.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    UrlAssignedTargetingOptionDetails = {
      description = "Details for assigned URL targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_URL`.",
      id = "UrlAssignedTargetingOptionDetails",
      properties = {
        negative = {
          description = "Indicates if this option is being negatively targeted.",
          type = "boolean",
        },
        url = {
          description = "Required. The URL, for example `example.com`. DV360 supports two levels of subdirectory targeting, for example `www.example.com/one-subdirectory-level/second-level`, and five levels of subdomain targeting, for example `five.four.three.two.one.example.com`.",
          type = "string",
        },
      },
      type = "object",
    },
    User = {
      description = "A single user in Display & Video 360.",
      id = "User",
      properties = {
        assignedUserRoles = {
          description = "The assigned user roles. Required in CreateUser. Output only in UpdateUser. Can only be updated through BulkEditAssignedUserRoles.",
          items = {
            ["$ref"] = "AssignedUserRole",
          },
          type = "array",
        },
        displayName = {
          description = "Required. The display name of the user. Must be UTF-8 encoded with a maximum size of 240 bytes.",
          type = "string",
        },
        email = {
          description = "Required. Immutable. The email address used to identify the user.",
          type = "string",
        },
        name = {
          description = "Output only. The resource name of the user.",
          readOnly = true,
          type = "string",
        },
        userId = {
          description = "Output only. The unique ID of the user. Assigned by the system.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    UserRewardedContentAssignedTargetingOptionDetails = {
      description = "User rewarded content targeting option details. This will be populated in the user_rewarded_content_details field when targeting_type is `TARGETING_TYPE_USER_REWARDED_CONTENT`.",
      id = "UserRewardedContentAssignedTargetingOptionDetails",
      properties = {
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_USER_REWARDED_CONTENT`.",
          type = "string",
        },
        userRewardedContent = {
          description = "Output only. User rewarded content status for video ads.",
          enum = {
            "USER_REWARDED_CONTENT_UNSPECIFIED",
            "USER_REWARDED_CONTENT_USER_REWARDED",
            "USER_REWARDED_CONTENT_NOT_USER_REWARDED",
          },
          enumDescriptions = {
            "User rewarded content is not specified or is unknown in this version.",
            "Represents ads where the user will see a reward after viewing.",
            "Represents all other ads besides user-rewarded.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    UserRewardedContentTargetingOptionDetails = {
      description = "Represents a targetable user rewarded content status for video ads only. This will be populated in the user_rewarded_content_details field when targeting_type is `TARGETING_TYPE_USER_REWARDED_CONTENT`.",
      id = "UserRewardedContentTargetingOptionDetails",
      properties = {
        userRewardedContent = {
          description = "Output only. User rewarded content status for video ads.",
          enum = {
            "USER_REWARDED_CONTENT_UNSPECIFIED",
            "USER_REWARDED_CONTENT_USER_REWARDED",
            "USER_REWARDED_CONTENT_NOT_USER_REWARDED",
          },
          enumDescriptions = {
            "User rewarded content is not specified or is unknown in this version.",
            "Represents ads where the user will see a reward after viewing.",
            "Represents all other ads besides user-rewarded.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    VideoPlayerSizeAssignedTargetingOptionDetails = {
      description = "Video player size targeting option details. This will be populated in the video_player_size_details field when targeting_type is `TARGETING_TYPE_VIDEO_PLAYER_SIZE`. Explicitly targeting all options is not supported. Remove all video player size targeting options to achieve this effect.",
      id = "VideoPlayerSizeAssignedTargetingOptionDetails",
      properties = {
        targetingOptionId = {
          description = "Required. The targeting_option_id field when targeting_type is `TARGETING_TYPE_VIDEO_PLAYER_SIZE`.",
          type = "string",
        },
        videoPlayerSize = {
          description = "The video player size. Output only in v1. Required in v2.",
          enum = {
            "VIDEO_PLAYER_SIZE_UNSPECIFIED",
            "VIDEO_PLAYER_SIZE_SMALL",
            "VIDEO_PLAYER_SIZE_LARGE",
            "VIDEO_PLAYER_SIZE_HD",
            "VIDEO_PLAYER_SIZE_UNKNOWN",
          },
          enumDescriptions = {
            "Video player size is not specified in this version. This enum is a place holder for a default value and does not represent a real video player size.",
            "The dimensions of the video player are less than 400×300 (desktop), or up to 20% of screen covered (mobile).",
            "The dimensions of the video player are between 400x300 and 1280x720 pixels (desktop), or 20% to 90% of the screen covered (mobile).",
            "The dimensions of the video player are 1280×720 or greater (desktop), or over 90% of the screen covered (mobile).",
            "The dimensions of the video player are unknown.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    VideoPlayerSizeTargetingOptionDetails = {
      description = "Represents a targetable video player size. This will be populated in the video_player_size_details field when targeting_type is `TARGETING_TYPE_VIDEO_PLAYER_SIZE`.",
      id = "VideoPlayerSizeTargetingOptionDetails",
      properties = {
        videoPlayerSize = {
          description = "Output only. The video player size.",
          enum = {
            "VIDEO_PLAYER_SIZE_UNSPECIFIED",
            "VIDEO_PLAYER_SIZE_SMALL",
            "VIDEO_PLAYER_SIZE_LARGE",
            "VIDEO_PLAYER_SIZE_HD",
            "VIDEO_PLAYER_SIZE_UNKNOWN",
          },
          enumDescriptions = {
            "Video player size is not specified in this version. This enum is a place holder for a default value and does not represent a real video player size.",
            "The dimensions of the video player are less than 400×300 (desktop), or up to 20% of screen covered (mobile).",
            "The dimensions of the video player are between 400x300 and 1280x720 pixels (desktop), or 20% to 90% of the screen covered (mobile).",
            "The dimensions of the video player are 1280×720 or greater (desktop), or over 90% of the screen covered (mobile).",
            "The dimensions of the video player are unknown.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    ViewabilityAssignedTargetingOptionDetails = {
      description = "Assigned viewability targeting option details. This will be populated in the viewability_details field of an AssignedTargetingOption when targeting_type is `TARGETING_TYPE_VIEWABILITY`.",
      id = "ViewabilityAssignedTargetingOptionDetails",
      properties = {
        targetingOptionId = {
          description = "Required. The targeting_option_id of a TargetingOption of type `TARGETING_TYPE_VIEWABILITY` (e.g., \"509010\" for targeting the `VIEWABILITY_10_PERCENT_OR_MORE` option).",
          type = "string",
        },
        viewability = {
          description = "The predicted viewability percentage. Output only in v1. Required in v2.",
          enum = {
            "VIEWABILITY_UNSPECIFIED",
            "VIEWABILITY_10_PERCENT_OR_MORE",
            "VIEWABILITY_20_PERCENT_OR_MORE",
            "VIEWABILITY_30_PERCENT_OR_MORE",
            "VIEWABILITY_40_PERCENT_OR_MORE",
            "VIEWABILITY_50_PERCENT_OR_MORE",
            "VIEWABILITY_60_PERCENT_OR_MORE",
            "VIEWABILITY_70_PERCENT_OR_MORE",
            "VIEWABILITY_80_PERCENT_OR_MORE",
            "VIEWABILITY_90_PERCENT_OR_MORE",
          },
          enumDescriptions = {
            "Default value when viewability is not specified in this version. This enum is a placeholder for default value and does not represent a real viewability option.",
            "Bid only on impressions that are at least 10% likely to be viewable.",
            "Bid only on impressions that are at least 20% likely to be viewable.",
            "Bid only on impressions that are at least 30% likely to be viewable.",
            "Bid only on impressions that are at least 40% likely to be viewable.",
            "Bid only on impressions that are at least 50% likely to be viewable.",
            "Bid only on impressions that are at least 60% likely to be viewable.",
            "Bid only on impressions that are at least 70% likely to be viewable.",
            "Bid only on impressions that are at least 80% likely to be viewable.",
            "Bid only on impressions that are at least 90% likely to be viewable.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    ViewabilityTargetingOptionDetails = {
      description = "Represents a targetable viewability. This will be populated in the viewability_details field of a TargetingOption when targeting_type is `TARGETING_TYPE_VIEWABILITY`.",
      id = "ViewabilityTargetingOptionDetails",
      properties = {
        viewability = {
          description = "Output only. The predicted viewability percentage.",
          enum = {
            "VIEWABILITY_UNSPECIFIED",
            "VIEWABILITY_10_PERCENT_OR_MORE",
            "VIEWABILITY_20_PERCENT_OR_MORE",
            "VIEWABILITY_30_PERCENT_OR_MORE",
            "VIEWABILITY_40_PERCENT_OR_MORE",
            "VIEWABILITY_50_PERCENT_OR_MORE",
            "VIEWABILITY_60_PERCENT_OR_MORE",
            "VIEWABILITY_70_PERCENT_OR_MORE",
            "VIEWABILITY_80_PERCENT_OR_MORE",
            "VIEWABILITY_90_PERCENT_OR_MORE",
          },
          enumDescriptions = {
            "Default value when viewability is not specified in this version. This enum is a placeholder for default value and does not represent a real viewability option.",
            "Bid only on impressions that are at least 10% likely to be viewable.",
            "Bid only on impressions that are at least 20% likely to be viewable.",
            "Bid only on impressions that are at least 30% likely to be viewable.",
            "Bid only on impressions that are at least 40% likely to be viewable.",
            "Bid only on impressions that are at least 50% likely to be viewable.",
            "Bid only on impressions that are at least 60% likely to be viewable.",
            "Bid only on impressions that are at least 70% likely to be viewable.",
            "Bid only on impressions that are at least 80% likely to be viewable.",
            "Bid only on impressions that are at least 90% likely to be viewable.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
  },
  servicePath = "",
  title = "Display & Video 360 API",
  version = "v1",
  version_module = true,
}
